% File src/library/base/man/RdUtils.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{RdUtils}
\alias{Rdconv}
\alias{Rd2pdf}
\alias{RD2PDF_INPUTENC}

\title{Utilities for Processing Rd Files}
\description{
  R のドキュメント用(Rd)書式のファイルを
  他の書式に変換したり，それらから索引を作ったり，他の書式のドキュメントを
  Rd 書式に変換するユーティリティ．
}
\usage{
\special{R CMD Rdconv [options] file}
\special{R CMD Rd2pdf [options] files}
}
\arguments{
  \item{file}{処理されるファイルへのパス．}
  \item{files}{使用する R ドキュメントのソースを指定する
    ファイル名のリスト，又はパッケージのソースがあるディレクトリ
    へのパス．}
  \item{options}{処理を制御，又は
    ユーティリティの用法とバージョンに関する情報を得るための
    追加のオプション．}
}
\details{
  \command{R CMD Rdconv} は Rd 書式を平文，HTML 又は LaTeX 書式に変換する：
  例を取り出すことも出来る．

  \command{R CMD Rd2pdf} は Rd ソースから PDF 出力を得るための
  ユーザレベルのプログラム．これは環境変数
#ifdef unix
  \env{R_PAPERSIZE} (\command{R CMD} で設定され，既定値は \R の
  インストール時に設定される：\env{R_PAPERSIZE} に対する値は \code{a4},
  \code{letter}, \code{legal} そして \code{executive})
#endif
#ifdef windows
  \env{R_PAPERSIZE} (既定は \code{a4}, または \code{legal} と
  \code{executive})
#endif
  そして \env{R_PDFVIEWER} (PDF ビューアー)を使う．
  また \env{RD2PDF_INPUTENC} は \code{inputenc} の代わりに使う
  \code{inputenx} という名前のパッケージの設定に使える．
  これは UTF-8 エンコーディングをより良く利用するために必要かもしれない．

  ユーティリティ \code{\var{foo}} の用法情報を得るためには
  \command{R CMD \var{foo} --help} を使う．  
}
\seealso{
  マニュアル \dQuote{Writing \R Extensions} 中の章 \dQuote{Processing Rd format}．
}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/RdUtils.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{RdUtils}
%\alias{Rdconv}
%\alias{Rd2pdf}
%\alias{RD2PDF_INPUTENC}
%
%\title{Utilities for Processing Rd Files}
%\description{
%  Utilities for converting files in R documentation (Rd) format to other
%  formats or create indices from them, and for converting documentation
%  in other formats to Rd format.
%}
%\usage{
%\special{R CMD Rdconv [options] file}
%\special{R CMD Rd2pdf [options] files}
%}
%\arguments{
%  \item{file}{the path to a file to be processed.}
%  \item{files}{a list of file names specifying the R documentation
%    sources to use, by either giving the paths to the files, or the path
%    to a directory with the sources of a package.}
%  \item{options}{further options to control the processing, or for
%    obtaining information about usage and version of the utility.}
%}
%\details{
%  \command{R CMD Rdconv} converts Rd format to plain text, HTML or LaTeX
%  formats: it can also extract the examples.
%
%  \command{R CMD Rd2pdf} is the user-level program for producing PDF output
%  from Rd sources.  It will make use of the environment variables
%#ifdef unix
%  \env{R_PAPERSIZE} (set by \command{R CMD}, with a default set when \R
%  was installed: values for \env{R_PAPERSIZE} are \code{a4},
%  \code{letter}, \code{legal} and \code{executive})
%#endif
%#ifdef windows
%  \env{R_PAPERSIZE} (default \code{a4}, also \code{legal} and
%  \code{executive})
%#endif
%  and \env{R_PDFVIEWER} (the PDF previewer).  Also,
%  \env{RD2PDF_INPUTENC} can be set to \code{inputenx} to make use of the
%  LaTeX package of that name rather than \code{inputenc}: this might be
%  needed for better support of the UTF-8 encoding.
%
%  Use \command{R CMD \var{foo} --help} to obtain usage information on utility
%  \code{\var{foo}}.
%}
%\seealso{
%  The chapter \dQuote{Processing Rd format} in the \dQuote{Writing \R
%    Extensions} manual.
%}
%\keyword{utilities}
%
\encoding{UTF8}
