% File src/library/base/man/UseMethod.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{UseMethod}
\title{Class Methods}
\alias{UseMethod}
\alias{NextMethod}
\alias{S3Methods}
\alias{.Method}
\alias{.Generic}
\alias{.Class}
\description{
  \R はオブジェクト志向風のプログラミングが可能になる
単純な総称的関数の機構を持つ．メソッドの選択適用は総称的関数の
第一引数のクラスや， \code{UseMethod} または \code{NextMethod} の
引数として与えられたオブジェクトに基づいて行われる．
}
\usage{
UseMethod(generic, object)

NextMethod(generic = NULL, object = NULL, \dots)
}
\arguments{
  \item{generic}{(組み込み演算子ではない)関数の名前である文字列.
 \code{UseMethod} に対して必要になる．}
  \item{object}{\code{UseMethod} 用：そのクラスが選択適用されるメソッドを
決定する決めるオブジェクト．既定値は囲み関数の第一引数．}
  \item{\dots}{次のメソッドに引き渡される追加引数．}
}
\details{
  \R のオブジェクトは \code{class} 属性を持つデータオブジェクト
である(そしてこれは \code{\link{is.object}} でチェックできる)．
クラス属性は文字列ベクトルで，オブジェクトがそこから\emph{継承}する
クラスの名前を与える．
もしオブジェクトがクラス属性を持たなければそれは暗黙のクラスを持つ．
行列と配列はクラス \code{"matrix"} または \code{"array"} を
持ち，これは根底にあるベクトルのクラスを引き継ぐ．
殆どのベクトルは \code{\link{mode}(x)} の結果であるクラスを
持つが，整数ベクトルは クラス \code{c("integer", "numeric")} を，
そして実ベクトルはクラス \code{c("double", "numeric")} を持つ．

 \code{UseMethod("fun")} を呼び出す関数がクラス属性
 \code{c("first", "second")} を持つオブジェクトに適用されると，
システムは \code{fun.first} と呼ばれる関数を探し，そしてもしそれが
見つかるとそれをオブジェクトに適用する．もしそうした関数が見つからなければ，
 \code{fun.second} という関数が試される．もしクラス名が
適当な関数に該当しないと，もしそれが存在すれば
関数 \code{fun.default} が使われるか，エラーになる．

 関数 \code{\link{methods}} は特定の総称的関数またはクラス
 に対するメソッドを見つけるのに使うことが出来る．

  \code{UseMethod} はプリミティブな関数であるが標準的な引数照合を
使用する．これはメソッドの選択適用の唯一の手段ではない．
なぜなら内部総称的そしてグループ総称的関数があるから．
 \code{UseMethod} は現在の所オブジェクトでない引数に
対しても暗黙のクラスに選択適用されるが，他の選択適用手段は
そうではない．

  \code{NextMethod} はネクストメソッドを起動する
(総称的関数に与えられたオブジェクトか，もしメソッドが直接起動されるのならば
 \code{NextMethod} を含む関数への第一引数のクラスベクトルによって決定される)．
通常 \code{NextMethod} はただひとつの引数とともに使われるが，
もし追加の引数が与えられればそれらはネクストメソッドへの呼び出しを
変更する．

  \code{NextMethod} は \code{UseMethod} から呼び出されたメソッド内部からか，
内部総称的関数からかを除いて呼びだされるべきではない
(\link{InternalGenerics} を見よ)．特にそれは匿名の呼び出し関数内部では
動作しない(例えば \code{get("print.ts")(AirPassengers)})．

名前空間は総称的関数に対するメソッドを登録できる．これをサポートするために，
 \code{UseMethod} と \code{NextMethod} はメソッドを二つの場所で探す：
最初は総称的関数が呼び出された環境中で，それから
総称的関数が定義された環境に対する登録データベース(典型的に名前空間)
中である．従って総称的関数に対するメソッドは総称的関数への呼び出し環境中で
利用可能である必要がある．さもなければ登録されなければならない．
(総称的関数が定義された環境中で可視的であるかどうかはどうでも良い．)
}
\section{技術的詳細}{
  どこかで触れる必要がある幾つかの曖昧な詳細を述べる．
これらのコメントは  Chambers(1992) のそれらと多少異なるであろう．
(ドラフト \sQuote{R Language Definition} を見よ．)
  \code{UseMethod} は総称的関数のマッチした引数を持つ新しい関数呼び出しを作る．
\code{UseMethod} の呼び出し以前に定義された任意の局所変数は保存される(S とは異なり)．
\code{UseMethod} の呼び出し後の実行文は  \code{UseMethod} が帰らないので評価されない．
\code{UseMethod} は二つ以上の引数とともに呼び出すことが出来るが，警告が出て
追加引数は無視される．(S ではそれらは完全には無視されない．)
もしそれが丁度一つの引数とともに呼び出されると，囲み関数の最初の引数のクラスが
 \code{object} として使われる．S とは異なり，これは引き渡される最初の実際の
引数であり，その名前のオブジェクトの現在の値ではない．

  \code{NextMethod} は次のメソッドに対する特別な呼び出しフレーム
を作ることで動作する．もし新しい引数が提供されないと，引数は現在のメソッドと
数，順序そして名前が同じになるが，それらの値は現在のメソッドと環境中で
名前を評価することが予約される．
\code{\dots} にマッチする任意の名前付き引数は特別に処理される．
それらは同名の既存の引数を置き換えるか，引数リストに追加される．
それらは現在の環境への引数として提供されたという予約として
引き渡される．(S はこれを違った風に行う!)  もしそれらが現在(もしくは以前の
環境で)評価されていたならば評価されたままでとどまる．
(これは複雑な話で変更されるかもしれない：ドラフト
 \sQuote{R Language Definition} を見よ．)

\code{NextMethod} に対するメソッドの探索は \code{UseMethod} と少し異なる．
\code{fun.default} が見つからなくても必ずしもエラーにならず，
探索は総称的関数自体に続く．これは別個の既定メソッドを持たない \code{[} の
ような内部総称的関数を取り扱うためで，もし総称的関数がプリミティブ関数か
同名の \code{\link{.Internal}} 関数に対するラッパの時だけ成功する．
(プリミティブ関数が既定メソッドとして呼び出されると，引数のマッチングは
プリミティブ関数の異なった意味から上で述べたようには動作しない．)

メッソド中には \code{.Generic}, \code{.Method} そして 
 \code{.Class} のようなオブジェクトが使われる．これらは以下のような選択適用の機構により
メソッドがその中で評価される環境の中で設定される：
  \enumerate{
    \item 呼び出し関数(総称的)に対する文脈を見つける：これは
オリジナルの呼び出しに対する未評価の引数を与える．
    \item 選択適用に対して使われるオブジェクト(普通引数)を評価し，
メソッド(もしかすると既定メソッド)を見つけるかエラーにする．
    \item メソッドを評価するための環境を作り，その環境中に特殊な変数(以下を参照)
を挿入する．また形式的(また実引数)でない総称的関数の環境中の凡ての変数をコピーする．
    \item 引数リストをメソッドの形式的引数にマッチする呼び出しの引数と決める．
  }
  \code{.Generic} は総称的関数の名前である長さ1の文字列ベクトル．

  \code{.Method} はメソッド関数の名前である文字列ベクトル(普通長さ1)．
(グループ総称 \code{\link[=S3groupGeneric]{Ops}} 内の関数に対しては長さ2．)

  \code{.Class} は次のメソッドを見つけるのに使われるクラスの文字列ベクトル．
  \code{NextMethod} は \code{.Class} に選択適用で最後に使われた \code{.Class} を
与える属性 \code{"previous"} を加える．そして \code{.Class} を選択適用に対して
使われたものに沿ってシフトする．

  \code{.GenericCallEnv} と \code{.GenericDefEnv} はそれぞれ総称的とされた呼び出し
と総称的関数を定義する環境である．
(後者は総称的関数に対して登録されたメソッドを見つけるために使われる．)

\code{.Class} は総称的関数が呼び出された時設定されることを注意する．
そしてもしメソッド中で選択適用された変数のクラスが変更されてもそのままである．
 \code{.Class} を操作して \code{NextMethod} が選択適用するメソッドを
 変更することは可能であるが， \sQuote{これは継承の機構を完全に理解していない限り勧められない}
(Chambers & Hastie, 1992, p.\sspace{}469).
}
\note{
  この機構は \emph{S3} (S version 3) と呼ばれている．
新しいプロジェクトに対しては，\pkg{methods} パッケージで提供される
より柔軟で頑健な \emph{S4} 機構を使うことが推奨される．
}
\seealso{
  ドラフト \sQuote{R Language Definition}.

  \code{\link{methods}}, \code{\link{class}},
  \code{\link{getS3method}}, \code{\link{is.object}}.
}
\references{
  Chambers, J. M. (1992)
  \emph{Classes and methods: object-oriented programming in S.}
  Appendix A of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\keyword{methods}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/UseMethod.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{UseMethod}
%\title{Class Methods}
%\alias{UseMethod}
%\alias{NextMethod}
%\alias{S3Methods}
%\alias{.Method}
%\alias{.Generic}
%\alias{.Class}
%\description{
%  \R possesses a simple generic function mechanism which can be used for
%  an object-oriented style of programming.  Method dispatch takes place
%  based on the class(es) of the first argument to the generic function or of
%  the object supplied as an argument to \code{UseMethod} or \code{NextMethod}.
%}
%\usage{
%UseMethod(generic, object)
%
%NextMethod(generic = NULL, object = NULL, \dots)
%}
%\arguments{
%  \item{generic}{a character string naming a function (and not a
%    built-in operator).  Required for \code{UseMethod}.}
%  \item{object}{for \code{UseMethod}: an object whose class will
%    determine the method to be dispatched.  Defaults to the first
%    argument of the enclosing function.}
%  \item{\dots}{further arguments to be passed to the next method.}
%}
%\details{
%  An \R object is a data object which has a \code{class}
%  attribute (and this can be tested by \code{\link{is.object}}).
%  A class attribute is a character vector giving the names of
%  the classes from which the object \emph{inherits}.
%  If the object does not have a class attribute, it has an implicit
%  class.  Matrices and arrays have class \code{"matrix"}
%  or\code{"array"} followed by the class of the underlying vector.
%  Most vectors have class the result of \code{\link{mode}(x)}, except
%  that integer vectors have class \code{c("integer", "numeric")} and
%  real vectors have class \code{c("double", "numeric")}.
%
%  When a function calling \code{UseMethod("fun")} is applied to an
%  object with class attribute \code{c("first", "second")}, the system
%  searches for a function called \code{fun.first} and, if it finds it,
%  applies it to the object.  If no such function is found a function
%  called \code{fun.second} is tried.  If no class name produces a
%  suitable function, the function \code{fun.default} is used, if it
%  exists, or an error results.
%
%  Function \code{\link{methods}} can be used to find out about the
%  methods for a particular generic function or class.
%
%  \code{UseMethod} is a primitive function but uses standard argument
%  matching.  It is not the only means of dispatch of methods, for there
%  are \link{internal generic} and \link{group generic} functions.
%  \code{UseMethod} currently dispatches on the implicit class even for
%  arguments that are not objects, but the other means of dispatch do
%  not.
%
%  \code{NextMethod} invokes the next method (determined by the
%  class vector, either of the object supplied to the generic, or of
%  the first argument to the function containing \code{NextMethod} if a
%  method was invoked directly).  Normally \code{NextMethod} is used with
%  only one argument, \code{generic}, but if further arguments are
%  supplied these modify the call to the next method.
%
%  \code{NextMethod} should not be called except in methods called by
%  \code{UseMethod} or from internal generics (see
%  \link{InternalGenerics}).  In particular it will not work inside
%  anonymous calling functions (e.g., \code{get("print.ts")(AirPassengers)}).
%
%  Namespaces can register methods for generic functions.  To support
%  this, \code{UseMethod} and \code{NextMethod} search for methods in
%  two places: first in the environment in which the generic function
%  is called, and then in the registration data base for the
%  environment in which the generic is defined (typically a namespace).
%  So methods for a generic function need to be available in the
%  environment of the call to the generic, or they must be registered.
%  (It does not matter whether they are visible in the environment in
%  which the generic is defined.)
%}
%\section{Technical Details}{
%  Now for some obscure details that need to appear somewhere.  These
%  comments will be slightly different than those in Chambers(1992).
%  (See also the draft \sQuote{R Language Definition}.)
%  \code{UseMethod} creates a new function call with
%  arguments matched as they came in to the generic.  Any local variables
%  defined before the call to \code{UseMethod} are retained (unlike S).  Any
%  statements after the call to \code{UseMethod} will not be evaluated as
%  \code{UseMethod} does not return.  \code{UseMethod} can be called with
%  more than two arguments: a warning will be given and additional
%  arguments ignored.  (They are not completely ignored in S.)  If it is
%  called with just one argument, the class of the first argument of the
%  enclosing function is used as \code{object}: unlike S this is the first
%  actual argument passed and not the current value of the object of that
%  name.
%
%  \code{NextMethod} works by creating a special call frame for the next
%  method.  If no new arguments are supplied, the arguments will be the
%  same in number, order and name as those to the current method but
%  their values will be promises to evaluate their name in the current
%  method and environment.  Any named arguments matched to \code{\dots}
%  are handled specially: they either replace existing arguments of the
%  same name or are appended to the argument list.  They are passed on as
%  the promise that was supplied as an argument to the current
%  environment.  (S does this differently!)  If they have been evaluated
%  in the current (or a previous environment) they remain evaluated.
%  (This is a complex area, and subject to change: see the draft
%  \sQuote{R Language Definition}.)
%
%  The search for methods for \code{NextMethod} is slightly different
%  from that for \code{UseMethod}.   Finding no \code{fun.default} is not
%  necessarily an error, as the search continues to the generic
%  itself.  This is to pick up an \link{internal generic} like \code{[}
%  which has no separate default method, and succeeds only if the generic
%  is a \link{primitive} function or a wrapper for a
%  \code{\link{.Internal}} function of the same name.  (When a primitive
%  is called as the default method, argument matching may not work as
%  described above due to the different semantics of primitives.)
%
%  You will see objects such as \code{.Generic}, \code{.Method}, and
%  \code{.Class} used in methods.  These are set in the environment
%  within which the method is evaluated by the dispatch mechanism, which
%  is as follows:
%  \enumerate{
%    \item Find the context for the calling function (the generic): this
%    gives us the unevaluated arguments for the original call.
%    \item Evaluate the object (usually an argument) to be used for
%    dispatch, and find a method (possibly the default method) or throw
%    an error.
%    \item Create an environment for evaluating the method and insert
%    special variables (see below) into that environment.  Also copy any
%    variables in the environment of the generic that are not formal (or
%    actual) arguments.
%    \item Fix up the argument list to be the arguments of the call
%    matched to the formals of the method.
%  }
%  \code{.Generic} is a length-one character vector naming the generic function.
%
%  \code{.Method} is a character vector (normally of length one) naming
%  the method function.  (For functions in the group generic
%  \code{\link[=S3groupGeneric]{Ops}} it is of length two.)
%
%  \code{.Class} is a character vector of classes used to find the next
%  method.  \code{NextMethod} adds an attribute \code{"previous"} to
%  \code{.Class} giving the \code{.Class} last used for dispatch, and
%  shifts \code{.Class} along to that used for dispatch.
%
%  \code{.GenericCallEnv} and \code{.GenericDefEnv} are the environments
%  of the call to be generic and defining the generic respectively.  (The
%  latter is used to find methods registered for the generic.)
%
%  Note that \code{.Class} is set when the generic is called, and is
%  unchanged if the class of the dispatching argument is changed in a
%  method.  It is possible to change the method that \code{NextMethod}
%  would dispatch by manipulating \code{.Class}, but \sQuote{this is not
%    recommended unless you understand the inheritance mechanism
%    thoroughly} (Chambers & Hastie, 1992, p.\sspace{}469).
%}
%\note{
%  This scheme is called \emph{S3} (S version 3).  For new projects,
%  it is recommended to use the more flexible and robust \emph{S4} scheme
%  provided in the \pkg{methods} package.
%}
%\seealso{
%  The draft \sQuote{R Language Definition}.
%
%  \code{\link{methods}}, \code{\link{class}},
%  \code{\link{getS3method}}, \code{\link{is.object}}.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Classes and methods: object-oriented programming in S.}
%  Appendix A of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\keyword{methods}
%
\encoding{UTF8}
