% File src/library/base/man/browser.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{browser}
\alias{browser}
\title{Environment Browser}
\description{
  表現式の実行を中断し
  \code{browser} が呼びだされた環境の吟味を許す．
}
\usage{
browser(text = "", condition = NULL, expr = TRUE, skipCalls = 0L)
}
\arguments{
  \item{text}{一旦ブラウザが起動されると探されるテキスト文字列．}
  \item{condition}{一旦ブラウザが起動されると探される条件．}
  \item{expr}{表現式．もしそれが \code{TRUE} と評価されるとデバッガが起動される．
    様の彼場制御は直接元に戻される．}
  \item{skipCalls}{呼び出し文脈を報告する際幾つ前の呼び出しをスキップするか．}
}
\details{
  \code{browser} の呼び出しは関数の本体中に入れられる．
  そこに至るとこれは現在の表現式の実行の休止を引き起こし \R のインタプリタへの
  アクセスを可能にする．

  引数 \code{text} と \code{condition} の目的は，ここで
  補助プログラム(例えば外部デバッガ)が指定した値を挿入することを
  許すことであり，そうするとブラウザへの特定の呼び出し(恐らくソースファイル中のその位置)
  が識別可能になり特別な処理が実行できるようになる．
  値は \code{\link{browserText}} と \code{\link{browserCondition}} の
  呼び出しで探すことが出来る．

  引数 \code{expr} の目的は条件付きデバッグのような見せかけを可能にすることである．
  これは見せかけである．なぜなら，実行は常にブラウザの呼び出しで休止されるが
  制御は \code{expr} の評価が \code{TRUE} になった時だけ下で述べる評価器に
  渡されるからである．殆どのケースでは呼び出しプログラム中で \code{if} 文を
  使うほうがより効率的になるであろうが，幾つかのケースではこの引数のほうが
  より簡単になる．

  引数 \code{skipCalls} は呼び出し \code{browser()} が別のデバッグ用関数と
  入れ子になっているときに使うべきである：これはその位置を報告するため
  呼び出しスタックを更に調べる．

  ブラウザのプロンプトに対しユーザは改行に続き命令や \R 表現式を入力できる．
  そうした命令としては

  \describe{
    \item{\code{c}}{ブラウザを抜け，次の文の実行を続ける．}
    \item{\code{cont}}{\code{c} の同義語．}
    \item{\code{f}}{現在のループや関数の実行を終了} 
    \item{\code{help}}{この命令リストをプリント}
    \item{\code{n}}{関数呼び出しを跨ぎ次の文を評価，
      \code{browser} 呼び出しで中断されたバイトコンパイルされた関数に対しては，
      \code{n} は \code{c} に等しい．}
    \item{\code{s}}{関数呼び出しに踏み込み次の文を評価する．
      再び，バイトコンパイルされた関数に対しては \code{s} は \code{c} に等しい．}
    \item{\code{where}}{すべてのアクティブな関数呼び出しのスタックのトレースを
      プリントする．}
    \item{\code{Q}}{ブラウザと現在の評価を抜けトップレベルのプロンプトに復帰する．}
  }
  空白行を除き，先頭と末尾の空白は無視される．
  空白行の処理は \code{"browserNLdisabled"} \link[=options]{オプション} に
  依存する；もしこれが \code{TRUE} なら空白行は無視される．
  さもなければ空白行は \code{n} (もしそれが直近に使われたならば \code{s})
  と同じになる．

  ブラウザのプロンプトに入力された他の全ては呼び出し環境中で評価される
  \R 表現式と解釈される：特にオブジェクトをタイプすればプリントされ，
  そして \code{ls()} は呼び出しフレーム中のオブジェクトをリストする．
  (もし \code{n} のような名前を持つオブジェクトを眺めたければそれを
  明示的にプリントする．)

  逆構文解析された呼び出しに対するプリントされる行数は設定
  \code{\link{options}(deparse.max.lines)} により制限できる．
  
  ブラウザのプロンプトは \code{Browse[\var{n}]>} のような形式になる：ここで
  \code{\var{n}} は \sQuote{ブラウザのレベル} を示す．ブラウザはブラウジング中に
  呼び出すことができ(そしてしばしば \code{\link{debug}} の使用中に)，
  そして各再帰的な呼び出しは番号を増加させる．
  (実際の番号は文脈スタック上の \sQuote{文脈} の数である：これは
  普通ブラウジングの外部レベルでは \code{2} で，\code{\link{debugger}} 中の
  ダンプを吟味中は \code{1} である．)
  
  これはプリミティブな関数であるが，標準的な方法で引数のマッチングを行う．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chambers, J. M. (1998)
  \emph{Programming with Data. A Guide to the S Language}.
  Springer.
}
\seealso{
  \code{\link{debug}}，そして
 エラー時のスタックに対しては \code{\link{traceback}}，
テキストと条件を調べるには  \code{\link{browserText}}．
}
\keyword{programming}
\keyword{environment}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/browser.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{browser}
%\alias{browser}
%\title{Environment Browser}
%\description{
%  Interrupt the execution of an expression and allow the inspection of
%  the environment where \code{browser} was called from.
%}
%\usage{
%browser(text = "", condition = NULL, expr = TRUE, skipCalls = 0L)
%}
%\arguments{
%  \item{text}{a text string that can be retrieved once the browser is invoked.}
%  \item{condition}{a condition that can be retrieved once the browser is
%    invoked.}
%  \item{expr}{An expression, which if it evaluates to \code{TRUE} the
%    debugger will invoked, otherwise control is returned directly.}
%  \item{skipCalls}{how many previous calls to skip when reporting the
%    calling context.}
%}
%\details{
%  A call to \code{browser} can be included in the body of a function.
%  When reached, this causes a pause in the execution of the
%  current expression and allows access to the \R interpreter.
%
%  The purpose of the \code{text} and \code{condition} arguments are to
%  allow helper programs (e.g., external debuggers) to insert specific
%  values here, so that the specific call to browser (perhaps its location
%  in a source file) can be identified and special processing can be
%  achieved.  The values can be retrieved by calling \code{\link{browserText}}
%  and \code{\link{browserCondition}}.
%
%  The purpose of the \code{expr} argument is to allow for the illusion
%  of conditional debugging. It is an illusion, because execution is
%  always paused at the call to browser, but control is only passed
%  to the evaluator described below if \code{expr} evaluates to \code{TRUE}.
%  In most cases it is going to be more efficient to use an \code{if}
%  statement in the calling program, but in some cases using this argument
%  will be simpler.
%
%  The \code{skipCalls} argument should be used when the \code{browser()}
%  call is nested within another debugging function:  it will look further
%  up the call stack to report its location.
%
%  At the browser prompt the user can enter commands or \R expressions,
%  followed by a newline.  The commands are
%
%  \describe{
%    \item{\code{c}}{exit the browser
%    and continue execution at the next statement.}
%    \item{\code{cont}}{synonym for \code{c}.}
%    \item{\code{f}}{finish execution of the current loop or function} 
%    \item{\code{help}}{print this list of commands}
%    \item{\code{n}}{evaluate the next statement, stepping over 
%      function calls.  For byte compiled functions interrupted by
%      \code{browser} calls, \code{n} is equivalent to \code{c}.}
%    \item{\code{s}}{evaluate the next statement, stepping into
%      function calls.  Again, byte compiled functions make
%      \code{s} equivalent to \code{c}.}
%    \item{\code{where}}{print a stack trace of all active function calls.}
%    \item{\code{Q}}{exit the browser and the current evaluation and
%      return to the top-level prompt.}
%  }
%  Leading and trailing whitespace is ignored, except for an empty line.
%  Handling of empty lines depends on the \code{"browserNLdisabled"} 
%  \link[=options]{option}; if it is \code{TRUE}, empty lines are ignored.  
%  If not, an empty line is the same as \code{n} (or \code{s}, if it was used 
%  most recently).
%
%  Anything else entered at the browser prompt is interpreted as an
%  \R expression to be evaluated in the calling environment: in
%  particular typing an object name will cause the object to be printed,
%  and \code{ls()} lists the objects in the calling frame.  (If you want
%  to look at an object with a name such as \code{n}, print it
%  explicitly.)
%
%  The number of lines printed for the deparsed call can be limited by
%  setting \code{\link{options}(deparse.max.lines)}.
%  
%  The browser prompt is of the form \code{Browse[\var{n}]>}: here
%  \code{var{n}} indicates the \sQuote{browser level}.  The browser can
%  be called when browsing (and often is when \code{\link{debug}} is in
%  use), and each recursive call increases the number.  (The actual
%  number is the number of \sQuote{contexts} on the context stack: this
%  is usually \code{2} for the outer level of browsing and \code{1} when
%  examining dumps in \code{\link{debugger}}.)
%  
%  This is a primitive function but does argument matching in the
%  standard way.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chambers, J. M. (1998)
%  \emph{Programming with Data. A Guide to the S Language}.
%  Springer.
%}
%\seealso{
%  \code{\link{debug}}, and
%  \code{\link{traceback}} for the stack on error.
%  \code{\link{browserText}} for how to retrieve the text and condition.
%}
%\keyword{programming}
%\keyword{environment}
%
\encoding{UTF8}
