% File src/library/base/man/class.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{class}
\title{Object Classes}
\alias{class}
\alias{class<-}
\alias{oldClass}
\alias{oldClass<-}
\alias{unclass}
\alias{inherits}
\description{
  \R はオブジェクト指向スタイルのプログラミングに使える単純な
  総称的関数の機構を持つ．メソッドの選択適用は総称的関数の第一引数の
  クラスに基づいて行われる．
}
\usage{
class(x)
class(x) <- value
unclass(x)
inherits(x, what, which = FALSE)

oldClass(x)
oldClass(x) <- value
}
\arguments{
  \item{x}{\R オブジェクト}
  \item{what, value}{クラスの名前である文字列ベクトル．\code{value}
    はまた \code{NULL} であっても良い．}
  \item{which}{返り値に影響する論理値：\sQuote{詳細}を見よ．}
}

\details{
  ここではいわゆる \dQuote{S3} クラス(とメソッド)を解説する．
  \dQuote{S4} クラス(とメソッド)については下の \sQuote{形式的クラス} を見よ．

  多くの \R オブジェクトは \code{class} 属性を持つ．これはオブジェクトがそこから
  継承するクラスの名前を与える文字列である．
  もしオブジェクトがクラス属性を持たなければ，それは
  暗黙のクラス \code{"matrix"}, \code{"array"} もしくは
  \code{\link{mode}(x)} の結果を持つ(例外として整数ベクトルは暗黙のクラス
  \code{"integer"} を持つ)．(関数 \code{oldClass} と
  \code{oldClass<-} は属性を得たり設定するが，直接行うことも出来る．)

  総称的関数 \code{fun} がクラス属性 \code{c("first", "second")} を
  持つオブジェクトに適用されるとき，システムは
  \code{fun.first} という関数を探し，もしそれが見つかればそれを関数に
  適用する．もしそうした関数がなければ \code{fun.second} という関数が
  試みられる．もしどのクラス名も適当な関数に該当しなければ
  関数 \code{fun.default} が使われる(もし存在すれば)．もし
  クラス属性がなければ暗黙のクラス，それから既定メソッドがが試みられる．

  関数 \code{class} はオブジェクトがそれから継承するクラスの名前を
  プリントする．対応して \code{class<-} はオブジェクトがそれから継承するクラスを
  設定する．\code{NULL} を付値すればクラス属性は取り除かれる．

  \code{unclass} はクラス属性を取り除いたその引数(のコピー)を返す．
  (これはコピーできないオブジェクトに対しては許されない，つまり
  環境と外部ポインターである．)

  \code{inherits} はその第一引数が \code{what} 引数中で指示された
  クラスのどれかを継承しているかどうかを示す．
  もし \code{which} が \code{TRUE} ならば \code{what} と同じ長さの
  整数ベクトルが返される．各要素は \code{what} の要素とマッチングされた
  \code{class(x)} 中の位置を示す；ゼロはマッチしないことを意味する．
  もし \code{which} が \code{FALSE} なら，\code{what} 中の名前のどれかが
  が  \code{class} にマッチすれば \code{TRUE} が \code{inherits} により
  返される．

  \code{inherits} を除くすべてはプリミティブな関数である．
}

\note{
  関数 \code{oldClass} と \code{oldClass<-} は S-PLUS 5/6 の同名の
  関数と同じように動作するが，しかし \R では \code{\link{UseMethod}} は
  \code{oldClass} ではなく \code{class}  (幾つかの保管されたクラスと共に；
  リンクを見よ)が返すクラスについて選択適用を行う．
  しかしながらグループ総称的関数は効率性のため \code{oldClass} に
  基づき，内部総称的関数は \code{\link{is.object}} が真であるようなオブジェクトに
  対して選択適用を行う．

  \R のある種のバージョンでは，クラスを持つ長さゼロのベクトルを付値すると
  クラスが取り除かれ，その他ではエラーになる(しかしながら 
  \code{oldClass} に対しては動作する). クラスを取り除くには \code{NULL}
  を付値するのがより明快である．
}

\section{形式的クラス}{
  \dQuote{S4} というニックネームを持つ追加の形式的クラス機構が
  既定で付属するパッケージ \pkg{methods} から利用可能である．
  形式的クラスを持つオブジェクトに対しては，その名前は \code{class} によって
  長さ1の文字列として返され，メソッドの選択適用は最初の引数だけでなく
  複数の引数について行われ得る．しかしながら S3 メソッド 選択は S4 クラス
  からのオブジェクトをそれらが S3 クラス属性を持つかのように扱おうとする．
  \code{inherits} も同様である．従って S3 メソッドは S4 クラスに対しても
  定義できる．詳細は \sQuote{\link{Classes}} と \sQuote{\link{Methods}} の
  ヘルプ頁を見よ．

  置き換え版の関数はクラスを与えられた値に設定する．
  形式的定義を持つクラスに対してはクラスをこのようにして直接置き換えることは
  強く不推奨される．表現式 \code{\link{as}(object, value)} がオブジェクトを特定の
  クラスに強制変換する方法である．

  形式的クラスに対する \code{inherits} の類似物は \code{\link{is}} である．
  二つの関数は一つの例外を除き矛盾なく動作する．
  S4 クラスは正確なテストを持つ条件付き継承を持つことが出来る．この場合
  \code{is} は条件をテストするが，\code{inherits} はすべての
  条件付き上位クラスを無視する．
}

\seealso{
  \code{\link{UseMethod}}, \code{\link{NextMethod}},
  \sQuote{\link{group generic}}, \sQuote{\link{internal generic}}
}
\examples{
x <- 10
class(x) # "numeric"
oldClass(x) # NULL
inherits(x, "a") #FALSE
class(x) <- c("a", "b")
inherits(x,"a") #TRUE
inherits(x, "a", TRUE) # 1
inherits(x, c("a", "b", "c"), TRUE) # 1 2 0
}
\keyword{methods}
\keyword{classes}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/class.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{class}
%\title{Object Classes}
%\alias{class}
%\alias{class<-}
%\alias{oldClass}
%\alias{oldClass<-}
%\alias{unclass}
%\alias{inherits}
%\description{
%  \R possesses a simple generic function mechanism which can be used for
%  an object-oriented style of programming.  Method dispatch takes place
%  based on the class of the first argument to the generic function.
%}
%\usage{
%class(x)
%class(x) <- value
%unclass(x)
%inherits(x, what, which = FALSE)
%
%oldClass(x)
%oldClass(x) <- value
%}
%\arguments{
%  \item{x}{a \R object}
%  \item{what, value}{a character vector naming classes.  \code{value}
%    can also be \code{NULL}.}
%  \item{which}{logical affecting return value: see \sQuote{Details}.}
%}
%
%\details{
%  Here, we describe the so called \dQuote{S3} classes (and methods). For
%  \dQuote{S4} classes (and methods), see \sQuote{Formal classes} below.
%
%  Many \R objects have a \code{class} attribute, a character vector
%  giving the names of the classes from which the object \emph{inherits}.
%  If the object does not have a class attribute, it has an implicit
%  class, \code{"matrix"}, \code{"array"} or the result of
%  \code{\link{mode}(x)} (except that integer vectors have implicit class
%  \code{"integer"}).  (Functions \code{oldClass} and
%  \code{oldClass<-} get and set the attribute, which can also be done
%  directly.)
%
%  When a generic function \code{fun} is applied to an object with class
%  attribute \code{c("first", "second")}, the system searches for a
%  function called \code{fun.first} and, if it finds it, applies it to
%  the object.  If no such function is found, a function called
%  \code{fun.second} is tried.  If no class name produces a suitable
%  function, the function \code{fun.default} is used (if it exists).  If
%  there is no class attribute, the implicit class is tried, then the
%  default method.
%
%  The function \code{class} prints the vector of names of classes an
%  object inherits from.  Correspondingly, \code{class<-} sets the
%  classes an object inherits from.  Assigning \code{NULL} removes the
%  class attribute.
%
%  \code{unclass} returns (a copy of) its argument with its class
%  attribute removed.  (It is not allowed for objects which cannot be
%  copied, namely environments and external pointers.)
%
%  \code{inherits} indicates whether its first argument inherits from any
%  of the classes specified in the \code{what} argument.  If \code{which}
%  is \code{TRUE} then an integer vector of the same length as
%  \code{what} is returned.  Each element indicates the position in the
%  \code{class(x)} matched by the element of \code{what}; zero indicates
%  no match. If \code{which} is \code{FALSE} then \code{TRUE} is
%  returned by \code{inherits} if any of the names in \code{what} match
%  with any \code{class}.
%
%  All but \code{inherits} are \link{primitive} functions.
%}
%
%\note{
%  Functions \code{oldClass} and \code{oldClass<-} behave in the same way
%  as functions of those names in S-PLUS 5/6, \emph{but} in \R
%  \code{\link{UseMethod}} dispatches on the class as returned by
%  \code{class} (with some interpolated classes: see the link) rather
%  than \code{oldClass}.  \emph{However}, \link{group generic}s dispatch
%  on the \code{oldClass} for efficiency, and \link{internal generic}s
%  only dispatch on objects for which \code{\link{is.object}} is true.
%
%  In some versions of \R, assigning a zero-length vector with
%  \code{class} removes the class: in others it is an error (whereas it
%  works for \code{oldClass}.  It is clearer to always assign \code{NULL}
%  to remove the class.
%}
%
%\section{Formal classes}{
%  An additional mechanism of \emph{formal} classes, nicknamed
%  \dQuote{S4}, is available in package \pkg{methods} which is attached
%  by default.  For objects which have a formal class, its name is
%  returned by \code{class} as a character vector of length one and
%  method dispatch can happen on \emph{several} arguments, instead of
%  only the first.  However, S3 method selection attempts to treat objects
%  from an S4 class as if they had the appropriate S3 class attribute, as
%  does \code{inherits}.  Therefore, S3 methods can be defined for S4
%  classes.  See the \sQuote{\link{Classes}} and \sQuote{\link{Methods}}
%  help pages for details.
%
%  The replacement version of the function sets the class to the value
%  provided.  For classes that have a formal definition, directly
%  replacing the class this way is strongly deprecated.  The expression
%  \code{\link{as}(object, value)} is the way to coerce an object to a
%  particular class.
%
%  The analogue of \code{inherits} for formal classes is
%  \code{\link{is}}.  The two functions behave consistently
%  with one exception:  S4 classes can have conditional
%  inheritance, with an explicit test.  In this case, \code{is} will
%  test the condition, but \code{inherits} ignores all conditional
%  superclasses.
%}
%
%\seealso{
%  \code{\link{UseMethod}}, \code{\link{NextMethod}},
%  \sQuote{\link{group generic}}, \sQuote{\link{internal generic}}
%}
%\examples{
%x <- 10
%class(x) # "numeric"
%oldClass(x) # NULL
%inherits(x, "a") #FALSE
%class(x) <- c("a", "b")
%inherits(x,"a") #TRUE
%inherits(x, "a", TRUE) # 1
%inherits(x, c("a", "b", "c"), TRUE) # 1 2 0
%}
%\keyword{methods}
%\keyword{classes}
%
\encoding{UTF8}
