% File src/library/base/man/connections.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{connections}
\title{Functions to Manipulate Connections (Files, URLs, ...)}
\alias{connections}
\alias{connection}
\alias{file}
\alias{clipboard}
\alias{pipe}
\alias{fifo}
\alias{gzfile}
\alias{unz}
\alias{bzfile}
\alias{xzfile}
\alias{url}
\alias{socketConnection}
\alias{open}
\alias{open.connection}
\alias{isOpen}
\alias{isIncomplete}
\alias{close}
\alias{close.connection}
\alias{flush}
\alias{flush.connection}
\alias{print.connection}
\alias{summary.connection}
\concept{encoding}
\concept{compression}
\concept{decompression}
\concept{zip}
\concept{gzip}
\concept{bzip2}
\concept{lzma}
\description{
  コネクションを作り，開き，そして閉じる関数，つまり 
  可能性として圧縮されたファイル，URL，パイプ等の\dQuote{一般化ファイル}．
}
\usage{
file(description = "", open = "", blocking = TRUE,
     encoding = getOption("encoding"), raw = FALSE,
     method   = getOption("url.method", "default"))

url(description, open = "", blocking = TRUE,
    encoding = getOption("encoding"), method)

gzfile(description, open = "", encoding = getOption("encoding"),
       compression = 6)

bzfile(description, open = "", encoding = getOption("encoding"),
       compression = 9)

xzfile(description, open = "", encoding = getOption("encoding"),
       compression = 6)

unz(description, filename, open = "", encoding = getOption("encoding"))

pipe(description, open = "", encoding = getOption("encoding"))

fifo(description, open = "", blocking = FALSE,
     encoding = getOption("encoding"))

socketConnection(host = "localhost", port, server = FALSE,
                 blocking = FALSE, open = "a+",
                 encoding = getOption("encoding"),
                 timeout = getOption("timeout"))

open(con, \dots)
\method{open}{connection}(con, open = "r", blocking = TRUE, \dots)

close(con, \dots)
\method{close}{connection}(con, type = "rw", \dots)

flush(con)

isOpen(con, rw = "")
isIncomplete(con)
}
\arguments{
  \item{description}{文字列．コネクションの説明：\sQuote{詳細}を見よ．}
  \item{open}{文字列. コネクションをどのように開くかの説明
    (もしそれが内部的に開かれる必要があるとき)．可能な値については\sQuote{モード}
    を見よ．}
  \item{blocking}{論理値．\sQuote{ブロック化}節を見よ．}
  \item{encoding}{仮定されるエンコーディングの名前．
    \sQuote{エンコーディング}節を見よ．}
  \item{raw}{論理値．もし真ならば \sQuote{raw} インタフェイスが使われる．
    これは文字デバイスのような通常のファイルでない引数に対してより適している．
    これはテキストモードで開かれるとき圧縮ファイルに対するチェックを抑制し，
    \sQuote{ファイル}が seek 可能でないかもしれないことを主張する．}
  \item{method}{文字列，部分的に 
    \code{c("default", "internal", "wininet", "libcurl")} とマッチする：
    \sQuote{詳細}を見よ．}
  \item{compression}{0--9 中の整数．書き込みの時適用される圧縮の度合いで，
    圧縮無しから可能な最大圧縮まで．
    \code{xzfile} に対しては負でも良い：\sQuote{圧縮}節を見よ．}
  \item{timeout}{数値：このコネクションに用いられる時間切れ(秒単位)．
    ある種の OS は非常に大きな値をゼロとして扱うかもしれないことを注意する：
    しかしながら POSIX 標準は最大31日をサポートする．}
  \item{filename}{zip ファイル中のファイル名．}
  \item{host}{文字列. ポートに対するホスト名．}
  \item{port}{整数．TCP ポート番号．}
  \item{server}{論理値．ソケットはクライアントかサーバーか?}
  \item{con}{コネクション.}
  \item{type}{文字列．現在無視される．}
  \item{rw}{文字列．空か \code{"read"} 又は \code{"write"}，
    部分マッチングが許される．}
  \item{\dots}{他のメソッドに(から)引き渡される引数．}
}
\details{
  最初の9個の関数はコネクションを作る．既定では
  (\code{socketConnection} を除けば)コネクションは開かれていないが，
  引数 \code{open} に空でない値を設定すれば開くことが出来る．

  \code{file} に対しては description 引数は開かれるべきファイルへのパスか，
  完全な URL (その時は呼び出し \code{url} と同値になる)，又は
  \code{""} (既定)か \code{"clipboard"} (\sQuote{クリップボード}節を見よ)
  である．プロセスの C レベルの標準入力を参照するには \code{"stdin"} を
  使う(これはコンソールや \R の埋め込みバージョンに接続している必要は無く，
  Windows の \code{RGui} 中にはない)．
  \code{stdin} の微妙に異なった \R レベルの概念についてはまた
  \code{\link{stdin}()} を見よ．

  \code{url} に対しては description 引数はスキームを含む完全な URL である
  (\samp{http://}, \samp{https://}, \samp{ftp://} 又は \samp{file://} のような)．
  メソッド \code{"internal"} はコネクション導入以来のそれである．
  メソッド \code{"wininet"} は Windows でだけ利用可能で，
  メソッド \code{"libcurl"} は \R 3.2.0 以来オプションで利用可能である．
  メソッド \code{"default"} (\R 3.2.0 以来)は URL スキームに依存して
  適当なメソッドを選ぶ，例えば 
  \samp{https://} そして \samp{ftps://} URL に
  対しては \code{"libcurl"} でその他には \code{"internal"} になる．
  既定メソッドは \code{\link{options}(url.method = )} (including for when
  URL が \code{file} に引き渡された時を含む)を使って変更できる：
  もし未設定ならそれはメソッド \code{"default"} である．
  プロキシが指定できる：\code{\link{download.file}} を見よ．
  
%#ifdef windows
  (Windows では \code{\link{setInternet2}} を見よ．これは
  \code{"internal"} メソッドが \code{"wininet"} にマップされているかどうかを選択する：
  これは \R 3.2.2. からは既定である．)
%#endif

  \code{gzfile} に対しては description 引数は \command{gzip} で
  圧縮されたファイルへのパスである：
  これはまた非圧縮ファイルに対しても，
  \command{bzip2}, \command{xz} そして \command{lzma} で圧縮された
  ファイルにも開くことができる．

  \code{bzfile} に対しては description 引数は
  \command{bzip2} で圧縮されたファイルへのパスである．

  \code{xzfile} に対しては description 引数は
  \command{xz} で圧縮されたファイル(\url{https://en.wikipedia.org/wiki/Xz})
  又は(読み込み専用) \command{lzma} で圧縮されたファイル
  (\url{https://en.wikipedia.org/wiki/LZMA}) のパスである．

  \code{unz} は zip ファイル中の一つのファイルのバイナリモードでの読み取り専用である．
  description 引数は zip ファイルへの完全なパスで，必要なら拡張子 \file{.zip}
  を持つ．

  \code{pipe} に対しては description 引数はパイプされる・パイプからの
  コマンドラインである．これはシェル中，Windows では
  環境変数 \env{COMSPEC} で指定されるもの，で実行される．

  \code{fifo} に対しては description 引数は fifo へのパスである．

  すべてのプラットフォームは \code{file}, \code{pipe}, \code{gzfile},
  \code{bzfile}, \code{xzfile}, \code{unz} そして \code{url("file://")}
  コネクションをサポートする．他のコネクションは部分的に移植されていたり，
  全く移植されていない可能性がある．
  (これらはほとんどの Unix プラットフォームとすべての 
  Windows で動作する．)

  意図することは \code{file} と \code{gzfile} は一般にそれぞれ
  テキストファイル(ファイル，\samp{http://} と
  \samp{https://} URL)とバイナリファイル用ということである．

  \code{open}, \code{close} そして \code{seek} は総称的関数である：以下は
  コネクションに関連するメソッドに適用される．

  \code{open} はコネクションを開く．一般にコネクションを使う関数はそれらが
  開かれていなければ開くが，再びそれらを閉じる．従ってコネクションを
  開いたままにするにはコネクションを明示的に呼び出す．

  \code{close} はコネクションを閉じ消去する．これはコネクションを参照する
  \R オブジェクトが最早なければそのうち自動的に起こる．

  最大128のコネクションがいつでも同時に確保できる(必ずしも開かれている必要はない)．
  これらのうち三つは予め確保されている(\code{\link{stdout}} を見よ)．
  OS が様々なタイプのコネクションの僧都うに制限を設けるが，
  これらは通常125より大きい．

  \code{flush} は読み書きで開かれたコネクションの出力ストリームを
  フラッシュする(移植されていれば，現在ファイルとクリップボード
  コネクション，\code{\link{stdout}} と \code{\link{stderr}})．

  もし \code{file} もしくは(殆どのプラットフォームで) \code{fifo} コネクション
  に対して description 引数が \code{""} ならば，ファイルと /fifo は即座に
  開かれ(\code{open = "w+b"} でない限り \code{"w+"} モードで)そして
  ファイルシステムからリンクを外される．
  これは書き込みとその後の読み取り用の一時的なファイルと fifo を
  提供する．
}

\section{URL}{
  \code{url} と \code{file} は URL スキーム \samp{http://},
  \samp{https://}, \samp{ftp://} そして \samp{file://} をサポートする：
  最初の三つは OS のサポートを必要とする(すべての既知の \R プラットフォームは
  サポートしている)．

  \code{method = "libcurl"} はより多くのスキームを認める：
  どのスキームかはプラットフォーム依存であるが
  (\code{\link{libcurlVersion}} を見よ)，殆どのプラットフォームは
  \samp{https://} と \samp{ftps://} を認める．

  殆どのメソッドは \samp{http://} (\code{\link{URLencode}} を見よ)が空白のような
  特殊文字をパーセントエンコードしないが，\code{"wininet"} メソッドはするように見える．

  \samp{file://} URL に関するノート．最も一般的な形式(RFC1738 から)は
  \samp{file://host/path/to/file} であるが，\R はローカルマシーンを
  参照する空の \code{host} 欄を持つ形式だけを認める．

  Unix 風システムでは，これはそうすると \samp{file:///path/to/file} である．
  ここで \samp{path/to/file} は \file{/} に相対的である．従って
  三案目のスラッシュは厳密にパスの一部ではない指定の一部であるが，
  これはファイル \file{/path/to/file} を指定する方法と見做される．
  ファイル URL を使って相対的なパスを指定することは不可能である．

  この形式ではパスはファイルシステムのルートに相対的であり，Windows の
  概念とは異なる．Windows での標準的形式は
  \samp{file:///d:/R/repos} である：\R と Unix の以前のバージョンとの互換性から
  他のすべての形式は \R に \samp{file://} プラス \code{path_to_file} として
  構文解析される．同様に，RFC1738 は認めていないが，バックスラッシュは
  パス中で認められる．

  パーセントエンコードされた \samp{file:} URL をデコードする試みは
  一切されない：必要なら \code{\link{URLdecode}} を呼び出す．

  \code{"internal"} メソッドはリダイレクトされた HTTP URL をフォローしない：
  メソッド \code{"wininet"} (Windows では既定)と \code{"libcurl"} は
  どちらもする(HTTPS URL に対しても)．

  サーバー側でキャッシュされたデータは常に受け入れられる．

  関数 \code{\link{download.file}} と貢献パッケージ
  \CRANpkg{RCurl} は URL からのダウンロードのより完備した
  機能を提供する．
}

\value{
  \code{file}, \code{pipe}, \code{fifo}, \code{url}, \code{gzfile},
  \code{bzfile}, \code{xzfile}, \code{unz} そして \code{socketconnection} 
  はクラス \code{"connection"} を継承するコネクションオブジェクトを返し，
  より多くの特殊なクラスを持つ．

  \code{open} と \code{flush} は不可視で \code{NULL} を返す．

  \code{close} は不可視で \code{NULL} か整数状態を返す．
  状態はコネクションが最後に閉じられた際のもので，
  ある種のコネクションに対してだけ得られる(たとえば，pipes, files そして
  fifo)：典型的にはゼロは成功を指示する．

  \code{isOpen} はコネクションが現在開かれているかどうかを示す論理値を返す．

  \code{isIncomplete} は最後の読み込みがブロックされたか，
  もしくは出力テキストコネクションに対してはフラッシュされていない出力が
  あるかどうかを示す論理値を返す．
}

\section{モード}{
  引数 \code{open} に対する可能な値は
  \describe{
    \item{\code{"r"} 又は \code{"rt"}}{テキストモードの読み込みで開く．}
    \item{\code{"w"} or \code{"wt"}}{テキストモードの書き込みで開く．}
    \item{\code{"a"} or \code{"at"}}{テキストモードの追加で開く．}
    \item{\code{"rb"}}{バイナリモードの読み取りで開く．}
    \item{\code{"wb"}}{バイナリモードの書き込みで開く．}
    \item{\code{"ab"}}{バイナリモードの追加で開く．}
    \item{\code{"r+"}, \code{"r+b"}}{読み書きで開く．}
    \item{\code{"w+"}, \code{"w+b"}}{最初にファイルを切り詰めてから読み書きで開く，}
    \item{\code{"a+"}, \code{"a+b"}}{読み取りと追加で開く．}
  }
  すべてのモードがすべてのコネクションに適用可能ではない：例えば URL は
  読み取りだけで開くことが出来る．ファイルとソケットコネクションだけが
  読み書き双方で開くことが出来る．サポートされていないモードは普通
  黙って取り替えられる．

  もしファイルや fifo が Unix 風システム上で作られると，
  そのパーミッションは現在の \code{umask} (\code{\link{Sys.umask}} を見よ)
  の設定から許される最大のものになる．

  多くのコネクションに対して，テキストとバイナリモードの間には
  ほとんどか全く差異が無い．Windows のファイル風コネクションに対しては，
  行末の翻訳(LF と CRLF)はテキストモードだけで行われる(しかし
  \code{\link{readLines}} のようなコネクション上のテキスト読み込み操作では
  \code{\link{scan}} と \code{\link{source}} は任意の行末形式にたいして動作する)．
  様々な \R の操作はもしかするとたった一つのモードでのみ可能かも
  しれない：例えば \code{\link{pushBack}} はテキスト向きで，テキストモードでの
  読み込みに対して開かれたコネクション上でのみ許される．
  そして \code{\link{readBin}}, \code{\link{load}} そして 
  \code{\link{save}} のような操作はバイナリモードのコネクション上でだけ
  許される．

  コネクションのモードは実際に開かれた時決定され，もし \code{open = ""} が
  与えられる(ソケットコネクション以外では既定)と延期される．
  \code{open} の明確な呼び出しでモードを指定できるが，
  さもなければモードは \code{"r"} になるであろう．
  (\code{gzfile}, \code{bzfile} そして \code{xzfile} コネクションは
  例外である．なぜなら圧縮ファイルは常にバイナリモードで開かれなければ
  ならず，Windows 上でさえ行末の変換はされないため，
  既定モードは \code{"rb"} と解釈されるから．)
  書き込みアクセス，テキストオンリー又はバイナリオンリーモードが必要な
  殆どの操作はまだ開かれていないコネクションの既定モードを上書きする．

  追加モードは圧縮ファイルコネクションに対しては慎重に考慮する必要がある．
  それらはファイルへの単一の圧縮ストリームではなく，
  むしろ新しいファイルへの圧縮ストリームを追加する．
  読み取りは最初のストリームの最後を超えるかもしれないし
  そうでないかもしれない：
  現在 \R は \code{gzfile}, \code{bzfile} そして \code{xzfile}
  コネクションに対してそのように振る舞う．
}

\section{圧縮}{
  \R は \command{gzip}, \command{bzip2} そして \command{xz} による
  圧縮をサポートしている(\R 2.10.0 で付け加わった：またその前進である
  \code{lzma} 圧縮の読み取り専用のサポート)．

  読み取りには圧縮(もしあれば)のタイプはファイルの先頭の数バイトから
  決定できる．従って \code{file(raw = FALSE)} コネクションに対しては，
  もし if \code{open} が \code{""}, \code{"r"} 又は \code{"rt"} ならば，
  コネクションは非圧縮ファイルのみならず任意の圧縮ファイルタイプを
  読み取ることが出来る．
  (\code{"rb"} を使えば圧縮ファイルをバイト単位で読み取ることが出来る．
  同様に \code{gzfile} コネクションは任意の読み取りモードで任意の圧縮と
  非圧縮形式ファイルを読むことが出来る．

  (もし \code{open} が未指定で，その名前のファイルが存在すれば，
  圧縮のタイプはコネクションが作られた時決定される.
  もしその名前で異なった圧縮形式でファイルに書き込むためにコネクションを
  開くことを意図しているならば，コネクションが作られた時に 
  \code{open = "w"} を指定する．もしくはコネクションを作る前に
  ファイルを \code{\link{unlink}} する．

  書き込みモードのコネクションに対しては \code{compress} はファイルサイズを
  最小化するためにどれだけ圧縮度を高めるかを指定する．
  そして高い値はより多くの CPU 時間と作業メモリ
  (\code{xzfile(compress = 9)} に対し最大 800Mb)を必要とする．
  \code{xzfile} に対しては負の \code{compress} 値は
  \command{xz} 引数 \option{-e} を加えることに対応する：
  これはより多くの圧縮時間(二倍?)を必要とするが(僅かに)より良い
  圧縮ができる可能性がある．既定値 (\code{6}) ha
  良い圧縮度と控えめなメモリ使用度(100Mb)を持つ：しかしながらもし
  \code{xz} 圧縮を使っているならば恐らく高度の圧縮を目指しているのだろう．

  圧縮のタイプを選ぶことはトレードオフを含む：
  \command{gzip}, \command{bzip2} そして \command{xz} は
  順によりサポートの度合いが減り，
  圧縮と解凍の双方により多くの資源を必要とし，より高度の
  圧縮度を達成する(しかしながら個々のファイルは一般的傾向に
  反するかもしれない)．典型的な経験では \code{bzip2} 圧縮はテキストファイルで
  \code{gzip} 圧縮より 15\% 優れており，
  \code{xz} 圧縮は最大 30\% 優れている．
  \R の \code{\link{save}} ファイルでの経験は同様であるが，
  ある種の大きな \file{.rda} ファイルでは
  \code{xz} 圧縮は他の二つよりも遥かに良い．
  現在の計算機では \code{compress = 9} でも
  解凍時間は典型的には控えめで，圧縮ファイルの読み取りは普通
  非圧縮のそれよりもディスクの動作の減少のせいで速い．
}

\section{エンコーディング}{
  コネクションの入出力ストリームのエンコーディングは
  \code{\link{iconv}} に与えたのと同様に名前で指定できる：
  自分のプラットフォームでどのようなエンコーディング名が
  認識されるのかを見つけるにはそのヘルプ頁を見よ．
  加えて \code{""} と \code{"native.enc"} は共に \sQuote{ネイティブ}
  エンコーディングを意味する，つまり現在のロケールでの内部
  エンコーディングであり，従って翻訳は行われない．

  再エンコーディングはテキストモードのコネクションに対してだけ動作する：
  最エンコーディングがバイナリモードで指定された
  コネクションからの読み取りはバイトのストリームを読み込むが，
  テキストとバイナリモードの読み取りの混合(つまり
  \code{\link{readLines}} と \code{\link{readChar}} の呼び出し)は
  恐らく不正な結果に導かれる．

  エンコーディング \code{"UCS-2LE"} と \code{"UTF-16LE"} は特別に
  扱われる．なぜならそれらは Windows の \sQuote{Unicode} テキストファイルに
  ふさわしい値であるからである．もし最初の2バイトが Byte Order Mark
  \code{0xFEFF} ならば \code{\link{iconv}} が BOM を受け入れないため，
  これらは取り除かれる．殆どの移植は BMO をエンコーディング \code{"UCS-2"}
  を用いて処理し適当なバイト順序を選択するが，
  しないもの(初期の \code{glibc} を含む)もある．
  \code{"UTF-16"} と \code{"UCS-2"} の間には微妙な差がある
  (\url{https://en.wikipedia.org/wiki/UTF-16} を見よ：
  代理ペアを必要とする \sQuote{Supplementary Planes} 中の文字の使用は
  非常に稀なため \code{"UCS-2LE"} が適切な最初の選択になる
  (より広範囲に実装されているため)．

  \R 3.0.0 以来エンコーディング \code{"UTF-8-BOM"} が読み取りで
  認められるようになり，もし存在すれば Byte Order Mark を取り去る
  (これは Microsoft のアプリケーションで作られたファイルで
  しばしばそうである)．書き込みでもし BOM が必要なら(推奨されないが)
  明確に例えば \code{writeBin(as.raw(c(0xef, 0xbb, 0xbf)), binary_con)} や\cr
  \code{writeChar("\ufeff", con, eos = NULL)} のように書かれるべきである．

  エンコーディング名 \code{"utf8"}, \code{"mac"} そして \code{"macroman"} は
  可搬性が無い．そしてすべての現在の \R プラットフォームで
  サポートされていない．
  \code{"UTF-8"} は可搬性を持ち，そして \code{"macintosh"} は
  \sQuote{Mac Roman} に対する公式(そして最も広範囲にサポートされている)名前である．

  サポートされない変換の要求はエラーであり，
  コネクションが開かれた時報告される．
  要求された翻訳が不正な入力に対してなされた時正確に何が起こるかは
  一般的にはドキュメント化されていない．
  出力では結果は警告を伴い，エラーを含んでいる．
  入力ではこれは入力のすべてか一部分がエラーを含むことが最も
  ありそうである．

  現在のネイティブエンコーディングを
  \code{\link{Sys.getlocale}("LC_CTYPE")} から導くことは可能かも
  しれないが，すべての OS がそれを記録しているわけではない．
}

\section{ブロック化}{
  コネクションのブロックがファイル，url (既定で可), fifo
  とソケットコネクション(既定で否)に指定できるかどうか．

  ブロック化モードでは，コネクションを使う関数は読み書きが終わるまで
  \R の評価器に復帰しない．非ブロック化モードでは
  操作は可能な限り速やかに復帰するので，入力では
  どんな入力が利用可能であっても(無い可能性も)復帰し，出力に対しては
  書き込みが成功しようとしまいと復帰する．

  関数 \code{\link{readLines}} は二つのモードでは不完全な最終行に
  関して異なった動作をする：ヘルプ頁を見よ．

  コネクションがブロック化モードにあっても，イベントループ，
  従って \R の GUI 部分の操作，をブロックしないことが
  保証されるように努力される．
  これらは常に成功するわけではなく，
  例えば \R プロセス全体が Unix の DNS 検索の間ブロックされる．

  HTTP/FTP URL とソケットへの殆どの操作は
  \code{options("timeout")} により時間切れとされる可能性がある．
  これは無反応への時間切れであり，操作全体への時間切れではないことを注意する．
  時間切れはコネクションが開かれた時設定される
  (より正確には，そのタイプ-- \samp{http:}, \samp{ftp:} 又はソケット --
  の最後のコネクションが開かれた時)．
}

\section{Fifo}{
  Fifo は既定でブロック化されない．これは S のバージョン4に従い，恐らく最も
  自然であるが，幾つかの含意がある．特に
  非ブロック化 fifo コネクションを書き込み(だけ)に開くと
  ある他のプロセスがその fifo を読込み中で無い限り失敗する．

  fifo を読み書き双方で開くと(どのようなモードでも：fifo には追加だけが可能)
  fifo の両端を \R プロセスに連結し，
  \code{file()} に類似の機能を提供する．
}

\section{クリップボード}{
  \code{file} は \code{description = "clipboard"} と共に
  使うことが出来るが，
%#ifdef windows
  Windows ではモード \code{"r"} と \code{"w"} だけである．
%#endif
%#ifdef unix
  Unix ではモード \code{"r"} だけである．これは X11 primary selection
  (\url{http://standards.freedesktop.org/clipboards-spec/clipboards-latest.txt} を見よ)
  と secondary selection を読み取る．これらは \code{"X11_primary"} と
  \code{"X11_secondary"} としても指定できる．殆どのシステムではクリップボードの
  選択(\sQuote{Edit} メニューからの \sQuote{Copy} で使われる)は
  \code{"X11_clipboard"} として指定できる．
%#endif

  クリップボードが読み込みのために開かれると内容は即座にコネクションの
  内部保管庫にコピーされる．

%#ifdef windows
  (Windows では)クリップボードに書き込むとき，出力はコネクションが閉じられているか
  フラッシュされている時だけクリップボードにコピーされる．
  クリップボードに書き込まれるテキストには 32Kb の制限がある．
  これは例えば \code{file("clipboard-128")} に 128Kb を与えることで
  増加できる．

  クリップボードは Unicode の幅広文字で動作するので，
  エンコーディングは期待されるようには動作しないかもしれない．
%#endif
%#ifdef unix
  (Unix では) X11 selection のどれかに書き込みたい Unix ユーザは
  \command{xclip} (\url{http://sourceforge.net/projects/xclip/}) または
  \command{xsel} (\url{http://www.vergenet.net/~conrad/software/xsel/}) を
  使って行うことが出来る．例えば primary selection に対しては
  \code{pipe("xclip -i", "w")} とする．

  OS X のユーザはシステムのクリップボードに読み書きするために
  \code{pipe("pbpaste")} と \code{pipe("pbcopy", "w")} を使うことが出来る．
%#endif
}
\note{
  \R のコネクションはバージョン４の S をモデルにしている(Chambers,
  1998 を見よ)．しかしながら \R は S のモデルを遥かに超えている．
  例えば出力テキストコネクションと URL，圧縮とソケットコネクション．

  \R の既定オープンモードはソケットコネクションを除いて \code{"r"} である．
  これは S とは異なる．S では \code{"r+"} と同値であり \code{"*"} として
  知られている．

  \code{vsnprintf} が必要な長さの出力を返さない(稀な)プラットフォームでは
  \code{fifo}, \code{gzfile}, \code{bzfile} そして \code{xzfile} コネクション
  に関するテキスト出力に対して一行の長さに 100,000 バイトの制限がある：
  長すぎる行は警告と共に刈り詰められる．
}
\references{
  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language.} Springer.

  Ripley, B. D. (2001) Connections. \emph{R News}, \bold{1/1}, 16--7.
  \url{https://www.r-project.org/doc/Rnews/Rnews_2001-1.pdf}
}

\seealso{
  \code{\link{textConnection}}, \code{\link{seek}},
  \code{\link{showConnections}}, \code{\link{pushBack}}.

  コネクションを直接利用する関数は (テキストモード)
  \code{\link{readLines}}, \code{\link{writeLines}}, \code{\link{cat}},
  \code{\link{sink}}, \code{\link{scan}}, \code{\link{parse}},
  \code{\link{read.dcf}}, \code{\link{dput}}, \code{\link{dump}} そして
  (バイナリモード) \code{\link{readBin}}, \code{\link{readChar}},
  \code{\link{writeBin}}, \code{\link{writeChar}}, \code{\link{load}}
  そして \code{\link{save}}．

  HTTP/FTP \code{url}, \code{fifo} そして \code{socketConnection} が
  この \R の構築でサポートされているかどうかを見るには 
  \code{\link{capabilities}}．

  コネクションまわりの \command{gzip} による圧縮と解凍のラッパは
  \code{\link{gzcon}}．
  
  \code{\link{options}} \code{HTTPUserAgent}, \code{internet.info} そして
  \code{timeout} はある種の URL コネクションに対するメソッドで使われる．
  
  より多種類の圧縮・解凍法とデータ圧縮に関する参考文献は \code{\link{memCompress}}．

  (Windows では)  コンソールへ出力をフラッシュするには \code{\link{flush.console}} を見よ．
}

\examples{
zz <- file("ex.data", "w")  # 出力ファイルコネクションを開く
cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
cat("One more line\n", file = zz)
close(zz)
readLines("ex.data")
unlink("ex.data")

zz <- gzfile("ex.gz", "w")  # 圧縮ファイル
cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
close(zz)
readLines(zz <- gzfile("ex.gz"))
close(zz)
unlink("ex.gz")

zz <- bzfile("ex.bz2", "w")  # bzip2 で圧縮したファイル
cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
close(zz)
print(readLines(zz <- bzfile("ex.bz2")))
close(zz)
unlink("ex.bz2")

## ファイルを読み書きのために開く例
Tfile <- file("test1", "w+")
c(isOpen(Tfile, "r"), isOpen(Tfile, "w")) # 共に TRUE
cat("abc\ndef\n", file = Tfile)
readLines(Tfile)
seek(Tfile, 0, rw = "r") # 最初にリセット
readLines(Tfile)
cat("ghi\n", file = Tfile)
readLines(Tfile)
close(Tfile)
unlink("test1")

## 同じことを匿名ファイルに行うことが出来る．
Tfile <- file()
cat("abc\ndef\n", file = Tfile)
readLines(Tfile)
close(Tfile)

\dontrun{## fifo の例 -- OS が fifo をサポートしていても立ち往生する可能性
if(capabilities("fifo")) {
  zz <- fifo("foo-fifo", "w+")
  writeLines("abc", zz)
  print(readLines(zz))
  close(zz)
  unlink("foo-fifo")
}}
# （Unixでは)
\donttest{
## Unix でのパイプの使用例

# 現在のディレクトリのリスティングを読む
readLines(pipe("ls -1"))

# 末尾のコンマを除く．以下を仮定する
\dontshow{
writeLines(c("450, 390, 467, 654,  30, 542, 334, 432, 421,",
"357, 497, 493, 550, 549, 467, 575, 578, 342,",
"446, 547, 534, 495, 979, 479"), "data2_")}
\dontrun{\% cat data2_
450, 390, 467, 654,  30, 542, 334, 432, 421,
357, 497, 493, 550, 549, 467, 575, 578, 342,
446, 547, 534, 495, 979, 479}
# それから次のように読む
scan(pipe("sed -e s/,$// data2_"), sep = ",")
\dontshow{unlink("data2_")}

# 出力中の小数点をカンマに変える：write.table も見よ
# R 文字列と(恐らく)シェル命令は二重引用化が必要
zz <- pipe(paste("sed s/\\\\\\\\./,/ >", "outfile"), "w")
cat(format(round(stats::rnorm(48), 4)), fill = 70, file = zz)
close(zz)
file.show("outfile", delete.file = TRUE)
}
\dontrun{
## finger daemon が走る計算機に対する例

con <- socketConnection(port = 79, blocking = TRUE)
writeLines(paste0(system("whoami", intern = TRUE), "\r"), con)
gsub(" *$", "", readLines(con))
close(con)
}

\dontrun{
## ブロック化されていないソケット経由で通信する二つの R プロセス
# R プロセス 1
con1 <- socketConnection(port = 6011, server = TRUE)
writeLines(LETTERS, con1)
close(con1)

# R プロセス 2
con2 <- socketConnection(Sys.info()["nodename"], port = 6011)
# ブロック化されていないので，入力にループが必要かもしれない
readLines(con2)
while(isIncomplete(con2)) {
   Sys.sleep(1)
   z <- readLines(con2)
   if(length(z)) print(z)
}
close(con2)

## エンコーディングの使用の例
# ファイルを UTF-8 で書く
cat(x, file = (con <- file("foo", "w", encoding = "UTF-8"))); close(con)
# 'Windows Unicode' ファイルを読む
A <- read.table(con <- file("students", encoding = "UCS-2LE")); close(con)
}}
\keyword{file}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/connections.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{connections}
%\title{Functions to Manipulate Connections (Files, URLs, ...)}
%\alias{connections}
%\alias{connection}
%\alias{file}
%\alias{clipboard}
%\alias{pipe}
%\alias{fifo}
%\alias{gzfile}
%\alias{unz}
%\alias{bzfile}
%\alias{xzfile}
%\alias{url}
%\alias{socketConnection}
%\alias{open}
%\alias{open.connection}
%\alias{isOpen}
%\alias{isIncomplete}
%\alias{close}
%\alias{close.connection}
%\alias{flush}
%\alias{flush.connection}
%\alias{print.connection}
%\alias{summary.connection}
%\concept{encoding}
%\concept{compression}
%\concept{decompression}
%\concept{zip}
%\concept{gzip}
%\concept{bzip2}
%\concept{lzma}
%\description{
%  Functions to create, open and close connections, i.e.,
%  \dQuote{generalized files}, such as possibly compressed files, URLs,
%  pipes, etc.
%}
%\usage{
%file(description = "", open = "", blocking = TRUE,
%     encoding = getOption("encoding"), raw = FALSE)
%
%url(description, open = "", blocking = TRUE,
%    encoding = getOption("encoding"), method)
%
%gzfile(description, open = "", encoding = getOption("encoding"),
%       compression = 6)
%
%bzfile(description, open = "", encoding = getOption("encoding"),
%       compression = 9)
%
%xzfile(description, open = "", encoding = getOption("encoding"),
%       compression = 6)
%
%unz(description, filename, open = "", encoding = getOption("encoding"))
%
%pipe(description, open = "", encoding = getOption("encoding"))
%
%fifo(description, open = "", blocking = FALSE,
%     encoding = getOption("encoding"))
%
%socketConnection(host = "localhost", port, server = FALSE,
%                 blocking = FALSE, open = "a+",
%                 encoding = getOption("encoding"),
%                 timeout = getOption("timeout"))
%
%open(con, \dots)
%\method{open}{connection}(con, open = "r", blocking = TRUE, \dots)
%
%close(con, \dots)
%\method{close}{connection}(con, type = "rw", \dots)
%
%flush(con)
%
%isOpen(con, rw = "")
%isIncomplete(con)
%}
%\arguments{
%  \item{description}{character string.  A description of the connection:
%    see \sQuote{Details}.}
%  \item{open}{character string.  A description of how to open the connection
%    (if it should be opened initially).  See section \sQuote{Modes} for
%    possible values.}
%  \item{blocking}{logical.  See the \sQuote{Blocking} section.}
%  \item{encoding}{The name of the encoding to be assumed.  See the
%    \sQuote{Encoding} section.}
%  \item{raw}{logical.  If true, a \sQuote{raw} interface is used which
%    will be more suitable for arguments which are not regular files,
%    e.g.\sspace{}character devices.  This suppresses the check for a compressed
%    file when opening for text-mode reading, and asserts that the
%    \sQuote{file} may not be seekable.}
%  \item{method}{character string, partially matched to
%    \code{c("default", "internal", "wininet", "libcurl")}:
%    see \sQuote{Details}.}
%  \item{compression}{integer in 0--9.  The amount of compression to be
%    applied when writing, from none to maximal available.  For
%    \code{xzfile} can also be negative: see the \sQuote{Compression}
%    section.}
%  \item{timeout}{numeric: the timeout (in seconds) to be used for this
%    connection.  Beware that some OSes may treat very large values as
%    zero: however the POSIX standard requires values up to 31 days to be
%    supported.}
%  \item{filename}{a filename within a zip file.}
%  \item{host}{character string.  Host name for the port.}
%  \item{port}{integer.  The TCP port number.}
%  \item{server}{logical.  Should the socket be a client or a server?}
%  \item{con}{a connection.}
%  \item{type}{character string.  Currently ignored.}
%  \item{rw}{character string.  Empty or \code{"read"} or \code{"write"},
%    partial matches allowed.}
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\details{
%  The first nine functions create connections.  By default the
%  connection is not opened (except for a \code{socketConnection}), but may
%  be opened by setting a non-empty value of argument \code{open}.
%
%  For \code{file} the description is a path to the file to be opened or
%  a complete URL (when it is the same as calling \code{url}), or
%  \code{""} (the default) or \code{"clipboard"} (see the
%  \sQuote{Clipboard} section).  Use \code{"stdin"} to refer to the
%  C-level \sQuote{standard input} of the process (which need not be
%  connected to anything in a console or embedded version of \R, and is
%  not in \code{RGui} on Windows).  See also \code{\link{stdin}()} for
%  the subtly different R-level concept of \code{stdin}.
%
%  For \code{url} the description is a complete URL including scheme
%  (such as \samp{http://}, \samp{https://}, \samp{ftp://} or
%  \samp{file://}).  Method \code{"internal"} is that available since
%  connections were introduced, method \code{"wininet"} is only available
%  on Windows and method \code{"libcurl"} is optionally supported as from
%  \R 3.2.0.  Method \code{"default"} (as from \R 3.2.0) selects a
%  suitable method depending on the URL scheme, e.g.\sspace{} method
%  \code{"libcurl"} for \samp{https://} and \samp{ftps://} URLs and
%  \code{"internal"} otherwise.  The default method can be changed
%  \emph{via} \code{\link{options}(url.method = )} (including for when
%  URLs are passed to \code{file}): if unset it is method
%  \code{"default"}.  Proxies can be specified: see
%  \code{\link{download.file}}.
%  
%#ifdef windows
%  (See \code{\link{setInternet2}}, which chooses whether the
%  \code{"internal"} method is mapped to \code{"wininet"}: this is
%  true by default as from \R 3.2.2.)
%#endif
%
%  For \code{gzfile} the description is the path to a file compressed by
%  \command{gzip}: it can also open for reading uncompressed files and
%  those compressed by \command{bzip2}, \command{xz} or \command{lzma}.
%
%  For \code{bzfile} the description is the path to a file compressed by
%  \command{bzip2}.
%
%  For \code{xzfile} the description is the path to a file compressed by
%  \command{xz} (\url{https://en.wikipedia.org/wiki/Xz}) or (for reading
%  only) \command{lzma} (\url{https://en.wikipedia.org/wiki/LZMA}).
%
%  \code{unz} reads (only) single files within zip files, in binary mode.
%  The description is the full path to the zip file, with \file{.zip}
%  extension if required.
%
%  For \code{pipe} the description is the command line to be piped to or
%  from.  This is run in a shell, on Windows that specified by the
%  \env{COMSPEC} environment variable.
%
%  For \code{fifo} the description is the path of the fifo.
%
%  All platforms support \code{file}, \code{pipe}, \code{gzfile},
%  \code{bzfile}, \code{xzfile}, \code{unz} and \code{url("file://")}
%  connections.  The other connections may be partially implemented or
%  not implemented at all.  (They do work on most Unix platforms, and all
%  on Windows.)
%
%  The intention is that \code{file} and \code{gzfile} can be used
%  generally for text input (from files, \samp{http://} and
%  \samp{https://} URLs) and binary input respectively.
%
%  \code{open}, \code{close} and \code{seek} are generic functions: the
%  following applies to the methods relevant to connections.
%
%  \code{open} opens a connection.  In general functions using
%  connections will open them if they are not open, but then close them
%  again, so to leave a connection open call \code{open} explicitly.
%
%  \code{close} closes and destroys a connection.  This will happen
%  automatically in due course (with a warning) if there is no longer an
%  \R object referring to the connection.
%
%  A maximum of 128 connections can be allocated (not necessarily open)
%  at any one time.  Three of these are pre-allocated (see
%  \code{\link{stdout}}).   The OS will impose limits on the numbers of
%  connections of various types, but these are usually larger than 125.
%
%  \code{flush} flushes the output stream of a connection open for
%  write/append (where implemented, currently for file and clipboard
%  connections, \code{\link{stdout}} and \code{\link{stderr}}).
%
%  If for a \code{file} or (on most platforms) a \code{fifo} connection
%  the description is \code{""}, the file/fifo is immediately opened (in
%  \code{"w+"} mode unless \code{open = "w+b"} is specified) and unlinked
%  from the file system.  This provides a temporary file/fifo to write to
%  and then read from.
%}
%
%\section{URLs}{
%  \code{url} and \code{file} support URL schemes \samp{http://},
%  \samp{https://}, \samp{ftp://} and \samp{file://}: the first three
%  require OS support (which all known \R platforms have).
%
%  \code{method = "libcurl"} allows more schemes: exactly which schemes
%  is platform-dependent (see \code{\link{libcurlVersion}}), but most
%  platforms will support \samp{https://} and \samp{ftps://}.
%
%  Most methods do not percent-encode special characters such as spaces
%  in \samp{http://} URLs (see \code{\link{URLencode}}), but it seems the
%  \code{"wininet"} method does.
%
%  A note on \samp{file://} URLs.  The most general form (from RFC1738) is
%  \samp{file://host/path/to/file}, but \R only accepts the form with an
%  empty \code{host} field referring to the local machine.
%
%  On a Unix-alike, this is then \samp{file:///path/to/file}, where
%  \samp{path/to/file} is relative to \file{/}.  So although the third
%  slash is strictly part of the specification not part of the path, this
%  can be regarded as a way to specify the file \file{/path/to/file}.  It
%  is not possible to specify a relative path using a file URL.
%
%  In this form the path is relative to the root of the filesystem, not a
%  Windows concept.  The standard form on Windows is
%  \samp{file:///d:/R/repos}: for compatibility with earlier versions of
%  \R and Unix versions, any other form is parsed as \R as \samp{file://}
%  plus \code{path_to_file}.  Also, backslashes are accepted within the
%  path even though RFC1738 does not allow them.
%
%  No attempt is made to decode a percent-encoded \samp{file:} URL: call
%  \code{\link{URLdecode}} if necessary.
%
%  The \code{"internal"} method does not follow re-directed HTTP URLs:
%  both methods \code{"wininet"} (the default on Windows) and
%  \code{"libcurl"} do (including for HTTPS URLs).
%
%  Server-side cached data is always accepted.
%
%  Function \code{\link{download.file}} and contributed package
%  \CRANpkg{RCurl} provide more comprehensive facilities to download
%  from URLs.
%}
%
%\value{
%  \code{file}, \code{pipe}, \code{fifo}, \code{url}, \code{gzfile},
%  \code{bzfile}, \code{xzfile}, \code{unz} and \code{socketConnection}
%  return a connection object which inherits from class
%  \code{"connection"} and has a first more specific class.
%
%  \code{open} and \code{flush} return \code{NULL}, invisibly.
%
%  \code{close} returns either \code{NULL} or an integer status,
%  invisibly. The status is from when the connection was last closed and
%  is available only for some types of connections (e.g., pipes, files and
%  fifos): typically zero values indicate success.
%
%  \code{isOpen} returns a logical value, whether the connection is
%  currently open.
%
%  \code{isIncomplete} returns a logical value, whether the last read
%  attempt was blocked, or for an output text connection whether there is
%  unflushed output.
%}
%
%\section{Modes}{
%  Possible values for the argument \code{open} are
%  \describe{
%    \item{\code{"r"} or \code{"rt"}}{Open for reading in text mode.}
%    \item{\code{"w"} or \code{"wt"}}{Open for writing in text mode.}
%    \item{\code{"a"} or \code{"at"}}{Open for appending in text mode.}
%    \item{\code{"rb"}}{Open for reading in binary mode.}
%    \item{\code{"wb"}}{Open for writing in binary mode.}
%    \item{\code{"ab"}}{Open for appending in binary mode.}
%    \item{\code{"r+"}, \code{"r+b"}}{Open for reading and writing.}
%    \item{\code{"w+"}, \code{"w+b"}}{Open for reading and writing,
%      truncating file initially.}
%    \item{\code{"a+"}, \code{"a+b"}}{Open for reading and appending.}
%  }
%  Not all modes are applicable to all connections: for example URLs can
%  only be opened for reading.  Only file and socket connections can be
%  opened for both reading and writing.  An unsupported mode is usually
%  silently substituted.
%
%  If a file or fifo is created on a Unix-alike, its permissions will be
%  the maximal allowed by the current setting of \code{umask} (see
%  \code{\link{Sys.umask}}).
%
%  For many connections there is little or no difference between text and
%  binary modes.  For file-like connections on Windows, translation of
%  line endings (between LF and CRLF) is done in text mode only (but text
%  read operations on connections such as \code{\link{readLines}},
%  \code{\link{scan}} and \code{\link{source}} work for any form of line
%  ending).  Various \R operations are possible in only one of the modes:
%  for example \code{\link{pushBack}} is text-oriented and is only
%  allowed on connections open for reading in text mode, and binary
%  operations such as \code{\link{readBin}}, \code{\link{load}} and
%  \code{\link{save}} can only be done on binary-mode connections.
%
%  The mode of a connection is determined when actually opened, which is
%  deferred if \code{open = ""} is given (the default for all but socket
%  connections).  An explicit call to \code{open} can specify the mode,
%  but otherwise the mode will be \code{"r"}.  (\code{gzfile},
%  \code{bzfile} and \code{xzfile} connections are exceptions, as the
%  compressed file always has to be opened in binary mode and no
%  conversion of line-endings is done even on Windows, so the default
%  mode is interpreted as \code{"rb"}.)  Most operations that need write
%  access or text-only or binary-only mode will override the default mode
%  of a non-yet-open connection.
%
%  Append modes need to be considered carefully for compressed-file
%  connections.  They do \strong{not} produce a single compressed stream
%  on the file, but rather append a new compressed stream to the file.
%  Readers may or may not read beyond end of the first stream: currently
%  \R does so for \code{gzfile}, \code{bzfile} and \code{xzfile}
%  connections.
%}
%
%\section{Compression}{
%  \R supports \command{gzip}, \command{bzip2} and \command{xz}
%  compression (added in \R 2.10.0: also read-only support for its
%  precursor \code{lzma} compression).
%
%  For reading, the type of compression (if any) can be determined from
%  the first few bytes of the file.  Thus for \code{file(raw = FALSE)}
%  connections, if \code{open} is \code{""}, \code{"r"} or \code{"rt"}
%  the connection can read any of the compressed file types as well as
%  uncompressed files.  (Using \code{"rb"} will allow compressed files to
%  be read byte-by-byte.)  Similarly, \code{gzfile} connections can read
%  any of the forms of compression and uncompressed files in any read
%  mode.
%
%  (The type of compression is determined when the connection is created
%  if \code{open} is unspecified and a file of that name exists.  If the
%  intention is to open the connection to write a file with a
%  \emph{different} form of compression under that name, specify
%  \code{open = "w"} when the connection is created or
%  \code{\link{unlink}} the file before creating the connection.)
%
%  For write-mode connections, \code{compress} specifies how hard the
%  compressor works to minimize the file size, and higher values need
%  more CPU time and more working memory (up to ca 800Mb for
%  \code{xzfile(compress = 9)}).  For \code{xzfile} negative values of
%  \code{compress} correspond to adding the \command{xz} argument
%  \option{-e}: this takes more time (double?) to compress but may
%  achieve (slightly) better compression.  The default (\code{6}) has
%  good compression and modest (100Mb memory) usage: but if you are using
%  \code{xz} compression you are probably looking for high compression.
%
%  Choosing the type of compression involves tradeoffs: \command{gzip},
%  \command{bzip2} and \command{xz} are successively less widely supported,
%  need more resources for both compression and decompression, and
%  achieve more compression (although individual files may buck the
%  general trend).  Typical experience is that \code{bzip2} compression
%  is 15\% better on text files than \code{gzip} compression, and
%  \code{xz} with maximal compression 30\% better.  The experience with
%  \R \code{\link{save}} files is similar, but on some large \file{.rda}
%  files \code{xz} compression is much better than the other two.  With
%  current computers decompression times even with \code{compress = 9}
%  are typically modest and reading compressed files is usually faster
%  than uncompressed ones because of the reduction in disc activity.
%}
%
%\section{Encoding}{
%  The encoding of the input/output stream of a connection can be
%  specified by name in the same way as it would be given to
%  \code{\link{iconv}}: see that help page for how to find out what
%  encoding names are recognized on your platform.  Additionally,
%  \code{""} and \code{"native.enc"} both mean the \sQuote{native}
%  encoding, that is the internal encoding of the current locale and
%  hence no translation is done.
%
%  Re-encoding only works for connections in text mode: reading from a
%  connection with re-encoding specified in binary mode will read the
%  stream of bytes, but mixing text and binary mode reads (e.g., mixing
%  calls to \code{\link{readLines}} and \code{\link{readChar}}) is likely
%  to lead to incorrect results.
%
%  The encodings \code{"UCS-2LE"} and \code{"UTF-16LE"} are treated
%  specially, as they are appropriate values for Windows \sQuote{Unicode}
%  text files.  If the first two bytes are the Byte Order Mark
%  \code{0xFEFF} then these are removed as some implementations of
%  \code{\link{iconv}} do not accept BOMs.  Note that whereas most
%  implementations will handle BOMs using encoding \code{"UCS-2"} and
%  choose the appropriate byte order, some (including earlier versions of
%  \code{glibc}) will not.  There is a subtle distinction between
%  \code{"UTF-16"} and \code{"UCS-2"} (see
%  \url{https://en.wikipedia.org/wiki/UTF-16}: the use of characters in
%  the \sQuote{Supplementary Planes} which need surrogate pairs is very
%  rare so \code{"UCS-2LE"} is an appropriate first choice (as it is more
%  widely implemented).
%
%  As from \R 3.0.0 the encoding \code{"UTF-8-BOM"} is accepted for
%  reading and will remove a Byte Order Mark if present (which it often
%  is for files and webpages generated by Microsoft applications).  If a
%  BOM is required (it is not recommended) when writing it should be
%  written explicitly, e.g.\sspace{}by \code{writeChar("\ufeff", con, eos
%  = NULL)} or \code{writeBin(as.raw(c(0xef, 0xbb, 0xbf)), binary_con)}
%
%  Encoding names \code{"utf8"}, \code{"mac"} and \code{"macroman"} are
%  not portable, and not supported on all current \R platforms.
%  \code{"UTF-8"} is portable and \code{"macintosh"} is the official
%  (and most widely supported) name for \sQuote{Mac Roman}.
%
%  Requesting a conversion that is not supported is an error, reported
%  when the connection is opened.  Exactly what happens when the
%  requested translation cannot be done for invalid input is in general
%  undocumented.  On output the result is likely to be that up to the
%  error, with a warning.  On input, it will most likely be all or some
%  of the input up to the error.
%
%  It may be possible to deduce the current native encoding from
%  \code{\link{Sys.getlocale}("LC_CTYPE")}, but not all OSes record it.
%}
%
%\section{Blocking}{
%  Whether or not the connection blocks can be specified for file, url
%  (default yes), fifo and socket connections (default not).
%
%  In blocking mode, functions using the connection do not return to the
%  \R evaluator until the read/write is complete.  In non-blocking mode,
%  operations return as soon as possible, so on input they will return
%  with whatever input is available (possibly none) and for output they
%  will return whether or not the write succeeded.
%
%  The function \code{\link{readLines}} behaves differently in respect of
%  incomplete last lines in the two modes: see its help page.
%
%  Even when a connection is in blocking mode, attempts are made to
%  ensure that it does not block the event loop and hence the operation
%  of GUI parts of \R.  These do not always succeed, and the whole \R
%  process will be blocked during a DNS lookup on Unix, for example.
%
%  Most blocking operations on HTTP/FTP URLs and on sockets are subject to the
%  timeout set by \code{options("timeout")}.  Note that this is a timeout
%  for no response, not for the whole operation.  The timeout is set at
%  the time the connection is opened (more precisely, when the last
%  connection of that type -- \samp{http:}, \samp{ftp:} or socket -- was
%  opened).
%}
%
%\section{Fifos}{
%  Fifos default to non-blocking.  That follows S version 4 and is
%  probably most natural, but it does have some implications.  In
%  particular, opening a non-blocking fifo connection for writing (only)
%  will fail unless some other process is reading on the fifo.
%
%  Opening a fifo for both reading and writing (in any mode: one can only
%  append to fifos) connects both sides of the fifo to the \R process,
%  and provides an similar facility to \code{file()}.
%}
%
%\section{Clipboard}{
%  \code{file} can be used with \code{description = "clipboard"}
%#ifdef windows
%  in modes \code{"r"} and \code{"w"} only.
%#endif
%#ifdef unix
%  in mode \code{"r"} only.  This reads the X11 primary selection (see
%  \url{http://standards.freedesktop.org/clipboards-spec/clipboards-latest.txt}),
%  which can also be specified as \code{"X11_primary"} and the secondary
%  selection as \code{"X11_secondary"}.  On most systems the clipboard
%  selection (that used by \sQuote{Copy} from an \sQuote{Edit} menu) can
%  be specified as \code{"X11_clipboard"}.
%#endif
%
%  When a clipboard is opened for reading, the contents are immediately
%  copied to internal storage in the connection.
%
%#ifdef windows
%  When writing to the clipboard, the output is copied to the clipboard
%  only when the connection is closed or flushed.  There is a 32Kb limit
%  on the text to be written to the clipboard.  This can be raised by
%  using e.g.\sspace{}\code{file("clipboard-128")} to give 128Kb.
%
%  The clipboard works in Unicode wide characters, so encodings might
%  not work as one might expect.
%#endif
%#ifdef unix
%  Unix users wishing to \emph{write} to one of the X11 selections may be
%  able to do so via \command{xclip}
%  (\url{http://sourceforge.net/projects/xclip/}) or \command{xsel}
%  (\url{http://www.vergenet.net/~conrad/software/xsel/}), for example by
%  \code{pipe("xclip -i", "w")} for the primary selection.
%
%  OS X users can use \code{pipe("pbpaste")} and
%  \code{pipe("pbcopy", "w")} to read from and write to that system's
%  clipboard.
%#endif
%}
%\note{
%  \R's connections are modelled on those in S version 4 (see Chambers,
%  1998).  However \R goes well beyond the S model, for example in output
%  text connections and URL, compressed and socket connections.
%
%  The default open mode in \R is \code{"r"} except for socket connections.
%  This differs from S, where it is the equivalent of \code{"r+"},
%  known as \code{"*"}.
%
%  On (rare) platforms where \code{vsnprintf} does not return the needed
%  length of output there is a 100,000 byte output limit on the length of
%  a line for text output on \code{fifo}, \code{gzfile}, \code{bzfile} and
%  \code{xzfile} connections: longer lines will be truncated with a
%  warning.
%}
%\references{
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language.} Springer.
%
%  Ripley, B. D. (2001) Connections. \emph{R News}, \bold{1/1}, 16--7.
%  \url{https://www.r-project.org/doc/Rnews/Rnews_2001-1.pdf}
%}
%
%\seealso{
%  \code{\link{textConnection}}, \code{\link{seek}},
%  \code{\link{showConnections}}, \code{\link{pushBack}}.
%
%  Functions making direct use of connections are (text-mode)
%  \code{\link{readLines}}, \code{\link{writeLines}}, \code{\link{cat}},
%  \code{\link{sink}}, \code{\link{scan}}, \code{\link{parse}},
%  \code{\link{read.dcf}}, \code{\link{dput}}, \code{\link{dump}} and
%  (binary-mode) \code{\link{readBin}}, \code{\link{readChar}},
%  \code{\link{writeBin}}, \code{\link{writeChar}}, \code{\link{load}}
%  and \code{\link{save}}.
%
%  \code{\link{capabilities}} to see if HTTP/FTP \code{url},
%  \code{fifo} and \code{socketConnection} are supported by this build of \R.
%
%  \code{\link{gzcon}} to wrap \command{gzip} (de)compression around a
%  connection.
%  
%  \code{\link{options}} \code{HTTPUserAgent}, \code{internet.info} and
%  \code{timeout} are used by some of the methods for URL connections.
%  
%  \code{\link{memCompress}} for more ways to (de)compress and references
%  on data compression.
%#ifdef windows
%
%  To flush output to the console, see \code{\link{flush.console}}.
%#endif
%}
%
%\examples{
%zz <- file("ex.data", "w")  # open an output file connection
%cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
%cat("One more line\n", file = zz)
%close(zz)
%readLines("ex.data")
%unlink("ex.data")
%
%zz <- gzfile("ex.gz", "w")  # compressed file
%cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
%close(zz)
%readLines(zz <- gzfile("ex.gz"))
%close(zz)
%unlink("ex.gz")
%
%zz <- bzfile("ex.bz2", "w")  # bzip2-ed file
%cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
%close(zz)
%print(readLines(zz <- bzfile("ex.bz2")))
%close(zz)
%unlink("ex.bz2")
%
%## An example of a file open for reading and writing
%Tfile <- file("test1", "w+")
%c(isOpen(Tfile, "r"), isOpen(Tfile, "w")) # both TRUE
%cat("abc\ndef\n", file = Tfile)
%readLines(Tfile)
%seek(Tfile, 0, rw = "r") # reset to beginning
%readLines(Tfile)
%cat("ghi\n", file = Tfile)
%readLines(Tfile)
%close(Tfile)
%unlink("test1")
%
%## We can do the same thing with an anonymous file.
%Tfile <- file()
%cat("abc\ndef\n", file = Tfile)
%readLines(Tfile)
%close(Tfile)
%
%\dontrun{## fifo example -- may hang even with OS support for fifos
%if(capabilities("fifo")) {
%  zz <- fifo("foo-fifo", "w+")
%  writeLines("abc", zz)
%  print(readLines(zz))
%  close(zz)
%  unlink("foo-fifo")
%}}
%#ifdef unix
%\donttest{
%## Unix examples of use of pipes
%
%# read listing of current directory
%readLines(pipe("ls -1"))
%
%# remove trailing commas.  Suppose
%\dontshow{
%writeLines(c("450, 390, 467, 654,  30, 542, 334, 432, 421,",
%"357, 497, 493, 550, 549, 467, 575, 578, 342,",
%"446, 547, 534, 495, 979, 479"), "data2_")}
%\dontrun{\% cat data2_
%450, 390, 467, 654,  30, 542, 334, 432, 421,
%357, 497, 493, 550, 549, 467, 575, 578, 342,
%446, 547, 534, 495, 979, 479}
%# Then read this by
%scan(pipe("sed -e s/,$// data2_"), sep = ",")
%\dontshow{unlink("data2_")}
%
%# convert decimal point to comma in output: see also write.table
%# both R strings and (probably) the shell need \ doubled
%zz <- pipe(paste("sed s/\\\\\\\\./,/ >", "outfile"), "w")
%cat(format(round(stats::rnorm(48), 4)), fill = 70, file = zz)
%close(zz)
%file.show("outfile", delete.file = TRUE)
%}
%\dontrun{
%## example for a machine running a finger daemon
%
%con <- socketConnection(port = 79, blocking = TRUE)
%writeLines(paste0(system("whoami", intern = TRUE), "\r"), con)
%gsub(" *$", "", readLines(con))
%close(con)
%}
%#endif
%
%\dontrun{
%## Two R processes communicating via non-blocking sockets
%# R process 1
%con1 <- socketConnection(port = 6011, server = TRUE)
%writeLines(LETTERS, con1)
%close(con1)
%
%# R process 2
%con2 <- socketConnection(Sys.info()["nodename"], port = 6011)
%# as non-blocking, may need to loop for input
%readLines(con2)
%while(isIncomplete(con2)) {
%   Sys.sleep(1)
%   z <- readLines(con2)
%   if(length(z)) print(z)
%}
%close(con2)
%
%## examples of use of encodings
%# write a file in UTF-8
%cat(x, file = (con <- file("foo", "w", encoding = "UTF-8"))); close(con)
%# read a 'Windows Unicode' file
%A <- read.table(con <- file("students", encoding = "UCS-2LE")); close(con)
%}}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
