% File src/library/base/man/data.frame.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{data.frame}
\title{Data Frames}
\alias{data.frame}
\alias{default.stringsAsFactors}
\description{
  この関数はデータフレームを作る．これは行列とリストの多く性質を共有する
  緊密に組み合わされた変数の集まりで，殆どの \R のモデリングソフトウェア
  により基本的なデータ構造として用いられている．
}
\usage{
data.frame(\dots, row.names = NULL, check.rows = FALSE,
           check.names = TRUE, fix.empty.names = TRUE,
           stringsAsFactors = default.stringsAsFactors())

default.stringsAsFactors()
}
\arguments{
  \item{\dots}{これらの引数は形式 \code{value} または
    \code{tag = value} を取る．成分名は(もしあれば)タグか
    逆構文解析された変数名自体から作られる．}
  \item{row.names}{\code{NULL}，一つの整数，行名として使われる
    列を指定する文字列，もしくはデーラフレームの行名を与える文字列
    又は整数ベクトル．}
  \item{check.rows}{もし \code{TRUE} なら，行は長さと名前が一貫しているか
    チェックされる．}
  \item{check.names}{論理値．もし \code{TRUE} ならばデータフレーム中の
    変数の名前は構文的に適正で重複していないことを保証するために検査される．
    もし必要ならそれらはそうなるように補正される
    (\code{\link{make.names}} を使い)．}
  \item{fix.empty.names}{logical indicating if arguments which are
    \dQuote{unnamed} (in the sense of not being formally called as
    \code{someName = arg}) get an automatically constructed name or
    rather name \code{""}.  Needs to be set to \code{FALSE} even when
    \code{check.names} is false if \code{""} names should be kept.}
  \item{stringsAsFactors}{論理値：文字列ベクトルは因子に変換されるべきか? 
    \sQuote{工場出荷}既定値は \code{TRUE} であるが，しかし
    これは設定 \code{\link{options}(stringsAsFactors = FALSE)} で
    変更できる．}
}
\value{
  データフレームはその列が異なった型(数値，論理値，因子そして文字列)
  であり得る行列風の構造である．

  データフレームの名前がどのように構成されるかは簡単ではなく，
  この節の残りは基本的な話のみである．
  もし引数が全て名前を持ち単純なオブジェクト(リスト，データフレームの行列で無い)
  でなければ引数の名前が列の名前になる．
  名前のない単純なオブジェクトに対しては引数を逆構文解析版が
  名前として使われる(囲み \code{I(...)} は取り除かれる)．
  名前付きの行列/リスト/データフレーム引数が二つ以上の名前付き引数を持てば，
  列の名前は引数の名前にドットと引数内の列名が続く：
  もし引数が名前無しなら引数の列名が使われる．
  名前付きか無しの行列/リスト/データフレーム引数が単一の列を含めば，
  結果の列名は引数中の列名になる．最後に \code{check.names = FALSE}
  でない限り，名前は重複がなく構文的に正当であるように補正される．
}

\details{
  データフレームはユニークな行名と同じ列数の変数のリストで
  クラス \code{"data.frame"} を持つ．もし変数が皆無なら行名が
  行数を決める．

  列名は空であってはならず，空の名前を使えば未サポートの結果が
  生じる．重複した列名は許されるが，
  そうしたデータフレームを生成するには
  \code{data.frame} に対して \code{check.names = FALSE} を使う
  必要がある．しかしながらすべてのデータフレームへの操作が
  重複した列名を保つとは限らない：例えば行列風の部分操作は
  結果中の列名がユニークであることを強制する．

  \code{data.frame} は \code{\link{as.data.frame}(optional = TRUE)} を呼び出し，
  その変数の各々を一つのデータフレームに変換する．
  これは総称的関数であるから，引数をそれらのクラスに応じて変更するメソッドを
  書くことが出来る：\R はそうしたメソッドを多く持つ．
  \code{data.frame} に渡された文字列変数は \code{\link{I}} で
  保護されるか引数 \code{stringsAsFactors} が偽でない限り
  因子の列に変換される．もしリスト，データフレーム，行列が
  \code{data.frame} に渡されると，それらはその成分や列の各々が
  個別の引数として渡されたかのように振る舞う(クラス \code{"\link{model.matrix}"}
  の行列と \code{\link{I}} で保護された物を除く)．

  \code{data.frame} に渡される引数は同じ数の列を持たなければならないが，
  原子的なベクトル(\code{\link{is.vector}} を見よ)，因子そして
  \code{\link{I}} で保護された文字列は必要なら何度でもリサイクル使用される
  (リスト引数の要素を含む)．

  もし列数が \code{data.frame} の引数として与えられなければ，
  列名は適切な名前を持つ最初の成分から取られる，
  例えば名前付きベクトル，列名を持つ行列やデータフレームである．
  (もしその成分がそれから零細クルされると，名前は警告と共に捨て去られる．)
  もし \code{row.names} が \code{NULL} として与えられるか適当な成分が
  見つからなければ，列名は1から始まる整数列とされる
  (そしてそうした列名は\sQuote{自動的}とされ，\code{\link{as.matrix}}
  で保護されない)．

  もし行名が長さ1として与えられデータフレームが単一の列を持てば，
  \code{row.names} は列名ではなく行名(名前もしくは数)を指定するとされる．

  名前は \code{\link{I}} で保護されないベクトル入力からは取り除かれる．

  \code{default.stringsAsFactors} はユーティリティで
  \code{\link{getOption}("stringsAsFactors")} を取り，結果が 
  \code{TRUE} 又は \code{FALSE} になる(もしくは値が \code{NULL} で
  なければエラーを生じる)．
}
\note{
  \R の 2.4.0 以前では \code{row.names} は文字列でなければならなかった；
  \code{row.names} 引数として文字列を与えるという
  そうした \R のバージョンとの一貫性を保つためである．
}
\references{
  Chambers, J. M. (1992)
  \emph{Data for models.}
  Chapter 3 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{I}}，
  \code{\link{plot.data.frame}}，
  \code{\link{print.data.frame}}，
  \code{\link{row.names}}, \code{\link{names}} (列名に対して)，
  部分抽出メソッドに対して \code{\link{[.data.frame}}，
  \code{data.frame} に対するグループメソッドは \code{\link{Math.data.frame}} 等，
  \code{\link{read.table}}，
  \code{\link{make.names}}．
}
\examples{
L3 <- LETTERS[1:3]
fac <- sample(L3, 10, replace = TRUE)
(d <- data.frame(x = 1, y = 1:10, fac = fac))
## 同じだが自動的な列名：
data.frame(1, 1:10, sample(L3, 10, replace = TRUE))

is.data.frame(d)

## I() を使い因子に変換しない：
(dd <- cbind(d, char = I(letters[1:10])))
rbind(class = sapply(dd, class), mode = sapply(dd, mode))

stopifnot(1:10 == row.names(d))  # {強制変換}

(d0  <- d[, FALSE])   # 0列，10行のデータフレーム
(d.0 <- d[FALSE, ])   # <0 行>データフレーム (3個の名前付き列)
(d00 <- d0[FALSE, ])  # 0列，0行のデータフレーム
}
\keyword{classes}
\keyword{methods}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/data.frame.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{data.frame}
%\title{Data Frames}
%\alias{data.frame}
%\alias{default.stringsAsFactors}
%\description{
%  This function creates data frames, tightly coupled
%  collections of variables which share many of the properties of
%  matrices and of lists, used as the fundamental data structure by most
%  of \R's modeling software.
%}
%\usage{
%data.frame(\dots, row.names = NULL, check.rows = FALSE,
%           check.names = TRUE,
%           stringsAsFactors = default.stringsAsFactors())
%
%default.stringsAsFactors()
%}
%\arguments{
%  \item{\dots}{these arguments are of either the form \code{value} or
%    \code{tag = value}.  Component names are created based on the tag (if
%    present) or the deparsed argument itself.}
%  \item{row.names}{\code{NULL} or a single integer or character string
%    specifying a column to be used as row names, or a character or
%    integer vector giving the row names for the data frame.}
%  \item{check.rows}{if \code{TRUE} then the rows are checked for
%    consistency of length and names.}
%  \item{check.names}{logical.  If \code{TRUE} then the names of the
%    variables in the data frame are checked to ensure that they are
%    syntactically valid variable names and are not duplicated.
%    If necessary they are adjusted (by \code{\link{make.names}})
%    so that they are.}
%  \item{stringsAsFactors}{logical: should character vectors be converted
%    to factors?  The \sQuote{factory-fresh} default is \code{TRUE}, but
%    this can be changed by setting \code{\link{options}(stringsAsFactors
%      = FALSE)}.}
%}
%\value{
%  A data frame, a matrix-like structure whose columns may be of
%  differing types (numeric, logical, factor and character and so on).
%
%  How the names of the data frame are created is complex, and the rest
%  of this paragraph is only the basic story.  If the arguments are all
%  named and simple objects (not lists, matrices of data frames) then the
%  argument names give the column names.  For an unnamed simple argument,
%  a deparsed version of the argument is used as the name (with an
%  enclosing \code{I(...)} removed).  For a named matrix/list/data frame
%  argument with more than one named column, the names of the columns are
%  the name of the argument followed by a dot and the column name inside
%  the argument: if the argument is unnamed, the argument's column names
%  are used.  For a named or unnamed matrix/list/data frame argument that
%  contains a single column, the column name in the result is the column
%  name in the argument.  Finally, the names are adjusted to be unique
%  and syntactically valid unless \code{check.names = FALSE}.
%}
%
%\details{
%  A data frame is a list of variables of the same number of rows with
%  unique row names, given class \code{"data.frame"}.  If no variables
%  are included, the row names determine the number of rows.
%
%  The column names should be non-empty, and attempts to use empty names
%  will have unsupported results.  Duplicate column names are allowed,
%  but you need to use \code{check.names = FALSE} for \code{data.frame}
%  to generate such a data frame.  However, not all operations on data
%  frames will preserve duplicated column names: for example matrix-like
%  subsetting will force column names in the result to be unique.
%
%  \code{data.frame} converts each of its arguments to a data frame by
%  calling \code{\link{as.data.frame}(optional = TRUE)}.  As that is a
%  generic function, methods can be written to change the behaviour of
%  arguments according to their classes: \R comes with many such methods.
%  Character variables passed to \code{data.frame} are converted to
%  factor columns unless protected by \code{\link{I}} or argument
%  \code{stringsAsFactors} is false.  If a list or data
%  frame or matrix is passed to \code{data.frame} it is as if each
%  component or column had been passed as a separate argument (except for
%  matrices of class \code{"\link{model.matrix}"} and those protected by
%  \code{\link{I}}).
%
%  Objects passed to \code{data.frame} should have the same number of
%  rows, but atomic vectors (see \code{\link{is.vector}}), factors and
%  character vectors protected by \code{\link{I}} will be recycled a
%  whole number of times if necessary (including as elements of list
%  arguments).
%
%  If row names are not supplied in the call to \code{data.frame}, the
%  row names are taken from the first component that has suitable names,
%  for example a named vector or a matrix with rownames or a data frame.
%  (If that component is subsequently recycled, the names are discarded
%  with a warning.)  If \code{row.names} was supplied as \code{NULL} or no
%  suitable component was found the row names are the integer sequence
%  starting at one (and such row names are considered to be
%  \sQuote{automatic}, and not preserved by \code{\link{as.matrix}}).
%
%  If row names are supplied of length one and the data frame has a
%  single row, the \code{row.names} is taken to specify the row names and
%  not a column (by name or number).
%
%  Names are removed from vector inputs not protected by \code{\link{I}}.
%
%  \code{default.stringsAsFactors} is a utility that takes
%  \code{\link{getOption}("stringsAsFactors")} and ensures the result is
%  \code{TRUE} or \code{FALSE} (or throws an error if the value is not
%  \code{NULL}).
%}
%\note{
%  In versions of \R prior to 2.4.0 \code{row.names} had to be
%  character: to ensure compatibility with such versions of \R, supply
%  a character vector as the \code{row.names} argument.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Data for models.}
%  Chapter 3 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{I}},
%  \code{\link{plot.data.frame}},
%  \code{\link{print.data.frame}},
%  \code{\link{row.names}}, \code{\link{names}} (for the column names),
%  \code{\link{[.data.frame}} for subsetting methods,% ./Extract.data.frame.Rd
%  \code{\link{Math.data.frame}} etc, about
%  \emph{Group} methods for \code{data.frame}s;
%  \code{\link{read.table}},
%  \code{\link{make.names}}.
%}
%\examples{
%L3 <- LETTERS[1:3]
%fac <- sample(L3, 10, replace = TRUE)
%(d <- data.frame(x = 1, y = 1:10, fac = fac))
%## The "same" with automatic column names:
%data.frame(1, 1:10, sample(L3, 10, replace = TRUE))
%
%is.data.frame(d)
%
%## do not convert to factor, using I() :
%(dd <- cbind(d, char = I(letters[1:10])))
%rbind(class = sapply(dd, class), mode = sapply(dd, mode))
%
%stopifnot(1:10 == row.names(d))  # {coercion}
%
%(d0  <- d[, FALSE])   # data frame with 0 columns and 10 rows
%(d.0 <- d[FALSE, ])   # <0 rows> data frame  (3 named cols)
%(d00 <- d0[FALSE, ])  # data frame with 0 columns and 0 rows
%}
%\keyword{classes}
%\keyword{methods}
%
\encoding{UTF8}
