% File src/library/base/man/format.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Copyright 2003-2013 The R Foundation
% Distributed under GPL 2 or later

\name{format}
\alias{format}
\alias{format.AsIs}
\alias{format.data.frame}
\alias{format.default}
\alias{format.factor}
\description{
  \R オブジェクトを見栄えの良いプリントのために整形する．
}
\title{Encode in a Common Format}
\usage{
format(x, \dots)

\method{format}{default}(x, trim = FALSE, digits = NULL, nsmall = 0L,
       justify = c("left", "right", "centre", "none"),
       width = NULL, na.encode = TRUE, scientific = NA,
       big.mark   = "",   big.interval = 3L,
       small.mark = "", small.interval = 5L,
       decimal.mark = getOption("OutDec"),
       zero.print = NULL, drop0trailing = FALSE, \dots)

\method{format}{data.frame}(x, \dots, justify = "none")

\method{format}{factor}(x, \dots)

\method{format}{AsIs}(x, width = 12, \dots)
}
\arguments{
  \item{x}{任意の \R オブジェクト(概念的に)；典型的には数値．}

  \item{trim}{論理値；もし \code{FALSE} なら論理値，数値そして複素数値は
    同じ幅になるように右揃えされる：もし \code{TRUE} なら
    揃えるための先頭の空白は抑制される．}

  \item{digits}{数値と複素数値 \code{x} のためにどれだけの有効桁数を使うか．
    既定の \code{NULL} は \code{\link{getOption}("digits")} を使う．
    これは提案である；十分な10進桁数が(大きさで)最小の数値がこの有効桁数を持ち
    そしてまた \code{nsmall} を満たすように使われる．
    (複素数値に対する解釈は \code{\link{signif}} を見よ．)}

  \item{nsmall}{科学的記法でない書式で実数/複素数を整形する際に小数点の右側に
    置かれる数字の最小数．
    許される値は \code{0 <= nsmall <= 20}．}

  \item{justify}{\emph{文字列}ベクトルは左揃え(既定)，
    右揃い，中央化又はそのままにするかを指示する．短縮出来る．}

  \item{width}{\code{default} メソッド：\emph{最小の}欄幅か，
    制限無しには \code{NULL} か \code{0}．

    \code{AsIs} メソッド：非文字列オブジェクトに対する\emph{最大の}欄幅．
    \code{NULL} は既定の \code{12} に対応する．
  }

  \item{na.encode}{論理値：\code{NA} 文字列をエンコードするか?
    これは文字列ベクトルにだけ適用され，数値，複素数値には適用され無いことを注意しよう．
    論理 \code{NA} にも適用されず，これは常に \code{"NA"} とエンコードされる．}
  % because Mr Gorjanc won't read, PR#12318

  \item{scientific}{数値や複素数値ベクトルの要素を科学的表記にエンコードすべきか
    どうかを指定する論理値．もしくは
    整数値ペナルティ(\code{\link{options}("scipen")} を見よ)．
    欠損値は現在の既定のペナルティに対応する．}

  \item{\dots}{他のメソッドから・へ渡される追加引数．}

  \item{big.mark, big.interval, small.mark}{%
    (長めの)数値と複素数値系列を見やすくするために使われる．
    \code{\link{prettyNum}} に渡される：そのヘルプ頁が詳細を説明する．}

  \item{small.interval, decimal.mark, zero.print,
    drop0trailing}{%
    同上．}
}
\details{
  \code{format} は総称的な関数である．ここで解説されるメソッドの他に
  日付(\code{\link{format.Date}} を見よ)，
  日付-時刻(\code{\link{format.POSIXct}} を見よ)，そして
  \code{format.octmode} や \code{format.dist} に
  対するメソッドがある．

  \code{format.data.frame} は \code{format} の適当なメソッドを各列に適用し
  データフレームを列ごとに整形する．
  列に対するメソッドはしばしば \code{as.character} に類似するがより多くの
  コントロールを提供する．
  行列とデータフレームは結果中の別個の列に変換され，文字列の列は(普通すべて)
  クラス \code{"\link{AsIs}"} を与えられる．

  \code{format.factor} は因子を文字列ベクトルに変換し，それから
  既定メソッドを呼び出す(従って \code{justify} が適用される)．

  \code{format.AsIs} はデータフレームから取り出された複雑なオブジェクトの列を処理する．
  文字列オブジェクトは既定メソッドに渡される(従って \code{width} は適用されない)．
  さもなければそれはオブジェクトを文字列に変換するために \code{\link{toString}} を
  呼び出し(ベクトル化リストなら要素毎に)そしてそれから結果を右端でジャスティファイする．

  文字列ベクトルに対する左右揃え(そしてそれらのメソッドで文字列に
  変換されたもの)はディスプレイ幅に関してなされ(\code{\link{nchar}} を見よ)，
  倍長文字や特殊文字の翻訳(エスケープ列として，バックスラッシュのエスケープかを含むが
  二重引用化は含まない：\code{\link{print.default}} を見よ)を考慮する．
  従って幅は \code{print(quote = FALSE)} による表示であり，
  \code{\link{cat}} による表示ではない．文字列は
  最も幅広の幅を表示するため空白で埋められる．
  (もし \code{na.encode = FALSE} なら，欠損文字列は幅の計算に含められず，
  エンコードされない．)

  数値ベクトルは少なくとも \code{digits} の有効桁数ですべての要素を表示するのに
  必要な最小の10進桁数でエンコードされる．
  しかしながら，もしそうするとすべての要素が末尾にゼロを持つならば，
  10進桁数は \code{nsmall} に届くか少なくともひとつの要素がゼロでない最終桁
  を持つまで縮小される；また上の
  \code{big.*}, \code{small.*} 等の引数に対するドキュメントを見よ．
  \code{digits >= 16} に関する \code{\link{print.default}} 中の注意を見よ．

  バイトベクトルは \code{\link{as.character}} によりそれらの2桁の16進数
  表現に変換される．

  内部コードは\sQuote{小数点}に対するオプション \code{\link{getOption}("OutDec")}
  を尊重するので，もしこれが \code{"."} 以外の何かに設定されていれば
  引数 \code{decimal.mark} より優先される．
}
\value{
  \code{x} に類似の構造のオブジェクトで，\code{x} の最初の引数の要素の共通の書式で
  現在のエンコーディングによる文字列表現を含む．

  文字列，数値，複素数値又は因子の \code{x} に対しては，
  行列/配列については次元と次元名が，ベクトルについては名前が保存される：
  他の属性はコピーされない．

  もし \code{x} がリストならば，結果はリストの各要素に \code{format.default(x, \dots)} を
  適用して
  (それ自体リストである要素は \code{\link{unlist}} してから)，
  それから各要素に対する結果を折りたたんでために
  \code{paste(collapse = ", ")} を使って得られる文字列ベクトルである．
  普通折りたたんだ文字列の整列は要求されないので，この場合の既定動作は
  \code{trim = TRUE, justify = "none"} である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}

\seealso{
  \code{\link{format.info}} は原子的ベクトルをどのように整形するかを指示する．

  \code{\link{formatC}}, \code{\link{paste}}, \code{\link{as.character}},
  \code{\link{sprintf}}, \code{\link{print}}, \code{\link{prettyNum}},
  \code{\link{toString}}, \code{\link{encodeString}}.
}
\examples{
format(1:10)
format(1:10, trim = TRUE)

zz <- data.frame("(row names)"= c("aaaaa", "b"), check.names = FALSE)
format(zz)
format(zz, justify = "left")

## nsmall の使用
format(13.7)
format(13.7, nsmall = 3)
format(c(6.0, 13.1), digits = 2)
format(c(6.0, 13.1), digits = 2, nsmall = 1)

## 科学的記法の使用
format(2^31-1)
format(2^31-1, scientific = TRUE)

## リスト
z <- list(a = letters[1:3], b = (-pi+0i)^((-2:2)/2), c = c(1,10,100,1000),
          d = c("a", "longer", "character", "string"),
          q = quote( a + b ), e = expression(1+x))
## "2" つの小さな違いが分かるだろうか?
(f1 <- format(z, digits = 2))
(f2 <- format(z, digits = 2, justify = "left", trim = FALSE))
f1 == f2 ## 2 FALSE, 4 TRUE
}
\keyword{character}
\keyword{print}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/format.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Copyright 2003-2013 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{format}
%\alias{format}
%\alias{format.AsIs}
%\alias{format.data.frame}
%\alias{format.default}
%\alias{format.factor}
%\description{
%  Format an \R object for pretty printing.
%}
%\title{Encode in a Common Format}
%\usage{
%format(x, \dots)
%
%\method{format}{default}(x, trim = FALSE, digits = NULL, nsmall = 0L,
%       justify = c("left", "right", "centre", "none"),
%       width = NULL, na.encode = TRUE, scientific = NA,
%       big.mark   = "",   big.interval = 3L,
%       small.mark = "", small.interval = 5L,
%       decimal.mark = getOption("OutDec"),
%       zero.print = NULL, drop0trailing = FALSE, \dots)
%
%\method{format}{data.frame}(x, \dots, justify = "none")
%
%\method{format}{factor}(x, \dots)
%
%\method{format}{AsIs}(x, width = 12, \dots)
%}
%\arguments{
%  \item{x}{any \R object (conceptually); typically numeric.}
%
%  \item{trim}{logical; if \code{FALSE}, logical, numeric and complex
%    values are right-justified to a common width: if \code{TRUE} the
%    leading blanks for justification are suppressed.}
%
%  \item{digits}{how many significant digits are to be used for
%    numeric and complex \code{x}.  The default, \code{NULL}, uses
%    \code{\link{getOption}("digits")}.  This is a suggestion: enough decimal
%    places will be used so that the smallest (in magnitude) number has
%    this many significant digits, and also to satisfy \code{nsmall}.
%    (For the interpretation for complex numbers see \code{\link{signif}}.)}
%
%  \item{nsmall}{the minimum number of digits to the right of the decimal
%    point in formatting real/complex numbers in non-scientific formats.
%    Allowed values are \code{0 <= nsmall <= 20}.}
%
%  \item{justify}{should a \emph{character} vector be left-justified (the
%    default), right-justified, centred or left alone.  Can be abbreviated.}
%
%  \item{width}{\code{default} method: the \emph{minimum} field width or
%    \code{NULL} or \code{0} for no restriction.
%
%    \code{AsIs} method: the \emph{maximum} field width for non-character
%    objects.  \code{NULL} corresponds to the default \code{12}.
%  }
%
%  \item{na.encode}{logical: should \code{NA} strings be encoded?  Note
%    this only applies to elements of character vectors, not to numerical,
%    complex nor logical \code{NA}s, which are always encoded as \code{"NA"}.}
%  % because Mr Gorjanc won't read, PR#12318
%
%  \item{scientific}{Either a logical specifying whether
%    elements of a real or complex vector should be encoded in scientific
%    format, or an integer penalty (see \code{\link{options}("scipen")}).
%    Missing values correspond to the current default penalty.}
%
%  \item{\dots}{further arguments passed to or from other methods.}
%
%  \item{big.mark, big.interval, small.mark,
%    small.interval, decimal.mark, zero.print, drop0trailing}{%
%    used for prettying (longish) numerical and complex sequences.
%    Passed to \code{\link{prettyNum}}: that help page explains the details.}
%}
%\details{
%  \code{format} is a generic function.  Apart from the methods described
%  here there are methods for dates (see \code{\link{format.Date}}),
%  date-times (see \code{\link{format.POSIXct}})) and for other classes such
%  as \code{format.octmode} and \code{format.dist}.
%
%  \code{format.data.frame} formats the data frame column by column,
%  applying the appropriate method of \code{format} for each column.
%  Methods for columns are often similar to \code{as.character} but offer
%  more control.  Matrix and data-frame columns will be converted to
%  separate columns in the result, and character columns (normally all)
%  will be given class \code{"\link{AsIs}"}.
%
%  \code{format.factor} converts the factor to a character vector and
%  then calls the default method (and so \code{justify} applies).
%
%  \code{format.AsIs} deals with columns of complicated objects that
%  have been extracted from a data frame.  Character objects are passed
%  to the default method (and so \code{width} does not apply).
%  Otherwise it calls \code{\link{toString}} to convert the object
%  to character (if a vector or list, element by element) and then
%  right-justifies the result.
%
%  Justification for character vectors (and objects converted to
%  character vectors by their methods) is done on display width (see
%  \code{\link{nchar}}), taking double-width characters and the rendering
%  of special characters (as escape sequences, including escaping
%  backslash but not double quote: see \code{\link{print.default}}) into
%  account.  Thus the width is as displayed by \code{print(quote =
%  FALSE)} and not as displayed by \code{\link{cat}}.  Character strings
%  are padded with blanks to the display width of the widest.  (If
%  \code{na.encode = FALSE} missing character strings are not included in
%  the width computations and are not encoded.)
%
%  Numeric vectors are encoded with the minimum number of decimal places
%  needed to display all the elements to at least the \code{digits}
%  significant digits.  However, if all the elements then have trailing
%  zeroes, the number of decimal places is reduced until
%  \code{nsmall} is reached or at least one
%  element has a non-zero final digit; see also the argument
%  documentation for \code{big.*}, \code{small.*} etc, above.  See the
%  note in \code{\link{print.default}} about \code{digits >= 16}.
%
%  Raw vectors are converted to their 2-digit hexadecimal representation
%  by \code{\link{as.character}}.
%
%  The internal code respects the option
%  \code{\link{getOption}("OutDec")} for the \sQuote{decimal mark}, so if
%  this is set to something other than \code{"."} then it takes precedence
%  over argument \code{decimal.mark}.
%}
%\value{
%  An object of similar structure to \code{x} containing character
%  representations of the elements of the first argument \code{x}
%  in a common format, and in the current locale's encoding.
%
%  For character, numeric, complex or factor \code{x}, dims and dimnames
%  are preserved on matrices/arrays and names on vectors: no other
%  attributes are copied.
%
%  If \code{x} is a list, the result is a character vector obtained by
%  applying \code{format.default(x, \dots)} to each element of the list
%  (after \code{\link{unlist}}ing elements which are themselves lists),
%  and then collapsing the result for each element with
%  \code{paste(collapse = ", ")}.  The defaults in this case are
%  \code{trim = TRUE, justify = "none"} since one does not usually want
%  alignment in the collapsed strings.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%
%\seealso{
%  \code{\link{format.info}} indicates how an atomic vector would be
%  formatted.
%
%  \code{\link{formatC}}, \code{\link{paste}}, \code{\link{as.character}},
%  \code{\link{sprintf}}, \code{\link{print}}, \code{\link{prettyNum}},
%  \code{\link{toString}}, \code{\link{encodeString}}.
%}
%\examples{
%format(1:10)
%format(1:10, trim = TRUE)
%
%zz <- data.frame("(row names)"= c("aaaaa", "b"), check.names = FALSE)
%format(zz)
%format(zz, justify = "left")
%
%## use of nsmall
%format(13.7)
%format(13.7, nsmall = 3)
%format(c(6.0, 13.1), digits = 2)
%format(c(6.0, 13.1), digits = 2, nsmall = 1)
%
%## use of scientific
%format(2^31-1)
%format(2^31-1, scientific = TRUE)
%
%## a list
%z <- list(a = letters[1:3], b = (-pi+0i)^((-2:2)/2), c = c(1,10,100,1000),
%          d = c("a", "longer", "character", "string"),
%          q = quote( a + b ), e = expression(1+x))
%## can you find the "2" small differences?
%(f1 <- format(z, digits = 2))
%(f2 <- format(z, digits = 2, justify = "left", trim = FALSE))
%f1 == f2 ## 2 FALSE, 4 TRUE
%}
%\keyword{character}
%\keyword{print}
%
\encoding{UTF8}
