% File src/library/base/man/gc.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{gc}
\title{Garbage Collection}
\usage{
gc(verbose = getOption("verbose"), reset = FALSE)
gcinfo(verbose)
}
\alias{gc}
\alias{gcinfo}
\arguments{
  \item{verbose}{論理値；もし \code{TRUE} ならガベージコレクションは cons cell と
     ベクトルに割り当てられたスペースについての統計をプリントする．}
  \item{reset}{論理値：もし \code{TRUE} なら使用される最大スペースは現在の値に
    リセットされる．}
}
\description{
  \code{gc} の呼び出しはガベージコレクションを惹き起こす．
  \code{gcinfo} は自動的なガベージコレクションが無言で行われる
  (\code{verbose = FALSE})か，又は
  メモリ使用量の統計をプリントするか(\code{verbose = TRUE})を
  指定するフラグを設定する．
}
\details{
  \code{gc} の呼び出しはガベージコレクションを惹き起こす．
  これはまたユーザの関与なしに自動的に起こり，そして
  \code{gc} を呼び出す主要な目的はメモリ使用のレポートである．

  しかしながら大きなオブジェクトが消去された後に \code{gc} を呼び出すのは，
  \R にメモリを OS に返すことを促すので，
  有用になり得る．

  \R はベクトルのためのスペースを 8 バイトの倍数で確保する：
  従って \code{"Vcells"} も同様になる．これは初期のメモリ確保機構の名残である
  (ベクトルヒープを使っていた)．

  \code{gcinfo(TRUE)} が実施されると各ガベージコレクション毎に
  メッセージコネクションに次のような形式のメッセージが送られる
\preformatted{    Garbage collection 12 = 10+0+2 (level 0) ...
    6.4 Mbytes of cons cells used (58\%)
    2.0 Mbytes of vectors used (32\%)
}
  ここで最後の二行は現在のメモリ使用量を 0.1Mb 単位で丸めたものと
  現在のトリガー値のパーセントで表したものである．
  最初の行は様々なレベルでのガベージコレクションの回数のブレークダウン
  を与える(説明についてはマニュアル \sQuote{R Internals} を見よ)．
}

\value{
  \code{gc} は行が \code{"Ncells"} (\emph{cons
    cells})，通常32ビットシステムでは各々 28 バイトで64ビットシステムでは 56 バイト，
    そして \code{"Vcells"} (\emph{ベクトルセル}，各々 8 バイト)，
    そして列が \code{"used"} と \code{"gc trigger"} で，
    各々がメガバイト単位(次の 0.1Mb に切り上げられる)，の
    行列を返す．

  もし \code{"Ncells"} か \code{"Vcells"} に最大値が設定されていれば，
  Mb で与えた現在の上限をプリントしている(限界がなければ \code{NA})．

  最後の二つの列は \code{gc(reset = TRUE)} (または \R の起動以来)の最後の
  呼び出し以来の使用最大スペースを示す．

  \code{gcinfo} は前のフラグの値を返す．
}
\seealso{
  マニュアル \sQuote{R Internals}．

  \R のメモリ管理は \code{\link{Memory}}，
  そしてもしあなたが \R の開発者なら \code{\link{gctorture}}．

  ガベージコレクション時に起こる行動については \code{\link{reg.finalizer}}．
}
\examples{\donttest{
gc() #- 今実行
gcinfo(TRUE) #-- 将来，いつRがそれを実行するかを示す
x <- integer(100000); for(i in 1:18) x <- c(x, i)
gcinfo(verbose = FALSE) #-- 二度とそれを見せない

gc(TRUE)

gc(reset = TRUE)
}}
\keyword{environment}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/gc.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{gc}
%\title{Garbage Collection}
%\usage{
%gc(verbose = getOption("verbose"), reset = FALSE)
%gcinfo(verbose)
%}
%\alias{gc}
%\alias{gcinfo}
%\arguments{
%  \item{verbose}{logical; if \code{TRUE}, the garbage collection prints
%    statistics about cons cells and the space allocated for vectors.}
%  \item{reset}{logical; if \code{TRUE} the values for maximum space used
%    are reset to the current values.}
%}
%\description{
%  A call of \code{gc} causes a garbage collection to take place.
%  \code{gcinfo} sets a flag so that
%  automatic collection is either silent (\code{verbose = FALSE}) or
%  prints memory usage statistics (\code{verbose = TRUE}).
%}
%\details{
%  A call of \code{gc} causes a garbage collection to take place.
%  This will also take place automatically without user intervention, and the
%  primary purpose of calling \code{gc} is for the report on memory usage.
%
%  However, it can be useful to call \code{gc} after a large object
%  has been removed, as this may prompt \R to return memory to the
%  operating system.
%
%  \R allocates space for vectors in multiples of 8 bytes: hence the
%  report of \code{"Vcells"}, a relict of an earlier allocator (that used
%  a vector heap).
%
%  When \code{gcinfo(TRUE)} is in force, messages are sent to the message
%  connection at each garbage collection of the form
%\preformatted{    Garbage collection 12 = 10+0+2 (level 0) ...
%    6.4 Mbytes of cons cells used (58\%)
%    2.0 Mbytes of vectors used (32\%)
%}
%  Here the last two lines give the current memory usage rounded up to
%  the next 0.1Mb and as a percentage of the current trigger value.
%  The first line gives a breakdown of the number of garbage collections
%  at various levels (for an explanation see the \sQuote{R Internals} manual).
%}
%
%\value{
%  \code{gc} returns a matrix with rows \code{"Ncells"} (\emph{cons
%    cells}), usually 28 bytes each on 32-bit systems and 56 bytes on
%  64-bit systems, and \code{"Vcells"} (\emph{vector cells}, 8 bytes
%  each), and columns \code{"used"} and \code{"gc trigger"},
%  each also interpreted in megabytes (rounded up to the next 0.1Mb).
%
%  If maxima have been set for either \code{"Ncells"} or \code{"Vcells"},
%  a fifth column is printed giving the current limits in Mb (with
%  \code{NA} denoting no limit).
%
%  The final two columns show the maximum space used since the last call
%  to \code{gc(reset = TRUE)} (or since \R started).
%
%  \code{gcinfo} returns the previous value of the flag.
%}
%\seealso{
%  The \sQuote{R Internals} manual.
%
%  \code{\link{Memory}} on \R's memory management,
%  and \code{\link{gctorture}} if you are an \R developer.
%
%  \code{\link{reg.finalizer}} for actions to happen at garbage
%  collection.
%}
%\examples{\donttest{
%gc() #- do it now
%gcinfo(TRUE) #-- in the future, show when R does it
%x <- integer(100000); for(i in 1:18) x <- c(x, i)
%gcinfo(verbose = FALSE) #-- don't show it anymore
%
%gc(TRUE)
%
%gc(reset = TRUE)
%}}
%\keyword{environment}
%
\encoding{UTF8}
