% File src/library/base/man/grep.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{grep}
\title{Pattern Matching and Replacement}
\alias{grep}
\alias{grepl}
\alias{sub}
\alias{gsub}
\alias{regexpr}
\alias{gregexpr}
\alias{regexec}
\description{
  \code{grep}, \code{grepl}, \code{regexpr}, \code{gregexpr} そして
  \code{regexec} は引数 \code{pattern} にマッチするものを文字列ベクトル
  中の各要素中で探す：これらは結果中の書式と説明の量で異なる．

  \code{sub} と \code{gsub} はそれぞれ最初とすべてのマッチしたものを置き換える．
}
\usage{
grep(pattern, x, ignore.case = FALSE, perl = FALSE, value = FALSE,
     fixed = FALSE, useBytes = FALSE, invert = FALSE)

grepl(pattern, x, ignore.case = FALSE, perl = FALSE,
      fixed = FALSE, useBytes = FALSE)

sub(pattern, replacement, x, ignore.case = FALSE, perl = FALSE,
    fixed = FALSE, useBytes = FALSE)

gsub(pattern, replacement, x, ignore.case = FALSE, perl = FALSE,
     fixed = FALSE, useBytes = FALSE)

regexpr(pattern, text, ignore.case = FALSE, perl = FALSE,
        fixed = FALSE, useBytes = FALSE)

gregexpr(pattern, text, ignore.case = FALSE, perl = FALSE,
         fixed = FALSE, useBytes = FALSE)

regexec(pattern, text, ignore.case = FALSE, perl = FALSE,
        fixed = FALSE, useBytes = FALSE)
}
\arguments{
  \item{pattern}{与えられた文字列ベクトル中でマッチされるべき
    正規表現を含む文字列(または \code{fixed = TRUE} に対しては文字列)．
    可能ならば \code{\link{as.character}} で文字列に変換される．
    もし長さ2もしくはそれ以上の文字列ベクトルが与えられると最初の文字列が
    警告と共に使われる．\code{regexpr} と \code{gregexpr} を除いて欠損値
    が許される．}
  \item{x, text}{マッチが探される文字列ベクトル，又は
    \code{as.character} で文字列ベクトルに変換できるオブジェクト．
    \link{long vectors} がサポートされている．}
  \item{ignore.case}{もし \code{FALSE} ならパターンマッチングは
      大・小文字を区別する．またもし \code{TRUE} ならばマッチングの
      間大・小文字は区別されない．}
  \item{perl}{論理値．Perl n互換の正規表現を使うか?}
  \item{value}{もし \code{FALSE} なら \code{grep} で決定されたマッチの
    整数添字を含むベクトルが返される．またもし \code{TRUE} ならば
    マッチした要素自体を含むベクトルが返される．}
  \item{fixed}{論理値．もし \code{TRUE} なら \code{pattern} は
    そのままでマッチされる文字列．矛盾するすべての引数は無視される．}
  \item{useBytes}{論理値．もし \code{TRUE} ならばマッチングは文字ごとではなく
    バイトごとに行われる．\sQuote{詳細}を見よ．}
  \item{invert}{論理値．もし \code{TRUE} ならマッチしない要素に対し添え字か
    値を返す．}
  \item{replacement}{\code{sub} と \code{gsub} 中でマッチしたパターンに対する
    置き換え．もし可能ならば文字列に変換される． \code{fixed = FALSE} に
    対してはこれは \code{pattern} の括弧で囲まれた副表現に対する
    バック参照 \code{"\\1"} から \code{"\\9"} を含むことが出来る．
    \code{perl = TRUE} に対してだけは，これはまた置き換えの残りを
    大文字もしくは小文字に変える \code{"\\U"} か \code{"\\L"}，そして
    end case への変換である \code{"\\E"} を含むことが出来る．
    もし2もしくはそれ以上の長さの文字列ベクトルが与えられると，最初の要素が使われ
    警告が出る．もし \code{NA} ならマッチに対応する結果中のすべての
    要素は \code{NA} に設定される．
  }
}
\details{
  文字列や文字列ベクトルであるべき引数はもし可能なら文字列に変換される．

  これらの関数の各々(現在 Perl スタイルの正規表現をサポートしない \code{regexec} を
  除く)は三つのモードのどれかで操作を行う：
  \enumerate{
    \item \code{fixed = TRUE}: 正確なマッチングを使う．
    \item \code{perl = TRUE}: Perl スタイルの正規表現．
    \item \code{fixed = FALSE, perl = FALSE}: POSIX 1003.2 
    拡張正規表現を使う．
  }
  異なったタイプの正規表現に関する詳細は \link{regular expression} に
  関するヘルプ頁を見よ．

  二つの \code{*sub} 関数は \code{sub} が \code{pattern} が最初に
  起きた時に置き換え，\code{gsub} がすべてを置き換える点で異なる．
  もし \code{replacement} が \code{pattern} 中に定義されていないバック参照
  を含めば，結果は未定義である(しかし最も普通にはバック参照は
  \code{""} とされる)．

  \code{regexpr}, \code{gregexpr} そして \code{regexec} に対しては
  \code{pattern} が \code{NA} になるのはエラーになる．
  さもなければ \code{NA} が許され \code{NA} マッチを与える．

  \code{useBytes} の主要効果は不正な入力と多バイトロケールに於ける
  偽りのマッチに関してエラー/警告を避けることであるが，
  \code{regexpr} に対してはそれは出力の解釈を変更する．
  それはマーク付きのエンコーディングを持つ入力の変換を禁止し，
  もし \code{"bytes"} とマークされた何らかの入力があれば強制される

  多バイトロケールでの大・小文字の区別なしのマッチングはあまり意味を持たず，
  \code{useBytes = TRUE} ならばアスキー文字に対してだけ動作することを
  期待すべきである．

  \code{perl = TRUE} での \code{regexpr} と \code{gregexpr} は
  Python 風の名前付きキャプチャーを許すが，
  \emph{long vector} 入力に対してはそうではない．
    
  現在のロケールでの不正な入力は最大5回まで警告される．
  
  非アスキー文字に対する大・小文字の区別なしの \code{PERL = TRUE} を使った
  マッチングは PCRE ライブラリが \sQuote{Unicode property support} 付きで
  コンパイルされていることに依存する：外部ライブラリはされていないかもしれない．
}

\value{
  (\code{invert = TRUE} を除き) \code{grep(value = FALSE)} は
  マッチがあった \code{x} の要素の添字の
  ベクトルを返す
  これは入力が\emph{ロングベクトル}でなければ整数ベクトルになり，
  さもなければ倍精度実数ベクトルになる．

  \code{grep(value = TRUE)} は \code{x} の選択された要素を含む文字列
  ベクトルを返す(強制変換され，名前は保存するが他の属性は保存しない)．

  \code{grepl} は論理値ベクトルを返す(\code{x} の各要素にマッチしたか
  否かを指示する)．

  \code{sub} と \code{gsub} に対しては，\code{x} と同じ長さと属性を持つ
  文字列ベクトルを返す(可能性として文字列への変換後)．
  取り替えられなかった文字列ベクトル \code{x} の要素は
  そのまま返される(任意の宣言されたエンコーディングを含む)．
  もし \code{useBytes = FALSE} なら非アスキーの取り替えられた結果は
  しばしばマーク付きエンコーディングを持つ UTF-8 で表現されている
  (つまり \code{fixed = TRUE} で無い限り，もし UTF-8 の入力がありそして
  多バイトロケール中ならば).
  そうした文字列は \code{\link{enc2native}} で再エンコーディングすることが出来る．

  \code{regexpr} は \code{text} と同じ長さの整数ベクトルを返し，
  最初のマッチ箇所かもしそれがなければ \eqn{-1} を与え，属性 \code{"match.length"}
  を持つ．
  マッチする位置と長さは \code{useBytes = TRUE} ならば文字数単位で，
  さもなければバイト数単位である．もし名前付きキャプチャーが使われれば
  更に属性 \code{"capture.start"},
  \code{"capture.length"} そして \code{"capture.names"} が付く．

  \code{gregexpr} は \code{text} と同じ長さのリストを返す．
  その各要素は \code{regexpr} に対する返り値と同じ形式であるが，
  すべての(排反な)マッチの開始位置が与えられる．

  \code{regexec} は \code{x} と同じ長さのリストを返す．
  その各要素はマッチがなければ \eqn{-1} か，
  マッチした開始地点の整数列と，\code{pattern} のすべての括弧付きの副表現
  に対応する副文字列と，マッチの長さ(またはマッチしなければ \eqn{-1})
  のベクトルである属性 \code{"match.length"}を持つ．
%  \code{regexec} returns a list of the same length as \code{text} each
%  element of which is either \eqn{-1} if there is no match, or a
%  sequence of integers with the starting positions of the match and all
%  substrings corresponding to parenthesized subexpressions of
%  \code{pattern}, with attribute \code{"match.length"} a vector
%  giving the lengths of the matches (or \eqn{-1} for no match).
}

\section{警告}{
  \code{gsub} と \code{gregexpr} の POSIX 1003.2 モードは繰り返される単語境界
  では正しく動作しない(例えば \code{pattern = "\\b"})．
  そうしたマッチには \code{perl = TRUE} を使う．(しかし\sQuote{単語}の意味は
  システム依存であるため，それは非アスキー入力では
  期待されるようには動作しないかもしれない)．
}

\section{実行性能の検討}{
  非常に長い文字列を含む，大量の正規表現マッチングを行うのなら，
  使われるオプションを考慮したくなるであろう．
  一般に PCRE は既定の正規表現エンジンより速く，
  \code{fixed = TRUE} は更に速い(特に各パターンが数回だけマッチされる場合)．

  単バイトロケールとそのロケールで表現可能なマーク付き UTF-8 文字列を
  操作しているのなら，それらを先ずたった一つの UTF-8 文字列に変換すれば
  すべてのマッチングは Unicode で行われ，これは
  既定の POSIX 1003.2 モードに対しては約3倍の
  ペナルティを招く．

  もし \code{useBytes = TRUE} が使えるのならば，文字列はマッチングの前に
  チェックされず, 実際のマッチングは速くなる．
  しばしばバイトに基づくマッチングは，一つの文字は決して別の部分に
  マッチしないため，UTF-8 ロケールで十分である．
}

\source{
  POSIX スタイルの正規表現マッチングに対する C コードは年と共に変化してきている．
  \R 2.10.0 以来 Ville Laurikari の TRE ライブラリ
  (\url{http://laurikari.net/tre/}) が使われている．POSIX 標準は
  ，特に不正な正規表現と文字列範囲の照合の処理で，幾らかの解釈の余地を
  与えているため，結果は年と共に少し変わるであろう．

  Perl スタイルのマッチングには PCRE (\url{http://www.pcre.org}) が使われている．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole (\code{grep})
}

% the `aka' below is for ESS
\seealso{
  パターン指定の詳細は \link{regular expression}
  (\code{\link{regexp}} としても知られている)．

  \code{regexpr}, \code{gregexpr} そして \code{regexec} を使ってマッチした
  部分文字列の取り出しには \code{\link{regmatches}}．

  ワイルドカードを正規表現に転換するには \code{\link{glob2rx}}．

  近似マッチングには \code{\link{agrep}}．

  部分マッチには \code{\link{charmatch}}, \code{\link{pmatch}}，
  文字列全体へのマッチには \code{\link{match}}．

  文字変換には \code{\link{tolower}}, \code{\link{toupper}} そして \code{\link{chartr}}．

  \code{\link{apropos}} は正規表現を使いより多くの例を持つ．

  バイトベクトルのマッチングには \code{\link{grepRaw}}．
}
\examples{
grep("[a-z]", letters)

txt <- c("arm","foot","lefroo", "bafoobar")
if(length(i <- grep("foo", txt)))
   cat("'foo' appears at least once in\n\t", txt, "\n")
i # 2 と 4
txt[i]

## すべての 'a' か 'b' を倍にする；"\\" はエスケープ化の必要，つまり
## gsub("([ab])", "\\\\1_\\\\1_", "abc and ABC")

txt <- c("The", "licenses", "for", "most", "software", "are",
  "designed", "to", "take", "away", "your", "freedom",
  "to", "share", "and", "change", "it.",
   "", "By", "contrast,", "the", "GNU", "General", "Public", "License",
   "is", "intended", "to", "guarantee", "your", "freedom", "to",
   "share", "and", "change", "free", "software", "--",
   "to", "make", "sure", "the", "software", "is",
   "free", "for", "all", "its", "users")
( i <- grep("[gu]", txt) ) # 添字
stopifnot( txt[i] == grep("[gu]", txt, value = TRUE) )

## en_US 等のロケールではこれは以下のように B を含む
## 並べる順序は aAbBcCdEe ...
(ot <- sub("[b-e]",".", txt))
txt[ot != gsub("[b-e]",".", txt)]#- gsub は"大局的"な代入を行う

txt[gsub("g","#", txt) !=
    gsub("g","#", txt, ignore.case = TRUE)] # 単語 "G"

regexpr("en", txt)

gregexpr("e", txt)

## grepl() をフィルタリングに使う
## 引数名が "warn" にマッチする関数を返す：
findArgs <- function(env, pattern) {
  nms <- ls(envir = as.environment(env))
  nms <- nms[is.na(match(nms, c("F","T")))] # <-- 応急措置の "checking hack"
  aa <- sapply(nms, function(.) { o <- get(.)
               if(is.function(o)) names(formals(o)) })
  iw <- sapply(aa, function(a) any(grepl(pattern, a, ignore.case=TRUE)))
  aa[iw]
}
findArgs("package:base", "warn")

## 末尾の空白を刈り詰め
str <- "Now is the time      "
sub(" +$", "", str)  ## 空白だけ
## 何が '空白' かはロケールに依存
sub("[[:space:]]+$", "", str) ## 空白，POSIX スタイル
## PCRE が空白と見做すものはバージョン 8.34 で変更された：?regex を見よ
sub("\\\\s+$", "", str, perl = TRUE) ## PCRE スタイルの空白

## 大文字化
txt <- "a test of capitalizing"
gsub("(\\\\w)(\\\\w*)", "\\\\U\\\\1\\\\L\\\\2", txt, perl=TRUE)
gsub("\\\\b(\\\\w)",    "\\\\U\\\\1",       txt, perl=TRUE)

txt2 <- "useRs may fly into JFK or laGuardia"
gsub("(\\\\w)(\\\\w*)(\\\\w)", "\\\\U\\\\1\\\\E\\\\2\\\\U\\\\3", txt2, perl=TRUE)
 sub("(\\\\w)(\\\\w*)(\\\\w)", "\\\\U\\\\1\\\\E\\\\2\\\\U\\\\3", txt2, perl=TRUE)

## 名前付きの捕捉
notables <- c("  Ben Franklin and Jefferson Davis",
              "\tMillard Fillmore")
# 名前グループ 'first' と 'last'
name.rex <- "(?<first>[[:upper:]][[:lower:]]+) (?<last>[[:upper:]][[:lower:]]+)"
(parsed <- regexpr(name.rex, notables, perl = TRUE))
gregexpr(name.rex, notables, perl = TRUE)[[2]]
parse.one <- function(res, result) {
  m <- do.call(rbind, lapply(seq_along(res), function(i) {
    if(result[i] == -1) return("")
    st <- attr(result, "capture.start")[i, ]
    substring(res[i], st, st + attr(result, "capture.length")[i, ] - 1)
  }))
  colnames(m) <- attr(result, "capture.names")
  m
}
parse.one(notables, parsed)

## URL をその成分に分解．
## Example by LT (http://www.cs.uiowa.edu/~luke/R/regexp.html).
x <- "http://stat.umn.edu:80/xyz"
m <- regexec("^(([^:]+)://)?([^:/]+)(:([0-9]+))?(/.*)", x)
m
regmatches(x, m)
## 要素 3 はプロトコル，4 はホスト，6 はポート，そして 7 はパス．
## これを使って URL の部分を取り出す関数を作れる：
URL_parts <- function(x) {
    m <- regexec("^(([^:]+)://)?([^:/]+)(:([0-9]+))?(/.*)", x)
    parts <- do.call(rbind,
                     lapply(regmatches(x, m), `[`, c(3L, 4L, 6L, 7L)))
    colnames(parts) <- c("protocol","host","port","path")
    parts
}
URL_parts(x)

## まだ gregexec() は無いが，regexec() を gregexpr() 経由で得られた
## 再マッチに regexec() を実行することでエミュレート出来る．例えば：
pattern <- "([[:alpha:]]+)([[:digit:]]+)"
s <- "Test: A1 BC23 DEF456"
lapply(regmatches(s, gregexpr(pattern, s)), 
       function(e) regmatches(e, regexec(pattern, e)))
}
\keyword{character}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/grep.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grep}
%\title{Pattern Matching and Replacement}
%\alias{grep}
%\alias{grepl}
%\alias{sub}
%\alias{gsub}
%\alias{regexpr}
%\alias{gregexpr}
%\alias{regexec}
%\description{
%  \code{grep}, \code{grepl}, \code{regexpr}, \code{gregexpr} and
%  \code{regexec} search for matches to argument \code{pattern} within
%  each element of a character vector: they differ in the format of and
%  amount of detail in the results.
%
%  \code{sub} and \code{gsub} perform replacement of the first and all
%  matches respectively.
%}
%\usage{
%grep(pattern, x, ignore.case = FALSE, perl = FALSE, value = FALSE,
%     fixed = FALSE, useBytes = FALSE, invert = FALSE)
%
%grepl(pattern, x, ignore.case = FALSE, perl = FALSE,
%      fixed = FALSE, useBytes = FALSE)
%
%sub(pattern, replacement, x, ignore.case = FALSE, perl = FALSE,
%    fixed = FALSE, useBytes = FALSE)
%
%gsub(pattern, replacement, x, ignore.case = FALSE, perl = FALSE,
%     fixed = FALSE, useBytes = FALSE)
%
%regexpr(pattern, text, ignore.case = FALSE, perl = FALSE,
%        fixed = FALSE, useBytes = FALSE)
%
%gregexpr(pattern, text, ignore.case = FALSE, perl = FALSE,
%         fixed = FALSE, useBytes = FALSE)
%
%regexec(pattern, text, ignore.case = FALSE,
%        fixed = FALSE, useBytes = FALSE)
%}
%\arguments{
%  \item{pattern}{character string containing a \link{regular expression}
%    (or character string for \code{fixed = TRUE}) to be matched
%    in the given character vector.  Coerced by
%    \code{\link{as.character}} to a character string if possible.  If a
%    character vector of length 2 or more is supplied, the first element
%    is used with a warning.  Missing values are allowed except for
%    \code{regexpr} and \code{gregexpr}.}
%  \item{x, text}{a character vector where matches are sought, or an
%    object which can be coerced by \code{as.character} to a character
%    vector.  \link{Long vectors} are supported.}
%  \item{ignore.case}{if \code{FALSE}, the pattern matching is \emph{case
%      sensitive} and if \code{TRUE}, case is ignored during matching.}
%  \item{perl}{logical.  Should Perl-compatible regexps be used?}
%  \item{value}{if \code{FALSE}, a vector containing the (\code{integer})
%    indices of the matches determined by \code{grep} is returned, and if
%    \code{TRUE}, a vector containing the matching elements themselves is
%    returned.}
%  \item{fixed}{logical.  If \code{TRUE}, \code{pattern} is a string to be
%    matched as is.  Overrides all conflicting arguments.}
%  \item{useBytes}{logical.  If \code{TRUE} the matching is done
%    byte-by-byte rather than character-by-character.  See
%    \sQuote{Details}.}
%  \item{invert}{logical.  If \code{TRUE} return indices or values for
%    elements that do \emph{not} match.}
%  \item{replacement}{a replacement for matched pattern in \code{sub} and
%    \code{gsub}.  Coerced to character if possible.  For \code{fixed =
%      FALSE} this can include backreferences \code{"\\1"} to
%    \code{"\\9"} to parenthesized subexpressions of \code{pattern}.  For
%    \code{perl = TRUE} only, it can also contain \code{"\\U"} or
%    \code{"\\L"} to convert the rest of the replacement to upper or
%    lower case and \code{"\\E"} to end case conversion.  If a
%    character vector of length 2 or more is supplied, the first element
%    is used with a warning.  If \code{NA}, all elements in the result
%    corresponding to matches will be set to \code{NA}.
%  }
%}
%\details{
%  Arguments which should be character strings or character vectors are
%  coerced to character if possible.
%
%  Each of these functions (apart from \code{regexec}, which currently
%  does not support Perl-style regular expressions) operates in one of
%  three modes:
%  \enumerate{
%    \item \code{fixed = TRUE}: use exact matching.
%    \item \code{perl = TRUE}: use Perl-style regular expressions.
%    \item \code{fixed = FALSE, perl = FALSE}: use POSIX 1003.2
%    extended regular expressions.
%  }
%  See the help pages on \link{regular expression} for details of the
%  different types of regular expressions.
%
%  The two \code{*sub} functions differ only in that \code{sub} replaces
%  only the first occurrence of a \code{pattern} whereas \code{gsub}
%  replaces all occurrences.  If \code{replacement} contains
%  backreferences which are not defined in \code{pattern} the result is
%  undefined (but most often the backreference is taken to be \code{""}).
%
%  For \code{regexpr}, \code{gregexpr} and \code{regexec} it is an error
%  for \code{pattern} to be \code{NA}, otherwise \code{NA} is permitted
%  and gives an \code{NA} match.
%
%  The main effect of \code{useBytes} is to avoid errors/warnings about
%  invalid inputs and spurious matches in multibyte locales, but for
%  \code{regexpr} it changes the interpretation of the output.
%  It inhibits the conversion of inputs with marked encodings, and is
%  forced if any input is found which is marked as \code{"bytes"}
%  see \code{\link{Encoding}}).
%
%  Caseless matching does not make much sense for bytes in a multibyte
%  locale, and you should expect it only to work for ASCII characters if
%  \code{useBytes = TRUE}.
%
%  \code{regexpr} and \code{gregexpr} with \code{perl = TRUE} allow
%  Python-style named captures, but not for \emph{long vector} inputs.  
%    
%  Invalid inputs in the current locale are warned about up to 5 times.
%  
%  Caseless matching with \code{PERL = TRUE} for non-ASCII characters
%  depends on the PCRE library being compiled with \sQuote{Unicode
%  property support}: an external library might not be.
%}
%
%\value{
%  \code{grep(value = FALSE)} returns a vector of the indices
%  of the elements of \code{x} that yielded a match (or not, for
%  \code{invert = TRUE}.  This will be an integer vector unless the input
%  is a \emph{long vector}, when it will be a double vector.
%
%  \code{grep(value = TRUE)} returns a character vector containing the
%  selected elements of \code{x} (after coercion, preserving names but no
%  other attributes).
%
%  \code{grepl} returns a logical vector (match or not for each element of
%  \code{x}).
%
%  For \code{sub} and \code{gsub} return a character vector of the same
%  length and with the same attributes as \code{x} (after possible
%  coercion to character).  Elements of character vectors \code{x} which
%  are not substituted will be returned unchanged (including any declared
%  encoding).  If \code{useBytes = FALSE} a non-ASCII substituted result
%  will often be in UTF-8 with a marked encoding (e.g., if there is a
%  UTF-8 input, and in a multibyte locale unless \code{fixed = TRUE}).
%  Such strings can be re-encoded by \code{\link{enc2native}}.
%
%  \code{regexpr} returns an integer vector of the same length as
%  \code{text} giving the starting position of the first match or
%  \eqn{-1} if there is none, with attribute \code{"match.length"}, an
%  integer vector giving the length of the matched text (or \eqn{-1} for
%  no match).  The match positions and lengths are in characters unless
%  \code{useBytes = TRUE} is used, when they are in bytes.  If named
%  capture is used there are further attributes \code{"capture.start"},
%  \code{"capture.length"} and \code{"capture.names"}.
%
%  \code{gregexpr} returns a list of the same length as \code{text} each
%  element of which is of the same form as the return value for
%  \code{regexpr}, except that the starting positions of every (disjoint)
%  match are given.
%
%  \code{regexec} returns a list of the same length as \code{text} each
%  element of which is either \eqn{-1} if there is no match, or a
%  sequence of integers with the starting positions of the match and all
%  substrings corresponding to parenthesized subexpressions of
%  \code{pattern}, with attribute \code{"match.length"} a vector
%  giving the lengths of the matches (or \eqn{-1} for no match).
%}
%
%\section{Warning}{
%  POSIX 1003.2 mode of \code{gsub} and \code{gregexpr} does not
%  work correctly with repeated word-boundaries (e.g., \code{pattern =
%  "\\b"}).  Use \code{perl = TRUE} for such matches (but that may not
%  work as expected with non-ASCII inputs, as the meaning of
%  \sQuote{word} is system-dependent).
%}
%
%\section{Performance considerations}{
%  If you are doing a lot of regular expression matching, including on
%  very long strings, you will want to consider the options used.
%  Generally PCRE will be faster than the default regular expression
%  engine, and \code{fixed = TRUE} faster still (especially when each
%  pattern is matched only a few times).
%
%  If you are working in a single-byte locale and have marked UTF-8
%  strings that are representable in that locale, convert them first as
%  just one UTF-8 string will force all the matching to be done in
%  Unicode, which attracts a penalty of around \eqn{3\times{}}{3x} for
%  the default POSIX 1003.2 mode.
%
%  If you can make use of \code{useBytes = TRUE}, the strings will not be
%  checked before matching, and the actual matching will be faster.
%  Often byte-based matching suffices in a UTF-8 locale since byte
%  patterns of one character never match part of another.
%}
%
%\source{
%  The C code for POSIX-style regular expression matching has changed
%  over the years.  As from \R 2.10.0 the TRE library of Ville Laurikari
%  (\url{http://laurikari.net/tre/}) is used.  The POSIX standard does
%  give some room for interpretation, especially in the handling of
%  invalid regular expressions and the collation of character ranges, so
%  the results will have changed slightly over the years.
%
%  For Perl-style matching PCRE (\url{http://www.pcre.org}) is used.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole (\code{grep})
%}
%
%% the `aka' below is for ESS
%\seealso{
%  \link{regular expression} (aka \code{\link{regexp}}) for the details
%  of the pattern specification.
%
%  \code{\link{regmatches}} for extracting matched substrings based on
%  the results of \code{regexpr}, \code{gregexpr} and \code{regexec}.
%
%  \code{\link{glob2rx}} to turn wildcard matches into regular expressions.
%
%  \code{\link{agrep}} for approximate matching.
%
%  \code{\link{charmatch}}, \code{\link{pmatch}} for partial matching,
%  \code{\link{match}} for matching to whole strings.
%
%  \code{\link{tolower}}, \code{\link{toupper}} and \code{\link{chartr}}
%  for character translations.
%
%  \code{\link{apropos}} uses regexps and has more examples.
%
%  \code{\link{grepRaw}} for matching raw vectors.
%}
%\examples{
%grep("[a-z]", letters)
%
%txt <- c("arm","foot","lefroo", "bafoobar")
%if(length(i <- grep("foo", txt)))
%   cat("'foo' appears at least once in\n\t", txt, "\n")
%i # 2 and 4
%txt[i]
%
%## Double all 'a' or 'b's;  "\\" must be escaped, i.e., 'doubled'
%gsub("([ab])", "\\\\1_\\\\1_", "abc and ABC")
%
%txt <- c("The", "licenses", "for", "most", "software", "are",
%  "designed", "to", "take", "away", "your", "freedom",
%  "to", "share", "and", "change", "it.",
%   "", "By", "contrast,", "the", "GNU", "General", "Public", "License",
%   "is", "intended", "to", "guarantee", "your", "freedom", "to",
%   "share", "and", "change", "free", "software", "--",
%   "to", "make", "sure", "the", "software", "is",
%   "free", "for", "all", "its", "users")
%( i <- grep("[gu]", txt) ) # indices
%stopifnot( txt[i] == grep("[gu]", txt, value = TRUE) )
%
%## Note that in locales such as en_US this includes B as the
%## collation order is aAbBcCdEe ...
%(ot <- sub("[b-e]",".", txt))
%txt[ot != gsub("[b-e]",".", txt)]#- gsub does "global" substitution
%
%txt[gsub("g","#", txt) !=
%    gsub("g","#", txt, ignore.case = TRUE)] # the "G" words
%
%regexpr("en", txt)
%
%gregexpr("e", txt)
%
%## Using grepl() for filtering
%## Find functions with argument names matching "warn":
%findArgs <- function(env, pattern) {
%  nms <- ls(envir = as.environment(env))
%  nms <- nms[is.na(match(nms, c("F","T")))] # <-- work around "checking hack"
%  aa <- sapply(nms, function(.) { o <- get(.)
%               if(is.function(o)) names(formals(o)) })
%  iw <- sapply(aa, function(a) any(grepl(pattern, a, ignore.case=TRUE)))
%  aa[iw]
%}
%findArgs("package:base", "warn")
%
%## trim trailing white space
%str <- "Now is the time      "
%sub(" +$", "", str)  ## spaces only
%## what is considered 'white space' depends on the locale.
%sub("[[:space:]]+$", "", str) ## white space, POSIX-style
%## what PCRE considered white space changed in version 8.34: see ?regex
%sub("\\\\s+$", "", str, perl = TRUE) ## PCRE-style white space
%
%## capitalizing
%txt <- "a test of capitalizing"
%gsub("(\\\\w)(\\\\w*)", "\\\\U\\\\1\\\\L\\\\2", txt, perl=TRUE)
%gsub("\\\\b(\\\\w)",    "\\\\U\\\\1",       txt, perl=TRUE)
%
%txt2 <- "useRs may fly into JFK or laGuardia"
%gsub("(\\\\w)(\\\\w*)(\\\\w)", "\\\\U\\\\1\\\\E\\\\2\\\\U\\\\3", txt2, perl=TRUE)
% sub("(\\\\w)(\\\\w*)(\\\\w)", "\\\\U\\\\1\\\\E\\\\2\\\\U\\\\3", txt2, perl=TRUE)
%
%## named capture
%notables <- c("  Ben Franklin and Jefferson Davis",
%              "\tMillard Fillmore")
%# name groups 'first' and 'last'
%name.rex <- "(?<first>[[:upper:]][[:lower:]]+) (?<last>[[:upper:]][[:lower:]]+)"
%(parsed <- regexpr(name.rex, notables, perl = TRUE))
%gregexpr(name.rex, notables, perl = TRUE)[[2]]
%parse.one <- function(res, result) {
%  m <- do.call(rbind, lapply(seq_along(res), function(i) {
%    if(result[i] == -1) return("")
%    st <- attr(result, "capture.start")[i, ]
%    substring(res[i], st, st + attr(result, "capture.length")[i, ] - 1)
%  }))
%  colnames(m) <- attr(result, "capture.names")
%  m
%}
%parse.one(notables, parsed)
%
%## Decompose a URL into its components.
%## Example by LT (http://www.cs.uiowa.edu/~luke/R/regexp.html).
%x <- "http://stat.umn.edu:80/xyz"
%m <- regexec("^(([^:]+)://)?([^:/]+)(:([0-9]+))?(/.*)", x)
%m
%regmatches(x, m)
%## Element 3 is the protocol, 4 is the host, 6 is the port, and 7
%## is the path.  We can use this to make a function for extracting the
%## parts of a URL:
%URL_parts <- function(x) {
%    m <- regexec("^(([^:]+)://)?([^:/]+)(:([0-9]+))?(/.*)", x)
%    parts <- do.call(rbind,
%                     lapply(regmatches(x, m), `[`, c(3L, 4L, 6L, 7L)))
%    colnames(parts) <- c("protocol","host","port","path")
%    parts
%}
%URL_parts(x)
%
%## There is no gregexec() yet, but one can emulate it by running
%## regexec() on the regmatches obtained via gregexpr().  E.g.:
%pattern <- "([[:alpha:]]+)([[:digit:]]+)"
%s <- "Test: A1 BC23 DEF456"
%lapply(regmatches(s, gregexpr(pattern, s)), 
%       function(e) regmatches(e, regexec(pattern, e)))
%}
%\keyword{character}
%\keyword{utilities}
%
\encoding{UTF8}
