% File src/library/base/man/lapply.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{lapply}
\title{Apply a Function over a List or Vector}
\alias{lapply}
\alias{sapply}
\alias{vapply}
\alias{replicate}
\alias{simplify2array}
\usage{
lapply(X, FUN, \dots)

sapply(X, FUN, \dots, simplify = TRUE, USE.NAMES = TRUE)

vapply(X, FUN, FUN.VALUE, \dots, USE.NAMES = TRUE)

replicate(n, expr, simplify = "array")

simplify2array(x, higher = TRUE)
}
\arguments{
  \item{X}{ベクトル(原子的かリスト)又は \code{\link{expression}} オブジェクト．
    他のオブジェクト(クラス付きオブジェクトを含む)は
    \code{base::\link{as.list}} で強制変換される．}
  \item{FUN}{\code{X} の各要素に適用される関数：
    \sQuote{詳細}を見よ．
    \code{+}, \code{\%*\%} のような関数に対しては関数名は逆引用化か引用化
    する必要がある．}
  \item{\dots}{\code{FUN} に対するオプション引数．}
  \item{simplify}{論理値か文字列：もし可能なら結果をベクトル，行列又は高次元配列
    に単純化するか? \code{sapply} に対してはこれは名前付きで簡略化できない．
    既定値の \code{TRUE} はもし適当ならばベクトルか行列を返すが，
    もし \code{simplify = "array"} ならば結果は
    配列でその\dQuote{ランク}(\eqn{=}\code{length(dim(.))})は
    \code{FUN(X[[i]])} の結果よりも一つ大きい．}
  \item{USE.NAMES}{論理値；もし \code{TRUE} で \code{X} が文字列ならば，
    既に名前を持たなければ結果に対して \code{X} を \code{\link{names}} として使う．
    この引数は \code{\dots} の後に来るのでその名前は簡略化できない．}
  \item{FUN.VALUE}{(一般化)ベクトル；FUN からの返り値のテンプレート．
    \sQuote{詳細}を見よ．}
  \item{n}{整数：繰り返し回数．}
  \item{expr}{繰り返し評価される表現式(言語オブジェクトで，普通呼び出し)．}
  \item{x}{リスト，典型的に \code{lapply()} から返される．}
  \item{higher}{論理値；もし真なら \code{simplify2array()} は適切ならば
    (\dQuote{高いランクの})配列を作る．一方
    \code{higher = FALSE} は行列(又はベクトル)だけを返す．
    これらの二つのケースは \code{sapply(*, simplify = "array")} や
    \code{simplify = TRUE} にそれぞれ対応する．}
}
\description{
  \code{lapply} は \code{X} と同じ長さのリストを返す．
  その各要素は \code{X} の対応する要素に関数 \code{FUN} を
  適用した結果である．

  \code{sapply} は \code{lapply} の使いやすいバージョンのラッパである．
  既定でベクトル，行列 を返す．又はもし \code{simplify = "array"} なら
  適切であれば \code{simplify2array()} を用いて配列を返す．
  \code{sapply(x, f, simplify = FALSE, USE.NAMES = FALSE)} は
  \code{lapply(x, f)} と同じである．

  \code{vapply} は \code{sapply} に似るが，返り値の型が予め指定されているので，
  より安全に(そして時には速く)使うことが出来る．

  \code{replicate} は表現式の繰り返し評価に対する \code{sapply} の
  通常の使用向けのラッパである(普通乱数生成を含む)．

  \code{simplify2array()} は \code{simplify} が偽でない時 \code{sapply()}
  から呼び出されるユーティリティである．同様に \code{\link{mapply}()}
  からも呼びだされる．
}
\details{
  \code{FUN} は \code{\link{match.fun}} の呼び出しで見つけられ，
  典型的に関数かシンボル(例えば逆引用化された名前)又は
  \code{lapply} への呼び出し環境から探される関数を指定する文字列である．

  関数 \code{FUN} は入力として \code{X} の任意の要素を受け入れなければならない．
  もし後者が原子的なベクトルならば，\code{FUN} は
  \code{X} と同じ型の長さ1のベクトルを渡される．

  \code{\dots} 中の引数は他の引数と同じ名前を持つことはできない．
  そして \code{FUN} への部分マッチングを避けるように配慮がいる．
  一般的に通用するコード中では，もし \code{\dots} が渡されるのならば
  最初の二つの引数を \code{X} と \code{FUN} と命名するのは
  良い習慣であり，もし \code{X} や \code{FUN} という名前の引数が
  \code{\dots} を通じて渡された時に理解しやすいエラーメッセージが
  与えられることを保証する．

  \code{sapply} 中の単純化はもし \code{X} がゼロより大きな長さを持ち，またもし
  \code{X} のすべての要素からの返り値がすべて同じ(正の)長さを持つ時だけ
  試みられる．もし共通の長さが1であれば結果はベクトルで，1より大きければ
  列が \code{X} の各要素に対応する行列である．

  \code{vapply} では常に単純化が行われる．この関数は \code{FUN} のすべての
  値価が \code{FUN.VALUE} と一貫性，同じ長さと型を持つか，があるかどうかをチェックする．
  (型は順序 logical < integer < double < complex の範囲内で高くされるかもしれないが，
  低くされることはない．)

  S4 クラスの使用は \code{lapply} と \code{vapply} にリストを渡すべきである：
  \code{as.list} を使った内部的な強制変換は基本名前空間中で行われ，
  ユーザが定義したそれ(例えば，基本関数に対し S4 メソッドを定義することにより)ではない．
  %% rather should really use  as(x, "list")  iff  isS4(x)

  \code{lapply} と \code{vapply} はプリミティブな関数である．
}
\value{
  \code{lapply}, \code{sapply(simplify = FALSE)} そして
  \code{replicate(simplify = FALSE)} に対してはリスト．

  \code{sapply(simplify = TRUE)} と \code{replicate(simplify =
  TRUE)} に対しては: もし \code{X} が長さゼロか \code{n = 0} なら空リスト．
  さもなければ \code{X} と同じ長さの原子ベクトルか行列かリスト
  (\code{replicate} に対しては \code{n})．もし単純化が起きれば，
  出力の型は階層 NULL < raw < logical < integer < double <
  complex < character < list < expression の中で最高の型
  (対リストはリストに変換した後)を持つ返り値から決まる．

\code{vapply} は \code{FUN.VALUE} にマッチした型のベクトルか配列を返す．
  もし \code{length(FUN.VALUE) == 1} なら，\code{X} と同じ長さのベクトルが
  返される．さもなければ配列が返される．
  もし \code{FUN.VALUE} が配列でなければ結果は
  \code{length(FUN.VALUE)} 行で \code{length(X)} 列の行列であり，
  さもなければ \code{\link{dim}(a) == c(dim(FUN.VALUE), length(X))} の
  配列 \code{a} である．

  配列の(次元)名前は，もし \code{FUN.VALUE} が名前を持てばそれから，
  さもなければ最初の関数呼び出しの結果から取られる．
  行列の列名，又はもっと一般に配列値の最後の次元名，もしくはベクトル値の
  名前は \code{sapply} 中の \code{X} と同様に設定される． 
}
\note{
  \code{sapply(*, simplify = FALSE, USE.NAMES = FALSE)} は
  \code{lapply(*)} と同値である．

  歴史的な理由から \code{lapply} で作られた呼び出しは評価されず，
  このことに依存したコードが書かれてきた(例えば \code{bquote})．
  これは記録された呼び出しは常に
  \code{FUN(X[[i]], ...)} の形で，\code{i} が現在の添字(整数か倍精度実数)で
  置き換えられている．これは普通問題ではないが，もし
  \code{FUN} が \code{\link{sys.call}} を使っているか，それが呼び出しを利用しているのが
  プリミティブな関数の時は問題になる可能性がある．
  これはプリミティブな関数をラッパを使って呼び出すのがしばしばより安全なことを
  意味し，従って例えば \code{lapply(ll, function(x) is.numeric(x))} が
  \code{is.numeric} に対するメソッド選択適用が正しく行われることを保証するために
  必要とされる．

  もし \code{expr} が関数呼び出しならば，それがどこで評価されるか，
  そして特に \code{\dots} が何を参照しているか，に関する仮定に注意しよう．

  関数呼び出しに対する追加の名前付き引数を
  \code{replicate} に対するそれのように渡すことができる：
  \sQuote{例} を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  関数を複数の引数に適用するには \code{\link{apply}}, \code{\link{tapply}},
  \code{\link{mapply}}．そして
  \code{lapply()} の再帰的バージョンは \code{\link{rapply}}，
  ある環境中の各項目に関数を適用するには \code{\link{eapply}}．
}
\examples{
require(stats); require(graphics)

x <- list(a = 1:10, beta = exp(-3:3), logic = c(TRUE,FALSE,FALSE,TRUE))
# リストの各要素のリスト平均を計算
lapply(x, mean)
# 各リスト要素に体操するメディアンとクォンタイル
lapply(x, quantile, probs = 1:3/4)
sapply(x, quantile)
i39 <- sapply(3:9, seq) # ベクトルのリスト
sapply(i39, fivenum)
vapply(i39, fivenum,
       c(Min. = 0, "1st Qu." = 0, Median = 0, "3rd Qu." = 0, Max. = 0))

## sapply(*, "array") -- 人工的な例
(v <- structure(10*(5:8), names = LETTERS[1:4]))
f2 <- function(x, y) outer(rep(x, length.out = 3), y)
(a2 <- sapply(v, f2, y = 2*(1:5), simplify = "array"))
a.2 <- vapply(v, f2, outer(1:3, 1:5), y = 2*(1:5))
stopifnot(dim(a2) == c(3,5,4), all.equal(a2, a.2),
          identical(dimnames(a2), list(NULL,NULL,LETTERS[1:4])))

hist(replicate(100, mean(rexp(10))))

##パラメータと共に replicate() を使う：
foo <- function(x = 1, y = 2) c(x, y)
# does not work: bar <- function(n, ...) replicate(n, foo(...))
bar <- function(n, x) replicate(n, foo(x = x))
bar(5, x = 3)
}
% taken from PR#8472
\keyword{iteration}
\keyword{list}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/lapply.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lapply}
%\title{Apply a Function over a List or Vector}
%\alias{lapply}
%\alias{sapply}
%\alias{vapply}
%\alias{replicate}
%\alias{simplify2array}
%\usage{
%lapply(X, FUN, \dots)
%
%sapply(X, FUN, \dots, simplify = TRUE, USE.NAMES = TRUE)
%
%vapply(X, FUN, FUN.VALUE, \dots, USE.NAMES = TRUE)
%
%replicate(n, expr, simplify = "array")
%
%simplify2array(x, higher = TRUE)
%}
%\arguments{
%  \item{X}{a vector (atomic or list) or an \code{\link{expression}}
%    object.  Other objects (including classed objects) will be coerced
%    by \code{base::\link{as.list}}.}
%  \item{FUN}{the function to be applied to each element of \code{X}:
%    see \sQuote{Details}.  In the case of functions like
%    \code{+}, \code{\%*\%}, the function name must be backquoted or quoted.}
%  \item{\dots}{optional arguments to \code{FUN}.}
%  \item{simplify}{logical or character string; should the result be
%    simplified to a vector, matrix or higher dimensional array if
%    possible?  For \code{sapply} it must be named and not abbreviated.
%    The default value, \code{TRUE}, returns a vector or matrix if appropriate,
%    whereas if \code{simplify = "array"} the result may be an
%    \code{\link{array}} of \dQuote{rank}
%    (\eqn{=}\code{length(dim(.))}) one higher than the result
%    of \code{FUN(X[[i]])}.}
%  \item{USE.NAMES}{logical; if \code{TRUE} and if \code{X} is character,
%    use \code{X} as \code{\link{names}} for the result unless it had names
%    already.  Since this argument follows \code{\dots} its name cannot
%    be abbreviated.}
%  \item{FUN.VALUE}{a (generalized) vector; a template for the return
%    value from FUN.  See \sQuote{Details}.}
%  \item{n}{integer: the number of replications.}
%  \item{expr}{the expression (a \link{language object}, usually a call)
%    to evaluate repeatedly.}
%
%  \item{x}{a list, typically returned from \code{lapply()}.}
%  \item{higher}{logical; if true, \code{simplify2array()} will produce a
%    (\dQuote{higher rank}) array when appropriate, whereas
%    \code{higher = FALSE} would return a matrix (or vector) only.
%    These two cases correspond to \code{sapply(*, simplify = "array")} or
%    \code{simplify = TRUE}, respectively.}
%}
%\description{
%  \code{lapply} returns a list of the same length as \code{X}, each
%  element of which is the result of applying \code{FUN} to the
%  corresponding element of \code{X}.
%
%  \code{sapply} is a user-friendly version and wrapper of \code{lapply}
%  by default returning a vector, matrix or, if \code{simplify = "array"}, an
%  array if appropriate, by applying \code{simplify2array()}.
%  \code{sapply(x, f, simplify = FALSE, USE.NAMES = FALSE)} is the same as
%  \code{lapply(x, f)}.
%
%  \code{vapply} is similar to \code{sapply}, but has a pre-specified
%  type of return value, so it can be safer (and sometimes faster) to
%  use.
%
%  \code{replicate} is a wrapper for the common use of \code{sapply} for
%  repeated evaluation of an expression (which will usually involve
%  random number generation).
%
%  \code{simplify2array()} is the utility called from \code{sapply()}
%  when \code{simplify} is not false and is similarly called from
%  \code{\link{mapply}()}.
%}
%\details{
%  \code{FUN} is found by a call to \code{\link{match.fun}} and typically
%  is specified as a function or a symbol (e.g., a backquoted name) or a
%  character string specifying a function to be searched for from the
%  environment of the call to \code{lapply}.
%
%  Function \code{FUN} must be able to accept as input any of the
%  elements of \code{X}.  If the latter is an atomic vector, \code{FUN}
%  will always be passed a length-one vector of the same type as \code{X}.
%
%  Arguments in \code{\dots} cannot have the same name as any of the
%  other arguments, and care may be needed to avoid partial matching to
%  \code{FUN}.  In general-purpose code it is good practice to name the
%  first two arguments \code{X} and \code{FUN} if \code{\dots} is passed
%  through: this both avoids partial matching to \code{FUN} and ensures
%  that a sensible error message is given if arguments named \code{X} or
%  \code{FUN} are passed through \code{\dots}.
%
%  Simplification in \code{sapply} is only attempted if \code{X} has
%  length greater than zero and if the return values from all elements
%  of \code{X} are all of the same (positive) length.  If the common
%  length is one the result is a vector, and if greater than one is a
%  matrix with a column corresponding to each element of \code{X}.
%
%  Simplification is always done in \code{vapply}.  This function
%  checks that all values of \code{FUN} are compatible with the
%  \code{FUN.VALUE}, in that they must have the same length and type.
%  (Types may be promoted to a higher type within the ordering logical
%  < integer < double < complex, but not demoted.)
%
%  Users of S4 classes should pass a list to \code{lapply} and
%  \code{vapply}: the internal coercion is done by the \code{as.list} in
%  the base namespace and not one defined by a user (e.g., by setting S4
%  methods on the base function).
%  %% rather should really use  as(x, "list")  iff  isS4(x)
%
%  \code{lapply} and \code{vapply} are \link{primitive} functions.
%}
%\value{
%  For \code{lapply}, \code{sapply(simplify = FALSE)} and
%  \code{replicate(simplify = FALSE)}, a list.
%
%  For \code{sapply(simplify = TRUE)} and \code{replicate(simplify =
%  TRUE)}: if \code{X} has length zero or \code{n = 0}, an empty list.
%  Otherwise an atomic vector or matrix or list of the same length as
%  \code{X} (of length \code{n} for \code{replicate}).  If simplification
%  occurs, the output type is determined from the highest type of the
%  return values in the hierarchy NULL < raw < logical < integer < double <
%  complex < character < list < expression, after coercion of pairlists
%  to lists.
%
%  \code{vapply} returns a vector or array of type matching the
%  \code{FUN.VALUE}.  If \code{length(FUN.VALUE) == 1} a
%  vector of the same length as \code{X} is returned, otherwise
%  an array.  If \code{FUN.VALUE} is not an \code{\link{array}}, the
%  result is a matrix   with \code{length(FUN.VALUE)} rows and
%  \code{length(X)} columns, otherwise an array \code{a} with
%  \code{\link{dim}(a) == c(dim(FUN.VALUE), length(X))}.
%
%  The (Dim)names of the array value are taken from the \code{FUN.VALUE}
%  if it is named, otherwise from the result of the first function call.
%  Column names of the matrix or more generally the names of the last
%  dimension of the array value or names of the vector value are set from
%  \code{X} as in \code{sapply}.
%}
%\note{
%  \code{sapply(*, simplify = FALSE, USE.NAMES = FALSE)} is
%  equivalent to \code{lapply(*)}.
%
%  For historical reasons, the calls created by \code{lapply} are
%  unevaluated, and code has been written (e.g., \code{bquote}) that
%  relies on this.  This means that the recorded call is always of the
%  form \code{FUN(X[[i]], ...)}, with \code{i} replaced by the current
%  (integer or double) index.  This is not normally a problem, but it can
%  be if \code{FUN} uses \code{\link{sys.call}} or
%  \code{\link{match.call}} or if it is a primitive function that makes
%  use of the call.  This means that it is often safer to call primitive
%  functions with a wrapper, so that e.g.\sspace{}\code{lapply(ll, function(x)
%  is.numeric(x))} is required to ensure that method dispatch for
%  \code{is.numeric} occurs correctly.
%
%  If \code{expr} is a function call, be aware of assumptions about where
%  it is evaluated, and in particular what \code{\dots} might refer to.
%  You can pass additional named arguments to a function call as
%  additional named arguments to \code{replicate}: see \sQuote{Examples}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{apply}}, \code{\link{tapply}},
%  \code{\link{mapply}} for applying a function to \bold{m}ultiple
%  arguments, and \code{\link{rapply}} for a \bold{r}ecursive version of
%  \code{lapply()}, \code{\link{eapply}} for applying a function to each
%  entry in an \code{\link{environment}}.
%}
%\examples{
%require(stats); require(graphics)
%
%x <- list(a = 1:10, beta = exp(-3:3), logic = c(TRUE,FALSE,FALSE,TRUE))
%# compute the list mean for each list element
%lapply(x, mean)
%# median and quartiles for each list element
%lapply(x, quantile, probs = 1:3/4)
%sapply(x, quantile)
%i39 <- sapply(3:9, seq) # list of vectors
%sapply(i39, fivenum)
%vapply(i39, fivenum,
%       c(Min. = 0, "1st Qu." = 0, Median = 0, "3rd Qu." = 0, Max. = 0))
%
%## sapply(*, "array") -- artificial example
%(v <- structure(10*(5:8), names = LETTERS[1:4]))
%f2 <- function(x, y) outer(rep(x, length.out = 3), y)
%(a2 <- sapply(v, f2, y = 2*(1:5), simplify = "array"))
%a.2 <- vapply(v, f2, outer(1:3, 1:5), y = 2*(1:5))
%stopifnot(dim(a2) == c(3,5,4), all.equal(a2, a.2),
%          identical(dimnames(a2), list(NULL,NULL,LETTERS[1:4])))
%
%hist(replicate(100, mean(rexp(10))))
%
%## use of replicate() with parameters:
%foo <- function(x = 1, y = 2) c(x, y)
%# does not work: bar <- function(n, ...) replicate(n, foo(...))
%bar <- function(n, x) replicate(n, foo(x = x))
%bar(5, x = 3)
%}
%% taken from PR#8472
%\keyword{iteration}
%\keyword{list}
%
\encoding{UTF8}
