% File src/library/base/man/mapply.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Copyright 2002-2010 The R Foundation
% Distributed under GPL 2 or later

\name{mapply}
\alias{mapply}
\title{Apply a Function to Multiple List or Vector Arguments}
\description{
  \code{mapply} は \code{\link{sapply}} の多変量バージョンである．.
  \code{mapply} は \code{FUN} を各 \dots 引数の最初の要素，
  二番目の要素，三番目の要素，等に適用する．
  引数は必要ならリサイクルされる．
}
\usage{
mapply(FUN, \dots, MoreArgs = NULL, SIMPLIFY = TRUE,
       USE.NAMES = TRUE)
}
\arguments{
  \item{FUN}{低起用される関数で，\code{\link{match.fun}} で見つけられる．}
  \item{\dots}{ベクトル化される引数(狭義に正の長さを持つベクトルまたはリスト)．
  \sQuote{詳細}も見よ．}
  \item{MoreArgs}{\code{FUN} への追加の引数．}
  \item{SIMPLIFY}{論理値又は文字列；結果をベクトル，行列又は高次元の配列に
    縮約しようと試みる；\code{\link{sapply}} の \code{simplify} 引数を見よ．}
  \item{USE.NAMES}{論理値；もし最初の \dots 引数が名前を持てば名前を使う．
    もしくはそれが文字列ベクトルならば文字列を名前として使う．}
}
\details{
  \code{mapply} は \code{MoreArgs} 中で与えられた引数が後に続く
  \code{\dots} の値に対して \code{FUN} を呼び出す
  (どれかが長さゼロでない限り最長の物の長さまでリサイクルされる)．
  
  呼び出し中の引数はもし \code{\dots} や \code{MoreArgs} が名前付きならば
  名前が付けられる．

  \code{\dots} 中にはクラス付きの引数が認められ，
  そしてそれらの部分抽出と \code{length} メソッドが使われる．
}
\value{
  リスト，もしくは \code{SIMPLIFY = TRUE} に対してはベクトル，配列又はリスト．
}
\seealso{
  \code{mapply()} がモデルにしている \code{\link{sapply}}．

  二つの引数の全ての組み合わせにベクトル化関数を適用する \code{\link{outer}}．
}
\examples{
mapply(rep, 1:4, 4:1)

mapply(rep, times = 1:4, x = 4:1)

mapply(rep, times = 1:4, MoreArgs = list(x = 42))

mapply(function(x, y) seq_len(x) + y,
       c(a =  1, b = 2, c = 3),  # 名前が最初
       c(A = 10, B = 0, C = -10))

word <- function(C, k) paste(rep.int(C, k), collapse = "")
utils::str(mapply(word, LETTERS[1:6], 6:1, SIMPLIFY = FALSE))
}
\keyword{manip}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/mapply.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Copyright 2002-2010 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{mapply}
%\alias{mapply}
%\title{Apply a Function to Multiple List or Vector Arguments}
%\description{
%  \code{mapply} is a multivariate version of \code{\link{sapply}}.
%  \code{mapply} applies \code{FUN} to the first elements of each \dots
%  argument, the second elements, the third elements, and so on.
%  Arguments are recycled if necessary.
%}
%\usage{
%mapply(FUN, \dots, MoreArgs = NULL, SIMPLIFY = TRUE,
%       USE.NAMES = TRUE)
%}
%\arguments{
%  \item{FUN}{function to apply, found via \code{\link{match.fun}}.}
%  \item{\dots}{arguments to vectorize over (vectors or lists of strictly
%    positive length, or all of zero length).  See also \sQuote{Details}.}
%  \item{MoreArgs}{a list of other arguments to \code{FUN}.}
%  \item{SIMPLIFY}{logical or character string; attempt to reduce the
%    result to a vector, matrix or higher dimensional array; see
%    the \code{simplify} argument of \code{\link{sapply}}.}
%  \item{USE.NAMES}{logical; use names if the first \dots argument has
%    names, or if it is a character vector, use that character vector as
%    the names.}
%}
%\details{
%  \code{mapply} calls \code{FUN} for the values of \code{\dots}
%  (re-cycled to the length of the longest, unless any have length zero),
%  followed by the arguments given in \code{MoreArgs}.  The arguments in
%  the call will be named if \code{\dots} or \code{MoreArgs} are named.
%
%  Arguments with classes in \code{\dots} will be accepted, and their
%  subsetting and \code{length} methods will be used.
%}
%\value{
%  A list, or for \code{SIMPLIFY = TRUE}, a vector, array or list.
%}
%\seealso{
%  \code{\link{sapply}}, after which \code{mapply()} is modelled.
%
%  \code{\link{outer}}, which applies a vectorized function to all
%  combinations of two arguments.
%}
%\examples{
%mapply(rep, 1:4, 4:1)
%
%mapply(rep, times = 1:4, x = 4:1)
%
%mapply(rep, times = 1:4, MoreArgs = list(x = 42))
%
%mapply(function(x, y) seq_len(x) + y,
%       c(a =  1, b = 2, c = 3),  # names from first
%       c(A = 10, B = 0, C = -10))
%
%word <- function(C, k) paste(rep.int(C, k), collapse = "")
%utils::str(mapply(word, LETTERS[1:6], 6:1, SIMPLIFY = FALSE))
%}
%\keyword{manip}
%\keyword{utilities}
%
\encoding{UTF8}
