% File src/library/base/man/maxCol.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{maxCol}
\alias{max.col}
\title{Find Maximum Position in Matrix}
\description{
 行列の各行に対する最大値を与える位置を見つける．
 タイがあればランダムに決定する．
}
\usage{
max.col(m, ties.method = c("random", "first", "last"))
}
\arguments{
  \item{m}{数値行列．}
  \item{ties.method}{タイをどのように扱うかを指示する文字列．
    既定では \code{"random"}；短縮化可能；\sQuote{詳細}を見よ．}
}
\value{各行の最大値の添字で，長さ \code{nrow(m)} の整数ベクトル．
}
\details{
  既定の \code{ties.method = "random"} ではタイは無作為に解消される．
  この場合タイの決定は項目が確率であることを仮定する：
  相対許容度は \eqn{10^{-5}}{1e-5} で，行の最大値(絶対値で，無限は除く)に対する
  相対許容度である．

  もし \code{ties.method = "first"} ならば \code{max.col} は各行の複数の
  最大値の\emph{最初}のものの列数を返し
  \code{\link{unname}(\link{apply}(m, 1, \link{which.max}))} と同値である．
  同様に \code{ties.method = "last"} は可能性として複数ある添字の\emph{最後}
  を返す．
}
\references{
  Venables, W. N. and Ripley, B. D. (2002)
  \emph{Modern Applied Statistics with S.}
  New York: Springer (4th ed).
}
\seealso{ベクトルには \code{\link{which.max}}．
}
\examples{
table(mc <- max.col(swiss))  # ほとんど "1" と "5", 5 x "2" そして "4" が一回
swiss[unique(print(mr <- max.col(t(swiss)))) , ]  # 3 33 45 45 33 6

set.seed(1)  # 再現可能な例：
(mm <- rbind(x = round(2*stats::runif(12)),
             y = round(5*stats::runif(12)),
             z = round(8*stats::runif(12))))
\dontrun{
  [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12]
x    1    1    1    2    0    2    2    1    1     0     0     0
y    3    2    4    2    4    5    2    4    5     1     3     1
z    2    3    0    3    7    3    4    5    4     1     7     5
}
## 全ての行最大値の列添字：
utils::str(lapply(1:3, function(i) which(mm[i,] == max(mm[i,]))))
max.col(mm) ; max.col(mm) # "random"
max.col(mm, "first") # -> 4 6 5
max.col(mm, "last")  # -> 7 9 11
\dontshow{
stopifnot(max.col(mm, "first") == c(4, 6, 5),
          max.col(mm, "last")  == c(7, 9, 11))
}
}
\keyword{utilities}
\keyword{array}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/maxCol.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{maxCol}
%\alias{max.col}
%\title{Find Maximum Position in Matrix}
%\description{
%  Find the maximum position for each row of a matrix, breaking ties at random.
%}
%\usage{
%max.col(m, ties.method = c("random", "first", "last"))
%}
%\arguments{
%  \item{m}{numerical matrix}
%  \item{ties.method}{a character string specifying how ties are
%    handled, \code{"random"} by default; can be abbreviated; see
%    \sQuote{Details}.}
%}
%\value{index of a maximal value for each row, an integer vector of
%  length \code{nrow(m)}.
%}
%\details{
%  When \code{ties.method = "random"}, as per default, ties are broken at
%  random.  In this case, the determination of a tie assumes that
%  the entries are probabilities: there is a relative tolerance of
%  \eqn{10^{-5}}{1e-5}, relative to the largest (in magnitude, omitting
%  infinity) entry in the row.
%
%  If \code{ties.method = "first"}, \code{max.col} returns the
%  column number of the \emph{first} of several maxima in every row, the
%  same   as \code{\link{unname}(\link{apply}(m, 1, \link{which.max}))}.\cr
%  Correspondingly, \code{ties.method = "last"} returns the \emph{last}
%  of possibly several indices.
%}
%\references{
%  Venables, W. N. and Ripley, B. D. (2002)
%  \emph{Modern Applied Statistics with S.}
%  New York: Springer (4th ed).
%}
%\seealso{\code{\link{which.max}} for vectors.
%}
%\examples{
%table(mc <- max.col(swiss))  # mostly "1" and "5", 5 x "2" and once "4"
%swiss[unique(print(mr <- max.col(t(swiss)))) , ]  # 3 33 45 45 33 6
%
%set.seed(1)  # reproducible example:
%(mm <- rbind(x = round(2*stats::runif(12)),
%             y = round(5*stats::runif(12)),
%             z = round(8*stats::runif(12))))
%\dontrun{
%  [,1] [,2] [,3] [,4] [,5] [,6] [,7] [,8] [,9] [,10] [,11] [,12]
%x    1    1    1    2    0    2    2    1    1     0     0     0
%y    3    2    4    2    4    5    2    4    5     1     3     1
%z    2    3    0    3    7    3    4    5    4     1     7     5
%}
%## column indices of all row maxima :
%utils::str(lapply(1:3, function(i) which(mm[i,] == max(mm[i,]))))
%max.col(mm) ; max.col(mm) # "random"
%max.col(mm, "first") # -> 4 6 5
%max.col(mm, "last")  # -> 7 9 11
%\dontshow{
%stopifnot(max.col(mm, "first") == c(4, 6, 5),
%          max.col(mm, "last")  == c(7, 9, 11))
%}
%}
%\keyword{utilities}
%\keyword{array}
%
\encoding{UTF8}
