% File src/library/base/man/rank.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{rank}
\alias{rank}
\title{Sample Ranks}
\description{
  ベクトル中の値の標本ランクを返す．タイ(つまり等しい値)と
  欠損値は幾つかの仕方で処理される．
}
\usage{
rank(x, na.last = TRUE,
     ties.method = c("average", "first", "last", "random", "max", "min"))
}
\arguments{
  \item{x}{数値，複素数値，文字列，又は論理値ベクトル．}
  \item{na.last}{\code{\link{NA}} の処理の制御用．
    もし \code{TRUE} ならばデータ中の欠損値は最後に置かれる；
    もし \code{FALSE} ならそれらは最初に置かれる；もし \code{NA} なら
    それらは取り除かれる；もし \code{"keep"} ならそれらは
    ランク \code{NA} として保たれる．}
  \item{ties.method}{タイをどのように扱うかを指示する文字列，
    \sQuote{詳細}を見よ；簡略化出来る．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\details{
  もし全ての成分が異なれば(そして \code{NA} が無ければ)，ランクは問題なしに
  定義でき，値は \code{seq_along(x)} 中にある．幾つかが同じ値
  (\sQuote{タイ}と呼ばれる)ならば，引数 \code{ties.method} が対応する
  添字位置での結果を決定する．メソッド \code{"first"} は各タイ位置での
  添字の集合で増加順になるような置換を施す．
  メソッド \code{"random"} はこれらを無作為な順序に置く．
  一方既定値の \code{"average"} はそれらをそれらの平均値で置き換える．
  そして \code{"max"} と \code{"min"} はそれらをそれらの最大値と
  最小値にそれぞれ置き換える．後者はスポーツのランキングでは典型的である．

  値 \code{NA} は決して等しいとは見做されない：
  \code{na.last = TRUE} で \code{na.last = FALSE} の時はこれらは \code{x}
  中に登場する順序で異なったランクを与えられる．

  \strong{NB}: \code{rank} 自体は総称的ではないが \code{\link{xtfrm}}
  はそうである．そして \code{rank(xtfrm(x), ....)} は \code{xtfrm} メソッドが
  あれば希望される結果を持つ．さもなければ \code{rank} は
  \code{==}, \code{>}, \code{is.na} そしてクラス付きオブジェクトに対する
  抽出メソッドを用いるが，かなり遅い可能性がある．
}
\value{
  \code{x} と同じ長さのベクトルで，名前が \code{x} からコピーされる
  (\code{na.last = NA} でない限り，そしてその時は欠損値は除かれる)．
  ベクトルは \code{x} がロングベクトルか \code{ties.method = "average"}
  でない限り整数型であり，さもなければ倍精度実数型である
  (タイの有無によらず)．
}
\seealso{
  \code{\link{order}} と \code{\link{sort}}；
  \code{\link{xtfrm}}, 上を見よ．
}
\examples{
(r1 <- rank(x1 <- c(3, 1, 4, 15, 92)))
x2 <- c(3, 1, 4, 1, 5, 9, 2, 6, 5, 3, 5)
names(x2) <- letters[1:11]
(r2 <- rank(x2)) # タイは平均化される

## rank() は "巾等" である：rank(rank(x)) == rank(x) :
stopifnot(rank(r1) == r1, rank(r2) == r2)

## 平均化無しのランク
rank(x2, ties.method= "first")  # 最初に起きたものが勝つ
rank(x2, ties.method= "random") # タイを無作為にブレイク
rank(x2, ties.method= "random") # そしてもう一度

## タイはタイのままで，平均を取らない
(rma <- rank(x2, ties.method= "max"))  # 古典的
(rmi <- rank(x2, ties.method= "min"))  # スポーツで使用
stopifnot(rma + rmi == round(r2 + r2))
}
\keyword{univar}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/rank.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{rank}
%\alias{rank}
%\title{Sample Ranks}
%\description{
%  Returns the sample ranks of the values in a vector.  Ties (i.e., equal
%  values) and missing values can be handled in several ways.
%}
%\usage{
%rank(x, na.last = TRUE,
%     ties.method = c("average", "first", "random", "max", "min"))
%}
%\arguments{
%  \item{x}{a numeric, complex, character or logical vector.}
%  \item{na.last}{for controlling the treatment of \code{\link{NA}}s.
%    If \code{TRUE}, missing values in the data are put last; if
%    \code{FALSE}, they are put first; if \code{NA}, they are removed; if
%    \code{"keep"} they are kept with rank \code{NA}.}
%  \item{ties.method}{a character string specifying how ties are treated,
%    see \sQuote{Details}; can be abbreviated.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\details{
%  If all components are different (and no \code{NA}s), the ranks are
%  well defined, with values in \code{seq_along(x)}.  With some values equal
%  (called \sQuote{ties}), the argument \code{ties.method} determines the
%  result at the corresponding indices.  The \code{"first"} method results
%  in a permutation with increasing values at each index set of ties.
%  The \code{"random"} method puts these in random order whereas the
%  default, \code{"average"}, replaces them by their mean, and
%  \code{"max"} and \code{"min"} replaces them by their maximum and
%  minimum respectively, the latter being the typical sports
%  ranking.
%
%  \code{NA} values are never considered to be equal: for \code{na.last =
%    TRUE} and \code{na.last = FALSE} they are given distinct ranks in
%  the order in which they occur in \code{x}.
%
%  \strong{NB}: \code{rank} is not itself generic but \code{\link{xtfrm}}
%  is, and \code{rank(xtfrm(x), ....)} will have the desired result if
%  there is a \code{xtfrm} method.  Otherwise, \code{rank} will make use
%  of \code{==}, \code{>}, \code{is.na} and extraction methods for
%  classed objects, possibly rather slowly.
%}
%\value{
%  A numeric vector of the same length as \code{x} with names copied from
%  \code{x} (unless \code{na.last = NA}, when missing values are
%  removed).  The vector is of integer type unless \code{x} is a long
%  vector or \code{ties.method = "average"} when it is of double type
%  (whether or not there are any ties).
%}
%\seealso{
%  \code{\link{order}} and \code{\link{sort}};
%  \code{\link{xtfrm}}, see above.
%}
%\examples{
%(r1 <- rank(x1 <- c(3, 1, 4, 15, 92)))
%x2 <- c(3, 1, 4, 1, 5, 9, 2, 6, 5, 3, 5)
%names(x2) <- letters[1:11]
%(r2 <- rank(x2)) # ties are averaged
%
%## rank() is "idempotent": rank(rank(x)) == rank(x) :
%stopifnot(rank(r1) == r1, rank(r2) == r2)
%
%## ranks without averaging
%rank(x2, ties.method= "first")  # first occurrence wins
%rank(x2, ties.method= "random") # ties broken at random
%rank(x2, ties.method= "random") # and again
%
%## keep ties ties, no average
%(rma <- rank(x2, ties.method= "max"))  # as used classically
%(rmi <- rank(x2, ties.method= "min"))  # as in Sports
%stopifnot(rma + rmi == round(r2 + r2))
%}
%\keyword{univar}
%
\encoding{UTF8}
