% File src/library/base/man/rm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{remove}
\title{Remove Objects from a Specified Environment}
\usage{
remove(\dots, list = character(), pos = -1,
       envir = as.environment(pos), inherits = FALSE)

rm    (\dots, list = character(), pos = -1,
       envir = as.environment(pos), inherits = FALSE)
}
\alias{rm}
\alias{remove}
\arguments{
  \item{\dots}{削除されるオブジェクト，名前(非引用化)又は文字列(引用化)．}
  \item{list}{削除されるべきオブジェクトの名前を与える文字列．}
  \item{pos}{どこで削除を行うか．既定では現在の環境を使う．
    他の可能性に付いては\sQuote{詳細}を見よ．}
  \item{envir}{使用する環境．\sQuote{詳細}を見よ．}
  \item{inherits}{環境の囲みフレームを吟味すべきか?}
}
\description{
  \code{remove} と \code{rm} はオブジェクトを削除するのに使える．
  これらは文字列として連続して与える，又は文字列ベクトルのリストとして，
  又はそれらの結合として与えることが出来る．このようにして与えられた
  全てのリストが削除される．

  もし \code{envir} が NULL ならば現在アクティブな環境が最初に
  探索される．

  もし \code{inherits} が \code{TRUE} ならば提供されたディレクトリの親が
  与えられた名前を持つ変数が現れるまで探される．見つからなかった各変数に対して
  警告がプリントされる．
}
\details{
  \code{pos} 引数はオブジェクトを削除すべき環境を幾つかの方法の
  いずれかで指定できる：
  整数として(\code{\link{search}} リスト中の位置)；
  検索リスト中の要素の名前；又は \code{\link{environment}} として
  (現在アクティブな関数呼び出しにアクセスする \code{\link{sys.frame}} の
  使用を含む)．
  \code{envir} 引数は環境を指定するもう一つの方法であるが，
  主に過去への互換性のためにある．

  基本環境から変数を削除することは認められないし，
  基本名前空間やロックされた環境
  からも出来ない(\code{\link{lockEnvironment}} を見よ)．

  \R の以前のバージョンは \code{\dots} 中に文字列を与えると
  文字列中で名前が与えられたオブジェクトが削除されると不正確に主張していたが，
  これは文字列ベクトルを削除する．オブジェクトを文字列ベクトルとして与えるには
  \code{list} 引数を使う．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{ls}}, \code{\link{objects}}
}
\examples{
tmp <- 1:4
## クリーンアップ
rm(tmp)

\dontrun{
## 作業空間中の(ほとんど)全てを削除．
## 警告が出るので，確信が無い限りこれをすべきではない．
rm(list = ls())
}}
\keyword{environment}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/rm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{remove}
%\title{Remove Objects from a Specified Environment}
%\usage{
%remove(\dots, list = character(), pos = -1,
%       envir = as.environment(pos), inherits = FALSE)
%
%rm    (\dots, list = character(), pos = -1,
%       envir = as.environment(pos), inherits = FALSE)
%}
%\alias{rm}
%\alias{remove}
%\arguments{
%  \item{\dots}{the objects to be removed, as names (unquoted) or
%    character strings (quoted).}
%  \item{list}{a character vector naming objects to be removed.}
%  \item{pos}{where to do the removal.  By default, uses the
%    current environment.  See \sQuote{details} for other possibilities.}
%  \item{envir}{the \code{\link{environment}} to use.  See \sQuote{details}.}
%  \item{inherits}{should the enclosing frames of the environment be
%    inspected?}
%}
%\description{
%  \code{remove} and \code{rm} can be used to remove objects.  These can
%  be specified successively as character strings, or in the character
%  vector \code{list}, or through a combination of both.  All objects
%  thus specified will be removed.
%
%  If \code{envir} is NULL then the currently active environment is
%  searched first.
%
%  If \code{inherits} is \code{TRUE} then parents of the supplied
%  directory are searched until a variable with the given name is
%  encountered.  A warning is printed for each variable that is not
%  found.
%}
%\details{
%  The \code{pos} argument can specify the  environment from which to remove
%  the objects in any of several ways:
%  as an integer (the position in the \code{\link{search}} list); as
%  the character string name of an element in the search list; or as an
%  \code{\link{environment}} (including using \code{\link{sys.frame}} to
%  access the currently active function calls).
%  The \code{envir} argument is an alternative way to specify an
%  environment, but is primarily there for back compatibility.
%
%  It is not allowed to remove variables from the base environment and
%  base namespace, nor from any environment which is locked (see
%  \code{\link{lockEnvironment}}).
%
%  Earlier versions of \R incorrectly claimed that supplying a character
%  vector in \code{\dots} removed the objects named in the character
%  vector, but it removed the character vector.  Use the \code{list}
%  argument to specify objects \emph{via} a character vector.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{ls}}, \code{\link{objects}}
%}
%\examples{
%tmp <- 1:4
%## work with tmp  and cleanup
%rm(tmp)
%
%\dontrun{
%## remove (almost) everything in the working environment.
%## You will get no warning, so don't do this unless you are really sure.
%rm(list = ls())
%}}
%\keyword{environment}
%
\encoding{UTF8}
