% File src/library/base/man/setTimeLimit.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{setTimeLimit}
\alias{setTimeLimit}
\alias{setSessionTimeLimit}
\title{Set CPU and/or Elapsed Time Limits}
\description{
  トップレベルの計算や現在のセッションに対する
  CPU や/または 経過時間の限界を設定する関数．
}
\usage{
setTimeLimit(cpu = Inf, elapsed = Inf, transient = FALSE)

setSessionTimeLimit(cpu = Inf, elapsed = Inf)
}
\arguments{
  \item{cpu}{倍精度実数値．全 CPU 時間の限界．}
  \item{elapsed}{倍精度実数値．全経過時間の限界．}
  \item{transient}{論理値．もし \code{TRUE} なら，限界は現在の計算の残りにだけ
    適用される．}
}
\details{
  \code{setTimeLimit} は各トップレベルの計算，
  つまりコーソールかファイルから入力されたコマンドライン(継続行を含む)
  に適用される限界を設定する．もしこれが計算の内部から呼び出されると
  限界は計算の残りと(\code{transient = TRUE} で無い限り)その後の
  トップレベルの計算に適用される．

  \code{setSessionTimeLimit} はセッションの残りに対する限界を設定する．
  セッションが限界に達するとそれは \code{Inf} にリセットされる．

  限界の設定は小さなオーバーヘッドを持つ -- 計測されているシステム上で
  1\% 未満．

  時間限界はユーザの中断が起きるたびにチェックされる．
  これは \R コード中と \code{\link{Sys.sleep}} の途中で頻繁に起きるが，
  コード作者により特定された C と Fortran コード中の場所に於いてだけである．
#ifdef unix

  \sQuote{トータル CPU 時間}は後者が報告される子プロセスによって
  使用されるものを含む．
#endif
}
\keyword{ utilities }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/setTimeLimit.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{setTimeLimit}
%\alias{setTimeLimit}
%\alias{setSessionTimeLimit}
%\title{Set CPU and/or Elapsed Time Limits}
%\description{
%  Functions to set CPU and/or elapsed time limits for top-level
%  computations or the current session.
%}
%\usage{
%setTimeLimit(cpu = Inf, elapsed = Inf, transient = FALSE)
%
%setSessionTimeLimit(cpu = Inf, elapsed = Inf)
%}
%\arguments{
%  \item{cpu}{double.  Limit on total cpu time.}
%  \item{elapsed}{double.  Limit on elapsed time.}
%  \item{transient}{logical.  If \code{TRUE}, the limits apply only to
%    the rest of the current computation.}
%}
%\details{
%  \code{setTimeLimit} sets limits which apply to each top-level
%  computation, that is a command line (including any continuation lines)
%  entered at the console or from a file.  If it is called from within a
%  computation the limits apply to the rest of the computation and
%  (unless \code{transient = TRUE}) to subsequent top-level computations.
%
%  \code{setSessionTimeLimit} sets limits for the rest of the
%  session.  Once a session limit is reached it is reset to \code{Inf}.
%
%  Setting any limit has a small overhead -- well under 1\% on the
%  systems measured.
%
%  Time limits are checked whenever a user interrupt could occur.
%  This will happen frequently in \R code and during \code{\link{Sys.sleep}},
%  but only at points in compiled C and Fortran code identified by the
%  code author.
%#ifdef unix
%
%  \sQuote{Total cpu time} includes that used by child processes where
%  the latter is reported.
%#endif
%}
%\keyword{ utilities }
%
\encoding{UTF8}
