% File src/library/base/man/shQuote.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{shQuote}
\alias{shQuote}
\title{Quote Strings for Use in OS Shells}
\description{
  OS のシェルに渡すために文字列を引用化する．
}
\usage{
shQuote(string, type = c("sh", "csh", "cmd", "cmd2"))
}
\arguments{
  \item{string}{文字列ベクトルで普通長さ 1．}
  \item{type}{文字列：シェルのタイプ．部分マッチングがサポートされている．
    \code{"cmd"} は Windows NT シェルを参照し Windows 下では既定である．}
}
\details{
  Unix 風システムでサポートされている既定の引用化のタイプは
  Bourne シェル \code{sh} である．もし文字列が一重引用符を含まなければ，
  それを単に一重引用符で囲めば良い．さもなければ文字列は
  二重引用符で囲まれ，これはドル記号，バックコートそしてバックスラッシュを除く
  全てのメタ文字の特殊な意味を抑制するので，これら(そして勿論二重引用符も)
  はバックスラッシュを前に付ける．このタイプの引用化はまた
  \code{bash}, \code{ksh} そして \code{zsh} に対しても適切である．

  他のタイプの引用化は C シェル (\code{csh} と \code{tcsh}) 用である．
  再び，もし文字列が一重引用符を含まなければそれを一重引用符で囲むことが出来る．
  もしそれが一重引用符を含めば，それがドル記号やバックコートを含まないと
  いう前提で(そしてバックスラッシュ，感嘆符そして二重引用符はエスケープか
  しなければならない)二重引用符を使うことが出来る．
  最後の手段として，文字列を一重引用符を含まない欠片に分割し，
  各々を一重引用符で囲み，そして一重引用符を二重引用符で囲む．

#ifdef windows
  Windows のシェルは二重引用符だけをサポートする．この実装が行う全ては
  文字列を二重引用符で囲みそして内部の二重引用符をバックスラッシュで
  囲むことである．Windows のパス名は二重引用符を含めないので，
  これは \code{\link{system}} 中のファイルパスの使用と，
  既定のシェルが使われている際の \code{\link{shell}} に対して
  \code{shQuote} をより安全にする．

  命令の引数を引用化するには \code{shQuote} の使用が安全であるが，
  しかし \code{\link{system}} はシェルを使わないので引用化された引数の
  解釈は実行可能プログラムの実行コードによってなされる．
  これは使用されたコンパイラに依存するかもしれない：Microsoft の
  C 実行プログラムに対する規則は
  \url{https://msdn2.microsoft.com/en-us/library/ms880421.aspx}
  に与えられている．
#endif
}
\references{
  Loukides, M. \emph{et al} (2002)
  \emph{Unix Power Tools} Third Edition.  O'Reilly.  Section 27.12.

% gone in Jan 2015  
% \url{http://www.mhuffman.com/Notes/dos/bash_cmd.htm}
}
\seealso{
  \R コードの引用化には \code{Quotes}．

  英文の引用化には \code{\link{sQuote}}．
}
\examples{
test <- "abc$def`gh`i\\\\j"
cat(shQuote(test), "\n")
\dontrun{system(paste("echo", shQuote(test)))}
test <- "don't do it!"
cat(shQuote(test), "\n")

tryit <- paste("use the", sQuote("-c"), "switch\nlike this")
cat(shQuote(tryit), "\n")
\dontrun{system(paste("echo", shQuote(tryit)))}
cat(shQuote(tryit, type = "csh"), "\n")

## Windows だけの例．
perlcmd <- 'print "Hello World\\n";'
\dontrun{shell(paste("perl -e", shQuote(perlcmd, type = "cmd")))}
}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/shQuote.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{shQuote}
%\alias{shQuote}
%\title{Quote Strings for Use in OS Shells}
%\description{
%  Quote a string to be passed to an operating system shell.
%}
%\usage{
%shQuote(string, type = c("sh", "csh", "cmd"))
%}
%\arguments{
%  \item{string}{a character vector, usually of length one.}
%  \item{type}{character: the type of shell.  Partial matching is
%    supported.  \code{"cmd"} refers to the Windows NT shell, and is the
%    default under Windows.}
%}
%\details{
%  The default type of quoting supported under Unix-alikes is that for
%  the Bourne shell \code{sh}.  If the string does not contain single
%  quotes, we can just surround it with single quotes.  Otherwise, the
%  string is surrounded in double quotes, which suppresses all special
%  meanings of metacharacters except dollar, backquote and backslash, so
%  these (and of course double quote) are preceded by backslash.  This
%  type of quoting is also appropriate for \code{bash}, \code{ksh} and
%  \code{zsh}.
%
%  The other type of quoting is for the C-shell (\code{csh} and
%  \code{tcsh}).  Once again, if the string does not contain single
%  quotes, we can just surround it with single quotes.  If it does
%  contain single quotes, we can use double quotes provided it does not
%  contain dollar or backquote (and we need to escape backslash,
%  exclamation mark and double quote).  As a last resort, we need to
%  split the string into pieces not containing single quotes and surround
%  each with single quotes, and the single quotes with double quotes.
%
%#ifdef windows
%  The Windows shell supports only double quoting.  All this
%  implementation does is to surround the string by double quotes and
%  escape internal double quotes by a backslash.  As Windows path names
%  cannot contain double quotes, this makes \code{shQuote} safe for use
%  with file paths in \code{\link{system}}, and with \code{\link{shell}}
%  if the default shell is used.
%
%  It will usually be safe to use \code{shQuote} to quote arguments of a
%  command, but because \code{\link{system}} does not use a shell,
%  interpretation of quoted arguments is done by the run-time code of the
%  executable.  This may depend on the compiler used: Microsoft's rules
%  for the C run-time are given at
%  \url{https://msdn2.microsoft.com/en-us/library/ms880421.aspx}.
%#endif
%}
%\references{
%  Loukides, M. \emph{et al} (2002)
%  \emph{Unix Power Tools} Third Edition.  O'Reilly.  Section 27.12.
%
%% gone in Jan 2015  
%% \url{http://www.mhuffman.com/Notes/dos/bash_cmd.htm}
%}
%\seealso{
%  \code{Quotes} for quoting \R code.
%
%  \code{\link{sQuote}} for quoting English text.
%}
%\examples{
%test <- "abc$def`gh`i\\\\j"
%cat(shQuote(test), "\n")
%\dontrun{system(paste("echo", shQuote(test)))}
%test <- "don't do it!"
%cat(shQuote(test), "\n")
%
%tryit <- paste("use the", sQuote("-c"), "switch\nlike this")
%cat(shQuote(tryit), "\n")
%\dontrun{system(paste("echo", shQuote(tryit)))}
%cat(shQuote(tryit, type = "csh"), "\n")
%
%## Windows-only example.
%perlcmd <- 'print "Hello World\\n";'
%\dontrun{shell(paste("perl -e", shQuote(perlcmd, type = "cmd")))}
%}
%\keyword{utilities}
%
\encoding{UTF8}
