% File src/library/base/man/socketSelect.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{socketSelect}
\alias{socketSelect}
\title{Wait on Socket Connections}
\usage{
socketSelect(socklist, write = FALSE, timeout = NULL)
}
\arguments{
  \item{socklist}{開かれたソケットコネクションのリスト．}
  \item{write}{論理値．もし \code{TRUE} なら対応するソケットが書き込み用に
               利用でまで待つ．さもなければそれが読み込み用に離島できるまで待つ．}
  \item{timeout}{数値又は \code{NULL}．ソケットが利用できるまで待つ時間(秒)；
                 \code{NULL} はいつまでも待つことを意味する．}
}
\description{
  幾つかのソケットコネクションの最初のものが利用できるのを待つ．
}
\value{\code{socklist} と同じ長さの論理値ベクトルで対応するソケットコネクションが
  体操する \code{write} に応じて利用できるかどうかを指示する．
}
\details{
  \code{write} 中の値は論理値ベクトルが \code{socklist} と同じ長さに
  なるまで必要に応じてリサイクル使用される．ソケットコネクションは
  \code{socklist} 中に一度以上登場できる；これはソケットコネクションが
  読み取りもしくは書き込み用に利用できるかを決定したいときに有用になる．
}
\examples{
\dontrun{
## ソケットコネクション s が書き出し又は読み込み用に利用できるかどうかを検査
socketSelect(list(s, s), c(TRUE, FALSE), timeout = 0)
}
}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/socketSelect.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{socketSelect}
%\alias{socketSelect}
%\title{Wait on Socket Connections}
%\usage{
%socketSelect(socklist, write = FALSE, timeout = NULL)
%}
%\arguments{
%  \item{socklist}{list of open socket connections}
%  \item{write}{logical.  If \code{TRUE} wait for corresponding socket to
%               become available for writing; otherwise wait for it to become
%               available for reading.}
%  \item{timeout}{numeric or \code{NULL}. Time in seconds to wait for a
%                 socket to become available; \code{NULL} means wait
%                 indefinitely.}
%}
%\description{
%  Waits for the first of several socket connections to become available.
%}
%\value{Logical the same length as \code{socklist} indicating
%  whether the corresponding socket connection is available for
%  output or input, depending on the corresponding value of \code{write}.
%}
%\details{
%  The values in \code{write} are recycled if necessary to make up a
%  logical vector the same length as \code{socklist}. Socket connections
%  can appear more than once in \code{socklist}; this can be useful if
%  you want to determine whether a socket is available for reading or
%  writing.
%}
%\examples{
%\dontrun{
%## test whether socket connection s is available for writing or reading
%socketSelect(list(s, s), c(TRUE, FALSE), timeout = 0)
%}
%}
%\keyword{connection}
%
\encoding{UTF8}
