% File src/library/base/man/trace.Rd
% Part of the R package, https://www.R-project.org
% Copyright (C) 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{trace}
\title{Interactive Tracing and Debugging of Calls to a Function or Method}
\alias{trace}
\alias{untrace}
\alias{tracingState}
\alias{.doTrace}
\alias{returnValue}
\description{
  \code{trace} の呼び出しは任意の関数中の選ばれた場所にデバッギングコード(例えば
  \code{\link{browser}} や \code{\link{recover}} への呼び出し) 
  を挿入することを許す．\code{untrace} の呼び出しはトレースをキャンセルする．
  指定されたメソッドは関数への全て呼び出しをトレースすることなしに同じように
  トレースできる．トレースコードは任意の \R 表現で良い．
  トレースは \code{tracingState} を呼び出すことで大局的に一時的に停止できる．
}
\usage{
trace(what, tracer, exit, at, print, signature,
      where = topenv(parent.frame()), edit = FALSE)
untrace(what, signature = NULL, where = topenv(parent.frame()))

tracingState(on = NULL)
.doTrace(expr, msg)
returnValue(default = NULL)
}
\arguments{
  \item{what}{トレースしたりトレースを中止する関数の名前
    (引用化されたりされなかったりする)．
    一つ以上の引数を持つ \code{untrace} や \code{trace} に対して，
    一つ以上の引数を引用化形式で与えることが出来，そして
    同じアクションが各々に対して適用できる．}
  \item{tracer}{関数か未評価の表現式．
    関数の呼び出しや表現式の評価が
    共に呼び出しの始めや，引数 \code{at} で指示される呼び出し中の
    各ステップの前に行われる．詳細の節を見よ．}
  \item{exit}{関数か未評価の表現式．
    関数の呼び出しや表現式の評価が
    関数の終了時に行われる．詳細の節を見よ．}
  \item{at}{オプションの数値ベクトル化リスト．もし提供されると \code{tracer}
    は関数本体の対応するステップの丁度手前で呼び出される．
    詳細の節を見よ．}
  \item{print}{もし \code{TRUE} (既定)ならば，任意のトレース表現式
    が評価される前に説明的な一行がプリントされる．}
  \item{signature}{もしこの引数が提供されると，それは
    関数 \code{what} に対するメソッドのシグネチャでなければならない．
    この場合関数自体ではなくメソッドがトレースされる．}
  \item{edit}{関数内のループ内部でのトレースのような複雑なトレースに対しては，
    関数本体を編集して希望する呼び出しを挿入する必要がある．
    もしそうなら，\code{edit} を \code{TRUE} にするか使いたいエディタの名前
    にして提供する．すると \code{trace()} は \code{\link{edit}} を呼び出し
    編集後に関数のバージョンを使う．追加の情報は詳細節を見よ．
    }
  \item{where}{トレースする関数をどこで探すか：既定では
    \code{trace} への呼び出しのトップレベル環境．

  この引数の重要な用法は名前空間を持つパッケージから呼び出された関数のトレース
  である．現在の名前空間の機構は呼び出される関数を移入する
  (基本パッケージ中の関数を例外として)．呼び出されている関数はトップレベルから
  みられるオブジェクトと同じものではない(一般に移入されたパッケージは付加すら
  されない)．従って正しいバージョンが使われていることを確認する必要がある．
  これを行う方法は名前空間中の関数に \code{where} 引数を設定することである．
  そうするとトレースの計算はその関数の環境を探す
  (それは対応するパッケージの名前空間である)．
  (これは微妙であるが，ここでのセマンティックスは R で名前空間がどのように
  動作するかの中心にある．)
  }
  \item{on}{論理値；サポート関数 \code{tracingState} はトレースが大局的に
    オンであれば \code{TRUE}，さもなければ \code{FALSE} を返す．
    これらの一つ又は他の値の引数は状態を設定する．
    もしトレース状態が \code{FALSE} ならばトレース行動のどれもが実際には
    起きない(例えば，デバッグ関数がデバッグの間中トレースを中断するために
    使われる)．}
  \item{expr, msg}{サポート関数 \code{.doTrace} への引数
    で，それの呼び出しは修正された関数やメソッドの中に挿入される：
    \code{expr} はトレース行動(\code{browser()} の呼び出し等)で，
    \code{msg} はトレース行動が起きる箇所を指定する文字列である．
  }
  \item{default}{もし \code{returnValue} が返り値を見つけられなかった時
    (たとえば関数が正常終了せずエラーで終了)，代わりに \code{default} が返される．}
}
\details{
  \code{trace} 関数は関数(又は \code{signature} が提供されればメソッド)
  の改訂版を構成することで動作し，
  オリジナルが見つかった場所に新しいオブジェクトを付値する．
  もし \code{what} 引数だけが与えられると，トレースをプリントする一行が
  関数への各呼び出しを生成する(\code{trace} の初期バージョンと後方互換)．

  \code{trace} で構成されるオブジェクトは \code{"function"} を
  拡大するクラスからのもので，オリジナルのトレース無しのバージョンを含む．
  \code{untrace} の呼び出しはこのバージョンを再付値する．

  もし引数 \code{tracer} か \code{exit} が関数の名前であれば，
  トレース表現式は引数無しのその関数の呼び出しである．
  これは最も簡単で普通のケースであり，関数
  \code{\link{browser}} と \code{\link{recover}} が最もありそうな候補である；
  前者はトレースされる関数のフレーム中でブラウズし，
  後者は任意の現在アクティブな呼び出し中のブラウズを許す．

  \code{tracer} や \code{exit} 引数は(\code{\link{quote}} や
  \code{\link{substitute}} への呼び出しが返すような)未評価の表現式でも良い．
  この表現式自体がトレースされる関数に挿入されるので，
  それは典型的にトレースされる関数中の引数や局所オブジェクトを
  含む．この形式の表現式は，もしある条件が適用された時に
  やり取りしたければ有用である(そしてこの場合恐らく \code{trace}
  への呼び出し中にもまた \code{print = FALSE} を補いたくなるであろう)．

  \code{at} 引数が与えられると，それは関数本体中の副ステップを参照する
  整数のベクトルで良い(これは関数の本体が \code{{ ...}} に
  囲まれているときにだけ動作する．)
  この場合 \code{tracer} は項目に対して呼び出されず，
  代わりに \code{at} 中にリストされた各ステップの評価のちょうど前に
  呼び出されず．(ヒント：
  関数のプリントバージョン中のステップを数えることを試みたくなければ，
  代わりに関数 \code{f} 中のステップに関連した数を得るために 
  \code{as.list(body(f))} を眺める．)

  \code{at} 引数はまた整数ベクトルのリストでも良い．この場合，
  各ベクトルは関数の別のステップ中に入れ子になったステップを
  参照する．例えば \code{at = list(c(3,4))} は
  関数の三番目のステップの四番目のステップのちょうど前に
  トレース関数を呼び出す．

  \code{\link{setBreakpoint}} (パッケージ \pkg{utils} から)は別の選択肢であり
  \code{trace(...., at, ...)} を呼び出す．

  \code{exit} 引数は \code{\link{on.exit}} の処理中に呼び出される．
  \code{on.exit} 表現式中には実験的な \code{returnValue()} 関数が
  関数により返され用途する値を得るために呼び出すことが出来る．
  この関数を他の状況で呼び出すと結果は未定義である．

  \code{exit} 引数中の固有の制限は，関数自体が \code{add = FALSE} (既定値)
  で \code{on.exit} を使っているときには動作しないことである．
  なぜなら既存の呼び出しが \code{trace} により与えられるものを上書きするからである．

  トレースは入れ子にならない．\code{trace} への任意の呼び出しは先の関数や
  メソッドのトレース用バージョンを置き換え(下で議論する編集用バージョンを除く)，
  そして \code{untrace} は常にトレース無しのバージョンを回復する．
  (トレースの入れ子を許すのは多すぎる混乱と，うっかりトレース用
  バージョンを後に残す可能性がある．)

  もし \code{edit} 引数が間に \code{untrace} の呼び出し無しに同じ関数に
  繰り返し使われると，先に編集されたバージョンは保存される．
  もし先のトレース全てを捨て去りそれから編集したければ，
  次の \code{trace} の呼び出しの前に \code{untrace} を呼び出す．
  編集は自動的なトレースと結びつけることが出来る；
  単に \code{tracer} のような他の引数を与えるか，同じく引数
  \code{edit} を与える．\code{edit = TRUE} 引数は既定のエディタを使う
  (\code{\link{edit}} を見よ)．

  基本パッケージからのプリミティブ関数(組み込みでスペシャル)のトレース
  が出来るが，特殊な機構によってだけであり情報が非常に少ない．
  プリミティブ関数のトレースは引数  \dots (だけ)を持つ関数で置き換えられる．
  僅かな情報が得られるが多くはない．プリミティブ関数に \code{trace} が使われると
  警告が出る．

  関数のトレースバージョンを関数が由来した場所に保存する作業は，
  もしトレースされる関数がセッションイメージに保存されると，
  トレース作業を一つのセッションから他のセッションへ持ち込むことを意味する．
  (次のセッションで \code{untrace} はトレースを取り除く．)
  一方で，大局的環境ではなくパッケージ中にあった関数は
  イメージ中に保存されないので，トレースはそうした関数に対しては
  そのセッションで終了する．

  メソッドのトレースは基本的には関数のトレースと正に類似しているが，
  トレースされたバージョンは直接の付値ではなく
  \code{\link{setMethod}} への呼び出しとして保存され，
  従って \code{untrace} の呼び出し後のトレース無しのバージョン
  も同様である．

  ここで解説された \code{trace} のバージョンは S-plus のバージョンと
  多く互換性があるが，両者は全く異なった機構で動作する．
  S-Plus の \code{trace} はセッションのフレームを使用し，
  トレースが一つのセッションから他のセッションに決して持ち越せないような
  結果を持つ(\R はセッションフレームを持たない)．別の関連する差異は
  \code{trace} とは直接には関係しない．S-Plus のブラウザはブラウズされている
  フレームへの変更を許し，変更はブラウザが終了後も残留する．
  \R のブラウザは変更を許すが，変更はブラウザが終了する時消え去る．
  S-Plus のバージョンは対話的にコードの変更を実験できるが，\R のバージョンでは
  出来ないという点で関係する．(将来のバージョンは \R に対する
  \sQuote{自滅的}なブラウザを含むかもしれない．)
}
\note{
  \code{trace()} の使用は概念的に \code{\link{debug}} の一般化であり，
  別個に実装され，\code{tracer} や \code{exit} 引数を使い
  \code{\link{browser}} を呼び出す，
  %% On the other hand, it sometimes triggers less consistently
  %% ?? lacks features of debug()- (which ??)

  関数名を除く任意の引数を含む関数のトレースのバージョンは
  \pkg{methods} パッケージを必要とする．
  (なぜならそれはトレースされる関数のバージョンを保管しそして再保管する
  特別なクラスのオブジェクトを使うからである)．

  もしメソッドの選択適用が現在未適用ならば，\code{trace} はメソッドの名前空間
  をロードするが，メソッドのパッケージを 
  \code{\link{search}} リスト上に置くことはない．
}
\value{
  簡単なバージョンでは(丁度最初の引数) \code{trace} は不可視の \code{NULL} を返す．
  さもなければトレースされた関数の名前．関連する結論は実行される付値．

  \code{untrace} は関数名を不可視で返す．

  \code{tracingState} は現在の大局的なトレース状態を返す，そして
  可能性としてそれを変更する．

  \code{on.exit} 処理の最中に呼び出されると，\code{returnValue} は終了関数が
  返そうとしている値を返す．他の状況での挙動は未定義である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  最もありそうなトレース関数である \code{\link{browser}} と \code{\link{recover}}；
  同様に一般的な表現式を構成する \code{\link{quote}} と \code{\link{substitute}}．
}
\examples{
require(stats)

##  非常に簡単な使用
trace(sum)
hist(rnorm(100)) # sum() への約 3-4 回の呼び出しを示す
untrace(sum)

## power.t.test() の内部からどのように pt() が呼び出されているか
if(FALSE)
  trace(pt) ## 20回の呼び出し，しかしもっと見たい：
trace(pt, tracer = quote(cat(sprintf("tracing pt(*, ncp = \%.15g)\n", ncp))),
      print = FALSE) # <- 典型的な特例を示さない
power.t.test(20, 1, power=0.8, sd=NULL)  ##--> ncp による根の発見を示す：
untrace(pt)

%% メソッドは必要な時ロードされる
%% if(.isMethodsDispatchOn()) { # 簡単な使用は 'methods' パッケージを必要とする
f <- function(x, y) {
    y <- pmax(y, 0.001)
    if (x > 0) x ^ y else stop("x must be positive")
}

## 関数 f の開始と終了時にブラウザを呼び出すようにアレンジ
trace("f", quote(browser(skipCalls = 4)),
      exit = quote(browser(skipCalls = 4)))

## 代わりに条件付きであるデータを付値し，そしてそれから
## 終了時にブラウズするが，しかしその時だけ．その他では煩わされたくない

trace("f", quote(if(any(y < 0)) yOrig <- y),
      exit = quote(if(exists("yOrig")) browser(skipCalls = 4)),
      print = FALSE)

## stop() が呼び出される直前にブラウザーを起動．
## 最初にステップ数を見出す

as.list(body(f))
as.list(body(f)[[3]])

## そしてそこでブラウザを呼び出す

trace("f", quote(browser(skipCalls = 4)), at = list(c(3,4)))

## ユーティリティ関数をトレースする，recover を使うので
## 呼び出し関数の中もブラウズ出来る

trace("as.matrix", recover)

## トレースを停止

untrace(c("f", "as.matrix"))

\dontrun{
## パッケージ nml からの関数 lm() への呼び出しをトレース
## (関数 nlme はそのパッケージ中にあり，パッケージは
## 名前空間を持つので，lm の正しいベージョンを得るためには
## where= argument が使われなければならない)

trace(lm, exit = recover, where = nlme)
}
%%}% only if 'methods'
}
\keyword{programming}
\keyword{debugging}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/trace.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright (C) 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{trace}
%\title{Interactive Tracing and Debugging of Calls to a Function or Method}
%\alias{trace}
%\alias{untrace}
%\alias{tracingState}
%\alias{.doTrace}
%\alias{returnValue}
%\description{
%  A call to \code{trace} allows you to insert debugging code (e.g., a
%  call to \code{\link{browser}} or \code{\link{recover}}) at chosen
%  places in any function.  A call to \code{untrace} cancels the tracing.
%  Specified methods can be traced the same way, without tracing all
%  calls to the function.  Trace code can be any \R expression.  Tracing
%  can be temporarily turned on or off globally by calling \code{tracingState}.
%}
%\usage{
%trace(what, tracer, exit, at, print, signature,
%      where = topenv(parent.frame()), edit = FALSE)
%untrace(what, signature = NULL, where = topenv(parent.frame()))
%
%tracingState(on = NULL)
%.doTrace(expr, msg)
%returnValue(default = NULL)
%}
%\arguments{
%  \item{what}{The name (quoted or not) of a function to be traced or
%    untraced.  For \code{untrace} or for \code{trace} with more than one
%    argument, more than one name can be given in the quoted form, and
%    the same action will be applied to each one.}
%  \item{tracer}{either a \link{function} or an unevaluated expression.  The
%    function will be called or the expression will be evaluated either
%    at the beginning of the call, or before those steps in the call
%    specified by the argument \code{at}.
%    See the details section.}
%  \item{exit}{either a \code{\link{function}} or an unevaluated expression.  The
%    function will be called or the expression will be evaluated on
%    exiting the function.
%    See the details section.}
%  \item{at}{optional numeric vector or list.  If supplied, \code{tracer}
%    will be called just before the corresponding step in the body of the
%    function.
%    See the details section. }
%  \item{print}{If \code{TRUE} (as per default), a descriptive line is
%    printed before any trace expression is evaluated.}
%  \item{signature}{ If this argument is supplied, it should be a
%    signature for a method for function \code{what}.  In this case, the
%    method, and \emph{not} the function itself, is traced.}
%  \item{edit}{ For complicated tracing, such as tracing within a loop
%    inside the function, you will need to insert the desired calls by
%    editing the body of the function.  If so, supply the \code{edit}
%    argument either as \code{TRUE}, or as the name of the editor you
%    want to use.  Then \code{trace()} will call \code{\link{edit}} and
%    use the version of the function after you edit it.  See the details
%    section for additional information.
%    }
%  \item{where}{where to look for the function to be
%    traced; by default, the top-level environment of the call to
%    \code{trace}.
%
%    An important use of this argument is to trace a function when it
%  is called from a package with a namespace.  The current namespace mechanism
%  imports the functions to be called (with the exception of functions
%  in the base package).  The functions being called are \emph{not} the
%  same objects seen from the top-level (in general, the imported
%  packages may not even be attached).  Therefore, you must ensure that
%  the correct versions are being traced.  The way to do this is to set
%  argument \code{where} to a function in the namespace.  The tracing
%  computations will then start looking in the environment of that
%  function (which will be the namespace of the corresponding package).
%  (Yes, it's subtle, but the semantics here are central to how
%  namespaces work in R.)
%  }
%  \item{on}{logical; a call to  the support function \code{tracingState} returns \code{TRUE}
%    if tracing is globally turned on, \code{FALSE} otherwise.  An
%    argument of one or the other of those values sets the state.  If the
%    tracing state is \code{FALSE}, none of the trace actions will
%    actually occur (used, for example, by debugging functions to shut
%    off tracing during debugging).}
%  \item{expr, msg}{arguments to the support function \code{.doTrace}, calls to
%    which are inserted into the modified function or method:
%    \code{expr} is the tracing action (such as a call to
%    \code{browser()}, and \code{msg} is a string identifying the
%    place where the trace action occurs.
%  }
%  \item{default}{If \code{returnValue} finds no return value (e.g.
%    a function exited because of an error, not a normal exit), it
%    will return \code{default} instead.
%  }
%}
%\details{
%  The \code{trace} function operates by constructing a revised version
%  of the function (or of the method, if \code{signature} is supplied),
%  and assigning the new object back where the original was found.
%  If only the \code{what} argument is given, a line of trace printing is
%  produced for each call to the function (back compatible with the
%  earlier version of \code{trace}).
%
%  The object constructed by \code{trace} is from a class that extends
%  \code{"function"} and which contains the original, untraced version.
%  A call to \code{untrace} re-assigns this version.
%
%  If the argument \code{tracer} or \code{exit} is the name of a
%  function, the tracing expression will be a call to that function, with
%  no arguments.  This is the easiest and most common case, with the
%  functions \code{\link{browser}} and \code{\link{recover}} the
%  likeliest candidates; the former browses in the frame of the function
%  being traced, and the latter allows browsing in any of the currently
%  active calls.
%
%  The \code{tracer} or \code{exit} argument can also be an unevaluated
%  expression (such as returned by a call to \code{\link{quote}} or
%  \code{\link{substitute}}).  This expression itself is inserted in the
%  traced function, so it will typically involve arguments or local
%  objects in the traced function.  An expression of this form is useful
%  if you only want to interact when certain conditions apply (and in
%  this case you probably want to supply \code{print = FALSE} in the call
%  to \code{trace} also).
%
%  When the \code{at} argument is supplied, it can be a vector of
%  integers referring to the substeps of the body of the function (this
%  only works if the body of the function is enclosed in \code{{ ...}}.  In
%  this case \code{tracer} is \emph{not} called on entry, but instead
%  just before evaluating each of the steps listed in \code{at}.  (Hint:
%  you don't want to try to count the steps in the printed version of a
%  function; instead, look at \code{as.list(body(f))} to get the numbers
%  associated with the steps in function \code{f}.)
%
%  The \code{at} argument can also be a list of integer vectors.  In
%  this case, each vector refers to a step nested within another step of
%  the function.  For example, \code{at = list(c(3,4))}
%  will call the tracer just before the fourth step of the third step
%  of the function.  See the example below.
%
%  Using \code{\link{setBreakpoint}} (from package \pkg{utils}) may be an
%  alternative, calling \code{trace(...., at, ...)}.
%
%  The \code{exit} argument is called during \code{\link{on.exit}}
%  processing.  In an \code{on.exit} expression, the experimental \code{returnValue()}
%  function may be called to obtain the value about to be returned by
%  the function. Calling this function in other circumstances will give
%  undefined results.
%
%  An intrinsic limitation in the \code{exit} argument is that it won't
%  work if the function itself uses \code{on.exit} with \code{add=
%  FALSE} (the default), since the existing calls will override the one
%  supplied by \code{trace}.
%
%  Tracing does not nest.  Any call to \code{trace} replaces previously
%  traced versions of that function or method (except for edited
%  versions as discussed below), and \code{untrace} always
%  restores an untraced version.  (Allowing nested tracing has too many
%  potentials for confusion and for accidentally leaving traced versions
%  behind.)
%
%  When the \code{edit} argument is used repeatedly with no call to
%  \code{untrace} on the same function or method in between, the
%  previously edited version is retained.  If you want to throw away
%  all the previous tracing and then edit, call \code{untrace} before the next
%  call to \code{trace}.  Editing may be combined with automatic
%  tracing; just supply the other arguments such as \code{tracer}, and
%  the \code{edit} argument as well.  The \code{edit = TRUE} argument
%  uses the default editor (see \code{\link{edit}}).
%
%  Tracing primitive functions (builtins and specials) from the base
%  package works, but only by a special mechanism and not very
%  informatively.  Tracing a primitive causes the primitive to be
%  replaced by a function with argument \dots (only).  You can get a bit
%  of information out, but not much.  A warning message is issued when
%  \code{trace} is used on a primitive.
%
%  The practice of saving the traced version of the function back where
%  the function came from means that tracing carries over from one
%  session to another, \emph{if} the traced function is saved in the
%  session image.  (In the next session, \code{untrace} will remove the
%  tracing.)  On the other hand, functions that were in a package, not in
%  the global environment, are not saved in the image, so tracing expires
%  with the session for such functions.
%
%  Tracing a method is basically just like tracing a function, with the
%  exception that the traced version is stored by a call to
%  \code{\link{setMethod}} rather than by direct assignment, and so is
%  the untraced version after a call to \code{untrace}.
%
%  The version of \code{trace} described here is largely compatible with
%  the version in S-Plus, although the two work by entirely different
%  mechanisms.  The S-Plus \code{trace} uses the session frame, with the
%  result that tracing never carries over from one session to another (\R
%  does not have a session frame).  Another relevant distinction has
%  nothing directly to do with \code{trace}:  The browser in S-Plus
%  allows changes to be made to the frame being browsed, and the changes
%  will persist after exiting the browser.  The \R browser allows changes,
%  but they disappear when the browser exits.  This may be relevant in
%  that the S-Plus version allows you to experiment with code changes
%  interactively, but the \R version does not.  (A future revision may
%  include a \sQuote{destructive} browser for \R.)
%}
%\note{
%  Using \code{trace()} is conceptually a generalization of
%  \code{\link{debug}}, implemented differently, by calling
%  \code{\link{browser}} via its \code{tracer} or \code{exit} argument.
%  %% On the other hand, it sometimes triggers less consistently
%  %% ?? lacks features of debug()- (which ??)
%
%  The version of function tracing that includes any of the arguments
%  except for the function name requires the \pkg{methods} package
%  (because it uses special classes of objects to store and restore
%  versions of the traced functions).
%
%  If methods dispatch is not currently on, \code{trace} will load the
%  methods namespace, but will not put the methods package on the
%  \code{\link{search}} list.
%}
%\value{
%  In the simple version (just the first argument), \code{trace} returns
%  an invisible \code{NULL}.
%  Otherwise, the traced function(s) name(s).  The relevant consequence is the
%  assignment that takes place.
%
%  \code{untrace} returns the function name invisibly.
%
%  \code{tracingState} returns the current global tracing state, and possibly
%  changes it.
%
%  When called during \code{on.exit} processing, \code{returnValue} returns
%  the value about to be returned by the exiting function.  Behaviour in
%  other circumstances is undefined.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{browser}} and \code{\link{recover}}, the likeliest
%  tracing functions;
%  also, \code{\link{quote}} and \code{\link{substitute}} for
%  constructing general expressions.
%}
%\examples{
%require(stats)
%
%##  Very simple use
%trace(sum)
%hist(rnorm(100)) # shows about 3-4 calls to sum()
%untrace(sum)
%
%## Show how pt() is called from inside power.t.test():
%if(FALSE)
%  trace(pt) ## would show ~20 calls, but we want to see more:
%trace(pt, tracer = quote(cat(sprintf("tracing pt(*, ncp = \%.15g)\n", ncp))),
%      print = FALSE) # <- not showing typical extra
%power.t.test(20, 1, power=0.8, sd=NULL)  ##--> showing the ncp root finding:
%untrace(pt)
%
%%% methods is loaded when needed
%%% if(.isMethodsDispatchOn()) { # non-simple use needs 'methods' package
%f <- function(x, y) {
%    y <- pmax(y, 0.001)
%    if (x > 0) x ^ y else stop("x must be positive")
%}
%
%## arrange to call the browser on entering and exiting
%## function f
%trace("f", quote(browser(skipCalls = 4)),
%      exit = quote(browser(skipCalls = 4)))
%
%## instead, conditionally assign some data, and then browse
%## on exit, but only then.  Don't bother me otherwise
%
%trace("f", quote(if(any(y < 0)) yOrig <- y),
%      exit = quote(if(exists("yOrig")) browser(skipCalls = 4)),
%      print = FALSE)
%
%## Enter the browser just before stop() is called.  First, find
%## the step numbers
%
%as.list(body(f))
%as.list(body(f)[[3]])
%
%## Now call the browser there
%
%trace("f", quote(browser(skipCalls = 4)), at = list(c(3,4)))
%
%## trace a utility function, with recover so we
%## can browse in the calling functions as well.
%
%trace("as.matrix", recover)
%
%
%## turn off the tracing
%
%untrace(c("f", "as.matrix"))
%
%\dontrun{
%## trace calls to the function lm() that come from
%## the nlme package.
%## (The function nlme is in that package, and the package
%## has a namespace, so the where= argument must be used
%## to get the right version of lm)
%
%trace(lm, exit = recover, where = nlme)
%}
%%%}% only if 'methods'
%}
%\keyword{programming}
%\keyword{debugging}
%\encoding{UTF8}

\encoding{UTF8}

