% File src/library/base/man/writeLines.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{writeLines}
\alias{writeLines}
\title{Write Lines to a Connection}
\description{
  テキスト行をコネクションに書き込む．
}
\usage{
writeLines(text, con = stdout(), sep = "\n", useBytes = FALSE)
}
\arguments{
  \item{text}{文字列．}
  \item{con}{コネクションオブジェクト又は文字列．}
  \item{sep}{文字列．テキストの各行の後にコネクションに書き込まれる文字列．}
  \item{useBytes}{論理値．\sQuote{詳細}を見よ．}
}
\details{
  もし \code{con} が文字列ならば，関数は
  関数呼び出しの間中開かれているファイルコネクションを得るために
  \code{\link{file}} を呼び出す．

  もしコネクションが開かれているとそれはその現在の位置から
  書き込まれる．
  もし開かれていなければ，それは呼び出しの間中
  モード \code{"wt"} で開かれそれから閉じられる．

  普通 \code{writeLines} はテキストモードコネクションと共に使われ，
  そして既定の分離記号はそのプラットフォームに対する通常の分離記号
  (Unix/Linux では LF，Windows では CRLF)に変換される．
  より多くの制御には，バイナリコネクションを開きファイルに書き込みたい正確な
  値を \code{sep} に指定する．更なる制御にはバイナリコネクションに対して
  \code{\link{writeChar}} を使う．

  \code{useBytes} はエキスパート用である．普通(偽の時)マーク付きエンコーディング
  を持つ文字列はコネクションに渡される前に現在のエンコーディングに
  変換される(更に再エンコーディングがされるかもしれない)．
  \code{useBytes = TRUE} はマーク付き文字列の再エンコーディングを抑制するので，
  それらはバイト毎にコネクションに渡される：
  これは文字列が既に \code{\link{iconv}} 等で再エンコーディングされているときは
  役に立つかもしれない．(これは文字列が \code{"bytes"} でエンコーディング
  されているときは自動的に起動される．)
}
\seealso{
  \code{\link{connections}}, \code{\link{writeChar}}, \code{\link{writeBin}},
  \code{\link{readLines}}, \code{\link{cat}}
}

\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/writeLines.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{writeLines}
%\alias{writeLines}
%\title{Write Lines to a Connection}
%\description{
%  Write text lines to a connection.
%}
%\usage{
%writeLines(text, con = stdout(), sep = "\n", useBytes = FALSE)
%}
%\arguments{
%  \item{text}{A character vector}
%  \item{con}{A \link{connection} object or a character string.}
%  \item{sep}{character string.  A string to be written to the connection
%    after each line of text.}
%  \item{useBytes}{logical.  See \sQuote{Details}.}
%}
%\details{
%  If the \code{con} is a character string, the function calls
%  \code{\link{file}} to obtain a file connection which is opened for
%  the duration of the function call.
%
%  If the connection is open it is written from its current position.
%  If it is not open, it is opened for the duration of the call in
%  \code{"wt"} mode and then closed again.
%
%  Normally \code{writeLines} is used with a text-mode  connection, and the
%  default separator is converted to the normal separator for that
%  platform (LF on Unix/Linux, CRLF on Windows).  For more control, open
%  a binary connection and specify the precise value you want written to
%  the file in \code{sep}.  For even more control, use
%  \code{\link{writeChar}} on a binary connection.
%
%  \code{useBytes} is for expert use.  Normally (when false) character
%  strings with marked encodings are converted to the current encoding
%  before being passed to the connection (which might do further
%  re-encoding).  \code{useBytes = TRUE} suppresses the re-encoding of
%  marked strings so they are passed byte-by-byte to the connection:
%  this can be useful when strings have already been re-encoded by
%  e.g.\sspace{}\code{\link{iconv}}.  (It is invoked automatically for strings
%  with marked encoding \code{"bytes"}.)
%}
%\seealso{
%  \code{\link{connections}}, \code{\link{writeChar}}, \code{\link{writeBin}},
%  \code{\link{readLines}}, \code{\link{cat}}
%}
%
%\keyword{file}
%\keyword{connection}
%\encoding{UTF8}

\encoding{UTF8}

