% File src/library/datasets/man/OrchardSprays.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{OrchardSprays}
\docType{data}
\alias{OrchardSprays}
\title{Potency of Orchard Sprays}
\description{
  様々な成分の果樹園散布剤がミツバチを寄せ付けない効果を
  調べる実験がラテン方画デザインを使って行われた．
}
\usage{OrchardSprays}
\format{
  4変数に関する64観測値のデータフレーム．
  \tabular{rlll}{
    [,1]  \tab rowpos    \tab 数値 \tab デザインの行\cr
    [,2]  \tab colpos    \tab 数値 \tab デザインの列\cr
    [,3]  \tab treatment \tab 因子 \tab 処理レベル\cr
    [,4]  \tab decrease  \tab 数値 \tab 応答
  }
 
  乾燥した蜂の巣の個々のセルを石灰硫黄合剤乳液の蔗糖溶液で満たした．
  石灰硫黄合剤の 1/100 から 1/1,562,500 の範囲の引き続く
  因子 1/5 の幾つかの異なった濃度が使われ，石灰硫黄合剤を含まない
  溶液も使われた．

  100匹の蜂を二時間部屋に放ち異なった溶液に対する応答が
  得られ，それから様々なセル中の溶液の体積の減少が測られた．

  \eqn{8 \times 8}{8 x 8} ラテン方画デザインが
  使われ，そして処理が次のようにコードされた：
  \tabular{rl}{
    A \tab 最大の石灰硫黄合剤のレベル\cr
    B \tab 次に大きな石灰硫黄合剤のレベル\cr
    . \tab \cr
    . \tab \cr
    . \tab \cr
    G \tab 最少の石灰硫黄合剤のレベル\cr
    H \tab 石灰硫黄合剤無し\cr
  }
}
\source{
  Finney, D. J. (1947)
  \emph{Probit Analysis}.
  Cambridge.
}
\references{
  McNeil, D. R. (1977)
  \emph{Interactive Data Analysis}.
  New York: Wiley.
}
\examples{
require(graphics)
pairs(OrchardSprays, main = "OrchardSprays data")
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/OrchardSprays.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{OrchardSprays}
%\docType{data}
%\alias{OrchardSprays}
%\title{Potency of Orchard Sprays}
%\description{
%  An experiment was conducted to assess the potency of various
%  constituents of orchard sprays in repelling honeybees, using a
%  Latin square design.
%}
%\usage{OrchardSprays}
%\format{
%  A data frame with 64 observations on 4 variables.
%  \tabular{rlll}{
%    [,1]  \tab rowpos    \tab numeric \tab Row of the design\cr
%    [,2]  \tab colpos    \tab numeric \tab Column of the design\cr
%    [,3]  \tab treatment \tab factor  \tab Treatment level\cr
%    [,4]  \tab decrease  \tab numeric \tab Response
%  }
%}
%\details{
%  Individual cells of dry comb were filled with measured amounts of lime
%  sulphur emulsion in sucrose solution.  Seven different concentrations
%  of lime sulphur ranging from a concentration of 1/100 to 1/1,562,500
%  in successive factors of 1/5 were used as well as a solution
%  containing no lime sulphur.
%
%  The responses for the different solutions were obtained by releasing
%  100 bees into the chamber for two hours, and then measuring the
%  decrease in volume of the solutions in the various cells.
%
%  An \eqn{8 \times 8}{8 x 8} Latin square design was used and the
%  treatments were coded as follows:
%  \tabular{rl}{
%    A \tab highest level of lime sulphur\cr
%    B \tab next highest level of lime sulphur\cr
%    . \tab \cr
%    . \tab \cr
%    . \tab \cr
%    G \tab lowest level of lime sulphur\cr
%    H \tab no lime sulphur
%  }
%}
%\source{
%  Finney, D. J. (1947)
%  \emph{Probit Analysis}.
%  Cambridge.
%}
%\references{
%  McNeil, D. R. (1977)
%  \emph{Interactive Data Analysis}.
%  New York: Wiley.
%}
%\examples{
%require(graphics)
%pairs(OrchardSprays, main = "OrchardSprays data")
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%
