% File src/library/grDevices/man/col2rgb.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{col2rgb}
\title{色を RGB に変換}
\alias{col2rgb}
%%\title{Color to RGB Conversion}
\description{
  \R の色を RGB (red/green/blue) に変換する．
}
\usage{
col2rgb(col, alpha = FALSE)
}
\arguments{
  \item{col}{
    三種類の \R の色指定のどれかのベクトル．つまり
    色名(\code{\link{colors}()} でリストされるような)，
    形式 \code{"#rrggbb"} の16進文字列，又は
    \code{"#rrggbbaa"} (\code{\link{rgb}} を見よ)，又は
    \code{\link{palette}()[i]} を意味する
    正整数 \code{i}．}
  \item{alpha}{
    アルファチャンネル(不透明度)値を返すべきかどうかを指示する論理値．}
}
\details{
  \code{\link{NA}} (整数か文字列としての)と \code{"NA"} は透明を意味する．

  これらの三つのタイプの一つでない \code{col} の値は強制変換される：
  実数ベクトルは整数に，他は文字列に変換される．
  (\R 3.0.2 以前では因子はそれらの整数コードに強制変換された：
  全てのその他のケースでは変換時にクラスは依然無視される．)

  ゼロ又は負の \code{col} 値はエラーになる．
}
\value{
  三つか四つの行(\code{alpha = TRUE} に対して)と
  \code{col} の長さの列数を持つ整数行列．
  もし \code{col} が名前を持てば，これらは返り値の
  列名に使われる．
}
\author{
  Martin Maechler と R core チーム．
}
\seealso{
  \code{\link{rgb}}, \code{\link{colors}}, \code{\link{palette}} 等．

  新しいより柔軟なインタフェイス \code{\link{convertColor}()}．
}
\examples{
col2rgb("peachpuff")
col2rgb(c(blu = "royalblue", reddish = "tomato"))  # 注意：colnames

col2rgb(1:8)  # palette() からのもの(もし既定なら)

col2rgb(paste0("gold", 1:4))

col2rgb("#08a0ff")
## 色指定の三種類すべて：
col2rgb(c(red = "red", hex = "#abcdef"))
col2rgb(c(palette = 1:3))

##-- 入門的でない例 --

grC <- col2rgb(paste0("gray", 0:100))
table(print(diff(grC["red",])))  # '2' または '3'：ほとんど等間隔
## '名前付き'グレイは中間に {"slate gray" は厳格にはグレイではない}
col2rgb(c(g66 = "gray66", darkg =  "dark gray", g67 = "gray67",
          g74 = "gray74", gray  =       "gray", g75 = "gray75",
          g82 = "gray82", light = "light gray", g83 = "gray83"))

crgb <col2rgb(cc <- colors())
colnames(crgb) <- cc
t(crgb)  # 全ての表

ccodes <- c(256^(2:0) \%*\% crgb)  # = 内部コード
## 幾つの名前が互いに'別名'か：
table(tcc <- table(ccodes))
length(uc <- unique(sort(ccodes))) # 502
## 全ての重複した色：
mult <- uc[tcc >= 2]
cl <- lapply(mult, function(m) cc[ccodes == m])
names(cl) <- apply(col2rgb(sapply(cl, function(x)x[1])),
                   2, function(n)paste(n, collapse = ","))
utils::str(cl)
\dontrun{
 if(require(xgobi)) { ## 色立方体をダイナミックに：
   tc <- t(crgb[, !duplicated(ccodes)])
   table(is.gray <- tc[,1] == tc[,2] & tc[,2] == tc[,3])  # (397, 105)
   xgobi(tc, color = c("gold", "gray")[1 + is.gray])
 }
}
}
\keyword{color}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/col2rgb.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{col2rgb}
%\alias{col2rgb}
%\title{Color to RGB Conversion}
%\description{
%  \R color to RGB (red/green/blue) conversion.
%}
%\usage{
%col2rgb(col, alpha = FALSE)
%}
%\arguments{
%  \item{col}{vector of any of the three kinds of \R color specifications,
%    i.e., either a color name (as listed by \code{\link{colors}()}), a
%    hexadecimal string of the form \code{"#rrggbb"} or
%    \code{"#rrggbbaa"} (see \code{\link{rgb}}), or a positive integer
%    \code{i} meaning \code{\link{palette}()[i]}.}
%  \item{alpha}{logical value indicating whether the alpha channel (opacity)
%    values should be returned.}
%}
%\details{
%  \code{\link{NA}} (as integer or character) and \code{"NA"} mean transparent.
%
%  Values of \code{col} not of one of these types are coerced: real
%  vectors are coerced to integer and other types to character.  (Prior to
%  \R 3.0.2 factors were coerced to their integer codes: in all other
%  cases the class is still ignored when doing the coercion.)
%
%  Zero and negative values of \code{col} are an error.
%}
%\value{
%  An integer matrix with three or four (for \code{alpha = TRUE}) rows
%  and number of columns the length of \code{col}.  If \code{col} has
%  names these are used as the column names of the return value.
%}
%\author{
%  Martin Maechler and the R core team.
%}
%\seealso{
%  \code{\link{rgb}}, \code{\link{colors}}, \code{\link{palette}}, etc.
%
%  The newer, more flexible interface, \code{\link{convertColor}()}.
%}
%\examples{
%col2rgb("peachpuff")
%col2rgb(c(blu = "royalblue", reddish = "tomato"))  # note: colnames
%
%col2rgb(1:8)  # the ones from the palette() (if the default)
%
%col2rgb(paste0("gold", 1:4))
%
%col2rgb("#08a0ff")
%## all three kinds of color specifications:
%col2rgb(c(red = "red", hex = "#abcdef"))
%col2rgb(c(palette = 1:3))
%
%##-- NON-INTRODUCTORY examples --
%
%grC <- col2rgb(paste0("gray", 0:100))
%table(print(diff(grC["red",])))  # '2' or '3': almost equidistant
%## The 'named' grays are in between {"slate gray" is not gray, strictly}
%col2rgb(c(g66 = "gray66", darkg =  "dark gray", g67 = "gray67",
%          g74 = "gray74", gray  =       "gray", g75 = "gray75",
%          g82 = "gray82", light = "light gray", g83 = "gray83"))
%
%crgb <- col2rgb(cc <- colors())
%colnames(crgb) <- cc
%t(crgb)  # The whole table
%
%ccodes <- c(256^(2:0) \%*\% crgb)  # = internal codes
%## How many names are 'aliases' of each other:
%table(tcc <- table(ccodes))
%length(uc <- unique(sort(ccodes))) # 502
%## All the multiply named colors:
%mult <- uc[tcc >= 2]
%cl <- lapply(mult, function(m) cc[ccodes == m])
%names(cl) <- apply(col2rgb(sapply(cl, function(x)x[1])),
%                   2, function(n)paste(n, collapse = ","))
%utils::str(cl)
%\dontrun{
% if(require(xgobi)) { ## Look at the color cube dynamically :
%   tc <- t(crgb[, !duplicated(ccodes)])
%   table(is.gray <- tc[,1] == tc[,2] & tc[,2] == tc[,3])  # (397, 105)
%   xgobi(tc, color = c("gold", "gray")[1 + is.gray])
% }
%}
%}
%\keyword{color}
%\keyword{dplot}
%
%\encoding{UTF-8}
%