% File src/library/grDevices/man/densCols.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later


\name{densCols}
\alias{densCols}
\title{平滑化密度プロットに対する色}
\alias{blues9}
%%\title{Colors for Smooth Density Plots}
\description{
  \code{densCols} は散布図の各点に於ける局所密度を
  表現する色を含むベクトルを作る．
}
\usage{
densCols(x, y = NULL, nbin = 128, bandwidth,
         colramp = colorRampPalette(blues9[-(1:3)]))
blues9
}
\arguments{
  \item{x, y}{引数 \code{x} と \code{y} は点の x と y 座標を与える．
    任意の合理的な座標の与え方が認められる．
    詳細は関数 \code{\link{xy.coords}} を見よ．
    もしこべテウに与えられれば，同じ長さでなければならない．}
  \item{nbin}{長さ1か2(x と y 個別に)の数値ベクトルで，
    密度推定に対する等間隔のグリッド点の数を指定する；
    \code{\link[KernSmooth]{bkde2D}()} 中の
    \code{gridsize} として直接に使われる．}
  \item{bandwidth}{
    平滑バンド幅の(長さ 1 か 2)の数値ベクトル．
    もし欠損していれば，多かれ少なかれ有用な既定値が使われる．
    \code{bandwidth} は続いて関数
    \code{\link[KernSmooth]{bkde2D}} に渡される．}
  \item{colramp}{整数 \code{n} を引数として受け入れ
    \code{n} 個の色を返す関数．}
}

\details{
  \code{densCols} はパッケージ \CRANpkg{KernSmooth} からの
  \code{\link[KernSmooth]{bkde2D}(*, bandwidth, gridsize = nbin, ..)}
  の呼び出しによるプロット中で
  使われる色のセットを計算し返す．

  \code{blues9} はプロットで既定として使われる青の9色の陰影の
  セットである．
}

\value{
  \code{densCols} は引き続く散布図中で使われる色を含む長さ
  \code{nrow(x)} のベクトルを返す．
  各色は対応する点のまわりの局所密度を表す．
}
\seealso{
  パッケージ \CRANpkg{KernSmooth} からの \code{\link[KernSmooth]{bkde2D}}，
  更に \code{densCols} と同じ計算に基づく
  \code{\link{smoothScatter}()} (パッケージ \pkg{graphics})．
}
\author{オリジナルは FHCRC のFlorian Hahne}
\examples{\donttest{
x1  <- matrix(rnorm(1e3), ncol = 2)
x2  <- matrix(rnorm(1e3, mean = 3, sd = 1.5), ncol = 2)
x   <- rbind(x1, x2)

dcols <- densCols(x)
graphics::plot(x, col = dcols, pch = 20, main = "n = 1000")
}}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/densCols.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%
%\name{densCols}
%\alias{densCols}
%\alias{blues9}
%\title{Colors for Smooth Density Plots}
%\description{
%  \code{densCols} produces a vector containing colors which encode the
%  local densities at each point in a scatterplot.
%}
%\usage{
%densCols(x, y = NULL, nbin = 128, bandwidth,
%         colramp = colorRampPalette(blues9[-(1:3)]))
%blues9
%}
%\arguments{
%  \item{x, y}{the \code{x} and \code{y} arguments provide the x and y
%    coordinates of the points.  Any reasonable way of defining the
%    coordinates is acceptable.  See the function \code{\link{xy.coords}}
%    for details.  If supplied separately, they must be of the same length.}
%  \item{nbin}{numeric vector of length one (for both directions) or two
%    (for x and y separately) specifying the number of equally spaced
%    grid points for the density estimation; directly used as
%    \code{gridsize} in \code{\link[KernSmooth]{bkde2D}()}.}
%  \item{bandwidth}{numeric vector (length 1 or 2) of smoothing bandwidth(s).
%    If missing, a more or less useful default is used. \code{bandwidth}
%    is subsequently passed to function \code{\link[KernSmooth]{bkde2D}}.}
%  \item{colramp}{function accepting an integer \code{n} as an argument and
%    returning \code{n} colors.}
%}
%
%\details{
%  \code{densCols} computes and returns the set of colors that will be
%  used in plotting, calling \code{\link[KernSmooth]{bkde2D}(*,
%  bandwidth, gridsize = nbin, ..)} from package \CRANpkg{KernSmooth}.
%
%  \code{blues9} is a set of 9 color shades of blue used as the default in
%  plotting.
%}
%
%\value{
%  \code{densCols} returns a vector of length \code{nrow(x)} that
%  contains colors to be used in a subsequent scatterplot.  Each color
%  represents the local density around the corresponding point.
%}
%\seealso{
%  \code{\link[KernSmooth]{bkde2D}} from package \CRANpkg{KernSmooth};
%  further, \code{\link{smoothScatter}()} (package \pkg{graphics}) which
%  builds on the same computations as \code{densCols}.
%}
%\author{Florian Hahne at FHCRC, originally}
%\examples{\donttest{
%x1  <- matrix(rnorm(1e3), ncol = 2)
%x2  <- matrix(rnorm(1e3, mean = 3, sd = 1.5), ncol = 2)
%x   <- rbind(x1, x2)
%
%dcols <- densCols(x)
%graphics::plot(x, col = dcols, pch = 20, main = "n = 1000")
%}}
%\keyword{dplot}
%
%\encoding{UTF-8}
%