% File src/library/grDevices/man/dev.capabilities.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-12 R Core Team
% Distributed under GPL 2 or later

\name{dev.capabilities}
\title{グラフィックスデバイスの機能の問い合わせ}
\alias{dev.capabilities}
%%\title{Query Capabilities of the Current Graphics Device}
\description{
  現在のグラフィックスデバイスの機能を問い合わせる．
}
\usage{
dev.capabilities(what = NULL)
}
\arguments{
  \item{what}{
    \sQuote{値}節に挙げられた成分の名前に部分的にマッチする
    文字列，又は全ての利用可能な機能を羅列するには \code{NULL}．}
}
\details{
  機能は，それらが欠損したフックから導かれるのでなければ，
  グラフィックスデバイスの作者により指定されなければならない．
  従ってそれらはしばしば \code{NA} として返され，
  数種類の出力書式が一つのデバイスでサポートされている基礎にあるデバイスの
  最大の機能を反映するかもしれない．

  最近の殆どのデバイスはグラフィックス書式がサポートする
  (PostScript はしない)半透明色をサポートする．
  他方で，
  (完全又は半)透明の背景をサポートするグラフィックスは相対的に
  殆ど無い：一般に後者は
  PDF と PNG プロットのみで見出される．
}
\value{
  次の成分の全てもしくは一部を持つ名前付きリストで，
  どれかは値 \code{NA} を取るかもしれない：
  \item{semiTransparency}{論理値：デバイスは半透明色をサポートするか?}
  \item{transparentBackground}{文字列：デバイスは
    (半)透明の背景をサポートするか?
    可能な値は \code{"no"}, \code{"fully"} (完全な透明のみ) そして \code{"semi"}
    (半透明背景色がサポートされている)．}
  \item{rasterImage}{文字列：デバイスはどの程度
    \code{\link{rasterImage}} と \code{\link{grid.raster}} で
    使われるラスタ―イメージをサポートするか?  可能な値は
    \code{"no"}, \code{"yes"} そして \code{"non-missing"}
    (欠損値のない配列に対してだけサポート)．}
  \item{capture}{論理値：現在のデバイスは
    \code{\link{grid.cap}} が使うようなラスタ―キャプチャーをサポートするか?}
  \item{locator}{論理値：現在のデバイスは
    \code{\link{locator}} と \code{\link{identify}} をサポートするか?}
  \item{events}{文字列：
    このデバイス上ではどのようなイベントが生成可能か?
    現在これは \code{c("MouseDown", "MouseMove", "MouseUp", "Keybd")} の
    部分集合であるが，将来他のイベントがサポートされるかもしれない．}
}
\seealso{
  対話的なイベントに関する詳細は \code{\link{getGraphicsEvent}} を見よ．
}
\examples{
dev.capabilities()
}
\keyword{ dplot }

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/dev.capabilities.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-12 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dev.capabilities}
%\alias{dev.capabilities}
%\title{Query Capabilities of the Current Graphics Device}
%\description{
%  Query the capabilities of the current graphics device.
%}
%\usage{
%dev.capabilities(what = NULL)
%}
%\arguments{
%  \item{what}{a character vector partially matching the names of the
%    components listed in section \sQuote{Value}, or \code{NULL} which
%    lists all available capabilities.}
%}
%\details{
%  The capabilities have to be specified by the author of the graphics
%  device, unless they can be deduced from missing hooks.  Thus they will
%  often by returned as \code{NA}, and may reflect the maximal
%  capabilities of the underlying device where several output formats are
%  supported by one device.
%
%  Most recent devices support semi-transparent colours provided the
%  graphics format does (which PostScript does not).  On the other hand,
%  relatively few graphics formats support (fully or semi-) transparent
%  backgrounds: generally the latter is found only in PDF and PNG plots.
%}
%\value{
%  A named list with some or all of the following components, any of which may
%  take value \code{NA}:
%  \item{semiTransparency}{logical:  Does the device support
%    semi-transparent colours?}
%  \item{transparentBackground}{character:  Does the device support
%    (semi)-transparent backgrounds?  Possible values are \code{"no"},
%    \code{"fully"} (only full transparency) and \code{"semi"}
%    (semi-transparent background colours are supported).}
%  \item{rasterImage}{character: To what extent does the device support
%    raster images as used by \code{\link{rasterImage}} and
%    \code{\link{grid.raster}}?  Possible values \code{"no"}, \code{"yes"} and
%    \code{"non-missing"} (support only for arrays without any missing
%    values).}
%  \item{capture}{logical:  Does the current device
%    support raster capture as used by \code{\link{grid.cap}}?}
%  \item{locator}{logical:  Does the current device
%    support \code{\link{locator}} and \code{\link{identify}}?}
%  \item{events}{character:  Which events can be generated on this device?
%    Currently this will be a subset of \code{c("MouseDown",
%    "MouseMove", "MouseUp", "Keybd")}, but other events may be
%    supported in the future.  }
%}
%\seealso{
%  See \code{\link{getGraphicsEvent}} for details on interactive events.
%}
%\examples{
%dev.capabilities()
%}
%\keyword{ dplot }
%
%\encoding{UTF-8}
%