% File src/library/grDevices/man/unix/x11Fonts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{X11Fonts}
\alias{X11Font}
\title{X11 のフォント}
\alias{X11Fonts}
\concept{fonts}
%%\title{X11 Fonts}
\encoding{UTF-8}
\description{
  これらの関数はデバイス独立な
  R のグラフィックスフォント名の
  X11 のフォント記述への翻訳を処理する．
}
\usage{
X11Font(font)

X11Fonts(...)
}
\arguments{
  \item{font}{X11 のフォント記述を含む文字列．}
  \item{\dots}{ディスプレイへのマッピングの名前を与える文字列か，
    又は新しい(名前付き)マッピングを定義する文字列．}
}
\details{
  これらの関数は
  \code{type = "Xlib"} である \code{\link{X11}} デバイスにだけ
  適用される -- \code{X11(type = "cairo")} はフォント選択の
  異なった機構を使う．

  そうしたデバイスは既定のフォントで作られるが
  (\code{\link{X11}} に対するドキュメントを見よ)，
  デバイスへの書き込みの際にフォントファミリを指定することも可能である
  (例えば \code{\link{par}} 中の \code{"family"} に対するドキュメントを，
  そして \pkg{grid} パッケージ中の \code{\link{gpar}} に対する
  \code{"fontfamily"} のドキュメントを見よ)．

  デバイスに送られるフォントファミリは単純な文字列で，
  X11 フォントに固有のものにマップされていなければならない．
  マッピングのりストが維持されておりユーザが変更することが出来る．

  \code{X11Fonts} 関数は既存のマッピングのリスト
  そして新しいマッピングの定義に使うことが出来る．
  \code{X11Font} 関数は新しいマッピングを作るのに使うことが出来る．

  既定のマッピングは三つのデバイス独立なフォントファミリ名に対して
  低供されている：
  sans-serif フォントに対しては \code{"sans"}，
  serif フォントに対しては \code{"serif"} そして
  monospace フォントに対しては \code{"mono"}．
  追加のマッピング
  \code{"Helvetica"} (デバイスの既定)， \code{"Times"},
  \code{"CyrHelvetica"}, \code{"CyrTimes"}
  (キリル文字を持つフォントのバージョン，少なくとも Linux 上)，
  \code{"Arial"}
  (OS X と Solaris を含むある種のプラットフォーム上)，そして
  \code{"Mincho"} (CJK フォント) が提供されている．
}
\seealso{
  \code{\link{X11}}
}
\examples{
X11Fonts()
X11Fonts("mono")
utopia <- X11Font("-*-utopia-*-*-*-*-*-*-*-*-*-*-*-*")
X11Fonts(utopia = utopia)
}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/unix/x11Fonts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{X11Fonts}
%\alias{X11Font}
%\alias{X11Fonts}
%\concept{fonts}
%\title{X11 Fonts}
%\description{
%  These functions handle the translation of a device-independent R graphics
%  font family name to an X11 font description.
%}
%\usage{
%X11Font(font)
%
%X11Fonts(...)
%}
%\arguments{
%  \item{font}{a character string containing an X11 font description.}
%  \item{\dots}{either character strings naming mappings to display,
%    or new (named) mappings to define.}
%}
%\details{
%  These functions apply only to an \code{\link{X11}} device with
%  \code{type = "Xlib"} -- \code{X11(type = "cairo")} uses a different
%  mechanism to select fonts.
%
%  Such a  device is created with a default font (see
%  the documentation for \code{\link{X11}}), but it is also possible
%  to specify a font family when drawing to the device (for example, see
%  the documentation for \code{"family"} in \code{\link{par}} and for
%  \code{"fontfamily"} in \code{\link{gpar}} in the \pkg{grid} package).
%
%  The font family sent to the device is a simple string name, which must be
%  mapped to something more specific to X11 fonts.  A list of
%  mappings is maintained and can be modified by the user.
%
%  The \code{X11Fonts} function can be used to list existing
%  mappings and to define new mappings.  The \code{X11Font}
%  function can be used to create a new mapping.
%
%  Default mappings are provided for three device-independent font family
%  names: \code{"sans"} for a sans-serif font, \code{"serif"} for a serif
%  font and \code{"mono"} for a monospaced font.  Further mappings are
%  provided for \code{"Helvetica"} (the device default), \code{"Times"},
%  \code{"CyrHelvetica"}, \code{"CyrTimes"} (versions of these fonts with
%  Cyrillic support, at least on Linux), \code{"Arial"} (on some
%  platforms including OS X and Solaris) and \code{"Mincho"} (a CJK
%  font).
%}
%\seealso{
%  \code{\link{X11}}
%}
%\examples{
%X11Fonts()
%X11Fonts("mono")
%utopia <- X11Font("-*-utopia-*-*-*-*-*-*-*-*-*-*-*-*")
%X11Fonts(utopia = utopia)
%}
%\keyword{device}
%
