% File src/library/grDevices/man/xfig.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{xfig}
\title{XFig グラフィックスデバイス}
\alias{xfig}
%%\title{XFig Graphics Device}
\description{
  \code{xfig} は
  XFig (バージョン 3.2)グラフィックスを生成するグラフィックスデバイス
  を開始する．

  補助関数 \code{ps.options} は
  \code{xfig} と \code{postscript} に対する既定値を
  設定したり眺めたり(もし引数無しで呼びだされた時)
  するのに使える．
}
\usage{
xfig(file = if(onefile) "Rplots.fig" else "Rplot\%03d.fig",
     onefile = FALSE, encoding = "none",
     paper = "default", horizontal = TRUE,
     width = 0, height = 0, family = "Helvetica",
     pointsize = 12, bg = "transparent", fg = "black",
     pagecentre = TRUE, defaultfont = FALSE, textspecial = FALSE)
}
\arguments{
  \item{file}{ファイル名を与える文字列．
    \code{onefile = FALSE} と共に使うには
    \code{"Rplot\%03d.fig"} (この場合の既定値)のような C の整数書式
    を使う．    
    (更なる詳細は \code{\link{postscript}} を見よ．)
  }
  \item{onefile}{論理値：もし真なら複数の図を一つのファイルに許す．
    もし偽ならファイル毎に一つだけのページを仮定しページ番号を含む
    ファイル番号を生成する．}
  \item{encoding}{Tテキスト文字を書くエンコーディング．
    既定では再エンコーディングしない．
    これは \code{\link{iconv}} が認識する任意のエンコーディングで良い：
    西欧の UTF-8 ロケールでは恐らく
    \code{latin1} の様な8ビットエンコーディング，
    東アジアのロケールでは
    \code{EUC} エンコーディングが必要になるであろう．
    もし再エンコーディングが失敗すると，文字列は警告と共に
    現在のエンコーディングで書かれる．}
  \item{paper}{用紙領域のサイズ．選択肢は
    \code{"A4"}, \code{"Letter"} そして \code{"Legal"} (そしてこれらは
    小文字でも良い)．更に既定値の \code{"default"} も良い．
    もしこれが選ばれると用紙サイズはもいｓそれが
    設定され空でなければオプション \code{"papersize"} から取られ，
    さもなければ \code{"A4"} とされる．}
  \item{horizontal}{プリントイメージの方向，論理値．
    既定は真でランドスケープ．}
  \item{width, height}{
    インチ単位のグラフィックス領域の幅と高さ．
    既定値は各余白に0.5インチを取った全ページを使う．
    (更なる詳細は \code{\link{postscript}} を見よ．)}
  \item{family}{使用されるフォントファミリ．
    \code{"AvantGarde"}, \code{"Bookman"}, \code{"Courier"},\cr
    \code{"Helvetica"} (既定値), \code{"Helvetica-Narrow"},
    \code{"NewCenturySchoolbook"}, \code{"Palatino"} 又は
    \code{"Times"} のどれかでなければならない．任意の他の値は
    警告と共に \code{"Helvetica"} に置き換えられる．}
  \item{pointsize}{使用される既定ポイントサイズ．}
  \item{bg}{使用される初期背景色．}
  \item{fg}{使用される初期前景色．}
  \item{pagecentre}{論理値：デバイス領域はページの中央に置かれるべきか?}
  \item{defaultfont}{論理値：デバイスは xfig の既定フォントを使うべきか?}
  \item{textspecial}{論理値：デバイスは全てのテキスト要素に対し
    textspecial フラグをたてるべきか?
    これは xfig 図から pstex を生成する際に有用である．}
}
%%>>> REAL DOC in SOURCE:    ../../../main/devices.c  &   ../../../unix/devPS.c
\details{
  \code{xfig} は一つのファイルに複数のプロットを生成できるが，
  XFig 書式はそれらを眺める時どのように分離するのかを述べていない．
  従って \code{onefile = FALSE} が既定値である．

  \code{file} 引数は \code{\link{sprintf}} によって使われるような
  C の整数書式として解釈され，整数引数はページ番号になる．
  既定値はファイル \file{Rplot001.fig}, \dots, \file{Rplot999.fig},
  \file{Rplot1000.fig}, \dots を与える．

  \code{par(lwd =)} で制御される線幅は
  5/6*1/72 インチの倍数である．1未満の倍数も許される．
  \code{cex = 1} の \code{pch = "."} は側面が
  1/72 インチの正方形に対応する．

  Windows のユーザは WinFIG
  (\url{http://www.schmidt-web-berlin.de/WinFIG.htm}, shareware)，
  又は Cygwin の下で XFig を使うことが出来る．
}
\note{
  幾つかの線テキスチャ(\code{0 <= lty < 4})だけが使われる．いつかはこれは
  部分的に救済されるかもしれないが，
  XFig ファイル書式は \R モデルの様に一般的な線テキスチャを
  認めない．未実装の線テキスチャは\emph{ダッシュと二重ドット}で表示される．

  ファイル毎に 512 色(プラス白と黒)の制限がある．
}
\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 内で設定されているグラフィックスデバイス
  に対する慣例の実装を説明している．

  \itemize{
    \item 既定サイズは全ての側面に
    0.25 インチの余白を持つペーパーサイズ．
    \item フォントのサイズはビッグポイント．
    \item 既定のフォントファミリは Helvetica．
    \item 線幅は整数で，5/432 インチの倍数．
    \item 円半径は 1/1200 インチの倍数．
    \item 色は表示/プリントアプリケーションにより解釈される．
  }
}
\author{
  Brian Ripley.  \code{defaultFont} と \code{textSpecial} に対する
  サポートは Sebastian Fischmeister の貢献．
}
\seealso{
  \code{\link{Devices}},
  \code{\link{postscript}},
  \code{\link{ps.options}}.
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/xfig.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xfig}
%\alias{xfig}
%\title{XFig Graphics Device}
%\description{
%  \code{xfig} starts the graphics device driver for producing XFig
%  (version 3.2) graphics.
%
%  The auxiliary function \code{ps.options} can be used to set and view
%  (if called without arguments) default values for the arguments to
%  \code{xfig} and \code{postscript}.
%}
%\usage{
%xfig(file = if(onefile) "Rplots.fig" else "Rplot\%03d.fig",
%     onefile = FALSE, encoding = "none",
%     paper = "default", horizontal = TRUE,
%     width = 0, height = 0, family = "Helvetica",
%     pointsize = 12, bg = "transparent", fg = "black",
%     pagecentre = TRUE, defaultfont = FALSE, textspecial = FALSE)
%}
%\arguments{
%  \item{file}{a character string giving the name of the file.   For use
%    with \code{onefile = FALSE} give a C integer format such as
%    \code{"Rplot\%03d.fig"} (the default in that case).
%    (See \code{\link{postscript}} for further details.)
%  }
%  \item{onefile}{logical: if true allow multiple figures
%    in one file. If false, assume only one page per file and generate a
%    file number containing the page number.}
%  \item{encoding}{The encoding in which to write text strings.  The
%    default is not to re-encode.  This can be any encoding recognized by
%    \code{\link{iconv}}: in a Western UTF-8 locale you probably want to
%    select an 8-bit encoding such as \code{latin1}, and in an East Asian
%    locale an \code{EUC} encoding.  If re-encoding fails, the text
%    strings will be written in the current encoding with a warning.}
%  \item{paper}{the size of paper region.  The choices
%    are \code{"A4"}, \code{"Letter"} and \code{"Legal"} (and these
%    can be lowercase).  A further choice is \code{"default"}, which
%    is the default.  If this is selected, the papersize is taken
%    from the option \code{"papersize"} if that is set to a non-empty
%    value, otherwise \code{"A4"}.}
%  \item{horizontal}{the orientation of the printed image, a
%    logical.  Defaults to true, that is landscape orientation.}
%  \item{width, height}{the width and height of the
%    graphics region in inches.  The default is to use the entire
%    page less a 0.5 inch overall margin in each direction.  (See
%    \code{\link{postscript}} for further details.)}
%  \item{family}{the font family to be used.  This must be one
%    of \code{"AvantGarde"}, \code{"Bookman"}, \code{"Courier"},
%    \code{"Helvetica"} (the default), \code{"Helvetica-Narrow"},
%    \code{"NewCenturySchoolbook"}, \code{"Palatino"} or
%    \code{"Times"}.  Any other value is replaced by
%    \code{"Helvetica"}, with a warning.}
%  \item{pointsize}{the default point size to be used.}
%  \item{bg}{the initial background color to be used.}
%  \item{fg}{the initial foreground color to be used.}
%  \item{pagecentre}{logical: should the device region be centred on the
%    page?}
%  \item{defaultfont}{logical: should the device use xfig's default
%    font?}
%  \item{textspecial}{logical: should the device set the textspecial flag
%  for all text elements. This is useful when generating pstex from xfig
%  figures.}
%}
%%%>>> REAL DOC in SOURCE:    ../../../main/devices.c  &   ../../../unix/devPS.c
%\details{
%  Although \code{xfig} can produce multiple plots in one file, the XFig
%  format does not say how to separate or view them.  So
%  \code{onefile = FALSE} is the default.
%
%  The \code{file} argument is interpreted as a C integer format as used
%  by \code{\link{sprintf}}, with integer argument the page number.
%  The default gives files \file{Rplot001.fig}, \dots, \file{Rplot999.fig},
%  \file{Rplot1000.fig}, \dots.
%
%  Line widths as controlled by \code{par(lwd =)} are in multiples of
%  5/6*1/72 inch.  Multiples less than 1 are allowed.  \code{pch = "."} with
%  \code{cex = 1} corresponds to a square of side 1/72 inch.
%
%  Windows users can make use of WinFIG
%  (\url{http://www.schmidt-web-berlin.de/WinFIG.htm}, shareware), or
%  XFig under Cygwin.
%}
%\note{
%  Only some line textures (\code{0 <= lty < 4}) are used.  Eventually this
%  may be partially remedied, but the XFig file format does not allow as
%  general line textures as the \R model.  Unimplemented line textures
%  are displayed as \emph{dash-double-dotted}.
%
%  There is a limit of 512 colours (plus white and black) per file.
%}
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is the paper size with a 0.25 inch
%    border on all sides.
%    \item Font sizes are in big points.
%    \item The default font family is Helvetica.
%    \item Line widths are integers, multiples of 5/432 inch.
%    \item Circle radii are multiples of 1/1200 inch.
%    \item Colours are interpreted by the viewing/printing application.
%  }
%}
%\author{
%  Brian Ripley.  Support for \code{defaultFont} and \code{textSpecial}
%  contributed by Sebastian Fischmeister.
%}
%\seealso{
%  \code{\link{Devices}},
%  \code{\link{postscript}},
%  \code{\link{ps.options}}.
%}
%\keyword{device}
%
%\encoding{UTF-8}
%