% File src/library/graphics/man/matplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{matplot}
\alias{matplot}
\alias{matpoints}
\alias{matlines}
\title{Plot Columns of Matrices}
\usage{
matplot(x, y, type = "p", lty = 1:5, lwd = 1, lend = par("lend"),
        pch = NULL,
        col = 1:6, cex = NULL, bg = NA,
        xlab = NULL, ylab = NULL, xlim = NULL, ylim = NULL,
        \dots, add = FALSE, verbose = getOption("verbose"))

matpoints(x, y, type = "p", lty = 1:5, lwd = 1, pch = NULL,
          col = 1:6, \dots)

matlines (x, y, type = "l", lty = 1:5, lwd = 1, pch = NULL,
          col = 1:6, \dots)
}
\arguments{
  \item{x,y}{プロットに対するデータのベクトル又は行列．
    行の数は一致しなければならない．もしそれらの一方が無ければ，
    他方が \code{y} とされ，\code{x} ベクトルは \code{1:n} とされる．
    欠損値(\code{NA})が許される．}
  \item{type}{文字列(長さ 1 のベクトル)または一文字のベクトルで
    \code{y} の各列に対するプロットのタイプを指示する，
    全ての可能なタイプについては \code{\link{plot}} を見よ．
    \code{type} の最初の文字は最初のプロットを定義し，
    二番目は二番目を定義する，等．
    \code{type} 中の文字はリサイクルされる；例えば \code{"pl"}
    は交互に点と線をプロットする．}
  \item{lty,lwd,lend}{線種，幅，そしてエンドスタイルのベクトル．
    たとえ線が全ての列に対してプロットされなくても，
    最初の要素は最初の列，二番目の要素は二番目の列，等である．
    線種は全てのプロットが描かれるまで周期的に使われる．}
  \item{pch}{文字列，一文字のベクトル，そして
    プロット文字に対する整数，\code{\link{points}} を見よ．
    最初の文字は最初のプロットに対するプロット文字であり，
    二番目の文字は二番目のプロットに対するプロット文字である，等．
    既定値は数字(1 から 9, 0) で小文字と大文字になる．
%%__FIXME__ Which of the following is still true; what's the "right" UI ?
%  To mix special plotting symbols (those specified by integers) and
%  plotting characters, either use character escapes \code{pch = "Xe002"}
%  or figure out the numeric equivalent of the ASCII character,
%  \code{pch = c(88, 2)}.
  }
  \item{col}{色のベクトル．色は周期的に使われる．}
  \item{cex}{文字の拡大サイズのベクトルで，周期的に使われる．
    これは \code{\link{par}("cex")} の倍数として使われる．
    \code{NULL} は \code{1.0} に等しい．}
  \item{bg}{\code{\link{points}} に於けるような
    \code{pch = 21:25} で与えられるプロットシンボルに対する
    背景(塗りつぶし)色のベクトル．
    既定の \code{NA} は基礎にある関数 \code{\link{plot.xy}}
    のそれに対応する．}
  \item{xlab, ylab}{\code{\link{plot}} に於けるような x と y 軸のタイトル．}
  \item{xlim, ylim}{\code{\link{plot}} に於けるような x と y 軸の範囲．}
  \item{\dots}{グラフィックスパラメータ(\code{\link{par}} を見よ)と任意の
    \code{plot} への追加パラメータ，典型的には \code{\link{plot.default}}，
    をまたこの関数への引数として与えることが出来る．
    従って \code{\link{par}} の下で説明されたようなグラフィックス引数と
    \code{\link{title}} への引数をこの関数に提供される．}
  \item{add}{論理値．もし \code{TRUE} ならばプロットは現在のものに
    \code{\link{points}} と \code{\link{lines}} を使って
    付け加えられる．}
  \item{verbose}{論理値．もし \code{TRUE} ならばなされることについて
    一行を表示する．}
}
\section{副作用}{関数 \code{matplot} は新しいプロットを作る；
  \code{matpoints} と \code{matlines} は現在のプロットに付け加える．}
\description{
  一つの行列の列を他の列に対してプロットする．
}
\details{
  欠損値を含む点はプロットされない．

  \code{x} の最初の列は \code{y} の最初の列に対して，
  \code{x} の二番目の列は \code{y} の二番目の列に対して
  プロットされる，等．
  もし一つの行列がより少ない列を持てば，
  プロットは列を通してリサイクルされる．
  (特に \code{x} 又は \code{y} はベクトルかもしれず，
  他の引数の全ての列に対してプロットされる．)

  \code{col, cex, lty, lwd} の最初の要素は最初の線のみならず軸を
  プロットする．

  シンボルのプロットは線とともに描かれ，これらの関数は
  線のスタイルを変更する可能性があるので，
  プロットシンボルを使う際は恐らく \code{lty = 1} を使う必要が
  ある．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{plot}}, \code{\link{points}}, \code{\link{lines}},
  \code{\link{matrix}}, \code{\link{par}}.
}
\examples{
require(grDevices)
matplot((-4:5)^2, main = "Quadratic") # ほとんど plot(*) と同じ
sines <- outer(1:20, 1:4, function(x, y) sin(x / 20 * pi * y))
matplot(sines, pch = 1:4, type = "o", col = rainbow(ncol(sines)))
matplot(sines, type = "b", pch = 21:23, col = 2:5, bg = 2:5,
        main = "matplot(...., pch = 21:23, bg = 2:5)")

x <- 0:50/50
matplot(x, outer(x, 1:8, function(x, k) sin(k*pi * x)),
        ylim = c(-2,2), type = "plobcsSh",
        main= "matplot(,type = \"plobcsSh\" )")
## pch & type = 1文字のベクトル：
matplot(x, outer(x, 1:4, function(x, k) sin(k*pi * x)),
        pch = letters[1:4], type = c("b","p","o"))

lends <- c("round","butt","square")
matplot(matrix(1:12, 4), type="c", lty=1, lwd=10, lend=lends)
text(cbind(2.5, 2*c(1,3,5)-.4), lends, col= 1:3, cex = 1.5)

table(iris$Species) # 因子 'Species' を持つデータフレーム
iS <- iris$Species == "setosa"
iV <- iris$Species == "versicolor"
op <- par(bg = "bisque")
matplot(c(1, 8), c(0, 4.5), type =  "n", xlab = "Length", ylab = "Width",
        main = "Petal and Sepal Dimensions in Iris Blossoms")
matpoints(iris[iS,c(1,3)], iris[iS,c(2,4)], pch = "sS", col = c(2,4))
matpoints(iris[iV,c(1,3)], iris[iV,c(2,4)], pch = "vV", col = c(2,4))
legend(1, 4, c("    Setosa Petals", "    Setosa Sepals",
               "Versicolor Petals", "Versicolor Sepals"),
       pch = "sSvV", col = rep(c(2,4), 2))

nam.var <- colnames(iris)[-5]
nam.spec <- as.character(iris[1+50*0:2, "Species"])
iris.S <- array(NA, dim = c(50,4,3),
                dimnames = list(NULL, nam.var, nam.spec))
for(i in 1:3) iris.S[,,i] <- data.matrix(iris[1:50+50*(i-1), -5])

matplot(iris.S[, "Petal.Length",], iris.S[, "Petal.Width",], pch = "SCV",
        col = rainbow(3, start = 0.8, end = 0.1),
        sub = paste(c("S", "C", "V"), dimnames(iris.S)[[3]],
                    sep = "=", collapse= ",  "),
        main = "Fisher's Iris Data")
par(op)
}
\keyword{hplot}
\keyword{aplot}
\keyword{array}

\encoding{UTF8}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/matplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{matplot}
%\alias{matplot}
%\alias{matpoints}
%\alias{matlines}
%\title{Plot Columns of Matrices}
%\usage{
%matplot(x, y, type = "p", lty = 1:5, lwd = 1, lend = par("lend"),
%        pch = NULL,
%        col = 1:6, cex = NULL, bg = NA,
%        xlab = NULL, ylab = NULL, xlim = NULL, ylim = NULL,
%        \dots, add = FALSE, verbose = getOption("verbose"))
%
%matpoints(x, y, type = "p", lty = 1:5, lwd = 1, pch = NULL,
%          col = 1:6, \dots)
%
%matlines (x, y, type = "l", lty = 1:5, lwd = 1, pch = NULL,
%          col = 1:6, \dots)
%}
%\arguments{
%  \item{x,y}{vectors or matrices of data for plotting.  The number of
%    rows should match.  If one of them are missing, the other is taken
%    as \code{y} and an \code{x} vector of \code{1:n} is used.
%    Missing values (\code{NA}s) are allowed.}
%  \item{type}{character string (length 1 vector) or vector of 1-character
%    strings indicating the type of plot for each
%    column of \code{y}, see \code{\link{plot}} for all possible
%    \code{type}s.  The first character of \code{type}
%    defines the first plot, the second character the second, etc.
%    Characters in \code{type} are cycled through; e.g., \code{"pl"}
%    alternately plots points and lines.}
%  \item{lty,lwd,lend}{vector of line types, widths, and end styles.
%    The first element is for the first column, the second element for
%    the second column, etc., even if lines are not plotted for all
%    columns. Line types will be used cyclically until all plots are
%    drawn.}
%  \item{pch}{character string or vector of 1-characters or integers for
%    plotting characters, see \code{\link{points}}.
%    The first character is the plotting-character for the first plot,
%    the second for the second, etc.  The default is the digits (1
%    through 9, 0) then the lowercase and uppercase letters.
%%%__FIXME__ Which of the following is still true; what's the "right" UI ?
%%  To mix special plotting symbols (those specified by integers) and
%%  plotting characters, either use character escapes \code{pch = "Xe002"}
%%  or figure out the numeric equivalent of the ASCII character,
%%  \code{pch = c(88, 2)}.
%  }
%  \item{col}{vector of colors.  Colors are used cyclically.}
%  \item{cex}{vector of character expansion sizes, used cyclically.
%    This works as a multiple of \code{\link{par}("cex")}.  \code{NULL} is
%    equivalent to \code{1.0}. }
%  \item{bg}{vector of background (fill) colors for the open plot
%    symbols given by \code{pch = 21:25} as in \code{\link{points}}.  The
%    default \code{NA} corresponds to the one of the underlying function
%    \code{\link{plot.xy}}.}
%  \item{xlab, ylab}{titles for x and y axes, as in \code{\link{plot}}.}
%  \item{xlim, ylim}{ranges of x and y axes, as in \code{\link{plot}}.}
%  \item{\dots}{Graphical parameters (see \code{\link{par}}) and any further
%    arguments of \code{plot}, typically \code{\link{plot.default}}, may also be
%    supplied as arguments to this function.  Hence, the high-level
%    graphics control arguments described under \code{\link{par}} and the
%    arguments to \code{\link{title}} may be supplied to this function.}
%  \item{add}{logical.  If \code{TRUE}, plots are added to current one,
%    using \code{\link{points}} and \code{\link{lines}}.}
%  \item{verbose}{logical.  If \code{TRUE}, write one line of what is
%    done.}
%}
%\section{Side Effects}{Function \code{matplot} generates a new plot;
%  \code{matpoints} and \code{matlines} add to the current one.}
%\description{
%  Plot the columns of one matrix against the columns of another.
%}
%\details{
%  Points involving missing values are not plotted.
%
%  The first column of \code{x} is plotted against the first column of
%  \code{y}, the second column of \code{x} against the second column of
%  \code{y}, etc.  If one matrix has fewer columns, plotting will cycle
%  back through the columns again.  (In particular, either \code{x} or
%  \code{y} may be a vector, against which all columns of the other
%  argument will be plotted.)
%
%  The first element of \code{col, cex, lty, lwd} is used to plot the axes
%  as well as the first line.
%
%  Because plotting symbols are drawn with lines and because these
%  functions may be changing the line style, you should probably specify
%  \code{lty = 1} when using plotting symbols.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{plot}}, \code{\link{points}}, \code{\link{lines}},
%  \code{\link{matrix}}, \code{\link{par}}.
%}
%\examples{
%require(grDevices)
%matplot((-4:5)^2, main = "Quadratic") # almost identical to plot(*)
%sines <- outer(1:20, 1:4, function(x, y) sin(x / 20 * pi * y))
%matplot(sines, pch = 1:4, type = "o", col = rainbow(ncol(sines)))
%matplot(sines, type = "b", pch = 21:23, col = 2:5, bg = 2:5,
%        main = "matplot(...., pch = 21:23, bg = 2:5)")
%
%x <- 0:50/50
%matplot(x, outer(x, 1:8, function(x, k) sin(k*pi * x)),
%        ylim = c(-2,2), type = "plobcsSh",
%        main= "matplot(,type = \"plobcsSh\" )")
%## pch & type =  vector of 1-chars :
%matplot(x, outer(x, 1:4, function(x, k) sin(k*pi * x)),
%        pch = letters[1:4], type = c("b","p","o"))
%
%lends <- c("round","butt","square")
%matplot(matrix(1:12, 4), type="c", lty=1, lwd=10, lend=lends)
%text(cbind(2.5, 2*c(1,3,5)-.4), lends, col= 1:3, cex = 1.5)
%
%table(iris$Species) # is data.frame with 'Species' factor
%iS <- iris$Species == "setosa"
%iV <- iris$Species == "versicolor"
%op <- par(bg = "bisque")
%matplot(c(1, 8), c(0, 4.5), type =  "n", xlab = "Length", ylab = "Width",
%        main = "Petal and Sepal Dimensions in Iris Blossoms")
%matpoints(iris[iS,c(1,3)], iris[iS,c(2,4)], pch = "sS", col = c(2,4))
%matpoints(iris[iV,c(1,3)], iris[iV,c(2,4)], pch = "vV", col = c(2,4))
%legend(1, 4, c("    Setosa Petals", "    Setosa Sepals",
%               "Versicolor Petals", "Versicolor Sepals"),
%       pch = "sSvV", col = rep(c(2,4), 2))
%
%nam.var <- colnames(iris)[-5]
%nam.spec <- as.character(iris[1+50*0:2, "Species"])
%iris.S <- array(NA, dim = c(50,4,3),
%                dimnames = list(NULL, nam.var, nam.spec))
%for(i in 1:3) iris.S[,,i] <- data.matrix(iris[1:50+50*(i-1), -5])
%
%matplot(iris.S[, "Petal.Length",], iris.S[, "Petal.Width",], pch = "SCV",
%        col = rainbow(3, start = 0.8, end = 0.1),
%        sub = paste(c("S", "C", "V"), dimnames(iris.S)[[3]],
%                    sep = "=", collapse= ",  "),
%        main = "Fisher's Iris Data")
%par(op)
%}
%\keyword{hplot}
%\keyword{aplot}
%\keyword{array}
%
%\encoding{UTF8}
%