% File src/library/grid/man/grid.bezier.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.bezier}
%@%\alias{ベジエ曲線を描く}
\alias{grid.bezier}
\alias{bezierGrob}
%\title{ Draw a Bezier Curve }
\title{ベジエ曲線を描く}
\description{
  これらの関数はベジエ曲線を作り描く
  (四つの制御点に関して描かれる曲線)．
}
\usage{
grid.bezier(...)
bezierGrob(x = c(0, 0.5, 1, 0.5), y = c(0.5, 1, 0.5, 0),
            id = NULL, id.lengths = NULL,
            default.units = "npc", arrow = NULL,
            name = NULL, gp = gpar(), vp = NULL)
}
\arguments{
  \item{x}{
    スプライン制御点の x 位置を指定する数値ベクトルまたは単位オブジェクト．}
  \item{y}{
    スプライン制御点の y 位置を指定する数値ベクトルまたは単位オブジェクト．}
  \item{id}{
    \code{x} と \code{y} 中の位置を複数のベジエ曲線に分離するのに
    使われる数値ベクトル．
    同じ \code{id} を持つ全ての位置は同じベジエ曲線に属する．}
  \item{id.lengths}{
    \code{x} と \code{y} 中の位置を複数のベジエ曲線に分離するのに
    使われる数値ベクトル．
    個別のベジエ曲線を構成する位置の引き続くブロックを指定する．}
  \item{default.units}{
    もし \code{x} や \code{y} が数値ベクトルとしてだけ
    与えられた時使われる既定の単位を指示する文字列．}
  \item{arrow}{
    ベジエ曲線のどちらかの端点に置かれる \code{arrow}
    関数が生成するような矢尻を記述するリスト．}
  \item{name}{文字列識別子．}
  \item{gp}{
    クラス \code{gpar} のオブジェクトで，典型的には
    関数 \code{gpar} の呼び出しからの出力．これは基本的に
    グラフィカルパラメータ設定のリストである．}
  \item{vp}{グリッドのビューポートオブジェクト(または NULL)．}
  \item{\dots}{
    \code{bezierGrob} に渡される引数．}
}
\value{
  grob オブジェクト．
}
\details{
  どちらの関数も beziergrob (ベジエ曲線を記述するグラフィカルオブジェクト)を
  作るが \code{grid.bezier} だけがベジエ曲線を描く．

  ベジエ曲線は四つの制御点に関して描かれる直線である．

  \code{x} と \code{y} に対する欠損値は許されない
  (つまり制御点が欠損することは不正である)．

  曲線は現在
  X-スプラインに基づく近似を使い描かれる．
}
\seealso{
  \link{Grid},
  \code{\link{viewport}},
  \code{\link{arrow}}.

  \code{\link{grid.xspline}}.
}
\examples{
x <- c(0.2, 0.2, 0.4, 0.4)
y <- c(0.2, 0.4, 0.4, 0.2)

grid.newpage()
grid.bezier(x, y)
grid.bezier(c(x, x + .4), c(y + .4, y + .4),
            id=rep(1:2, each=4))
grid.segments(.4, .6, .6, .6)
grid.bezier(x, y,
            gp=gpar(lwd=3, fill="black"),
            arrow=arrow(type="closed"),
            vp=viewport(x=.9))
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.bezier.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.bezier}
%\alias{grid.bezier}
%\alias{bezierGrob}
%\title{ Draw a Bezier Curve }
%\description{
%  These functions create and draw Bezier Curves (a curve drawn
%  relative to 4 control points).
%}
%\usage{
%grid.bezier(...)
%bezierGrob(x = c(0, 0.5, 1, 0.5), y = c(0.5, 1, 0.5, 0),
%            id = NULL, id.lengths = NULL,
%            default.units = "npc", arrow = NULL,
%            name = NULL, gp = gpar(), vp = NULL)
%}
%\arguments{
%  \item{x}{A numeric vector or unit object specifying x-locations of
%    spline control points.}
%  \item{y}{A numeric vector or unit object specifying y-locations of
%    spline control points.}
%  \item{id}{A numeric vector used to separate locations in \code{x} and
%    \code{y} into multiple beziers.  All locations with the same
%    \code{id} belong to the same bezier.}
%  \item{id.lengths}{A numeric vector used to separate locations in \code{x} and
%    \code{y} into multiple bezier.  Specifies consecutive blocks of
%    locations which make up separate beziers.}
%  \item{default.units}{A string indicating the default units to use
%    if \code{x} or \code{y}
%    are only given as numeric vectors.}
%  \item{arrow}{A list describing arrow heads to place at either end
%    of the bezier, as produced by the \code{arrow} function.}
%  \item{name}{ A character identifier. }
%  \item{gp}{An object of class \code{gpar}, typically the output
%    from a call to the function \code{gpar}.  This is basically
%    a list of graphical parameter settings.}
%  \item{vp}{A Grid viewport object (or NULL).}
%  \item{\dots}{Arguments to be passed to \code{bezierGrob}.}
%}
%\value{
%  A grob object.
%}
%\details{
%  Both functions create a beziergrob (a graphical object describing a
%  Bezier curve), but only \code{grid.bezier}
%  draws the Bezier curve.
%
%  A Bezier curve is a line drawn relative to 4 control points.
%
%  Missing values are not allowed for \code{x} and \code{y}
%  (i.e., it is not valid for a control point to be missing).
%
%  The curve is currently drawn using an approximation based on
%  X-splines.
%}
%\seealso{
%  \link{Grid},
%  \code{\link{viewport}},
%  \code{\link{arrow}}.
%
%  \code{\link{grid.xspline}}.
%}
%\examples{
%x <- c(0.2, 0.2, 0.4, 0.4)
%y <- c(0.2, 0.4, 0.4, 0.2)
%
%grid.newpage()
%grid.bezier(x, y)
%grid.bezier(c(x, x + .4), c(y + .4, y + .4),
%            id=rep(1:2, each=4))
%grid.segments(.4, .6, .6, .6)
%grid.bezier(x, y,
%            gp=gpar(lwd=3, fill="black"),
%            arrow=arrow(type="closed"),
%            vp=viewport(x=.9))
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%