% File src/library/grid/man/grid.clip.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{grid.clip}
%@%\alias{クリップ領域の設定}
\alias{grid.clip}
\alias{clipGrob}
\title{クリップ領域を設定する}
%\title{Set the Clipping Region}
\description{
  これらの関数は現在の座標系を変更せずに
  現在のビューポート内にクリップ領域を設定する．
}
\usage{
grid.clip(...)
clipGrob(x = unit(0.5, "npc"), y = unit(0.5, "npc"),
         width = unit(1, "npc"), height = unit(1, "npc"),
         just = "centre", hjust = NULL, vjust = NULL,
         default.units = "npc", name = NULL, vp = NULL)
}
\arguments{
  \item{x}{
    x 位置を指定する数値ベクトルか単位オブジェクト．}
  \item{y}{
    y 位置を指定する数値ベクトルか単位オブジェクト．}
  \item{width}{
    幅を指定する数値ベクトルか単位オブジェクト．}
  \item{height}{
    高さを指定する数値ベクトルか単位オブジェクト．}
  \item{just}{クリップ矩形の
    その (x, y) 位置に関する位置揃え．
    もし二つの値があれば，最初の値は水平位置揃え，二番目の値は
    垂直位置揃えを指定する．
    可能な文字値は：\code{"left"},
    \code{"right"}, \code{"centre"}, \code{"center"}, \code{"bottom"},
    そして \code{"top"}．数値に対しては
    0 は左揃えで 1 は右揃えを意味する．
  }
  \item{hjust}{水平位置揃えを指定する数値ベクトル．
    もし指定されると \code{just} 設定を上書きする．}
  \item{vjust}{垂直位置揃えを指定する数値ベクトル．
    もし指定されると \code{just} 設定を上書きする．}
  \item{default.units}{
    もし \code{x}, \code{y}, \code{width} または \code{height}
    が数値ベクトルとしてだけ与えられている時使用される
    既定単位を指示する文字列．}
  \item{name}{文字列識別子．}
  \item{vp}{グリッドのビューポートオブジェクト(または NULL)．}
  \item{\dots}{
    \code{clipGrob} に渡される引数．}
}
\details{
  どちらの関数もクリップ矩形
  (クリップ矩形を記述するグラフィカルオブジェクト)を作るが，
  \code{grid.clip} だけがクリップを実行する．

  ビューポートのプッシュとポップは
  \emph{常に}クリップ grob によって設定されたクリップ領域を上書きし，
  ビューポートがクリップ領域を明示的に実行するかどうかに依存しない．
}
\value{
  \code{clipGrob} はクリップ grob を返す．
}
\author{Paul Murrell}
\seealso{
  \link{Grid},
  \code{\link{viewport}}
}
\examples{
# ビューポート全体に渡って描画するがクリップする
grid.clip(x = 0.3, width = 0.1)
grid.lines(gp=gpar(col="green", lwd=5))
# ビューポート全体に渡って描画するがクリップする(異なった場所に)
grid.clip(x = 0.7, width = 0.1)
grid.lines(gp=gpar(col="red", lwd=5))
# ビューポートが新しいクリップ領域を設定する
pushViewport(viewport(width=0.5, height=0.5, clip=TRUE))
grid.lines(gp=gpar(col="grey", lwd=3))
# 元々のビューポートに戻る；
# クリップ領域を以前の grid.clip() から得る
# (以前のビューポートクリップ領域からではない)
popViewport()
grid.lines(gp=gpar(col="black"))
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.clip.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.clip}
%\alias{grid.clip}
%\alias{clipGrob}
%\title{Set the Clipping Region}
%\description{
%  These functions set the clipping region within the current viewport
%  \emph{without} altering the current coordinate system.
%}
%\usage{
%grid.clip(...)
%clipGrob(x = unit(0.5, "npc"), y = unit(0.5, "npc"),
%         width = unit(1, "npc"), height = unit(1, "npc"),
%         just = "centre", hjust = NULL, vjust = NULL,
%         default.units = "npc", name = NULL, vp = NULL)
%}
%\arguments{
%  \item{x}{A numeric vector or unit object specifying x-location.}
%  \item{y}{A numeric vector or unit object specifying y-location.}
%  \item{width}{A numeric vector or unit object specifying width.}
%  \item{height}{A numeric vector or unit object specifying height.}
%  \item{just}{The justification of the clip rectangle
%    relative to its (x, y) location.  If there are two values, the first
%    value specifies horizontal justification and the second value specifies
%    vertical justification.  Possible string values are: \code{"left"},
%    \code{"right"}, \code{"centre"}, \code{"center"}, \code{"bottom"},
%    and \code{"top"}.  For numeric values, 0 means left alignment
%    and 1 means right alignment.
%  }
%  \item{hjust}{A numeric vector specifying horizontal justification.
%    If specified, overrides the \code{just} setting.}
%  \item{vjust}{A numeric vector specifying vertical justification.
%    If specified, overrides the \code{just} setting.}
%  \item{default.units}{A string indicating the default units to use
%    if \code{x}, \code{y}, \code{width}, or \code{height}
%    are only given as numeric vectors.}
%  \item{name}{ A character identifier. }
%  \item{vp}{A Grid viewport object (or NULL).}
%  \item{\dots}{Arguments passed to \code{clipGrob}.}
%}
%\details{
%  Both functions create a clip rectangle (a graphical object describing
%  a clip rectangle), but only \code{grid.clip}
%  enforces the clipping.
%
%  Pushing or popping a viewport \emph{always} overrides the clip
%  region set by a clip grob, regardless of whether that viewport
%  explicitly enforces a clipping region.
%}
%\value{
%  \code{clipGrob} returns a clip grob.
%}
%\author{Paul Murrell}
%\seealso{
%  \link{Grid},
%  \code{\link{viewport}}
%}
%\examples{
%# draw across entire viewport, but clipped
%grid.clip(x = 0.3, width = 0.1)
%grid.lines(gp=gpar(col="green", lwd=5))
%# draw across entire viewport, but clipped (in different place)
%grid.clip(x = 0.7, width = 0.1)
%grid.lines(gp=gpar(col="red", lwd=5))
%# Viewport sets new clip region
%pushViewport(viewport(width=0.5, height=0.5, clip=TRUE))
%grid.lines(gp=gpar(col="grey", lwd=3))
%# Return to original viewport;  get
%# clip region from previous grid.clip()
%# (NOT from previous viewport clip region)
%popViewport()
%grid.lines(gp=gpar(col="black"))
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%