% File src/library/grid/man/grid.convert.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.convert}
%@%\alias{convertUnit}
\alias{convertUnit}
\alias{convertX}
\alias{convertY}
\alias{convertWidth}
\alias{convertHeight}
\title{異なったグリッド座標系間の変換}
%\title{ Convert Between Different grid Coordinate Systems }
\description{
  これらの関数は単位オブジェクトを取り，
  それを異なった座標系での同値な単位オブジェクトに変換する．
}
\usage{
convertX(x, unitTo, valueOnly = FALSE)
convertY(x, unitTo, valueOnly = FALSE)
convertWidth(x, unitTo, valueOnly = FALSE)
convertHeight(x, unitTo, valueOnly = FALSE)
convertUnit(x, unitTo,
             axisFrom = "x", typeFrom = "location",
             axisTo = axisFrom, typeTo = typeFrom,
             valueOnly = FALSE)
}
\arguments{
  \item{x}{単位オブジェクト．}
  \item{unitTo}{単位をそこに変換する座標系．
    適正な座標系については \code{\link{unit}} 関数を見よ．}
  \item{axisFrom}{
    単位オブジェクトが
    x 方向の値か y 方向の値を表すかを指示する \code{"x"} か \code{"y"}．}
  \item{typeFrom}{
    単位オブジェクトが
    位置か長さかを指示する \code{"location"} か \code{"dimension"}．}
  \item{axisTo}{
    \code{axisFrom} と同じであるが，作られるべき単位オブジェクトに
    適用される．}
  \item{typeTo}{
    \code{typeFrom} であるが，
    作られるべき単位オブジェクトに適用される．}
  \item{valueOnly}{
    論理値，もし \code{TRUE} ならば関数は単位オブジェクトを返さず，
    変換された数値だけを返す． }
}
\details{
  \code{convertUnit} 関数は一般的な変換を許す．
  他の四つの関数は単に最も普通のケースに対する
  そのフロントエンドである．

  変換は現在のビューポート内で行われる．

  現在全ての適正な座標系に変換することは不可能である
  (例えば "strwidth" や "grobwidth")．
  これら全てが不可能かどうかは確かではないが，
  この段階では単に不可能のように見える．

  グリッドの通常の用法では，これらの関数は必要になるべきではない．
  もしユーザ座標系ではなく位置や次元をインチで表現したければ，
  \code{unit(0.134, "native")} の様なものではなく
  単に \code{unit(1, "inches")} の様なものを行うべきである．

  しかしながらある場合には，ユーザが単位値に基づいて
  計算を実行することが必要になり，そしてこの関数が
  必要になる．そうした場合，下の警告に留意して欲しい．
}
\value{
  指定された座標系での単位オブジェクト
  (\code{valueOnly} が \code{TRUE} でない限り，その場合は
  返り値は数値である)．
}
\author{ Paul Murrell }

\section{警告}{
  変換は現在のデバイスのサイズに対してのみ適正である．
  もしデバイスのサイズが変更されると少なくともある種の
  変換は不正になる．
  例えば，単位オブジェクトを次のように作る：
  \code{oneinch <- convertUnit(unit(1, "inches"), "native"}．
  そしてデバイスのサイズを変更すると，1インチ単位の単位オブジェクト
  は最早物理的な1インチには対応しない．
  }
\seealso{ \code{\link{unit}} }
\examples{
## 同語反復
convertX(unit(1, "inches"), "inches")
## 物理的単位
convertX(unit(2.54, "cm"), "inches")
convertX(unit(25.4, "mm"), "inches")
convertX(unit(72.27, "points"), "inches")
convertX(unit(1/12*72.27, "picas"), "inches")
convertX(unit(72, "bigpts"), "inches")
convertX(unit(1157/1238*72.27, "dida"), "inches")
convertX(unit(1/12*1157/1238*72.27, "cicero"), "inches")
convertX(unit(65536*72.27, "scaledpts"), "inches")
convertX(unit(1/2.54, "inches"), "cm")
convertX(unit(1/25.4, "inches"), "mm")
convertX(unit(1/72.27, "inches"), "points")
convertX(unit(1/(1/12*72.27), "inches"), "picas")
convertX(unit(1/72, "inches"), "bigpts")
convertX(unit(1/(1157/1238*72.27), "inches"), "dida")
convertX(unit(1/(1/12*1157/1238*72.27), "inches"), "cicero")
convertX(unit(1/(65536*72.27), "inches"), "scaledpts")

pushViewport(viewport(width=unit(1, "inches"),
                       height=unit(2, "inches"),
                       xscale=c(0, 1),
                       yscale=c(1, 3)))
  ## 位置と次元
  convertY(unit(2, "native"), "inches")
  convertHeight(unit(2, "native"), "inches")
  ## "x" から "y"  へ(変換は "inches" による)
  convertUnit(unit(1, "native"), "native",
               axisFrom="x", axisTo="y")
  ## 幾つかの値を一度に変換
  convertX(unit(c(0.5, 2.54), c("npc", "cm")),
                c("inches", "native"))
popViewport()
## 複雑な単位を変換
convertX(unit(1, "strwidth", "Hello"), "native")
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.convert.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.convert}
%\alias{convertUnit}
%\alias{convertX}
%\alias{convertY}
%\alias{convertWidth}
%\alias{convertHeight}
%\title{ Convert Between Different grid Coordinate Systems }
%\description{
%  These functions take a unit object and convert it to an
%  equivalent
%  unit object in a different coordinate system.
%}
%\usage{
%convertX(x, unitTo, valueOnly = FALSE)
%convertY(x, unitTo, valueOnly = FALSE)
%convertWidth(x, unitTo, valueOnly = FALSE)
%convertHeight(x, unitTo, valueOnly = FALSE)
%convertUnit(x, unitTo,
%             axisFrom = "x", typeFrom = "location",
%             axisTo = axisFrom, typeTo = typeFrom,
%             valueOnly = FALSE)
%}
%\arguments{
%  \item{x}{ A unit object. }
%  \item{unitTo}{ The coordinate system to convert the unit to.
%    See the \code{\link{unit}} function for valid coordinate systems.}
%  \item{axisFrom}{ Either \code{"x"} or \code{"y"} to indicate
%    whether the unit object represents a value in the x- or
%    y-direction. }
%  \item{typeFrom}{ Either \code{"location"} or \code{"dimension"}
%    to indicate whether the unit object represents a location or a
%    length. }
%  \item{axisTo}{ Same as \code{axisFrom}, but applies to the unit object
%    that is to be created. }
%  \item{typeTo}{ Same as \code{typeFrom}, but applies to the unit object
%    that is to be created. }
%  \item{valueOnly}{ A logical indicating.  If \code{TRUE} then
%    the function does not return a unit object, but rather only the
%    converted numeric values. }
%}
%\details{
%  The \code{convertUnit} function allows for general-purpose
%  conversions.  The other four functions are just more convenient
%  front-ends to it for the most common conversions.
%
%  The conversions occur within the current viewport.
%
%  It is not currently possible to convert to all valid coordinate systems
%  (e.g., "strwidth" or "grobwidth").  I'm not sure if all of these
%  are impossible, they just seem implausible at this stage.
%
%  In normal usage of grid, these functions should not be necessary.
%  If you want to express a location or dimension in inches rather
%  than user coordinates then you should simply do something like
%  \code{unit(1, "inches")} rather than something like
%  \code{unit(0.134, "native")}.
%
%  In some cases, however, it is necessary for the user to
%  perform calculations on a unit value and this function becomes
%  necessary.  In such cases, please take note of the warning below.
%}
%\value{
%  A unit object in the specified coordinate system
%  (unless \code{valueOnly} is \code{TRUE} in which case
%  the returned value is a numeric).
%}
%\author{ Paul Murrell }
%
%\section{Warning}{
%  The conversion is only valid for the current device size.
%  If the device is resized then at least some conversions will
%  become invalid.  For example, suppose that I create a unit
%  object as follows: \code{oneinch <- convertUnit(unit(1, "inches"),
%    "native"}.  Now if I resize the device, the unit object in
%  oneinch no longer corresponds to a physical length of 1 inch.
%  }
%\seealso{ \code{\link{unit}} }
%\examples{
%## A tautology
%convertX(unit(1, "inches"), "inches")
%## The physical units
%convertX(unit(2.54, "cm"), "inches")
%convertX(unit(25.4, "mm"), "inches")
%convertX(unit(72.27, "points"), "inches")
%convertX(unit(1/12*72.27, "picas"), "inches")
%convertX(unit(72, "bigpts"), "inches")
%convertX(unit(1157/1238*72.27, "dida"), "inches")
%convertX(unit(1/12*1157/1238*72.27, "cicero"), "inches")
%convertX(unit(65536*72.27, "scaledpts"), "inches")
%convertX(unit(1/2.54, "inches"), "cm")
%convertX(unit(1/25.4, "inches"), "mm")
%convertX(unit(1/72.27, "inches"), "points")
%convertX(unit(1/(1/12*72.27), "inches"), "picas")
%convertX(unit(1/72, "inches"), "bigpts")
%convertX(unit(1/(1157/1238*72.27), "inches"), "dida")
%convertX(unit(1/(1/12*1157/1238*72.27), "inches"), "cicero")
%convertX(unit(1/(65536*72.27), "inches"), "scaledpts")
%
%pushViewport(viewport(width=unit(1, "inches"),
%                       height=unit(2, "inches"),
%                       xscale=c(0, 1),
%                       yscale=c(1, 3)))
%  ## Location versus dimension
%  convertY(unit(2, "native"), "inches")
%  convertHeight(unit(2, "native"), "inches")
%  ## From "x" to "y" (the conversion is via "inches")
%  convertUnit(unit(1, "native"), "native",
%               axisFrom="x", axisTo="y")
%  ## Convert several values at once
%  convertX(unit(c(0.5, 2.54), c("npc", "cm")),
%                c("inches", "native"))
%popViewport()
%## Convert a complex unit
%convertX(unit(1, "strwidth", "Hello"), "native")
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%