% File src/library/grid/man/grid.edit.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.edit}
%@%\alias{grob のスロットを変更}
\alias{grid.edit}
\alias{grid.gedit}
\alias{editGrob}
\title{グリッドのグラフィカルオブジェクトの記述を編集}
%\title{Edit the Description of a Grid Graphical Object}
\description{
  grob のスロットの一つの値を変更しそれを再描画する．
}
\usage{
grid.edit(gPath, ..., strict = FALSE, grep = FALSE,
          global = FALSE, allDevices = FALSE, redraw = TRUE)

grid.gedit(..., grep = TRUE, global = TRUE)

editGrob(grob, gPath = NULL, ..., strict = FALSE, grep = FALSE,
         global = FALSE, warn = TRUE)
}
\arguments{
  \item{grob}{grob オブジェクト．}
  \item{\dots}{新しいスロット値を指定するゼロかそれ以上の名前付き引数．}
  \item{gPath}{gPath オブジェクト．
    \code{grid.edit} に対してはこれはディスプレイリスト上の
    grob を指定する．
    \code{editGrob} に対してはこれは指定された grob の
    子孫を指定する．}
  \item{strict}{
    gPath は正確にマッチされるべきかどうかを指示するブール値．}
  \item{grep}{
    \code{gPath} が正規表現として扱われるべきかどうかを指示するブール値．
    値は \code{gPath} の要素を跨がりリサイクルされる
    (例えば \code{c(TRUE, FALSE)} は
    \code{gPath} の全ての奇数番目の要素が正規表現として
    扱われるべきであることを意味する)．
  }
  \item{global}{
    関数が \code{gPath} の最初のマッチに影響すべきか，
    全てのマッチに影響すべきかを指示するブール値．
  }
  \item{warn}{
    指定された gPath を見つけるのに失敗したらエラーを発生するかどうかを
    指示する論理値．}
  \item{allDevices}{
    全ての開かれたデバイスがマッチに対して検索されるか，
    または現在のデバイスだけかを指示するブール値．
    まだ実装されていない．
  }
  \item{redraw}{grob を再描画するかどうかを指示する論理値．}
}
\details{
  \code{editGrob} は指定された grob をコピーし
  修正された grob を返す．

  \code{grid.edit} はディスプレイリスト上の grob を破壊的に修正する．
  もし \code{redraw} が \code{TRUE} ならばそれから
  変更を反映するために全てを再描画する．

  どちらの関数も grob がカスタム化された行動を実行することを
  許すために \code{editDetails} を呼び出し，
  修正された grob が依然首尾一貫しているかどうかをチェックする
  ために \code{validDetails} を呼び出す．

  \code{grid.gedit} (global に対する \code{g})は異なった既定値に対する
  \code{grid.edit} の単なる便利なラッパである．
}
\value{
  \code{editGrob} は grob オブジェクトを返す；
  \code{grid.edit} は \code{NULL} を返す．
}
\author{Paul Murrell}
\seealso{
  \code{\link{grob}}, \code{\link{getGrob}},
  \code{\link{addGrob}}, \code{\link{removeGrob}}.
}
\examples{
grid.newpage()
grid.xaxis(name = "xa", vp = viewport(width=.5, height=.5))
grid.edit("xa", gp = gpar(col="red"))
# チックが無い(at が NULL)なので動作しない
try(grid.edit(gPath("xa", "ticks"), gp = gpar(col="green")))
grid.edit("xa", at = 1:4/5)
# 今や動作すべきである
try(grid.edit(gPath("xa", "ticks"), gp = gpar(col="green")))
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.edit.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.edit}
%\alias{grid.edit}
%\alias{grid.gedit}
%\alias{editGrob}
%\title{Edit the Description of a Grid Graphical Object}
%\description{
%  Changes the value of one of the slots of a grob
% and redraws the grob.
%}
%\usage{
%grid.edit(gPath, ..., strict = FALSE, grep = FALSE,
%          global = FALSE, allDevices = FALSE, redraw = TRUE)
%
%grid.gedit(..., grep = TRUE, global = TRUE)
%
%editGrob(grob, gPath = NULL, ..., strict = FALSE, grep = FALSE,
%         global = FALSE, warn = TRUE)
%}
%\arguments{
%  \item{grob}{A grob object.}
%  \item{\dots}{Zero or more named arguments specifying new slot values.}
%  \item{gPath}{ A gPath object. For \code{grid.edit} this
%    specifies a grob on the display list.  For \code{editGrob} this
%    specifies a descendant of the specified grob. }
%  \item{strict}{ A boolean indicating whether the gPath must be
%    matched exactly. }
%  \item{grep}{A boolean indicating whether the \code{gPath} should
%    be treated as a regular expression.  Values are recycled across
%    elements of the \code{gPath} (e.g., \code{c(TRUE, FALSE)} means
%    that every odd element of the \code{gPath} will be treated as
%    a regular expression).
%  }
%  \item{global}{ A boolean indicating whether the function should affect
%    just the first match of the \code{gPath}, or whether all matches
%    should be affected.
%  }
%  \item{warn}{A logical to indicate whether failing to find the
%    specified gPath should trigger an error.  }
%  \item{allDevices}{ A boolean indicating whether all open devices
%    should
%    be searched for matches, or just the current device.
%    NOT YET IMPLEMENTED.
%  }
%  \item{redraw}{A logical value to indicate whether to redraw the grob. }
%}
%\details{
%  \code{editGrob} copies the specified grob and returns a modified
%  grob.
%
%  \code{grid.edit} destructively modifies a grob on the display list.
%  If \code{redraw}
%  is \code{TRUE} it then redraws everything to reflect the change.
%
%  Both functions call \code{editDetails} to allow a grob to perform
%  custom actions and \code{validDetails} to check that the modified grob
%  is still coherent.
%
%  \code{grid.gedit} (\code{g} for global) is just a convenience wrapper for
%  \code{grid.edit} with different defaults.
%}
%\value{
%  \code{editGrob} returns a grob object;  \code{grid.edit} returns \code{NULL}.
%}
%\author{Paul Murrell}
%\seealso{
%  \code{\link{grob}}, \code{\link{getGrob}},
%  \code{\link{addGrob}}, \code{\link{removeGrob}}.
%}
%\examples{
%grid.newpage()
%grid.xaxis(name = "xa", vp = viewport(width=.5, height=.5))
%grid.edit("xa", gp = gpar(col="red"))
%# won't work because no ticks (at is NULL)
%try(grid.edit(gPath("xa", "ticks"), gp = gpar(col="green")))
%grid.edit("xa", at = 1:4/5)
%# Now it should work
%try(grid.edit(gPath("xa", "ticks"), gp = gpar(col="green")))
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%