% File src/library/grid/man/grid.function.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{grid.function}
%@%\alias{関数を表す曲線}
\alias{grid.function}
\alias{functionGrob}
\alias{grid.abline}
\title{関数を表す曲線を描く}
%\title{Draw a curve representing a function}
\description{
  関数を表す曲線
}
\usage{
grid.function(...)
functionGrob(f, n = 101, range = "x", units = "native",
             name = NULL, gp=gpar(), vp = NULL)

grid.abline(intercept, slope, ...)
}
\arguments{
  \item{f}{単一の引数を取り
    名前が \code{x} と \code{y} の数値成分を持つリストを返す関数．}
  \item{n}{
    関数 \code{f} への入力として生成される数の値．}
  \item{range}{
    \code{"x"}, \code{"y"} または数値．
    \sQuote{詳細}節を見よ．}
  \item{units}{
    関数により生成される \code{x} と \code{y} 値に対して
    使われる単位を指定する文字列．}
  \item{intercept}{数値．}
  \item{slope}{数値．}
  \item{\dots}{
    \code{grid.function()} に渡される引数．}
  \item{name}{文字列識別子．}
  \item{gp}{
    クラス \code{gpar} のオブジェクトで，典型的には
    関数 \code{gpar} への呼び出しからの出力．
    これは基本的にはグラフィカルパラメータ設定のリスト．}
  \item{vp}{グリッドのビューポートオブジェクト(または NULL)．}
}
\details{
  値 \code{n} が生成され関数
  \code{f} へ渡され，一連の線が
  結果の値 \code{x} と \code{y} を通って引かれる．

  \code{n} 個の値の生成は \code{range} の値に依存する．
  既定のケースでは \code{dim} は \code{"x"} で，これは
  \code{x} 値のセットが
  現在の x 次元中のビューポートのスケールの範囲をカバーするように
  生成される．もし \code{dim} が \code{"y"} なら値は代わりに
  現在の y スケールから使われる．
  もし \code{range} が数値ベクトルならば，値はその範囲から生成される．

  \code{grid.abline()} は
  \code{intercept} と \code{slope} でパラメータ化された
  直線に対する簡単なフロントエンドである．
}
\value{
  functiongrob grob.
}
\author{Paul Murrell}
\seealso{
  \link{Grid},
  \code{\link{viewport}}
}
\examples{
    # abline
    # 注意：スクリーン上の ROOT ビューポート，(0, 0) はトップ左
    #       そして "native" はピクセル単位!
    grid.function(function(x) list(x=x, y=0 + 1*x))
    # 既定の正規化された "native" 座標のより"通常"のビューポート
    grid.newpage()
    pushViewport(viewport())
    grid.function(function(x) list(x=x, y=0 + 1*x))
    # すこし簡単
    grid.newpage()
    pushViewport(viewport())
    grid.abline()
    # サイン曲線
    grid.newpage()
    pushViewport(viewport(xscale=c(0, 2*pi), yscale=c(-1, 1)))
    grid.function(function(x) list(x=x, y=sin(x)))
    # 制約付きサイン曲線
    grid.newpage()
    pushViewport(viewport(xscale=c(0, 2*pi), yscale=c(-1, 1)))
    grid.function(function(x) list(x=x, y=sin(x)),
                  range=0:1)
    # 逆サイン曲線
    grid.newpage()
    pushViewport(viewport(xscale=c(-1, 1), yscale=c(0, 2*pi)))
    grid.function(function(y) list(x=sin(y), y=y),
                  range="y")
    # パラメトリックな曲線
    grid.newpage()
    pushViewport(viewport(xscale=c(-1, 1), yscale=c(-1, 1)))
    grid.function(function(t) list(x=cos(t), y=sin(t)),
                  range=c(0, 9*pi/5))
    # 物理的な abline
    grid.newpage()
    grid.function(function(x) list(x=x, y=0 + 1*x),
                  units="in")
}
\keyword{dplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.function.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.function}
%\alias{grid.function}
%\alias{functionGrob}
%\alias{grid.abline}
%\title{Draw a curve representing a function}
%\description{
%  Draw a curve representing a function.
%}
%\usage{
%grid.function(...)
%functionGrob(f, n = 101, range = "x", units = "native",
%             name = NULL, gp=gpar(), vp = NULL)
%
%grid.abline(intercept, slope, ...)
%}
%\arguments{
%  \item{f}{ A function that must take a single argument
%    and return a list with two numeric components named \code{x} and
%    \code{y}.}
%  \item{n}{ The number values that will be generated as input
%    to the function \code{f}.}
%  \item{range}{ Either \code{"x"}, \code{"y"}, or a numeric vector.
%    See the \sQuote{Details} section.}
%  \item{units}{A string indicating the units to use
%    for the \code{x} and \code{y} values generated by the function.}
%  \item{intercept}{ Numeric.}
%  \item{slope}{ Numeric. }
%  \item{\dots}{ Arguments passed to \code{grid.function()}}
%  \item{name}{ A character identifier. }
%  \item{gp}{An object of class \code{gpar}, typically the output
%    from a call to the function \code{gpar}.  This is basically
%    a list of graphical parameter settings.}
%  \item{vp}{A Grid viewport object (or NULL).}
%}
%\details{
%  \code{n} values are generated and passed to the function \code{f}
%  and a series of lines are
%  drawn through the resulting \code{x} and \code{y} values.
%
%  The generation of the \code{n} values depends on the value of
%  \code{range}.  In the default case, \code{dim} is
%  \code{"x"}, which means that a set
%  of \code{x} values are generated covering the range of the current
%  viewport scale in the x-dimension.  If \code{dim} is \code{"y"}
%  then values are generated from the current y-scale instead.
%  If \code{range} is a numeric vector, then values are generated
%  from that range.
%
%  \code{grid.abline()} provides a simple front-end for a straight
%  line parameterized by \code{intercept} and \code{slope}.
%}
%\value{
%  A functiongrob grob.
%}
%\author{Paul Murrell}
%\seealso{
%  \link{Grid},
%  \code{\link{viewport}}
%}
%\examples{
%    # abline
%    # NOTE: in ROOT viewport on screen, (0, 0) at top-left
%    #       and "native" is pixels!
%    grid.function(function(x) list(x=x, y=0 + 1*x))
%    # a more "normal" viewport with default normalized "native" coords
%    grid.newpage()
%    pushViewport(viewport())
%    grid.function(function(x) list(x=x, y=0 + 1*x))
%    # slightly simpler
%    grid.newpage()
%    pushViewport(viewport())
%    grid.abline()
%    # sine curve
%    grid.newpage()
%    pushViewport(viewport(xscale=c(0, 2*pi), yscale=c(-1, 1)))
%    grid.function(function(x) list(x=x, y=sin(x)))
%    # constrained sine curve
%    grid.newpage()
%    pushViewport(viewport(xscale=c(0, 2*pi), yscale=c(-1, 1)))
%    grid.function(function(x) list(x=x, y=sin(x)),
%                  range=0:1)
%    # inverse sine curve
%    grid.newpage()
%    pushViewport(viewport(xscale=c(-1, 1), yscale=c(0, 2*pi)))
%    grid.function(function(y) list(x=sin(y), y=y),
%                  range="y")
%    # parametric function
%    grid.newpage()
%    pushViewport(viewport(xscale=c(-1, 1), yscale=c(-1, 1)))
%    grid.function(function(t) list(x=cos(t), y=sin(t)),
%                  range=c(0, 9*pi/5))
%    # physical abline
%    grid.newpage()
%    grid.function(function(x) list(x=x, y=0 + 1*x),
%                  units="in")
%}
%\keyword{dplot}
%
%\encoding{UTF8}
%