% File src/library/grid/man/grid.ls.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{grid.ls}
%@%\alias{grob かビューポートの名前のリスト}
\alias{grid.ls}
\alias{nestedListing}
\alias{pathListing}
\alias{grobPathListing}
\title{grob かビューポートの名前をリストする}
%\title{ List the names of grobs or viewports }
\description{
  grob やビューポートの名前のりストを返す．

  これは grob (gTrees を含む)とビューポート(vpTree を含む)に対する
  メソッドを含む総称的関数である．
}
\usage{
grid.ls(x=NULL, grobs=TRUE, viewports=FALSE, fullNames=FALSE,
        recursive=TRUE, print=TRUE, flatten=TRUE, ...)

nestedListing(x, gindent="  ", vpindent=gindent)
pathListing(x, gvpSep=" | ", gAlign=TRUE)
grobPathListing(x, ...)
}
\arguments{
  \item{x}{grob かビューポートか \code{NULL}．もし \code{NULL} なら，
    現在のグリッドディスプレイがリストされる．

    プリント関数に対しては，これは
    \code{grid.ls} への呼び出しの結果であるべきである．}
  \item{grobs}{grob をリストするかどうかを示す論理値．}
  \item{viewports}{ビューポートをリストするかどうかを示す論理値．}
  \item{fullNames}{
    オブジェクト名をオブジェクトのタイプに関する情報で
    装飾するかどうかを指示する論理値．}
  \item{recursive}{
    再帰的な構造がそれらの子供もリストすべきかどうかを指示する論理値．}
  \item{print}{
    リスティングかリスティングをプリントする関数をプリントするかどうかを
    指示する論理値．}
  \item{flatten}{
    リスティングをフラット化すべきかどうかを指示する論理値．
    さもなければより複雑な階層的オブジェクトが作られる．}
  \item{gindent}{
    grob に対する出力中の入れ子を表示するために使われるインデント量．}
  \item{vpindent}{
    ビューポートに対する出力中の入れ子を表示するために使われるインデント量．}
  \item{gvpSep}{
    ビューポートのパスを grob のパスから分離するのに使われる文字列．}
  \item{gAlign}{
    全ての grob パスの左端を揃えるかどうかを指示する論理値．}
  \item{...}{
    \code{print} 関数に渡される引数．}
}
\details{
  もし引数 \code{x} が \code{NULL} ならば，
  グリッドのディスプレイリストの現在の内容が
  リストされる(ビューポートと grob の双方)．
  換言すれば，現在のシーンを表現する全てのオブジェクトが
  リストされる．

  換言すれば \code{x} は grob かビューポートで無ければならない．

  この関数の既定動作は現在のシーン中の grob に関する情報をプリント
  することである．
  シーン中のビューポートに関する情報を加えることも又可能である．
  既定ではリスティングは再帰的であり，
  gTree の全ての子供と全ての入れ子のビューポートが報告される．

  情報の書式は \code{print} 引数で制御することが出来，
  整形を実行する関数を与えることが出来る．
  \code{nestedListing} 関数は grob かビューポート毎に一行を作り，
  入れ子を表示するためにインデントが使われる．
  \code{pathListing} 関数は grob かビューポート毎に一行を作り，
  grob かビューポートのパスと grob のパスが入れ子を示すために
  使われる．\code{grobPathListing} は grob に対する行だけを示す簡単な
  派生物である．ユーザは新しい関数を定義できる．
}
\value{
  この関数の結果は
  \code{"gridFlatListing"} オブジェクト
  (もし \code{flatten} が \code{TRUE} なら)か\cr
  \code{"gridListing"} オブジェクトである．

  前者は単純(フラット)なベクトルのりストである．これは例えば
  grob やビューポート名のリストを使ったプログラム，または
  リスティングのための新しいディスプレイ関数を書くのに
  便利である．

  後者はより複雑な階層的オブジェクト(リストのリスト)であるが，
  より詳細な情報は含まないので
  より高度なカスタム化のために有用かもしれない．
}
\seealso{
  \code{\link{grob}}
  \code{\link{viewport}}
}
\author{ Paul Murrell }
\examples{
# "parent" と呼ばれる gTree と childrenvp vpTree (vp1 中に vp2)
# そして "child" と呼ばれる grob で vp vpPath (vp2 の下方)を持つ
sampleGTree <- gTree(name="parent",
                     children=gList(grob(name="child", vp="vp1::vp2")),
                     childrenvp=vpTree(parent=viewport(name="vp1"),
                                       children=vpList(viewport(name="vp2"))))
grid.ls(sampleGTree)
# viewports も示す
grid.ls(sampleGTree, view=TRUE)
# ビューポートだけを示す
grid.ls(sampleGTree, view=TRUE, grob=FALSE)
# 別の表示
# 入れ子のリスティング，カスタムインデント
grid.ls(sampleGTree, view=TRUE, print=nestedListing, gindent="--")
# パスのリスティング
grid.ls(sampleGTree, view=TRUE, print=pathListing)
# パスのリスティング，grob の整列なし
grid.ls(sampleGTree, view=TRUE, print=pathListing, gAlign=FALSE)
# grob パスのリスティング
grid.ls(sampleGTree, view=TRUE, print=grobPathListing)
# パスのリスティング，grob だけ
grid.ls(sampleGTree, print=pathListing)
# パスのリスティング，ビューポートだけ
grid.ls(sampleGTree, view=TRUE, grob=FALSE, print=pathListing)
# 生のフラットなリスティング
str(grid.ls(sampleGTree, view=TRUE, print=FALSE))
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/grid.ls.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{grid.ls}
%\alias{grid.ls}
%\alias{nestedListing}
%\alias{pathListing}
%\alias{grobPathListing}
%\title{ List the names of grobs or viewports }
%\description{
%  Return a listing of the names of grobs or viewports.
%
%  This is a generic function with methods for grobs (including
%  gTrees) and viewports (including vpTrees).
%}
%\usage{
%grid.ls(x=NULL, grobs=TRUE, viewports=FALSE, fullNames=FALSE,
%        recursive=TRUE, print=TRUE, flatten=TRUE, ...)
%
%nestedListing(x, gindent="  ", vpindent=gindent)
%pathListing(x, gvpSep=" | ", gAlign=TRUE)
%grobPathListing(x, ...)
%}
%\arguments{
%  \item{x}{A grob or viewport or \code{NULL}.  If \code{NULL}, the current
%    grid display list is listed.
%
%    For print functions, this should be the result of a call to
%    \code{grid.ls}.}
%  \item{grobs}{A logical value indicating whether to list grobs.}
%  \item{viewports}{A logical value indicating whether to list
%    viewports.}
%  \item{fullNames}{A logical value indicating whether to embellish
%    object names with information about the object type.}
%  \item{recursive}{A logical value indicating whether recursive
%    structures should also list their children.}
%  \item{print}{A logical indicating whether to print the listing
%    or a function that will print the listing.}
%  \item{flatten}{A logical value indicating whether to flatten
%    the listing.  Otherwise a more complex hierarchical object is
%    produced.}
%  \item{gindent}{The indent used to show nesting in the output for
%    grobs.}
%  \item{vpindent}{The indent used to show nesting in the output for
%    viewports.}
%  \item{gvpSep}{The string used to separate viewport paths from grob
%    paths.}
%  \item{gAlign}{Logical indicating whether to align the left hand
%    edge of all grob paths.}
%  \item{...}{Arguments passed to the \code{print} function.}
%}
%\details{
%  If the argument \code{x} is \code{NULL}, the current contents
%  of the grid display list are listed (both viewports and grobs).
%  In other words, all objects representing the current scene
%  are listed.
%
%  Otherwise, \code{x} should be a grob or a viewport.
%
%  The default behaviour of this function is to print information
%  about the grobs in the current scene.  It is also possible to
%  add information about the viewports in the scene.  By default,
%  the listing is recursive, so all children of gTrees and all
%  nested viewports are reported.
%
%  The format of the information can be controlled via the \code{print}
%  argument, which can be given a function to perform the formatting.
%  The \code{nestedListing} function produces a line per grob or
%  viewport, with indenting used to show nesting.  The \code{pathListing}
%  function produces a line per grob or viewport, with viewport paths
%  and grob paths used to show nesting.  The \code{grobPathListing}
%  is a simple derivation that only shows lines for grobs.  The user
%  can define new functions.
%}
%\value{
%  The result of this function is either a \code{"gridFlatListing"}
%  object (if \code{flatten} is \code{TRUE}) or a \code{"gridListing"}
%  object.
%
%  The former is a simple (flat) list of vectors.  This is convenient,
%  for example,
%  for working programmatically with the list of grob and viewport
%  names, or for writing a new display function for the listing.
%
%  The latter is a more complex hierarchical object (list of lists),
%  but it does contain more detailed information so may be of use for
%  more advanced customisations.
%}
%\seealso{
%  \code{\link{grob}}
%  \code{\link{viewport}}
%}
%\author{ Paul Murrell }
%\examples{
%# A gTree, called "parent", with childrenvp vpTree (vp2 within vp1)
%# and child grob, called "child", with vp vpPath (down to vp2)
%sampleGTree <- gTree(name="parent",
%                     children=gList(grob(name="child", vp="vp1::vp2")),
%                     childrenvp=vpTree(parent=viewport(name="vp1"),
%                                       children=vpList(viewport(name="vp2"))))
%grid.ls(sampleGTree)
%# Show viewports too
%grid.ls(sampleGTree, view=TRUE)
%# Only show viewports
%grid.ls(sampleGTree, view=TRUE, grob=FALSE)
%# Alternate displays
%# nested listing, custom indent
%grid.ls(sampleGTree, view=TRUE, print=nestedListing, gindent="--")
%# path listing
%grid.ls(sampleGTree, view=TRUE, print=pathListing)
%# path listing, without grobs aligned
%grid.ls(sampleGTree, view=TRUE, print=pathListing, gAlign=FALSE)
%# grob path listing
%grid.ls(sampleGTree, view=TRUE, print=grobPathListing)
%# path listing, grobs only
%grid.ls(sampleGTree, print=pathListing)
%# path listing, viewports only
%grid.ls(sampleGTree, view=TRUE, grob=FALSE, print=pathListing)
%# raw flat listing
%str(grid.ls(sampleGTree, view=TRUE, print=FALSE))
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%