% File src/library/grid/man/showGrob.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{showGrob}
%@%\alias{グリッドの grob のラベル}
\alias{showGrob}
\title{グリッドの grob のラベル}
%\title{Label grid grobs.}
\description{
  (既定では)現在のグリッドのシーンにシーン中の各 grob の名前を示す
  ラベル付きのグラフィカルディスプレイを作成する．
  シーン中の特定の grob にだけラベルを付けることも出来る．
}
\usage{
showGrob(x = NULL,
         gPath = NULL, strict = FALSE, grep = FALSE,
         recurse = TRUE, depth = NULL,
         labelfun = grobLabel, ...)
}
\arguments{
  \item{x}{
    もし \code{NULL} なら現在のグリッドのシーンにラベルが付く．
    さもなければ
    描画されそれからラベルが付く grob (または gTree)．
  }
  \item{gPath}{
    現在のシーンの一部分またはラベルを付ける grob を
    指定するパス．
  }
  \item{strict}{
    gPath が厳密かどうかを指定する論理値．
  }
  \item{grep}{
    gPath が正規表現かどうかを指示する論理値．
  }
  \item{recurse}{
    gTree の子供もラベルを付けるか?
  }
  \item{depth}{
    指定された深さ(ベクトルかもしれない)の grob だけを表示する．
  }
  \item{labelfun}{
    各 grob からラベルを生成するために使われる関数．
  }
  \item{...}{
    生成されたラベルの細かい詳細を制御する
    \code{labelfun} に渡される引数．
  }
}
\details{
  どんなラベルもグリッドのディスプレイリスト上には
  記録され無いので，オリジナルのシーンは
  \code{grid.refresh} の呼び出しで再生出来る．
}
\seealso{
  \code{\link{grob}} と
  \code{\link{gTree}}
}
\examples{
    grid.newpage()
    gt <- gTree(childrenvp=vpStack(
                  viewport(x=0, width=.5, just="left", name="vp"),
                  viewport(y=.5, height=.5, just="bottom", name="vp2")),
                children=gList(rectGrob(vp="vp::vp2", name="child")),
                name="parent")
    grid.draw(gt)
    showGrob()
    showGrob(gPath="child")
    showGrob(recurse=FALSE)
    showGrob(depth=1)
    showGrob(depth=2)
    showGrob(depth=1:2)
    showGrob(gt)
    showGrob(gt, gPath="child")
    showGrob(just="left", gp=gpar(col="red", cex=.5), rot=45)
    showGrob(labelfun=function(grob, ...) {
        x <- grobX(grob, "west")
        y <- grobY(grob, "north")
        gTree(children=gList(rectGrob(x=x, y=y,
                width=stringWidth(grob$name) + unit(2, "mm"),
                height=stringHeight(grob$name) + unit(2, "mm"),
                gp=gpar(col=NA, fill=rgb(1, 0, 0, .5)),
                just=c("left", "top")),
                textGrob(grob$name,
                         x=x + unit(1, "mm"), y=y - unit(1, "mm"),
                         just=c("left", "top"))))
    })

\dontrun{
    # 高水準のパッケージからの例

    library(lattice)
    # 最初の例の後に Ctrl-c
    example(histogram)
    showGrob()
    showGrob(gPath="plot_01.ylab")

    library(ggplot2)
    # 最初の例の後に Ctrl-c
    example(qplot)
    showGrob()
    showGrob(recurse=FALSE)
    showGrob(gPath="panel-3-3")
    showGrob(gPath="axis.title", grep=TRUE)
    showGrob(depth=2)
}
}
\keyword{ dplot }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grid/man/showGrob.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{showGrob}
%\alias{showGrob}
%\title{
%  Label grid grobs.
%}
%\description{
%  Produces a graphical display of (by default) the current grid scene,
%  with labels showing the names of each grob in the scene.
%  It is also possible to label only specific grobs in the scene.
%}
%\usage{
%showGrob(x = NULL,
%         gPath = NULL, strict = FALSE, grep = FALSE,
%         recurse = TRUE, depth = NULL,
%         labelfun = grobLabel, ...)
%}
%\arguments{
%  \item{x}{
%    If \code{NULL}, the current grid scene is labelled.
%    Otherwise, a grob (or gTree) to draw and then label.
%  }
%  \item{gPath}{
%    A path identifying a subset of the current scene or grob
%    to be labelled.
%  }
%  \item{strict}{
%    Logical indicating whether the gPath is strict.
%  }
%  \item{grep}{
%    Logical indicating whether the gPath is a regular expression.
%  }
%  \item{recurse}{
%    Should the children of gTrees also be labelled?
%  }
%  \item{depth}{
%    Only display grobs at the specified depth (may be a vector
%    of depths).
%  }
%  \item{labelfun}{
%    Function used to generate a label from each grob.
%  }
%  \item{...}{
%    Arguments passed to \code{labelfun} to control fine details
%    of the generated label.
%  }
%}
%\details{
%  None of the labelling is recorded on the grid display list so the
%  original scene can be reproduced by calling \code{grid.refresh}.
%}
%\seealso{
%  \code{\link{grob}} and
%  \code{\link{gTree}}
%}
%\examples{
%    grid.newpage()
%    gt <- gTree(childrenvp=vpStack(
%                  viewport(x=0, width=.5, just="left", name="vp"),
%                  viewport(y=.5, height=.5, just="bottom", name="vp2")),
%                children=gList(rectGrob(vp="vp::vp2", name="child")),
%                name="parent")
%    grid.draw(gt)
%    showGrob()
%    showGrob(gPath="child")
%    showGrob(recurse=FALSE)
%    showGrob(depth=1)
%    showGrob(depth=2)
%    showGrob(depth=1:2)
%    showGrob(gt)
%    showGrob(gt, gPath="child")
%    showGrob(just="left", gp=gpar(col="red", cex=.5), rot=45)
%    showGrob(labelfun=function(grob, ...) {
%        x <- grobX(grob, "west")
%        y <- grobY(grob, "north")
%        gTree(children=gList(rectGrob(x=x, y=y,
%                width=stringWidth(grob$name) + unit(2, "mm"),
%                height=stringHeight(grob$name) + unit(2, "mm"),
%                gp=gpar(col=NA, fill=rgb(1, 0, 0, .5)),
%                just=c("left", "top")),
%                textGrob(grob$name,
%                         x=x + unit(1, "mm"), y=y - unit(1, "mm"),
%                         just=c("left", "top"))))
%    })
%
%\dontrun{
%    # Examples from higher-level packages
%
%    library(lattice)
%    # Ctrl-c after first example
%    example(histogram)
%    showGrob()
%    showGrob(gPath="plot_01.ylab")
%
%    library(ggplot2)
%    # Ctrl-c after first example
%    example(qplot)
%    showGrob()
%    showGrob(recurse=FALSE)
%    showGrob(gPath="panel-3-3")
%    showGrob(gPath="axis.title", grep=TRUE)
%    showGrob(depth=2)
%}
%}
%\keyword{ dplot }
%
%\encoding{UTF8}
%