% File src/library/parallel/man/detectCores.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011-2016 R Core Team
% Distributed under GPL 2 or later

\name{detectCores}
\alias{detectCores}
\title{Detect the Number of CPU Cores}
\description{
  現在のホストの CPU コア数を検出しようと試みる．
}
\usage{
detectCores(all.tests = FALSE, logical = TRUE)
}
\arguments{
  \item{all.tests}{論理値：もし真なら全ての既知の検査を適用する．}
  \item{logical}{論理値：もし可能なら
    物理的な CPU/コア 数
    (もし \code{FALSE} ならば)，又は論理的な CPU 数(もし \code{TRUE} ならば)．
    を使用する．現在これは
    Linux, OS X, Sparc Solaris そして Windows だけで有効である．}
}
\details{
  これは利用可能な CPU コアの数を検出しようと試みる．

  それを行う
  Linux, OS X, FreeBSD, OpenBSD, Solaris,
  Irix そして Windows 用のメソッドがある．
  他の Unix 風システムでは \code{detectCores(TRUE)} が
  適用できるかもしれない．

  \R 3.3.0 以前では既定は Windows を除いて \code{logical = FALSE}
  であったが，\code{logical = TRUE} は
  Sparc Solaris と Windows でだけ有効であった(それらに対しては
  既定であった)．
}
\value{
  整数，もし回答が未知なら \code{NA}．

  これが何を表すかは正確には OS 依存である：
  既定では可能な場所では
  それは論理的 CPU (つまりハイパースレッド)であり物理的なコアやパッケージではない．

  OS X では更に
  \sQuote{現在のパワー管理モードで利用可能}と
  \sQuote{ブートすれば利用可能}の違いがあり，
  この関数は最初を返す．

#ifdef windows
  XP SP3 以来の Windows のバージョンだけがサポートされている．
  Microsoft は
  \code{logical = FALSE} は
  Vista 又はそれ以降ではコア数を報告するが，
  XP や Server 2003 では物理的な CPU パッケージ数を報告すると
  ドキュメントに書いている．

  しかしながらそれは我々がテストした
  XP システムでも正確に報告をした．
#endif
% https://msdn.microsoft.com/en-us/library/ms683194%28v=VS.85%29.aspx

  Sparc Solaris では \code{logical = FALSE} は物理的コア数を返し，
  \code{logical = TRUE} は利用可能なハードウェアスレッド数を
  返す．
  (ある Sparc CPU は CPU 毎に複数のコアを持ち，
  他はコアごとに複数のスレッドを持ち，両方を持つものもある．)
  例えば CRAN のチェックサーバー中の UltraSparc T2 CPU は
  8 コアを持つ単一の CPU で，各コアは 8 個のハードウェアスレッド
  を持つ．
  従って \code{detectCores(logical = FALSE)} は 8 を返し，
  \code{detectCores(logical = TRUE)} は 64 を返す．

  仮想マシーンが使われているときは，
  結果はその特定の VM に対して利用可能な(又は潜在的に利用可能な)
  CPU 数を表していると期待できる．
}
\author{
  Simon Urbanek と Brian Ripley
}
\note{
  これは \code{mclapply} の \code{mc.cores} 引数に対してや
  \code{makeCluster} 中のコア数の指定に
  直接使うのには向いていない．
  
  先ずそれは \code{NA} を返すかもしれないし，次に
  それは\emph{許される}コア数を与えず，
  三つには Sparc Solaris とある種の Windows ボックスでは
  全ての論理的 CPU を一度に全て使おうとするのは
  合理的ではないからである．
}
\examples{
detectCores()
detectCores(logical = FALSE)
}

\encoding{UTF-8}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/detectCores.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{detectCores}
%\alias{detectCores}
%\title{Detect the Number of CPU Cores}
%\description{
%  Attempt to detect the number of CPU cores on the current host.
%}
%\usage{
%detectCores(all.tests = FALSE, logical = TRUE)
%}
%\arguments{
%  \item{all.tests}{Logical: if true apply all known tests.}
%  \item{logical}{Logical: if possible, use the number of physical CPUs/cores
%    (if \code{FALSE}) or logical CPUs (if \code{TRUE}).  Currently this
%    is honoured only on Linux, OS X, Sparc Solaris and Windows.}
%}
%\details{
%  This attempts to detect the number of available CPU cores.
%
%  It has methods to do so for Linux, OS X, FreeBSD, OpenBSD, Solaris,
%  Irix and Windows.  \code{detectCores(TRUE)} could be tried on other
%  Unix-alike systems.
%
%  Prior to \R 3.3.0 the default was \code{logical = FALSE} except on
%  Windows, but \code{logical = TRUE} had an effect only on Sparc Solaris
%  and Windows (where it was the default).
%}
%\value{
%  An integer, \code{NA} if the answer is unknown.
%
%  Exactly what this represents is OS-dependent: where possible by
%  default it counts logical (e.g., hyperthreaded) CPUs and not physical
%  cores or packages.
%
%  Under OS X there is a further distinction between \sQuote{available in
%    the current power management mode} and \sQuote{could be available
%    this boot}, and this function returns the first.
%
%#ifdef windows
%  Only versions of Windows since XP SP3 are supported.  Microsoft
%  documents that \code{logical = FALSE} it will report the number of
%  cores on Vista or later, but the number of physical CPU packages on XP
%  or Server 2003: however it reported correctly on the XP systems we
%  tested.
%#endif
%% https://msdn.microsoft.com/en-us/library/ms683194%28v=VS.85%29.aspx
%
%  On Sparc Solaris \code{logical = FALSE} returns the number of physical
%  cores and \code{logical = TRUE} returns the number of available
%  hardware threads. (Some Sparc CPUs which do have multiple cores per
%  CPU, others have multiple threads per core and some have both.)  For
%  example, the UltraSparc T2 CPU in the CRAN check server is a single
%  physical CPU with 8 cores, and each core supports 8 hardware threads.
%  So \code{detectCores(logical = FALSE)} returns 8, and
%  \code{detectCores(logical = TRUE)} returns 64.
%
%  Where virtual machines are in use, one would hope that the result
%  represents the number of CPUs available (or potentially available) to
%  that particular VM.
%}
%\author{
%  Simon Urbanek and Brian Ripley
%}
%\note{
%  This is not suitable for use directly for the \code{mc.cores} argument
%  of \code{mclapply} nor specifying the number of cores in
%  \code{makeCluster}.  First because it may return \code{NA}, second
%  because it does not give the number of \emph{allowed} cores, and third
%  because on Sparc Solaris and some Windows boxes it is not reasonable
%  to try to use all the logical CPUs at once.
%}
%\examples{
%detectCores()
%detectCores(logical = FALSE)
%}
%\encoding{UTF8}

