% File src/library/splines/man/periodicSpline.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{periodicSpline}
%@%\alias{周期的な補間スプライン}
\alias{periodicSpline}
\title{周期的な補間スプラインを作る}
%\title{Create a Periodic Interpolation Spline}
\description{
  \code{x} と \code{y} ベクトルからか，または
  公式/データフレームの組み合わせから周期的な補間スプラインを作る．
}
\usage{
periodicSpline(obj1, obj2, knots, period = 2*pi, ord = 4)
}
\arguments{
 \item{obj1}{
   \code{x} 値の数値ベクトル化公式．}
 \item{obj2}{
   もし \code{obj1} が数値ならばこれは同じ長さの数値ベクトルで
   なければならない．もし \code{obj1} が公式ならばこれは
   公式中の名前をその中で評価するオプションのデータフレームに
   取ることが出来る．}
 \item{knots}{
   ノット位置のオプション数値ベクトル．}
 \item{period}{
   周期的スプラインに対する酒器を与える正数値．
   既定では \code{2 * pi}．}
 \item{ord}{
   スプラインの次数を与える整数で，少なくとも 2．既定では 4．
   スプラインの次数の定義については \code{\link{splineOrder}} を見よ．}
}
\value{
  クラス \code{spline} を継承するオブジェクト．
  オブジェクトは B スプライン表現になり得，その場合
  それは \code{pbSpline} オブジェクト．または
  区分的多項式表現も可能である
  (\code{ppolySpline} オブジェクト)．
}
\author{Douglas Bates と Bill Venables}
\seealso{
  \code{\link{splineKnots}},
  \code{\link{interpSpline}}
}
\examples{
require(graphics); require(stats)
xx <- seq( -pi, pi, length.out = 16 )[-1]
yy <- sin( xx )
frm <- data.frame( xx, yy )
pispl <- periodicSpline( xx, yy, period = 2 * pi)
\donttest{pispl}
pispl2 <- periodicSpline( yy ~ xx, frm, period = 2 * pi )
stopifnot(all.equal(pispl, pispl2))  # pispl と pispl2 は同じ

plot( pispl )          # 1周期について表示
points( yy ~ xx, col = "brown")
plot( predict( pispl, seq(-3*pi, 3*pi, length.out = 101) ), type = "l" )
}
\keyword{models}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/splines/man/periodicSpline.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{periodicSpline}
%\alias{periodicSpline}
%\title{Create a Periodic Interpolation Spline}
%\description{
%  Create a periodic interpolation spline, either from \code{x} and
%  \code{y} vectors, or from a formula/data.frame combination.
%}
%\usage{
%periodicSpline(obj1, obj2, knots, period = 2*pi, ord = 4)
%}
%\arguments{
% \item{obj1}{either a numeric vector of \code{x} values or a formula.}
% \item{obj2}{if \code{obj1} is numeric this should be a numeric vector
%   of the same length.  If \code{obj1} is a formula this can be an
%   optional data frame in which to evaluate the names in the formula.}
% \item{knots}{optional numeric vector of knot positions.}
% \item{period}{positive numeric value giving the period for the
%   periodic spline.  Defaults to \code{2 * pi}.}
% \item{ord}{integer giving the order of the spline, at least 2.  Defaults
%   to 4.  See \code{\link{splineOrder}} for a definition of the order of
%   a spline.}
%}
%\value{
%  An object that inherits from class \code{spline}.  The object can be in
%  the B-spline representation, in which case it will be a
%  \code{pbSpline} object, or in the piecewise polynomial representation
%  (a \code{ppolySpline} object).
%}
%\author{Douglas Bates and Bill Venables}
%\seealso{
%  \code{\link{splineKnots}},
%  \code{\link{interpSpline}}
%}
%\examples{
%require(graphics); require(stats)
%xx <- seq( -pi, pi, length.out = 16 )[-1]
%yy <- sin( xx )
%frm <- data.frame( xx, yy )
%pispl <- periodicSpline( xx, yy, period = 2 * pi)
%\donttest{pispl}
%pispl2 <- periodicSpline( yy ~ xx, frm, period = 2 * pi )
%stopifnot(all.equal(pispl, pispl2))  # pispl and pispl2 are the same
%
%plot( pispl )          # displays over one period
%points( yy ~ xx, col = "brown")
%plot( predict( pispl, seq(-3*pi, 3*pi, length.out = 101) ), type = "l" )
%}
%\keyword{models}
%
%\encoding{UTF8}
%