% File src/library/splines/man/predict.bSpline.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{predict.bSpline}
%@%\alias{新しい値に於いてスプラインを評価}
\alias{predict.bSpline}
\alias{predict.nbSpline}
\alias{predict.pbSpline}
\alias{predict.npolySpline}
\alias{predict.ppolySpline}

\title{新しい x 値に対してスプラインを評価する}
%\title{Evaluate a Spline at New Values of x}
\description{
  仮想クラス \code{bSpline} と \code{polySpline} を継承するクラスに対する
  \code{predict} メソッドはスプラインやその微分係数を評価するために使われる．
  スプラインオブジェクトに対する \code{plot} メソッドは
  先ず \code{predict} を欠損した引数 \code{x} で評価し，それから
  結果の \code{xyVector} を \code{type = "l"} でプロットする．}
\usage{
\method{predict}{bSpline}(object, x, nseg = 50, deriv = 0, \dots)
\method{predict}{nbSpline}(object, x, nseg = 50, deriv = 0, \dots)
\method{predict}{pbSpline}(object, x, nseg = 50, deriv = 0, \dots)
\method{predict}{npolySpline}(object, x, nseg = 50, deriv = 0, \dots)
\method{predict}{ppolySpline}(object, x, nseg = 50, deriv = 0, \dots)
}
\arguments{
  \item{object}{
    \code{bSpline} や \code{polySpline} クラスを継承するオブジェクト．}
  \item{x}{
    そこでスプラインを評価する
    \code{x} 値の数値ベクトル．もしこの値が欠損していると
    \code{x} の適当な値がノットの範囲を張る
    \code{nseq} 個の分割列として生成される．}
  \item{nseg}{
    \code{object} 中の
    ノットの範囲を張る等間隔の分割を与える正整数．
    この値は \code{x} が欠損している場合にだけ使われる．}
  \item{deriv}{
    評価される微分係数を指定する
    0 と \code{splineOrder(object) - 1} の間の整数．}
  \item{\dots}{他のメソッドへ・から渡される追加引数．}
}
\value{
  次の成分を持つ \code{xyVector}
  \item{x}{提供されたか推測された \code{x} 値}
  \item{y}{
    スプラインの値(または \code{x} 値における
    その \code{deriv} 階の微分係数)のベクトル}
}
\author{Douglas Bates と Bill Venables}
\seealso{
  \code{\link{xyVector}},
  \code{\link{interpSpline}},
  \code{\link{periodicSpline}}
}
\examples{
require(graphics); require(stats)
ispl <- interpSpline( weight ~ height,  women )
opar <- par(mfrow = c(2, 2), las = 1)
plot(predict(ispl, nseg = 201),     # plots over the range of the knots
     main = "Original data with interpolating spline", type = "l",
     xlab = "height", ylab = "weight")
points(women$height, women$weight, col = 4)
plot(predict(ispl, nseg = 201, deriv = 1),
     main = "First derivative of interpolating spline", type = "l",
     xlab = "height", ylab = "weight")
plot(predict(ispl, nseg = 201, deriv = 2),
     main = "Second derivative of interpolating spline", type = "l",
     xlab = "height", ylab = "weight")
plot(predict(ispl, nseg = 401, deriv = 3),
     main = "Third derivative of interpolating spline", type = "l",
     xlab = "height", ylab = "weight")
par(opar)
}
\keyword{models}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/splines/man/predict.bSpline.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict.bSpline}
%\alias{predict.bSpline}
%\alias{predict.nbSpline}
%\alias{predict.pbSpline}
%\alias{predict.npolySpline}
%\alias{predict.ppolySpline}
%
%\title{Evaluate a Spline at New Values of x}
%\description{
%  The \code{predict} methods for the classes that inherit from the
%  virtual classes \code{bSpline} and \code{polySpline} are used to
%  evaluate the spline or its derivatives.  The \code{plot} method for a
%  spline object first evaluates \code{predict} with the \code{x}
%  argument missing, then plots the resulting \code{xyVector} with
%  \code{type = "l"}.}
%\usage{
%\method{predict}{bSpline}(object, x, nseg = 50, deriv = 0, \dots)
%\method{predict}{nbSpline}(object, x, nseg = 50, deriv = 0, \dots)
%\method{predict}{pbSpline}(object, x, nseg = 50, deriv = 0, \dots)
%\method{predict}{npolySpline}(object, x, nseg = 50, deriv = 0, \dots)
%\method{predict}{ppolySpline}(object, x, nseg = 50, deriv = 0, \dots)
%}
%\arguments{
%  \item{object}{An object that inherits from the \code{bSpline} or the
%    \code{polySpline} class.}
%  \item{x}{A numeric vector of \code{x} values at which to evaluate the
%    spline.  If this argument is missing a suitable set of \code{x}
%    values is generated as a sequence of \code{nseq} segments spanning
%    the range of the knots.}
%  \item{nseg}{A positive integer giving the number of segments in a set
%    of equally-spaced \code{x} values spanning the range of the knots
%    in \code{object}.  This value is only used if \code{x} is missing.}
%  \item{deriv}{An integer between 0 and \code{splineOrder(object) - 1}
%    specifying the derivative to evaluate.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\value{
%  an \code{xyVector} with components
%  \item{x}{the supplied or inferred numeric vector of \code{x} values}
%  \item{y}{the value of the spline (or its \code{deriv}'th derivative)
%      at the \code{x} vector}
%}
%\author{Douglas Bates and Bill Venables}
%\seealso{
%  \code{\link{xyVector}},
%  \code{\link{interpSpline}},
%  \code{\link{periodicSpline}}
%}
%\examples{
%require(graphics); require(stats)
%ispl <- interpSpline( weight ~ height,  women )
%opar <- par(mfrow = c(2, 2), las = 1)
%plot(predict(ispl, nseg = 201),     # plots over the range of the knots
%     main = "Original data with interpolating spline", type = "l",
%     xlab = "height", ylab = "weight")
%points(women$height, women$weight, col = 4)
%plot(predict(ispl, nseg = 201, deriv = 1),
%     main = "First derivative of interpolating spline", type = "l",
%     xlab = "height", ylab = "weight")
%plot(predict(ispl, nseg = 201, deriv = 2),
%     main = "Second derivative of interpolating spline", type = "l",
%     xlab = "height", ylab = "weight")
%plot(predict(ispl, nseg = 401, deriv = 3),
%     main = "Third derivative of interpolating spline", type = "l",
%     xlab = "height", ylab = "weight")
%par(opar)
%}
%\keyword{models}
%
%\encoding{UTF8}
%