% File src/library/splines/man/xyVector.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{xyVector}
%@%\alias{xyVector オブジェクト}
\alias{xyVector}
\title{\code{xyVector} オブジェクトを作る}
%\title{Construct an \code{xyVector} Object}
\description{
  x-y のペアのセットを表すオブジェクトを作る．
  結果のオブジェクトは行列としてもデータフレームとしても
  そしてベクトルとしても扱うことが出来る．
  ベクトルとして扱われる場合はこれは
  \code{y} 成分だけに帰着する．

  \code{predict.spline} のような関数の結果は
  \code{xyVector} オブジェクトとして返されるので
  y 位置を生成した x 値が例えばプロットを生成する目的のために
  保持される．
}
\usage{
xyVector(x, y)
}
\arguments{
  \item{x}{数値ベクトル}
  \item{y}{\code{x} と同じ長さの数値ベクトル}
}
\value{
  クラス \code{xyVector} のオブジェクトで次の成分を持つ
  \item{x}{数値ベクトル}
  \item{y}{\code{x} と同じ長さの数値ベクトル}
}
\author{Douglas Bates と Bill Venables}
\examples{
require(stats); require(graphics)
ispl <- interpSpline( weight ~ height, women )
weights <- predict( ispl, seq( 55, 75, length.out = 51 ))
class( weights )
plot( weights, type = "l", xlab = "height", ylab = "weight" )
points( women$height, women$weight )
weights
}
\keyword{ models }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/splines/man/xyVector.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xyVector}
%\alias{xyVector}
%\title{Construct an \code{xyVector} Object}
%\description{
%  Create an object to represent a set of x-y pairs.  The resulting
%  object can be treated as a matrix or as a data frame or as a vector.
%  When treated as a vector it reduces to the \code{y} component only.
%
%  The result of functions such as \code{predict.spline} is returned as
%  an \code{xyVector} object so the x-values used to generate the
%  y-positions are retained, say for purposes of generating plots.
%}
%\usage{
%xyVector(x, y)
%}
%\arguments{
%  \item{x}{a numeric vector}
%  \item{y}{a numeric vector of the same length as \code{x}}
%}
%\value{
%  An object of class \code{xyVector} with components
%  \item{x}{a numeric vector}
%  \item{y}{a numeric vector of the same length as \code{x}}
%}
%\author{Douglas Bates and Bill Venables}
%\examples{
%require(stats); require(graphics)
%ispl <- interpSpline( weight ~ height, women )
%weights <- predict( ispl, seq( 55, 75, length.out = 51 ))
%class( weights )
%plot( weights, type = "l", xlab = "height", ylab = "weight" )
%points( women$height, women$weight )
%weights
%}
%\keyword{ models }
%
%\encoding{UTF8}
%