% File src/library/stats/man/Geometric.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Geometric}
\alias{Geometric}
\alias{dgeom}
\alias{pgeom}
\alias{qgeom}
\alias{rgeom}
\title{The Geometric Distribution}
\description{
  パラメータ \code{prob} の
  幾何分布に対する密度，分布関数，クォンタイル関数と乱数生成．
}
\usage{
dgeom(x, prob, log = FALSE)
pgeom(q, prob, lower.tail = TRUE, log.p = FALSE)
qgeom(p, prob, lower.tail = TRUE, log.p = FALSE)
rgeom(n, prob)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．ベルヌイ試行の系列で成功が起きるまでの
    失敗数を表す．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが必要な個数とされる．}
  \item{prob}{各試行での成功確率． \code{0 < prob <= 1}．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\details{
  \code{prob} \eqn{= p} の幾何確率は
  \eqn{x = 0, 1, 2, \ldots}, \eqn{0 < p \le 1} に対して密度
  \deqn{p(x) = p {(1-p)}^{x}}{p(x) = p (1-p)^x}
を持つ． 

  もし \code{x} のある要素が整数でなければ
  \code{dgeom} の結果はゼロで警告が出る．

  クォンタイルは
  \eqn{F(x) \ge p} となる最少の
  \eqn{x} の値として定義される，ここで
  \eqn{F} は分布関数である．
}
\value{
  \code{dbeta} は密度，\code{pbeta} は分布関数，
  \code{qbeta} はクォンタイル関数，そして
  \code{rbeta} は乱数を生成する．

  不正な \code{prob} は値 \code{NaN} を返し，警告が出る．

  \code{rgeom} に対しては結果の長さは \code{n} で決まり，
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\source{
  \code{dgeom} は \code{dbinom} を使い計算される，
  使用コードは Catherine Loader による(\code{\link{dbinom}} を見よ)．

  \code{pgeom} と \code{qgeom} は閉じた形の公式の基礎である．

  \code{rgeom} はポアッソン乱数の指数分布による混合を使う，
  次を見よ

  Devroye, L. (1986) \emph{Non-Uniform Random Variate Generation.}
  Springer-Verlag, New York. Page 480.
}
\seealso{
  幾何分布を拡張する負の二項分布 \code{\link{dnbinom}} を含む
  他の標準分布は \link{Distributions}．
}
\examples{
qgeom((1:9)/10, prob = .2)
Ni <- rgeom(20, prob = 1/4); table(factor(Ni, 0:max(Ni)))
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Geometric.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Geometric}
%\alias{Geometric}
%\alias{dgeom}
%\alias{pgeom}
%\alias{qgeom}
%\alias{rgeom}
%\title{The Geometric Distribution}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the geometric distribution with parameter \code{prob}.
%}
%\usage{
%dgeom(x, prob, log = FALSE)
%pgeom(q, prob, lower.tail = TRUE, log.p = FALSE)
%qgeom(p, prob, lower.tail = TRUE, log.p = FALSE)
%rgeom(n, prob)
%}
%\arguments{
%  \item{x, q}{vector of quantiles representing the number of failures in
%    a sequence of Bernoulli trials before success occurs.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{prob}{probability of success in each trial. \code{0 < prob <= 1}.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\details{
%  The geometric distribution with \code{prob} \eqn{= p} has density
%  \deqn{p(x) = p {(1-p)}^{x}}{p(x) = p (1-p)^x}
%  for \eqn{x = 0, 1, 2, \ldots}, \eqn{0 < p \le 1}.
%
%  If an element of \code{x} is not integer, the result of \code{dgeom}
%  is zero, with a warning.
%
%  The quantile is defined as the smallest value \eqn{x} such that
%  \eqn{F(x) \ge p}, where \eqn{F} is the distribution function.
%}
%\value{
%  \code{dgeom} gives the density,
%  \code{pgeom} gives the distribution function,
%  \code{qgeom} gives the quantile function, and
%  \code{rgeom} generates random deviates.
%
%  Invalid \code{prob} will result in return value \code{NaN}, with a warning.
%
%  The length of the result is determined by \code{n} for
%  \code{rgeom}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.  
%  
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\source{
%  \code{dgeom} computes via \code{dbinom}, using code contributed by
%  Catherine Loader (see \code{\link{dbinom}}).
%
%  \code{pgeom} and \code{qgeom} are based on the closed-form formulae.
%
%  \code{rgeom} uses the derivation as an exponential mixture of Poissons, see
%
%  Devroye, L. (1986) \emph{Non-Uniform Random Variate Generation.}
%  Springer-Verlag, New York. Page 480.
%}
%\seealso{
%  \link{Distributions} for other standard distributions, including
%  \code{\link{dnbinom}} for the negative binomial which generalizes
%  the geometric distribution.
%}
%\examples{
%qgeom((1:9)/10, prob = .2)
%Ni <- rgeom(20, prob = 1/4); table(factor(Ni, 0:max(Ni)))
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%