% File src/library/stats/man/StructTS.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{StructTS}
\alias{StructTS}
\alias{print.StructTS}
\alias{predict.StructTS}
\title{Fit Structural Time Series}
\description{
  最大尤度で時系列に構造モデルを当てはめる．
}
\usage{
StructTS(x, type = c("level", "trend", "BSM"), init = NULL,
         fixed = NULL, optim.control = NULL)
}
\arguments{
  \item{x}{位置変量時系列．欠損値が許される．}
  \item{type}{構造モデルのクラス．もし省略されると
    BSM が \code{frequency(x) > 1} の時系列に対して使われ，さもなければ
    局所トレンドモデルが使われる．短縮化が可能．}
  \item{init}{分散パラメータに対する初期値．}
  \item{fixed}{パラメータの総数と同じ長さのオプションの数値ベクトル．
    もし提供されると
    \code{fixed} 中の \code{NA} 項目だけが変化する．
    恐らく分散をセロに設定することが最も有用である．}
  \item{optim.control}{
    \code{\link{optim}} に対する制御パラメータのリスト．
    メソッド \code{"L-BFGS-B"} が使われる．}
}
\details{
 \emph{構造時系列}モデルは(位置変量)時系列に対する
 (線形ガウシアン)状態空間モデルで，系列の幾つかの成分への分割
 に基づく．それらはエラー分散の組で指定され，そのうちの
 幾つかはゼロでも良い．

 最も簡単なモデルは\emph{局所レベル}モデルで，
 \code{type = "level"} で指定される．
 これは基礎にあるレベル
 \eqn{\mu_t}{m[t]} を持ち，それが式
 \deqn{\mu_{t+1} = \mu_t + \xi_t,  \qquad \xi_t \sim N(0, \sigma^2_\xi)}{m[t+1] = m[t] + xi[t], xi[t] ~ N(0, \sigma^2_\xi)}
 で変化する．観測値は
 \deqn{x_t = \mu_t + \epsilon_t, \qquad \epsilon_t \sim  N(0, \sigma^2_\epsilon)}{x[t] = m[t] + eps[t], eps[t] ~  N(0, \sigma^2_\eps)}
 である．
 二つのパラメータ \eqn{\sigma^2_\xi} と
 \eqn{\sigma^2_\epsilon}{\sigma^2_eps} がある．これは
 ARIMA(0,1,1) モデルであるが，パラメータの組に制限がある．

 \emph{局所線形トレンドモデル}，
 \code{type = "trend"}，は同じ観測方程式を持つが，
 \eqn{\mu_t}{m[t]} に対し次のような時間と共に変化する傾きを持ち，
 三つのパラメータを持つ
 \deqn{
   \mu_{t+1} = \mu_t + \nu_t + \xi_t, \qquad  \xi_t \sim N(0, \sigma^2_\xi)
 }{m[t+1] = m[t] + n[t] + xi[t], xi[t] ~ N(0, \sigma^2_\xi)}
 \deqn{
   \nu_{t+1} = \nu_t + \zeta_t, \qquad \zeta_t \sim N(0, \sigma^2_\zeta)
 }{n[t+1] = n[t] + \zeta[t],  \zeta[t] ~ N(0, \sigma^2_\zeta)}
 \eqn{\sigma^2_\zeta = 0} (これは局所モデルに帰着する)
 又は \eqn{\sigma^2_\xi = 0} となることは普通でなく，
 これは滑らかなトレンドを保証する．
 これは制約付きの ARIMA(0,2,2) モデルである．

 \emph{基本構造モデル}，\code{type = "BSM"}，は追加の季節成分を持つ
 局所トレンドモデルである．従って観測方程式は
 \deqn{x_t = \mu_t + \gamma_t + \epsilon_t, \qquad \epsilon_t \sim  N(0, \sigma^2_\epsilon)}{x[t] = m[t] + s[t] + eps[t], eps[t] ~  N(0, \sigma^2_eps)}
 であり，ここで \eqn{\gamma_t}{s[t]} は季節成分で変化
 \deqn{
   \gamma_{t+1} = -\gamma_t + \cdots + \gamma_{t-s+2} + \omega_t, \qquad
   \omega_t \sim N(0, \sigma^2_\omega)
 }{s[t+1] = -s[t] - \dots - s[t - s + 2] + w[t],  w[t] ~ N(0, \sigma^2_w)}
を持つ．境界ケース
\eqn{\sigma^2_\omega = 0}{\sigma^2_w = 0} は
決定論的(しかし任意の)季節パターンに相当する．
(これはしばしば BSM の\sQuote{ダミー変数}版として知られる．)
}
\value{
  クラス \code{"StructTS"} のりストで次の成分持つ：

  \item{coef}{成分の推定分散．}
  \item{loglik}{最大対数尤度．
    これら全ては非定常であるため，これは
    ある観測値に対して拡散事前分布を含み，従って
    \code{\link{arima}} とも異なったタイプの構造モデルとも比較可能
    では無いことを注意する．}
  \item{loglik0}{
    \R 3.0.0 以前で使われた定数を含む最大化対数尤度で，
    後方互換性用．}
  \item{data}{時系列 \code{x}．}
  \item{residuals}{標準化残差．}
  \item{fitted}{多変量時系列で，
    同時的(つまり時刻 \eqn{t} で推定され系列の最後ではない)
    に推定されたレベル，傾き，そして季節成分を持つ．}
  \item{call}{マッチした呼び出し．}
  \item{series}{系列 \code{x} の名前．}
  \item{code}{\code{\link{optim}} が返した
    \code{convergence} コード．}
  \item{model, model0}{当てはめで使われたカルマンフィルターを
    表すリスト．\code{\link{KalmanLike}} を見よ．\code{model0} は
    フィルターの初期状態で，\code{model} はその最終状態である．}
  \item{xtsp}{\code{x} の \code{tsp} 属性．}
}
\references{
  Brockwell, P. J. & Davis, R. A. (1996).
  \emph{Introduction to Time Series and Forecasting}.
  Springer, New York.
  Sections 8.2 and 8.5.

  Durbin, J. and Koopman, S. J. (2001) \emph{Time Series Analysis by
    State Space Methods.}  Oxford University Press.

  Harvey, A. C. (1989)
  \emph{Forecasting, Structural Time Series Models and the Kalman Filter}.
  Cambridge University Press.

  Harvey, A. C. (1993) \emph{Time Series Models}.
  2nd Edition, Harvester Wheatsheaf.
}
\note{
  構造モデルの最適化は多くの参考文献が述べるよりもはるかに
  困難である．例えば
  Brockwell & Davis (1996) で \code{\link{AirPassengers}} データが
  扱われている：彼らの解は局所的最大値と思われるが，
  \code{StructTS} が与える当てはめにはとても及ばない．
  一つもしくはそれ以上の分散がゼロになることは極めて普通であり，
  これは \eqn{\sigma^2_\epsilon}{sigma^2_eps} も含む．
}

\seealso{
  \code{\link{KalmanLike}}, \code{\link{tsSmooth}};
  異なった種類の(季節的)分解には \code{\link{stl}}．
}

\examples{
## JohnsonJohnson, Nile そして AirPassengers も見よ
require(graphics)

trees <- window(treering, start = 0)
(fit <- StructTS(trees, type = "level"))
plot(trees)
lines(fitted(fit), col = "green")
tsdiag(fit)

(fit <- StructTS(log10(UKgas), type = "BSM"))
par(mfrow = c(4, 1)) # 次のプロットに適当なアスペクト比を与えるため
plot(log10(UKgas))
plot(cbind(fitted(fit), resids=resid(fit)), main = "UK gas consumption")

## 幾つかのパラメータを保存；最適過程をトレース：
StructTS(log10(UKgas), type = "BSM", fixed = c(0.1,0.001,NA,NA),
         optim.control = list(trace = TRUE))
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/StructTS.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{StructTS}
%\alias{StructTS}
%\alias{print.StructTS}
%\alias{predict.StructTS}
%\title{Fit Structural Time Series}
%\description{
%  Fit a structural model for a time series by maximum likelihood.
%}
%\usage{
%StructTS(x, type = c("level", "trend", "BSM"), init = NULL,
%         fixed = NULL, optim.control = NULL)
%}
%\arguments{
%  \item{x}{a univariate numeric time series. Missing values are allowed.}
%
%  \item{type}{the class of structural model.  If omitted, a BSM is used
%    for a time series with \code{frequency(x) > 1}, and a local trend
%    model otherwise.  Can be abbreviated.}
%
%  \item{init}{initial values of the variance parameters.}
%
%  \item{fixed}{optional numeric vector of the same length as the total
%    number of parameters.  If supplied, only \code{NA} entries in
%    \code{fixed} will be varied.  Probably most useful for setting
%    variances to zero.}
%
%  \item{optim.control}{List of control parameters for
%    \code{\link{optim}}.  Method \code{"L-BFGS-B"} is used.}
%}
%\details{
% \emph{Structural time series} models are (linear Gaussian) state-space
% models for (univariate) time series based on a decomposition of the
% series into a number of components. They are specified by a set of
% error variances, some of which may be zero.
%
% The simplest model is the \emph{local level} model specified by
% \code{type = "level"}.  This has an underlying level \eqn{\mu_t}{m[t]} which
% evolves by
% \deqn{\mu_{t+1} = \mu_t + \xi_t,  \qquad \xi_t \sim N(0, \sigma^2_\xi)}{m[t+1] = m[t] + xi[t], xi[t] ~ N(0, \sigma^2_\xi)}
% The observations are
% \deqn{x_t = \mu_t + \epsilon_t, \qquad \epsilon_t \sim  N(0, \sigma^2_\epsilon)}{x[t] = m[t] + eps[t], eps[t] ~  N(0, \sigma^2_\eps)}
% There are two parameters, \eqn{\sigma^2_\xi}
% and \eqn{\sigma^2_\epsilon}{\sigma^2_eps}.  It is an ARIMA(0,1,1) model,
% but with restrictions on the parameter set.
%
% The \emph{local linear trend model}, \code{type = "trend"}, has the same
% measurement equation, but with a time-varying slope in the dynamics for
% \eqn{\mu_t}{m[t]}, given by
% \deqn{
%   \mu_{t+1} = \mu_t + \nu_t + \xi_t, \qquad  \xi_t \sim N(0, \sigma^2_\xi)
% }{m[t+1] = m[t] + n[t] + xi[t], xi[t] ~ N(0, \sigma^2_\xi)}
% \deqn{
%   \nu_{t+1} = \nu_t + \zeta_t, \qquad \zeta_t \sim N(0, \sigma^2_\zeta)
% }{n[t+1] = n[t] + \zeta[t],  \zeta[t] ~ N(0, \sigma^2_\zeta)}
% with three variance parameters.  It is not uncommon to find
% \eqn{\sigma^2_\zeta = 0} (which reduces to the local
% level model) or \eqn{\sigma^2_\xi = 0}, which ensures a
% smooth trend.  This is a restricted ARIMA(0,2,2) model.
%
% The \emph{basic structural model}, \code{type = "BSM"}, is a local
% trend model with an additional seasonal component. Thus the measurement
% equation is
% \deqn{x_t = \mu_t + \gamma_t + \epsilon_t, \qquad \epsilon_t \sim  N(0, \sigma^2_\epsilon)}{x[t] = m[t] + s[t] + eps[t], eps[t] ~  N(0, \sigma^2_eps)}
% where \eqn{\gamma_t}{s[t]} is a seasonal component with dynamics
% \deqn{
%   \gamma_{t+1} = -\gamma_t + \cdots + \gamma_{t-s+2} + \omega_t, \qquad
%   \omega_t \sim N(0, \sigma^2_\omega)
% }{s[t+1] = -s[t] - \dots - s[t - s + 2] + w[t],  w[t] ~ N(0, \sigma^2_w)}
% The boundary case \eqn{\sigma^2_\omega = 0}{\sigma^2_w = 0} corresponds
% to a deterministic (but arbitrary) seasonal pattern.  (This is
% sometimes known as the \sQuote{dummy variable} version of the BSM.)
%}
%\value{
%  A list of class \code{"StructTS"} with components:
%
%  \item{coef}{the estimated variances of the components.}
%  \item{loglik}{the maximized log-likelihood.  Note that as all these
%    models are non-stationary this includes a diffuse prior for some
%    observations and hence is not comparable to \code{\link{arima}}
%    nor different types of structural models.}
%  \item{loglik0}{the maximized log-likelihood with the constant used
%    prior to \R 3.0.0, for backwards compatibility.}
%  \item{data}{the time series \code{x}.}
%  \item{residuals}{the standardized residuals.}
%  \item{fitted}{a multiple time series with one component for the level,
%    slope and seasonal components, estimated contemporaneously (that is
%    at time \eqn{t} and not at the end of the series).}
%  \item{call}{the matched call.}
%  \item{series}{the name of the series \code{x}.}
%  \item{code}{the \code{convergence} code returned by \code{\link{optim}}.}
%  \item{model, model0}{Lists representing the Kalman Filter used in the
%    fitting.  See \code{\link{KalmanLike}}.  \code{model0} is the
%    initial state of the filter, \code{model} its final state.}
%  \item{xtsp}{the \code{tsp} attributes of \code{x}.}
%}
%\references{
%  Brockwell, P. J. & Davis, R. A. (1996).
%  \emph{Introduction to Time Series and Forecasting}.
%  Springer, New York.
%  Sections 8.2 and 8.5.
%
%  Durbin, J. and Koopman, S. J. (2001) \emph{Time Series Analysis by
%    State Space Methods.}  Oxford University Press.
%
%  Harvey, A. C. (1989)
%  \emph{Forecasting, Structural Time Series Models and the Kalman Filter}.
%  Cambridge University Press.
%
%  Harvey, A. C. (1993) \emph{Time Series Models}.
%  2nd Edition, Harvester Wheatsheaf.
%}
%\note{
%  Optimization of structural models is a lot harder than many of the
%  references admit.  For example, the \code{\link{AirPassengers}} data
%  are considered in Brockwell & Davis (1996): their solution appears to
%  be a local maximum, but nowhere near as good a fit as that produced by
%  \code{StructTS}.  It is quite common to find fits with one or more
%  variances zero, and this can include \eqn{\sigma^2_\epsilon}{sigma^2_eps}.
%}
%
%\seealso{
%  \code{\link{KalmanLike}}, \code{\link{tsSmooth}};
%  \code{\link{stl}} for different kind of (seasonal) decomposition.
%}
%
%\examples{
%## see also JohnsonJohnson, Nile and AirPassengers
%require(graphics)
%
%trees <- window(treering, start = 0)
%(fit <- StructTS(trees, type = "level"))
%plot(trees)
%lines(fitted(fit), col = "green")
%tsdiag(fit)
%
%(fit <- StructTS(log10(UKgas), type = "BSM"))
%par(mfrow = c(4, 1)) # to give appropriate aspect ratio for next plot.
%plot(log10(UKgas))
%plot(cbind(fitted(fit), resids=resid(fit)), main = "UK gas consumption")
%
%## keep some parameters fixed; trace optimizer:
%StructTS(log10(UKgas), type = "BSM", fixed = c(0.1,0.001,NA,NA),
%         optim.control = list(trace = TRUE))
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%