% File src/library/stats/man/ansari.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{ansari.test}
\alias{ansari.test}
\alias{ansari.test.default}
\alias{ansari.test.formula}
%%\title{Ansari-Bradley Test}
\title{Ansari-Bradley のスケール差に対する二標本検定}
\description{
  スケールパラメータの差に対する Ansari-Bradley の二標本検定を
  実行する．
}
\usage{
ansari.test(x, \dots)

\method{ansari.test}{default}(x, y,
            alternative = c("two.sided", "less", "greater"),
            exact = NULL, conf.int = FALSE, conf.level = 0.95,
            \dots)

\method{ansari.test}{formula}(formula, data, subset, na.action, \dots)
}
\arguments{
  \item{x}{データ値の数値ベクトル．}
  \item{y}{データ値の数値ベクトル．}
  \item{alternative}{対立仮説を指示し，
    \code{"two.sided"}, \code{"greater"} 又は \code{"less"}
    の一つでなければならない．頭文字だけの指定で良い．}
  \item{exact}{正確な p 値を計算すべきかどうかを指示する．}
  \item{conf.int}{論理値，信頼区間を計算すべきか．}
  \item{conf.level}{区間の信頼係数．}
  \item{formula}{
    型式 \code{lhs ~ rhs} の公式で，ここで
    \code{lhs} はデータ値を与える数値変数で
    \code{rhs} は対応するグループを与える二つの水準を持つ因子．}
  \item{data}{オプションの行列かデータフレーム
    (又は類似物：\code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．
    既定では変数は \code{environment(formula)} から取られる．}
  \item{subset}{使用される観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} を含んだ時の処理を指示する関数．
    \code{getOption("na.action")} が既定．}
  \item{\dots}{メソッドに/から渡される追加引数．}
}
\details{
  \code{x} と \code{y} がそれぞれ密度
  \eqn{f((t-m)/s)/s} と \eqn{f(t-m)} を持つ分布からの独立標本とする，
  ここで \eqn{m} は未知の局外母数で
  \eqn{s} はスケール比であり，興味のあるパラメータである．

  Ansari-Bradley 検定は
  \eqn{s} が 1 に等しいという帰無仮説の検定に対して使われる．
  両側対立仮説は
  \eqn{s \ne 1}{s != 1} (分布は分散だけが異なる)，そして
  片側帰無仮説は
  \eqn{s > 1} (\code{x} の分布は大きな分散を持つ，
  \code{"greater"}) 又は\eqn{s < 1} (\code{"less"})．

  既定では(もし \code{exact} が指定されていないと)，
  両方の標本が50未満の有限値を含みタイがなければ，正確な p 値が計算される．
  さもなければ正規近似が使われる．

  オプションでノンパラメトリックな信頼区間と
  \eqn{s} に対する推定量が計算される．
  もし正確な p 値が利用できれば，正確な信頼区間が
  Bauer (1972) で解説されているアルゴリズムで得られ，
  Hodges-Lehmann 推定量が用いられる．
  さもなければ返される信頼区間と点推定値は正規近似に基づく．

  タイのケースでは
  Hollander & Wolfe (1973) で用いられた平均スコアではなく
  ランクの中点が用いられる．より多くの情報については例えば
  Hajek, Sidak and Sen (1999), pages 131ff を見よ．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{Ansari-Bradley 検定統計量．}
  \item{p.value}{検定の p 値．}
  \item{null.value}{帰無仮説の下でのスケール \eqn{s} の比，1．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{文字列 \code{"Ansari-Bradley test"}．}
  \item{data.name}{データの名前を与える文字列．}
  \item{conf.int}{スケールパラメータの信頼区間．
    (\code{conf.int = TRUE} の時だけ存在する．)}
  \item{estimate}{スケール比の推定値．
    (\code{conf.int = TRUE} の時だけ存在する．)}
}
\note{
  Ansari-Bradley 検定の結果を
  (正規性の仮定下で)二つの分散を比較する F 検定
  と比較するためには，
  \eqn{s} はスケール比であり従って
  \eqn{s^2} は分散比(存在すれば)であり，
  一方で F 検定に対しては分散比そのものが興味のある
  パラメータであることを注意する．
  特に Ansari-Bradley t検定では信頼区間は \eqn{s} 用であり，
  F 検定では \eqn{s^2} 用である．
}
\references{
  David F. Bauer (1972),
  Constructing confidence sets using rank statistics.
  \emph{Journal of the American Statistical Association}
  \bold{67}, 687--690.

  Jaroslav Hajek, Zbynek Sidak and Pranab K. Sen (1999),
  \emph{Theory of Rank Tests}.
  San Diego, London: Academic Press.

  Myles Hollander and Douglas A. Wolfe (1973),
  \emph{Nonparametric Statistical Methods.}
  New York: John Wiley & Sons.
  Pages 83--92.
}
\seealso{
  \code{\link{fligner.test}}
  ランクに基づいた(ノンパラメトリック)分散の同一性に
  対する \eqn{k} 標本検定については
  スケールパラメータの差に対するランクに基づく
  2標本検定については  \code{\link{mood.test}}．
  分散の等質性に対するパラメトリックな検定については \code{\link{var.test}}
  と \code{\link{bartlett.test}}．

  Ansari-Bradley 検定に対する正確と近似
  \emph{条件付き} p 値，及びタイを処理する異なった手法については
  パッケージ \CRANpkg{coin} 中の
  \code{\link[coin:ScaleTests]{ansari_test}}．
}
\examples{
## Hollander & Wolfe (1973, p. 86f):
## Hyland 対照血清を用いた血清鉄の決定
ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108, 104, 99,
            101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105, 104,
            100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
ansari.test(ramsay, jung.parekh)

ansari.test(rnorm(10), rnorm(10, 0, 2), conf.int = TRUE)

## より多くの点を試みる - 2.4.1 で失敗
ansari.test(rnorm(100), rnorm(100, 0, 2), conf.int = TRUE)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ansari.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ansari.test}
%\alias{ansari.test}
%\alias{ansari.test.default}
%\alias{ansari.test.formula}
%\title{Ansari-Bradley Test}
%\description{
%  Performs the Ansari-Bradley two-sample test for a difference in scale
%  parameters.
%}
%\usage{
%ansari.test(x, \dots)
%
%\method{ansari.test}{default}(x, y,
%            alternative = c("two.sided", "less", "greater"),
%            exact = NULL, conf.int = FALSE, conf.level = 0.95,
%            \dots)
%
%\method{ansari.test}{formula}(formula, data, subset, na.action, \dots)
%}
%\arguments{
%  \item{x}{numeric vector of data values.}
%  \item{y}{numeric vector of data values.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.  You
%    can specify just the initial letter.}
%  \item{exact}{a logical indicating whether an exact p-value
%    should be computed.}
%  \item{conf.int}{a logical,indicating whether a confidence interval
%    should be computed.}
%  \item{conf.level}{confidence level of the interval.}
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    is a numeric variable giving the data values and \code{rhs} a factor
%    with two levels giving the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\details{
%  Suppose that \code{x} and \code{y} are independent samples from
%  distributions with densities \eqn{f((t-m)/s)/s} and \eqn{f(t-m)},
%  respectively, where \eqn{m} is an unknown nuisance parameter and
%  \eqn{s}, the ratio of scales, is the parameter of interest.  The
%  Ansari-Bradley test is used for testing the null that \eqn{s} equals
%  1, the two-sided alternative being that \eqn{s \ne 1}{s != 1} (the
%  distributions differ only in variance), and the one-sided alternatives
%  being \eqn{s > 1} (the distribution underlying \code{x} has a larger
%  variance, \code{"greater"}) or \eqn{s < 1} (\code{"less"}).
%
%  By default (if \code{exact} is not specified), an exact p-value
%  is computed if both samples contain less than 50 finite values and
%  there are no ties.  Otherwise, a normal approximation is used.
%
%  Optionally, a nonparametric confidence interval and an estimator for
%  \eqn{s} are computed.  If exact p-values are available, an exact
%  confidence interval is obtained by the algorithm described in Bauer
%  (1972), and the Hodges-Lehmann estimator is employed.  Otherwise, the
%  returned confidence interval and point estimate are based on normal
%  approximations.
%
%  Note that mid-ranks are used in the case of ties rather than average
%  scores as employed in Hollander & Wolfe (1973).  See, e.g., Hajek,
%  Sidak and Sen (1999), pages 131ff, for more information.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the Ansari-Bradley test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{null.value}{the ratio of scales \eqn{s} under the null, 1.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{the string \code{"Ansari-Bradley test"}.}
%  \item{data.name}{a character string giving the names of the data.}
%  \item{conf.int}{a confidence interval for the scale parameter.
%    (Only present if argument \code{conf.int = TRUE}.)}
%  \item{estimate}{an estimate of the ratio of scales.
%    (Only present if argument \code{conf.int = TRUE}.)}
%}
%\note{
%  To compare results of the Ansari-Bradley test to those of the F test
%  to compare two variances (under the assumption of normality), observe
%  that \eqn{s} is the ratio of scales and hence \eqn{s^2} is the ratio
%  of variances (provided they exist), whereas for the F test the ratio
%  of variances itself is the parameter of interest.  In particular,
%  confidence intervals are for \eqn{s} in the Ansari-Bradley test but
%  for \eqn{s^2} in the F test.
%}
%\references{
%  David F. Bauer (1972),
%  Constructing confidence sets using rank statistics.
%  \emph{Journal of the American Statistical Association}
%  \bold{67}, 687--690.
%
%  Jaroslav Hajek, Zbynek Sidak and Pranab K. Sen (1999),
%  \emph{Theory of Rank Tests}.
%  San Diego, London: Academic Press.
%
%  Myles Hollander and Douglas A. Wolfe (1973),
%  \emph{Nonparametric Statistical Methods.}
%  New York: John Wiley & Sons.
%  Pages 83--92.
%}
%\seealso{
%  \code{\link{fligner.test}} for a rank-based (nonparametric)
%  \eqn{k}-sample test for homogeneity of variances;
%  \code{\link{mood.test}} for another rank-based two-sample test for a
%  difference in scale parameters;
%  \code{\link{var.test}} and \code{\link{bartlett.test}} for parametric
%  tests for the homogeneity in variance.
%
%  \code{\link[coin:ScaleTests]{ansari_test}} in package \CRANpkg{coin}
%  for exact and approximate \emph{conditional} p-values for the
%  Ansari-Bradley test, as well as different methods for handling ties.
%}
%\examples{
%## Hollander & Wolfe (1973, p. 86f):
%## Serum iron determination using Hyland control sera
%ramsay <- c(111, 107, 100, 99, 102, 106, 109, 108, 104, 99,
%            101, 96, 97, 102, 107, 113, 116, 113, 110, 98)
%jung.parekh <- c(107, 108, 106, 98, 105, 103, 110, 105, 104,
%            100, 96, 108, 103, 104, 114, 114, 113, 108, 106, 99)
%ansari.test(ramsay, jung.parekh)
%
%ansari.test(rnorm(10), rnorm(10, 0, 2), conf.int = TRUE)
%
%## try more points - failed in 2.4.1
%ansari.test(rnorm(100), rnorm(100, 0, 2), conf.int = TRUE)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
