% File src/library/stats/man/ar.ols.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{ar.ols}
\alias{ar.ols}
%%\title{Fit Autoregressive Models to Time Series by OLS}
\title{自己回帰時系列の AR モデルの当てはめ}
\usage{
ar.ols(x, aic = TRUE, order.max = NULL, na.action = na.fail,
       demean = TRUE, intercept = demean, series, \dots)
}
\arguments{
  \item{x}{一変量か多変量時系列．}

  \item{aic}{論理フラグ．もし \code{TRUE} なら赤池の情報量規準が
    自己回帰モデルの次数を決めるために使われる．
    もし \code{FALSE} なら次数 \code{order.max} のモデルが当てはめられる．}

  \item{order.max}{当てはめられるモデルの最大次数(又は次数)．
    既定では \eqn{N-1} と \eqn{10\log_{10}(N)}{10*log10(N)} の小さい方で，
    ここで \eqn{N} は観測値数．}

  \item{na.action}{欠損値を処理するために呼び出される関数．}

  \item{demean}{
    AR モデルは \code{x} からその平均を取り去ったものにすべきか?}

  \item{intercept}{別個の切片項を当てはめるべきか?}

  \item{series}{系列に対する名前．既定では
    \code{deparse(substitute(x))}．}

  \item{\dots}{他のメソッドへ/からの追加引数．}

}
\description{
  データに自己回帰時系列を通常最少二乗法で当てはめる．
  既定では AIC で複雑さを選択する．
}
\details{
  \code{ar.ols} は一般的な AR モデルを定常でないかもしれない
  そして/又 多変量系列 \code{x} に当てはめる．結果の
  無制約最少二乗推定量は，たとえ系列が非定常 かつ/また は
  co-integrated でも一致性を持つ．
  明確にするために，AR 係数は次のような符号を持つとする

  \deqn{x_t - \mu = a_0 + a_1(x_{t-1} - \mu) + \cdots + a_p(x_{t-p} - \mu) + e_t}{(x[t] - m) = a[0] + a[1]*(x[t-1] - m) + \dots +  a[p]*(x[t-p] - m) + e[t]}

  ここで \eqn{a_0}{a[0]} は
  \code{intercept} が真で無い限りゼロで，
  \eqn{\mu}{m} は
  \code{demean} が真なら標本平均，さもなければゼロである．

  次数の選択はもし
  \code{aic} が真なら AIC でなされる．
  メソッドの内 \code{ar.mle} だけが真の最尤推定を行うため，
  これは問題があるかもしれない．
  AIC はあたかも分散推定値が MLE であるかのように計算され，
  尤度から行列式部分を除外する．
  これは推定パラメータ値で評価されたガウシアン尤度とは
  同じでないことを注意する．

  もし \code{intercept} が真なで \code{demean} が偽なら
  幾らかの注意が必要になる．これは系列がおおよそゼロを
  中心としている場合だけ使う．さもなけれ
  計算は不正確かもしれないし，全く失敗するかもしれない．
}
\value{
  クラス \code{"ar"} のりストで次の成分を持つ：
  \item{order}{当てはめモデルの次数．これはもし
    \code{aic = TRUE} ならば AIC を最小化して選ばれる，
    さもなければそれは \code{order.max} である．}
  \item{ar}{当てはめモデルに対する推定自己回帰係数．}
  \item{var.pred}{予測分散：自己回帰モデルで説明できない
    時系列の分散の部分の推定値．}
  \item{x.mean}{当てはめと予測中で用いられる推定平均
    (もし \code{demean} が偽なら 0)．}
  \item{x.intercept}{
    \code{x - x.mean} に対するモデル中の切片．
    (もし \code{demean} が偽なら 0)．}
  \item{x.intercept}{
    \code{x - x.mean} に対するモデル中の切片．
    (もし \code{demean} が偽なら 0)．}
  \item{aic}{各モデルと最良の当てはめモデル間の AIC の差．
    後者は \code{-Inf} の AIC を持ち得ることを注意する．}
  \item{n.used}{時系列中の観測値数．}
  \item{order.max}{\code{order.max} 引数の値．}
  \item{partialacf}{\code{NULL}．\code{ar} との一貫性のため．}
  \item{resid}{最初の \code{order} 観測値で条件付けられた
    当てはめモデルからの残差．
    最初の \code{order} 個の残差は
    \code{NA} とされる．もし \code{x} が時系列ならば
    \code{resid} もそうである．}
  \item{method}{文字列 \code{"Unconstrained LS"}．}
  \item{series}{時系列の名前．}
  \item{frequency}{時系列の周波数．}
  \item{call}{マッチした呼び出し．}
  \item{asy.var.coef}{(一変量ケース，\code{order > 0}．)
    係数推定値の漸近理論による分散行列．}

  \code{predict.ar} に対しては予測値の時系列，又は
  もし \code{se.fit = TRUE} なら予測値
  \code{pred} と推定標準エラー \code{se} を成分に持つリスト．
  どちらの成分も時系列である．
}
\author{Adrian Trapletti, Brian Ripley.}
\seealso{
  \code{\link{ar}}
}
\references{
  Luetkepohl, H. (1991): \emph{Introduction to Multiple Time Series
    Analysis.} Springer Verlag, NY, pp.\sspace{}368--370.
}
\examples{
ar(lh, method = "burg")
ar.ols(lh)
ar.ols(lh, FALSE, 4) # ar(4) を当てはめる

ar.ols(ts.union(BJsales, BJsales.lead))

x <- diff(log(EuStockMarkets))
ar.ols(x, order.max = 6, demean = FALSE, intercept = TRUE)
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ar.ols.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ar.ols}
%\alias{ar.ols}
%\title{Fit Autoregressive Models to Time Series by OLS}
%\usage{
%ar.ols(x, aic = TRUE, order.max = NULL, na.action = na.fail,
%       demean = TRUE, intercept = demean, series, \dots)
%}
%\arguments{
%  \item{x}{A univariate or multivariate time series.}
%
%  \item{aic}{Logical flag.  If \code{TRUE} then the Akaike Information
%    Criterion is used to choose the order of the autoregressive
%    model. If \code{FALSE}, the model of order \code{order.max} is
%    fitted.}
%
%  \item{order.max}{Maximum order (or order) of model to fit. Defaults
%    to \eqn{10\log_{10}(N)}{10*log10(N)} where \eqn{N} is the number
%    of observations.}
%
%  \item{na.action}{function to be called to handle missing values.}
%
%  \item{demean}{should the AR model be for \code{x} minus its mean?}
%
%  \item{intercept}{should a separate intercept term be fitted?}
%
%  \item{series}{names for the series.  Defaults to
%    \code{deparse(substitute(x))}.}
%
%  \item{\dots}{further arguments to be passed to or from methods.}
%}
%\description{
%  Fit an autoregressive time series model to the data by ordinary
%  least squares, by default selecting the complexity by AIC.
%}
%\details{
%  \code{ar.ols} fits the general AR model to a possibly non-stationary
%  and/or multivariate system of series \code{x}. The resulting
%  unconstrained least squares estimates are consistent, even if
%  some of the series are non-stationary and/or co-integrated.
%  For definiteness, note that the AR coefficients have the sign in
%
%  \deqn{x_t - \mu = a_0 + a_1(x_{t-1} - \mu) + \cdots + a_p(x_{t-p} - \mu) + e_t}{(x[t] - m) = a[0] + a[1]*(x[t-1] - m) + \dots +  a[p]*(x[t-p] - m) + e[t]}
%
%  where \eqn{a_0}{a[0]} is zero unless \code{intercept} is true, and
%  \eqn{\mu}{m} is the sample mean if \code{demean} is true, zero
%  otherwise.
%
%  Order selection is done by AIC if \code{aic} is true. This is
%  problematic, as \code{ar.ols} does not perform
%  true maximum likelihood estimation. The AIC is computed as if
%  the variance estimate (computed from the variance matrix of the
%  residuals) were the MLE, omitting the determinant term from the
%  likelihood. Note that this is not the same as the Gaussian
%  likelihood evaluated at the estimated parameter values.
%
%  Some care is needed if \code{intercept} is true and \code{demean} is
%  false. Only use this is the series are roughly centred on
%  zero. Otherwise the computations may be inaccurate or fail entirely.
%}
%\value{
%  A list of class \code{"ar"} with the following elements:
%  \item{order}{The order of the fitted model.  This is chosen by
%    minimizing the AIC if \code{aic = TRUE}, otherwise it is
%    \code{order.max}.}
%  \item{ar}{Estimated autoregression coefficients for the fitted
%    model.}
%  \item{var.pred}{The prediction variance: an estimate of the portion of
%    the variance of the time series that is not explained by the
%    autoregressive model.}
%  \item{x.mean}{The estimated mean (or zero if \code{demean} is false)
%    of the series used in fitting and for use in prediction.}
%  \item{x.intercept}{The intercept in the model for
%    \code{x - x.mean}, or zero if \code{intercept} is false.}
%  \item{aic}{The differences in AIC between each model and the
%    best-fitting model.  Note that the latter can have an AIC of \code{-Inf}.}
%  \item{n.used}{The number of observations in the time series.}
%  \item{order.max}{The value of the \code{order.max} argument.}
%  \item{partialacf}{\code{NULL}.  For compatibility with \code{ar}.}
%  \item{resid}{residuals from the fitted model, conditioning on the
%    first \code{order} observations.  The first \code{order} residuals
%    are set to \code{NA}. If \code{x} is a time series, so is
%    \code{resid}.}
%  \item{method}{The character string \code{"Unconstrained LS"}.}
%  \item{series}{The name(s) of the time series.}
%  \item{frequency}{The frequency of the time series.}
%  \item{call}{The matched call.}
%  \item{asy.se.coef}{The asymptotic-theory standard errors of the
%    coefficient estimates.}
%}
%\author{Adrian Trapletti, Brian Ripley.}
%\seealso{
%  \code{\link{ar}}
%}
%\references{
%  Luetkepohl, H. (1991): \emph{Introduction to Multiple Time Series
%    Analysis.} Springer Verlag, NY, pp.\sspace{}368--370.
%}
%\examples{
%ar(lh, method = "burg")
%ar.ols(lh)
%ar.ols(lh, FALSE, 4) # fit ar(4)
%
%ar.ols(ts.union(BJsales, BJsales.lead))
%
%x <- diff(log(EuStockMarkets))
%ar.ols(x, order.max = 6, demean = FALSE, intercept = TRUE)
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
