% File src/library/stats/man/chisq.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{chisq.test}
\alias{chisq.test}
\concept{goodness-of-fit}
%%\title{Pearson's Chi-squared Test for Count Data}
\title{分類表のカイ二乗検定と適合度検定}
\description{
  \code{chisq.test} は分類表のカイ二乗検定と適合度検定を行う．
}
\usage{
chisq.test(x, y = NULL, correct = TRUE,
           p = rep(1/length(x), length(x)), rescale.p = FALSE,
           simulate.p.value = FALSE, B = 2000)
}
\arguments{
  \item{x}{数値ベクトル又は行列．
    \code{x} と \code{y} は共に因子でも良い．}
  \item{y}{数値ベクトル；
    もし \code{x} が行列なら無視される．
    もし \code{x} が因子ならば，
    \code{y} は同じ長さの因子でなければならない．}
  \item{correct}{
    2 x 2 テーブルに対する検定統計量を計算する際
    連続補正をするかどうかを指示する論理値：
    全ての \eqn{|O - E|} 差から 0.5 を引く；
    しかしながら補正は差そのものより大きくなることはない．
    もし \code{simulate.p.value = TRUE} ならば補正は行われない．}
  \item{p}{
    \code{x} と同じ長さの確率のベクトル．
    もし \code{p} の項目のどれかが負ならばエラーになる．}
  \item{rescale.p}{論理値のスカラー；
    もし真なら \code{p} は(必要なら)総和 1 に再スケール化される．
    もし \code{rescale.p} が偽で
    \code{p} の総和が 1 でなければエラーを与える．}
  \item{simulate.p.value}{
    p 値をモンテカルロ・シミュレーションで計算するかどうかを指示する論理値．}
  \item{B}{モンテカルロ検定で使われる複製の数を指定する整数．}
}
\details{
  もし \code{x} が一行又は一列の行列か，
  またはもし \code{x} がベクトルで \code{y} が与えられなければ，
  \emph{適合度検定}が実行される
  (\code{x} は一次元分割表とされる)．
  \code{x} の項目は非負整数でなければならない．
  この場合検定される仮説は
  母集団確率が \code{p} 中のそれに等しいか，又は
  \code{p} が与えられなければ全て等しいか，である．

  もし \code{x} が少なくとも二つの行か列を持つ行列ならば
  それは二次元の分割表と見做される：
  \code{x} の項目は非負整数でなければならない．
  さもなければ \code{x} と \code{y} は同じ長さのベクトルか
  因子でなければならない；
  欠損値を含むケースは取り除かれ，
  オブジェクトは因子に変換され，
  それらから分割表が計算される．
  そして，ペアソンのカイ二乗検定を用いて
  二次元分割表のセルの個数の同時分布が
  行と列の周辺分布の積かどうかが検定される．

  もし \code{simulate.p.value} が \code{FALSE} なら，p 値は
  検定統計量の漸近的カイ二乗分布から計算される；
  連続補正は
  2 x 2 ケースでだけ使われる
  (もし既定の \code{correct} が \code{TRUE} の時)．
  さもなければ p 値は \code{B} 個の複製を用いて
  モンテカルロ検定で行われる(Hope, 1968)．

  分割表ケースではシミュレーションは
  与えられた周辺カウントを持つ全ての分割表の集合からの
  無作為標本で行われ，そして
  周辺カウントが狭義に正でなければならない．
  連続補正は決して使われず，統計量はそれなしに参照される．
  これはカイ二乗検定に対して仮定される普通のサンプリングの状況ではなく，
  むしろ Fisher の正確検定用である．

  適合度検定ではシミュレーションは
  \code{p} で指定される離散分布からの無作為抽出で行われ，
  各サンプルはサイズ
  \code{n = sum(x)} である．シミュレーションは \R で行われ遅いかもしれない．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{カイ二乗検定統計量の値．}
  \item{parameter}{検定統計量の近似カイ二乗分布の自由度，
    もし p 値がモンテカルロシミュレーションで計算されれば
    \code{NA}．}
  \item{p.value}{検定に対する p 値．}
  \item{method}{実行された検定のタイプと，
    モンテカルロ・シミュレーションや連続補正が
    行われたかどうかを示す文字列．}
  \item{data.name}{データの名前を与える文字列．}
  \item{observed}{観測値の個数．}
  \item{expected}{帰無仮説の下での期待個数．}
  \item{residuals}{ペアソン残差，
    \code{(observed - expected) / sqrt(expected)}．}
  \item{stdres}{標準化残差，
    \code{(observed - expected) / sqrt(V)}，
    ここで \code{V} は残差セル分散
    (\code{x} が行列の場合，Agresti, 2007,
    section 2.4.5 ，さもなければ
    \code{n * p * (1 - p)})．}
}
\seealso{
  適合度検定，特に連続分布に対しては \code{\link{ks.test}}．
}
\source{
  モンテカルロ・シミュレーションに対するコードは
  Patefield (1981) の Fortran アルゴリズムの C 翻訳である．
}

\references{
  Hope, A. C. A. (1968)
  A simplified Monte Carlo significance test procedure.
  \emph{J. Roy, Statist. Soc. B} \bold{30}, 582--598.

  Patefield, W. M. (1981)
  Algorithm AS159.  An efficient method of generating r x c tables
  with given row and column totals.
  \emph{Applied Statistics} \bold{30}, 91--97.

  Agresti, A. (2007)
  \emph{An Introduction to Categorical Data Analysis, 2nd ed.},
  New York: John Wiley & Sons.
  Page 38.
}
\examples{

## Agresti(2007) p.39 より
M <- as.table(rbind(c(762, 327, 468), c(484, 239, 477)))
dimnames(M) <- list(gender = c("F", "M"),
                    party = c("Democrat","Independent", "Republican"))
(Xsq <- chisq.test(M))  # 検定要約のプリント
Xsq$observed   # 観測個数(M と同じ)
Xsq$expected   # 帰無仮説の下の期待個数
Xsq$residuals  # ペアソンの残差
Xsq$stdres     # 標準化残差


## シミュレーションによる p 値の効果
x <- matrix(c(12, 5, 7, 7), ncol = 2)
chisq.test(x)$p.value           # 0.4233
chisq.test(x, simulate.p.value = TRUE, B = 10000)$p.value
                                # 約 0.29!

## 母集団確率引退する検定
## Case A. Tabulated data
x <- c(A = 20, B = 15, C = 25)
chisq.test(x)
chisq.test(as.table(x))             # 同じ
x <- c(89,37,30,28,2)
p <- c(40,20,20,15,5)
try(
chisq.test(x, p = p)                # エラーを与える
)
chisq.test(x, p = p, rescale.p = TRUE)
                                # works
p <- c(0.40,0.20,0.20,0.19,0.01)
                                # カテゴリー 5 の期待回数
                                # 1.86 < 5 ==> カイ二乗近似．
chisq.test(x, p = p)            #              疑わしいが問題ない!
chisq.test(x, p = p, simulate.p.value = TRUE)

## ケース B．生データ
x <- trunc(5 * runif(100))
chisq.test(table(x))            # 'chisq.test(x)' では無い!
}
\keyword{htest}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/chisq.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{chisq.test}
%\alias{chisq.test}
%\concept{goodness-of-fit}
%\title{Pearson's Chi-squared Test for Count Data}
%\description{
%  \code{chisq.test} performs chi-squared contingency table tests
%                    and goodness-of-fit tests.
%}
%\usage{
%chisq.test(x, y = NULL, correct = TRUE,
%           p = rep(1/length(x), length(x)), rescale.p = FALSE,
%           simulate.p.value = FALSE, B = 2000)
%}
%\arguments{
%  \item{x}{a numeric vector or matrix. \code{x} and \code{y} can also
%    both be factors.}
%  \item{y}{a numeric vector; ignored if \code{x} is a matrix.  If
%    \code{x} is a factor, \code{y} should be a factor of the same length.}
%  \item{correct}{a logical indicating whether to apply continuity
%    correction when computing the test statistic for 2 by 2 tables: one
%    half is subtracted from all \eqn{|O - E|} differences; however, the
%    correction will not be bigger than the differences themselves.  No correction
%    is done if \code{simulate.p.value = TRUE}.}
%  \item{p}{a vector of probabilities of the same length of \code{x}.
%    An error is given if any entry of \code{p} is negative.}
%  \item{rescale.p}{a logical scalar; if TRUE then \code{p} is rescaled
%    (if necessary) to sum to 1.  If \code{rescale.p} is FALSE, and
%    \code{p} does not sum to 1, an error is given.}
%  \item{simulate.p.value}{a logical indicating whether to compute
%    p-values by Monte Carlo simulation.}
%  \item{B}{an integer specifying the number of replicates used in the
%    Monte Carlo test.}
%}
%\details{
%  If \code{x} is a matrix with one row or column, or if \code{x} is a
%  vector and \code{y} is not given, then a \emph{goodness-of-fit test}
%  is performed (\code{x} is treated as a one-dimensional
%  contingency table).  The entries of \code{x} must be non-negative
%  integers.  In this case, the hypothesis tested is whether the
%  population probabilities equal those in \code{p}, or are all equal if
%  \code{p} is not given.
%
%  If \code{x} is a matrix with at least two rows and columns, it is
%  taken as a two-dimensional contingency table: the entries of \code{x}
%  must be non-negative integers.  Otherwise, \code{x} and \code{y} must
%  be vectors or factors of the same length; cases with missing values
%  are removed, the objects are coerced to factors, and the contingency
%  table is computed from these.  Then Pearson's chi-squared test is
%  performed of the null hypothesis that the joint distribution of the
%  cell counts in a 2-dimensional contingency table is the product of the
%  row and column marginals.
%
%  If \code{simulate.p.value} is \code{FALSE}, the p-value is computed
%  from the asymptotic chi-squared distribution of the test statistic;
%  continuity correction is only used in the 2-by-2 case (if \code{correct}
%  is \code{TRUE}, the default).  Otherwise the p-value is computed for a
%  Monte Carlo test (Hope, 1968) with \code{B} replicates.
%
%  In the contingency table case simulation is done by random sampling
%  from the set of all contingency tables with given marginals, and works
%  only if the marginals are strictly positive.  Continuity correction is
%  never used, and the statistic is quoted without it.  Note that this is
%  not the usual sampling situation assumed for the chi-squared test but
%  rather that for Fisher's exact test.
%
%  In the goodness-of-fit case simulation is done by random sampling from
%  the discrete distribution specified by \code{p}, each sample being
%  of size \code{n = sum(x)}.  This simulation is done in \R and may be
%  slow.
%}
%\value{
%  A list with class \code{"htest"} containing the following
%  components:
%  \item{statistic}{the value the chi-squared test statistic.}
%  \item{parameter}{the degrees of freedom of the approximate
%    chi-squared distribution of the test statistic, \code{NA} if the
%    p-value is computed by Monte Carlo simulation.}
%  \item{p.value}{the p-value for the test.}
%  \item{method}{a character string indicating the type of test
%    performed, and whether Monte Carlo simulation or continuity
%    correction was used.}
%  \item{data.name}{a character string giving the name(s) of the data.}
%  \item{observed}{the observed counts.}
%  \item{expected}{the expected counts under the null hypothesis.}
%  \item{residuals}{the Pearson residuals,
%    \code{(observed - expected) / sqrt(expected)}.}
%  \item{stdres}{standardized residuals,
%    \code{(observed - expected) / sqrt(V)}, where \code{V} is the residual cell variance (Agresti, 2007,
%    section 2.4.5 for the case where \code{x} is a matrix, \code{n * p * (1 - p)} otherwise).}
%}
%\seealso{
%  For goodness-of-fit testing, notably of continuous distributions,
%  \code{\link{ks.test}}.
%}
%\source{
%  The code for Monte Carlo simulation is a C translation of the Fortran
%  algorithm of Patefield (1981).
%}
%
%\references{
%  Hope, A. C. A. (1968)
%  A simplified Monte Carlo significance test procedure.
%  \emph{J. Roy, Statist. Soc. B} \bold{30}, 582--598.
%
%  Patefield, W. M. (1981)
%  Algorithm AS159.  An efficient method of generating r x c tables
%  with given row and column totals.
%  \emph{Applied Statistics} \bold{30}, 91--97.
%
%  Agresti, A. (2007)
%  \emph{An Introduction to Categorical Data Analysis, 2nd ed.},
%  New York: John Wiley & Sons.
%  Page 38.
%}
%\examples{
%
%## From Agresti(2007) p.39
%M <- as.table(rbind(c(762, 327, 468), c(484, 239, 477)))
%dimnames(M) <- list(gender = c("F", "M"),
%                    party = c("Democrat","Independent", "Republican"))
%(Xsq <- chisq.test(M))  # Prints test summary
%Xsq$observed   # observed counts (same as M)
%Xsq$expected   # expected counts under the null
%Xsq$residuals  # Pearson residuals
%Xsq$stdres     # standardized residuals
%
%
%## Effect of simulating p-values
%x <- matrix(c(12, 5, 7, 7), ncol = 2)
%chisq.test(x)$p.value           # 0.4233
%chisq.test(x, simulate.p.value = TRUE, B = 10000)$p.value
%                                # around 0.29!
%
%## Testing for population probabilities
%## Case A. Tabulated data
%x <- c(A = 20, B = 15, C = 25)
%chisq.test(x)
%chisq.test(as.table(x))             # the same
%x <- c(89,37,30,28,2)
%p <- c(40,20,20,15,5)
%try(
%chisq.test(x, p = p)                # gives an error
%)
%chisq.test(x, p = p, rescale.p = TRUE)
%                                # works
%p <- c(0.40,0.20,0.20,0.19,0.01)
%                                # Expected count in category 5
%                                # is 1.86 < 5 ==> chi square approx.
%chisq.test(x, p = p)            #               maybe doubtful, but is ok!
%chisq.test(x, p = p, simulate.p.value = TRUE)
%
%## Case B. Raw data
%x <- trunc(5 * runif(100))
%chisq.test(table(x))            # NOT 'chisq.test(x)'!
%}
%\keyword{htest}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
