% File src/library/stats/man/interaction.plot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{interaction.plot}
\alias{interaction.plot}%@%\alias{相互作用プロット}
\title{Two-way Interaction Plot}
\description{
  二つの因子の組み合わせ毎に対する応答の平均(又は他の要約)をプロットし，
  可能な相互作用を図解する．
}
\usage{
interaction.plot(x.factor, trace.factor, response, fun = mean,
                 type = c("l", "p", "b", "o", "c"), legend = TRUE,
                 trace.label = deparse(substitute(trace.factor)),
                 fixed = FALSE,
                 xlab = deparse(substitute(x.factor)),
                 ylab = ylabel,
                 ylim = range(cells, na.rm = TRUE),
                 lty = nc:1, col = 1, pch = c(1:9, 0, letters),
                 xpd = NULL, leg.bg = par("bg"), leg.bty = "n",
                 xtick = FALSE, xaxt = par("xaxt"), axes = TRUE,
                 \dots)
}
\arguments{
  \item{x.factor}{その水準が x 軸を形作る因子．}
  \item{trace.factor}{その水準がトレースを形作る別の因子．}
  \item{response}{応答を与える数値変数．}
  \item{fun}{要約を計算する関数．単一の実数を返さなければならない．}
  \item{type}{プロットのタイプ(\code{\link{plot.default}} を見よ)：
    線又は点もしくは双方．}
  \item{legend}{論理値．凡例を含めるべきか?}
  \item{trace.label}{凡例に対する全般的なラベル．}
  \item{fixed}{論理値．凡例は
    \code{trace.factor} の水準の順序か，又は
    それらの右端のトレースの順序か?}
  \item{xlab,ylab}{意味のある既定値を持つプロットの x と y ラベル．}
  \item{ylim}{プロットの y 範囲を与える長さ 2 のベクトル．}
  \item{lty}{描かれる線の線種で，意味のある既定値を持つ．}
  \item{col}{プロットに使われる色．}
  \item{pch}{プロットされるシンボルか文字のベクトルで，意味のある
    既定値を持つ．}
  \item{xpd}{
    使われる凡例に対するクリップ動作を決める，
    \code{\link{par}(xpd)} を見よ．既定では，
    凡例は図の境界でクリップ
    \emph{されない}．}
  \item{leg.bg, leg.bty}{
    \code{\link{legend}()} に渡される引数．}
  \item{xtick}{論理値．x 軸にチックマークを使うべきか?}
  \item{xaxt, axes, \dots}{プロットルーチンに渡されるグラフィックスパラメータ．}
}
\details{
  既定では
  \code{x.factor} の水準は x 軸上に与えられた順序でプロットされ，
  (もし指定されれば)凡例のために右側に余分のスペースが残される
  \code{x.factor} が順序付き因子で水準が数値ならば，これらの数値が x 軸
  に対して使われる．

  応答と従ってその要約も欠損値を含むことが出来る．
  もしそうならば，欠損値とそれらをつなぐ線分はプロットから除かれる
  (そしてこれは幾らか当惑させることになる)．

  グラフィックスパラメータ
  \code{xlab}, \code{ylab}, \code{ylim},
  \code{lty}, \code{col} そして \code{pch} は適切な既定値を与えられる
  (そして \code{xlim} と \code{xaxs} が設定され上書きできない)．
  既定値は線種を通じて循環され，前景色を使い，
  トレースをプロットするのにシンボル 1:9, 0 と大文字を使う．
}
\note{
  幾つかの引数名と正確な動作は
  S との互換性のため選ばれている．
}
\references{
  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
  \emph{Analysis of variance; designed experiments.}
  Chapter 5 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}

\examples{
require(graphics)

with(ToothGrowth, {
interaction.plot(dose, supp, len, fixed = TRUE)
dose <- ordered(dose)
interaction.plot(dose, supp, len, fixed = TRUE, col = 2:3, leg.bty = "o")
interaction.plot(dose, supp, len, fixed = TRUE, col = 2:3, type = "p")
})

with(OrchardSprays, {
  interaction.plot(treatment, rowpos, decrease)
  interaction.plot(rowpos, treatment, decrease, cex.axis = 0.8)
  ## 行をそれらの平均効果で並べる
  rowpos <- factor(rowpos,
                   levels = sort.list(tapply(decrease, rowpos, mean)))
  interaction.plot(rowpos, treatment, decrease, col = 2:9, lty = 1)
})

with(esoph, {
  interaction.plot(agegp, alcgp, ncases/ncontrols, main = "'esoph' Data")
  interaction.plot(agegp, tobgp, ncases/ncontrols, trace.label = "tobacco",
                   fixed = TRUE, xaxt = "n")
})
## NA の処理：
esoph[66,] # 二番目から最後までの年齢グループ：65-74
esophNA <- esoph; esophNA$ncases[66] <- NA
with(esophNA, {
  interaction.plot(agegp, alcgp, ncases/ncontrols, col = 2:5)
                                # 最後のグループも示さない
  interaction.plot(agegp, alcgp, ncases/ncontrols, col = 2:5, type = "b")
  ## NA でないものを選ぶ別法 {"騙す"}
  interaction.plot(agegp, alcgp, ncases/ncontrols, col = 2:5,
                   fun = function(x) mean(x, na.rm = TRUE),
                   sub = "function(x) mean(x, na.rm=TRUE)")
})
rm(esophNA) # to clear up
}
\keyword{hplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/interaction.plot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{interaction.plot}
%\alias{interaction.plot}
%\title{Two-way Interaction Plot}
%\description{
%  Plots the mean (or other summary) of the response for two-way
%  combinations of factors, thereby illustrating possible interactions.
%}
%\usage{
%interaction.plot(x.factor, trace.factor, response, fun = mean,
%                 type = c("l", "p", "b", "o", "c"), legend = TRUE,
%                 trace.label = deparse(substitute(trace.factor)),
%                 fixed = FALSE,
%                 xlab = deparse(substitute(x.factor)),
%                 ylab = ylabel,
%                 ylim = range(cells, na.rm = TRUE),
%                 lty = nc:1, col = 1, pch = c(1:9, 0, letters),
%                 xpd = NULL, leg.bg = par("bg"), leg.bty = "n",
%                 xtick = FALSE, xaxt = par("xaxt"), axes = TRUE,
%                 \dots)
%}
%\arguments{
%  \item{x.factor}{a factor whose levels will form the x axis.}
%  \item{trace.factor}{another factor whose levels will form the traces.}
%  \item{response}{a numeric variable giving the response}
%  \item{fun}{the function to compute the summary. Should return a single
%    real value.}
%  \item{type}{the type of plot (see \code{\link{plot.default}}): lines
%    or points or both.}
%  \item{legend}{logical. Should a legend be included?}
%  \item{trace.label}{overall label for the legend.}
%  \item{fixed}{logical.  Should the legend be in the order of the levels
%    of \code{trace.factor} or in the order of the traces at their right-hand ends?}
%  \item{xlab,ylab}{the x and y label of the plot each with a sensible default.}
%  \item{ylim}{numeric of length 2 giving the y limits for the plot.}
%  \item{lty}{line type for the lines drawn, with sensible default.}
%  \item{col}{the color to be used for plotting.}
%  \item{pch}{a vector of plotting symbols or characters, with sensible
%    default.}
%  \item{xpd}{determines clipping behaviour for the \code{\link{legend}}
%    used, see \code{\link{par}(xpd)}.  Per default, the legend is
%    \emph{not} clipped at the figure border.}
%  \item{leg.bg, leg.bty}{arguments passed to \code{\link{legend}()}.}
%  \item{xtick}{logical. Should tick marks be used on the x axis?}
%  \item{xaxt, axes, \dots}{graphics parameters to be passed to the plotting routines.}
%}
%\details{
%  By default the levels of \code{x.factor} are plotted on the x axis in
%  their given order, with extra space left at the right for the legend
%  (if specified). If \code{x.factor} is an ordered factor and the levels
%  are numeric, these numeric values are used for the x axis.
%
%  The response and hence its summary can contain missing values. If so,
%  the missing values and the line segments joining them are omitted from
%  the plot (and this can be somewhat disconcerting).
%
%  The graphics parameters \code{xlab}, \code{ylab}, \code{ylim},
%  \code{lty}, \code{col} and \code{pch} are given suitable defaults
%  (and \code{xlim} and \code{xaxs} are set and cannot be overridden).
%  The defaults are to cycle through the line types, use the foreground
%  colour, and to use the symbols 1:9, 0, and the capital letters to plot
%  the traces.
%}
%\note{
%  Some of the argument names and the precise behaviour are chosen for
%  S-compatibility.
%}
%\references{
%  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
%  \emph{Analysis of variance; designed experiments.}
%  Chapter 5 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%
%\examples{
%require(graphics)
%
%with(ToothGrowth, {
%interaction.plot(dose, supp, len, fixed = TRUE)
%dose <- ordered(dose)
%interaction.plot(dose, supp, len, fixed = TRUE, col = 2:3, leg.bty = "o")
%interaction.plot(dose, supp, len, fixed = TRUE, col = 2:3, type = "p")
%})
%
%with(OrchardSprays, {
%  interaction.plot(treatment, rowpos, decrease)
%  interaction.plot(rowpos, treatment, decrease, cex.axis = 0.8)
%  ## order the rows by their mean effect
%  rowpos <- factor(rowpos,
%                   levels = sort.list(tapply(decrease, rowpos, mean)))
%  interaction.plot(rowpos, treatment, decrease, col = 2:9, lty = 1)
%})
%
%with(esoph, {
%  interaction.plot(agegp, alcgp, ncases/ncontrols, main = "'esoph' Data")
%  interaction.plot(agegp, tobgp, ncases/ncontrols, trace.label = "tobacco",
%                   fixed = TRUE, xaxt = "n")
%})
%## deal with NAs:
%esoph[66,] # second to last age group: 65-74
%esophNA <- esoph; esophNA$ncases[66] <- NA
%with(esophNA, {
%  interaction.plot(agegp, alcgp, ncases/ncontrols, col = 2:5)
%                                # doesn't show *last* group either
%  interaction.plot(agegp, alcgp, ncases/ncontrols, col = 2:5, type = "b")
%  ## alternative take non-NA's  {"cheating"}
%  interaction.plot(agegp, alcgp, ncases/ncontrols, col = 2:5,
%                   fun = function(x) mean(x, na.rm = TRUE),
%                   sub = "function(x) mean(x, na.rm=TRUE)")
%})
%rm(esophNA) # to clear up
%}
%\keyword{hplot}
%
%\encoding{UTF-8}
%
