% File src/library/stats/man/ks.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{ks.test}
\alias{ks.test}%@%\alias{コルモゴロフ・スミルノフ検定}
\title{Kolmogorov-Smirnov Tests}
\description{
  一変量もしくは二変量のコルモゴロフ・スミルノフ検定を実行する．
}
\usage{
ks.test(x, y, \dots,
        alternative = c("two.sided", "less", "greater"),
        exact = NULL)
}
\arguments{
  \item{x}{データ値の数値ベクトル．}
  \item{y}{データ値の数値ベクトルか
    累積分布関数の名前の文字列，又は \code{pnorm} のような実際の
    累積分布関数．連続 CDF だけが許される．}
  \item{\dots}{
    \code{y} で指定される(文字列としての)分布のパラメータ．}    
  \item{alternative}{
    対立仮説を指示し
    \code{"two.sided"} (既定)，\code{"less"} 又は
    \code{"greater"} のどれかでなければならない．
    頭文字だけを指定すれば良いが引数名は完全に与えなければならない．
    可能な値に関する詳細は\sQuote{詳細}節を見よ．}
  \item{exact}{\code{NULL} か正確な p 値を計算すべきかどうかを
    指示する論理値．
    \code{NULL} の意味は\sQuote{詳細}節を見よ．
    片側検定の二標本ケースやタイがある場合は利用できない．}
}
\details{
  もし \code{y} が数値ならば，
  \code{x} と \code{y} が同じ
  \emph{連続分布}に由来するという帰無仮説に対する
  二標本検定が実行される．

  もしくは，\code{y} が連続(累積)分布関数の名前の文字列，もしくは
  そうした関数でも良い．この場合
  \code{x} を生成した分布が \code{\dots} で指定されたパラメータの
  \code{y} であるという帰無仮説の検定が実行される．
  
  連続分布ではそれはあり得ないからタイが存在すると常に警告がでる．
  もしタイが丸めのせいで発生すれば検定は近似的に適正であるが，
  程々の程度の丸めも計算される統計量に大きな影響を与える．

  欠損値は \code{x} と(二標本ケースでは) \code{y} から黙って取り除かれる．

  \code{alternative} の可能な値 \code{"two.sided"}, \code{"less"} そして
  \code{"greater"} は
  それぞれ，真の \code{x} は仮説の分布関数(一変量ケース)か
  \code{y} の分布(二変量ケース)に等しくない，小さくない，又は大きくない
  という対立仮説を指定する．
  これは累積分布関数の比較であり，検定統計量は値の最大差であり，
  \code{"greater"} 対立仮説中の統計量は
  \eqn{D^+ = \max_u [ F_x(u) - F_y(u) ]}{D^+ = max[F_x(u) - F_y(u)]} である．
  このように二変量ケースの \code{alternative = "greater"} は
  \code{\link{t.test}} や \code{\link{wilcox.test}} と比較すると
  \code{x} が確率的に \code{y} より\emph{小さい}
  (\code{x} の CDF が \code{y} のそれの上，つまり左にある)場合を含む．


  二変量ケースの正確な p 値は
  片側検定やタイが存在する場合は得られない．
  もし \code{exact = NULL} (既定) ならば，
  一標本ケースで\emph{そしてタイが無く}標本数が 100 未満であるか，
  二標本ケースで標本数の積が 10000 未満ならば
  正確な p 値が計算される．
  そして，もし
  さもなければ，近似分布が使われるが，その近似は小標本では
  不正確かもしれない．
  一標本で両側検定ならば
  Marsaglia, Tsang & Wang (2003) で説明されているような正確な p 値が
  計算される(しかし右裾でオプションの近似を使わないので
  小さな p 値に対しては遅いことがあり得る)．
  Birnbaum & Tingey (1951) の公式が一変量片側検定に対して使われる．

  もし一変量検定が使われると，
  \code{\dots} 中で指定されるパラメータは予め求めておかれるべきで，
  データから推定してはならない．
  推定されたパラメータを用いた KS 検定のいくらかより精密な分布理論が
  ある(Durbin, 1973 を見よ)が，それは
  \code{ks.test} には実装されていない．
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{検定統計量の値．}
  \item{p.value}{検定の p 値．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{どのタイプの検定を実行するかを指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\source{
  両側一変量分布は Marsaglia, Tsang and Wang (2003) に基づく．
}
\references{
  Z. W. Birnbaum and Fred H. Tingey (1951),
  One-sided confidence contours for probability distribution functions.
  \emph{The Annals of Mathematical Statistics}, \bold{22}/4, 592--596.

  William J. Conover (1971),
  \emph{Practical Nonparametric Statistics}.
  New York: John Wiley & Sons.
  Pages 295--301 (one-sample Kolmogorov test),
  309--314 (two-sample Smirnov test).

  Durbin, J. (1973),
  \emph{Distribution theory for tests based on the sample distribution
    function}.  SIAM.

  George Marsaglia, Wai Wan Tsang and Jingbo Wang (2003),
  Evaluating Kolmogorov's distribution.
  \emph{Journal of Statistical Software}, \bold{8}/18.
  \url{http://www.jstatsoft.org/v08/i18/}.

}
\seealso{
  正規性に対する Shapiro-Wilk 検定を実行する \code{\link{shapiro.test}}．
}
\examples{
require(graphics)

x <- rnorm(50)
y <- runif(30)
# x と y は同じ分布に由来するか?
ks.test(x, y)
# x は形状パラメータ 3 でレートパラメータ 27 のガンマ分布由来か?
ks.test(x+2, "pgamma", 3, 2) # 両側，正確
ks.test(x+2, "pgamma", 3, 2, exact = FALSE)
ks.test(x+2, "pgamma", 3, 2, alternative = "gr")

# x が確率的に x2 より大きいか
x2 <- rnorm(50, -1)
plot(ecdf(x), xlim = range(c(x, x2)))
plot(ecdf(x2), add = TRUE, lty = "dashed")
t.test(x, x2, alternative = "g")
wilcox.test(x, x2, alternative = "g")
ks.test(x, x2, alternative = "l")
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ks.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ks.test}
%\alias{ks.test}
%\title{Kolmogorov-Smirnov Tests}
%\description{
%  Perform a one- or two-sample Kolmogorov-Smirnov test.
%}
%\usage{
%ks.test(x, y, \dots,
%        alternative = c("two.sided", "less", "greater"),
%        exact = NULL)
%}
%\arguments{
%  \item{x}{a numeric vector of data values.}
%  \item{y}{either a numeric vector of data values, or a character string
%    naming a cumulative distribution function or an actual cumulative
%    distribution function such as \code{pnorm}.  Only continuous CDFs
%    are valid.}
%  \item{\dots}{parameters of the distribution specified (as a character
%    string) by \code{y}.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"} (default), \code{"less"}, or
%    \code{"greater"}.  You can specify just the initial letter of the
%    value, but the argument name must be give in full.
%    See \sQuote{Details} for the meanings of the possible values.}
%  \item{exact}{\code{NULL} or a logical indicating whether an exact
%    p-value should be computed.  See \sQuote{Details} for the meaning of
%    \code{NULL}.  Not available in the two-sample case for a one-sided
%    test or if ties are present.}
%}
%\details{
%  If \code{y} is numeric, a two-sample test of the null hypothesis
%  that \code{x} and \code{y} were drawn from the same \emph{continuous}
%  distribution is performed.
%
%  Alternatively, \code{y} can be a character string naming a continuous
%  (cumulative) distribution function, or such a function.  In this case,
%  a one-sample test is carried out of the null that the distribution
%  function which generated \code{x} is distribution \code{y} with
%  parameters specified by \code{\dots}.
%
%  The presence of ties always generates a warning, since continuous
%  distributions do not generate them.  If the ties arose from rounding
%  the tests may be approximately valid, but even modest amounts of
%  rounding can have a significant effect on the calculated statistic.
%
%  Missing values are silently omitted from \code{x} and (in the
%  two-sample case) \code{y}.
%
%  The possible values \code{"two.sided"}, \code{"less"} and
%  \code{"greater"} of \code{alternative} specify the null hypothesis
%  that the true distribution function of \code{x} is equal to, not less
%  than or not greater than the hypothesized distribution function
%  (one-sample case) or the distribution function of \code{y} (two-sample
%  case), respectively.  This is a comparison of cumulative distribution
%  functions, and the test statistic is the maximum difference in value,
%  with the statistic in the \code{"greater"} alternative being
%  \eqn{D^+ = \max_u [ F_x(u) - F_y(u) ]}{D^+ = max[F_x(u) - F_y(u)]}.
%  Thus in the two-sample case \code{alternative = "greater"} includes
%  distributions for which \code{x} is stochastically \emph{smaller} than
%  \code{y} (the CDF of \code{x} lies above and hence to the left of that
%  for \code{y}), in contrast to \code{\link{t.test}} or
%  \code{\link{wilcox.test}}.
%
%  Exact p-values are not available for the two-sample case if one-sided
%  or in the presence of ties.  If \code{exact = NULL} (the default), an
%  exact p-value is computed if the sample size is less than 100 in the
%  one-sample case \emph{and there are no ties}, and if the product of
%  the sample sizes is less than 10000 in the two-sample case.
%  Otherwise, asymptotic distributions are used whose approximations may
%  be inaccurate in small samples.  In the one-sample two-sided case,
%  exact p-values are obtained as described in Marsaglia, Tsang & Wang
%  (2003) (but not using the optional approximation in the right tail, so
%  this can be slow for small p-values).  The formula of Birnbaum &
%  Tingey (1951) is used for the one-sample one-sided case.
%
%  If a single-sample test is used, the parameters specified in
%  \code{\dots} must be pre-specified and not estimated from the data.
%  There is some more refined distribution theory for the KS test with
%  estimated parameters (see Durbin, 1973), but that is not implemented
%  in \code{ks.test}.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{a character string indicating what type of test was
%    performed.}
%  \item{data.name}{a character string giving the name(s) of the data.}
%}
%\source{
%  The two-sided one-sample distribution comes \emph{via}
%  Marsaglia, Tsang and Wang (2003).
%}
%\references{
%  Z. W. Birnbaum and Fred H. Tingey (1951),
%  One-sided confidence contours for probability distribution functions.
%  \emph{The Annals of Mathematical Statistics}, \bold{22}/4, 592--596.
%
%  William J. Conover (1971),
%  \emph{Practical Nonparametric Statistics}.
%  New York: John Wiley & Sons.
%  Pages 295--301 (one-sample Kolmogorov test),
%  309--314 (two-sample Smirnov test).
%
%  Durbin, J. (1973),
%  \emph{Distribution theory for tests based on the sample distribution
%    function}.  SIAM.
%
%  George Marsaglia, Wai Wan Tsang and Jingbo Wang (2003),
%  Evaluating Kolmogorov's distribution.
%  \emph{Journal of Statistical Software}, \bold{8}/18.
%  \url{http://www.jstatsoft.org/v08/i18/}.
%
%}
%\seealso{
%  \code{\link{shapiro.test}} which performs the Shapiro-Wilk test for
%  normality.
%}
%\examples{
%require(graphics)
%
%x <- rnorm(50)
%y <- runif(30)
%# Do x and y come from the same distribution?
%ks.test(x, y)
%# Does x come from a shifted gamma distribution with shape 3 and rate 2?
%ks.test(x+2, "pgamma", 3, 2) # two-sided, exact
%ks.test(x+2, "pgamma", 3, 2, exact = FALSE)
%ks.test(x+2, "pgamma", 3, 2, alternative = "gr")
%
%# test if x is stochastically larger than x2
%x2 <- rnorm(50, -1)
%plot(ecdf(x), xlim = range(c(x, x2)))
%plot(ecdf(x2), add = TRUE, lty = "dashed")
%t.test(x, x2, alternative = "g")
%wilcox.test(x, x2, alternative = "g")
%ks.test(x, x2, alternative = "l")
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
