% File src/library/stats/man/model.frame.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{model.frame}
\alias{model.frame}%@%\alias{公式や当てはめからモデルフレームを取り出す}
\alias{model.frame.default}
\alias{model.frame.lm}
\alias{model.frame.glm}
\alias{model.frame.aovlist}
\alias{get_all_vars}
\title{Extracting the Model Frame from a Formula or Fit}
\usage{
model.frame(formula, \dots)

\method{model.frame}{default}(formula, data = NULL,
           subset = NULL, na.action = na.fail,
           drop.unused.levels = FALSE, xlev = NULL, \dots)

\method{model.frame}{aovlist}(formula, data = NULL, \dots)

\method{model.frame}{glm}(formula, \dots)

\method{model.frame}{lm}(formula, \dots)

get_all_vars(formula, data, \dots)
}
\arguments{
  \item{formula}{モデル \code{\link{formula}} か \code{\link{terms}}
    オブジェクト，又は \R オブジェクト．}

  \item{data}{\code{formula} 中の変数を含むデータフレーム，リスト，又は
    環境(又はデータフレームに
    \code{\link{as.data.frame}} で変換できるオブジェクト)．
    行列や配列は受け入れられない．}

  \item{subset}{使われる行の指定：既定では全ての行．
    これは \code{data} の行に対する
    任意の適正な添字ベクトル(\code{\link{[.data.frame}} を見よ)で良い．
    又はもしそれが与えられないと \code{formula} 中で使われる
    変数からなるデータフレーム．} 

  \item{na.action}{\code{NA} をどのように扱うか．既定では先ず
    \code{data} の \code{na.action} 属性，次に
    \code{\link{options}} の \code{na.action} 設定，そして
    それが未設定なら三番目には \code{\link{na.fail}}．
    \sQuote{工場出荷時}既定値は
    \code{\link{na.omit}}．もう一つの可能な値は \code{NULL}．}

  \item{drop.unused.levels}{因子から使われない水準を除くか?
    既定は \code{FALSE}．}

  \item{xlev}{各因子に対して仮定される水準の完全なセットを与える名前付き
    文字列リスト．}

  \item{\dots}{
    \code{data}, \code{na.action}, \code{subset} のような追加引数．
    \code{offset} と \code{weights} のとうな既定メソッドに影響する
    追加引数はモデルフレーム中に追加の列を作るのに使われ，
    \code{"(offset)"} のような括弧月の名前を持つ．}
}
\description{
  \code{model.frame} (総称関数)とそのメソッドは
  \code{formula} を使うのに必要な変数と任意の \code{\dots}
  引数を持つデータフレームを返す．
}
\details{
  正確に何が起きるかは
  オブジェクト \code{formula} のクラスと属性に依存する．
  もしこれが
  \code{"lm"} のようなモデル当てはめクラスのオブジェクトならば，
  メソッドはモデルを当てはめた時に保存されたモデルを
  返すか(もしあれば，しばしば引数
  \code{model = TRUE} で選択される)か，
  既定メソッドに関する当てはめで使われた呼び出しを渡す．
  既定メソッド自体は他の引数が何も提供されなければ
  パッケージ \CRANpkg{MASS}のクラス \code{"\link[MASS]{lqs}"}
  のようなかなり標準的なモデルオブジェクトを処理する．

  この節の残りは既定メソッドだけに当てはまる．

  もし \code{formula} か \code{data} が既にモデルフレーム
  (\code{"terms"} 属性を持つデータフレーム)で他が欠損していれば，
  モデルフレームが返される．
  \code{formula} が項オブジェクトでない限り，
  \code{as.formula} そしてそれから \code{terms} がそれに対して呼び出される．
  (もし \code{terms.formula} の
  \code{keep.order} 引数を使いたければ，公式ではなく項オブジェクトを渡す．)

  モデルフレームの行名はもしあれば
  \code{data} 引数から取られ，それから
  公式(又はそれが行列ならば行名)中の応答の名前があればそれから取られる．

  \code{formula}, \code{subset} 中と \code{\dots} 中の全ての変数は
  最初 \code{data} 中で，そして次に
  \code{formula} の環境中で探され
  (より詳しくは \code{\link{formula}()} に対するヘルプを見よ)，
  そしてデータフレーム中に集められる．
  それから \code{subset} 表現式が評価され，それがデータフレームの
  行添字として使われる．
  ついで \code{na.action} 関数がデータフレームに適用される
  (そして属性が加えられるかもしれない)．
  データフレーム中の任意の因子の水準は
  \code{drop.unused.levels} と \code{xlev} 引数に従い補正される：
  もし \code{xlev} が因子を指定し文字列変数が見つかれば，
  それは因子に変換される
  (\R 2.10.0 以来)．

  \code{na.action = NULL} で無い限り，時系列属性は見つかった変数から
  除かれる
  (\code{NA} が除かれると時系列では無くなるため)．

  公式中の\emph{全ての}変数は，たとえそれの先頭に \code{-}
  がついていても，データフレームに含まれる．

  タイプがバイト，論理値，整数，実数，複素数，又は文字列の変数だけが
  モデルフレームに含まれる：
  これは因子のようなクラス付き変数を含む
  (その基礎のタイプは整数)が，リストは除く．

  \code{get_all_vars} は
  \code{formula} 中で使われる変数に加え \code{\dots} で
  指定されたものも含む
  \code{\link{data.frame}} を返す．
  \code{model.frame.default} とは異なり，これは入力変数を返し，
  \code{formula} 中の関数呼び出しの結果であるものは返さない．
}
\value{
  \code{formula} 中で使われた変数と
  \code{\dots} で指定されたものを含むデータフレーム．
  それは \code{formula} から導かれたクラス \code{"\link[=terms.object]{terms}"}
  のオブジェクトに対する
  \code{"terms"} ともしかすると \code{NA} 値の処理に関する
  \code{"na.action"}
  (これは例えば \sspace{}\code{\link{na.pass}} のような
  何も特別な処理がされなければ存在しない)のような
  追加の属性を含む．
}
\seealso{\sQuote{デザイン行列}に対しては \code{\link{model.matrix}}，
  公式に対しては \code{\link{formula}}，そして
  モデルフレームの操作には \code{\link{expand.model.frame}}．
}
\references{
  Chambers, J. M. (1992)
  \emph{Data for models.}
  Chapter 3 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\examples{
data.class(model.frame(dist ~ speed, data = cars))
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/model.frame.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{model.frame}
%\alias{model.frame}
%\alias{model.frame.default}
%\alias{model.frame.lm}
%\alias{model.frame.glm}
%\alias{model.frame.aovlist}
%\alias{get_all_vars}
%\title{Extracting the Model Frame from a Formula or Fit}
%\usage{
%model.frame(formula, \dots)
%
%\method{model.frame}{default}(formula, data = NULL,
%           subset = NULL, na.action = na.fail,
%           drop.unused.levels = FALSE, xlev = NULL, \dots)
%
%\method{model.frame}{aovlist}(formula, data = NULL, \dots)
%
%\method{model.frame}{glm}(formula, \dots)
%
%\method{model.frame}{lm}(formula, \dots)
%
%get_all_vars(formula, data, \dots)
%}
%\arguments{
%  \item{formula}{a model \code{\link{formula}} or \code{\link{terms}}
%    object or an \R object.}
%
%  \item{data}{a data.frame, list or environment (or object
%    coercible by \code{\link{as.data.frame}} to a data.frame),
%    containing the variables in \code{formula}.  Neither a matrix nor an
%    array will be accepted.}
%
%  \item{subset}{a specification of the rows to be used: defaults to all
%    rows. This can be any valid indexing vector (see
%    \code{\link{[.data.frame}}) for the rows of \code{data} or if that is not
%    supplied, a data frame made up of the variables used in \code{formula}.}
%
%  \item{na.action}{how \code{NA}s are treated.  The default is first,
%    any \code{na.action} attribute of \code{data}, second
%    a \code{na.action} setting of \code{\link{options}}, and third
%    \code{\link{na.fail}} if that is unset.  The \sQuote{factory-fresh}
%    default is \code{\link{na.omit}}.  Another possible value is \code{NULL}.}
%
%  \item{drop.unused.levels}{should factors have unused levels dropped?
%    Defaults to \code{FALSE}.}
%
%  \item{xlev}{a named list of character vectors giving the full set of levels
%    to be assumed for each factor.}
%
%  \item{\dots}{further arguments such as \code{data}, \code{na.action},
%    \code{subset}.  Any additional arguments such as \code{offset} and
%    \code{weights} which reach the default method are used to create
%    further columns in the model frame, with parenthesised names such as
%    \code{"(offset)"}.}
%}
%\description{
%  \code{model.frame} (a generic function) and its methods return a
%  \code{\link{data.frame}} with the variables needed to use
%  \code{formula} and any \code{\dots} arguments.
%}
%\details{
%  Exactly what happens depends on the class and attributes of the object
%  \code{formula}.  If this is an object of fitted-model class such as
%  \code{"lm"}, the method will either return the saved model frame
%  used when fitting the model (if any, often selected by argument
%  \code{model = TRUE}) or pass the call used when fitting on to the
%  default method.  The default method itself can cope with rather
%  standard model objects such as those of class
%  \code{"\link[MASS]{lqs}"} from package \CRANpkg{MASS} if no other
%  arguments are supplied.
%
%  The rest of this section applies only to the default method.
%
%  If either \code{formula} or \code{data} is already a model frame (a
%  data frame with a \code{"terms"} attribute) and the other is missing,
%  the model frame is returned.  Unless \code{formula} is a terms object,
%  \code{as.formula} and then \code{terms} is called on it.  (If you wish
%  to use the \code{keep.order} argument of \code{terms.formula}, pass a
%  terms object rather than a formula.)
%
%  Row names for the model frame are taken from the \code{data} argument
%  if present, then from the names of the response in the formula (or
%  rownames if it is a matrix), if there is one.
%
%  All the variables in \code{formula}, \code{subset} and in \code{\dots}
%  are looked for first in \code{data} and then in the environment of
%  \code{formula} (see the help for \code{\link{formula}()} for further
%  details) and collected into a data frame.  Then the \code{subset}
%  expression is evaluated, and it is used as a row index to the data
%  frame.  Then the \code{na.action} function is applied to the data frame
%  (and may well add attributes).  The levels of any factors in the data
%  frame are adjusted according to the \code{drop.unused.levels} and
%  \code{xlev} arguments: if \code{xlev} specifies a factor and a
%  character variable is found, it is converted to a factor (as from \R
%  2.10.0).
%
%  Unless \code{na.action = NULL}, time-series attributes will be removed
%  from the variables found (since they will be wrong if \code{NA}s are
%  removed).
%
%  Note that \emph{all} the variables in the formula are included in the
%  data frame, even those preceded by \code{-}.
%
%  Only variables whose type is raw, logical, integer, real, complex or
%  character can be included in a model frame: this includes classed
%  variables such as factors (whose underlying type is integer), but
%  excludes lists.
%
%  \code{get_all_vars} returns a \code{\link{data.frame}} containing the
%  variables used in \code{formula} plus those specified \code{\dots}.
%  Unlike \code{model.frame.default}, it returns the input variables and
%  not those resulting from function calls in \code{formula}.
%}
%\value{
%  A \code{\link{data.frame}} containing the variables used in
%  \code{formula} plus those specified in \code{\dots}.  It will have
%  additional attributes, including \code{"terms"} for an object of class
%  \code{"\link[=terms.object]{terms}"} derived from \code{formula},
%  and possibly \code{"na.action"} giving information on the handling of
%  \code{NA}s (which will not be present if no special handling was done,
%  e.g.\sspace{}by \code{\link{na.pass}}).
%}
%\seealso{\code{\link{model.matrix}} for the \sQuote{design matrix},
%  \code{\link{formula}} for formulas  and
%  \code{\link{expand.model.frame}} for model.frame manipulation.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Data for models.}
%  Chapter 3 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\examples{
%data.class(model.frame(dist ~ speed, data = cars))
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
