% File src/library/stats/man/model.matrix.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{model.matrix}
\alias{model.matrix}%@%\alias{デザイン行列を作る}
\alias{model.matrix.default}
\alias{model.matrix.lm}
\title{Construct Design Matrices}
\usage{
model.matrix(object, \dots)

\method{model.matrix}{default}(object, data = environment(object),
             contrasts.arg = NULL, xlev = NULL, \dots)
}
\arguments{
  \item{object}{適当なクラスのオブジェクト．
    既定メソッドに対しては
    モデル \link{formula} か \code{\link{terms}} オブジェクト．}
  \item{data}{
    \code{\link{model.frame}} で作られたデータフレーム．
    もし他の類のオブジェクトなら，まず
    \code{model.frame} が呼び出される．}
  \item{contrasts.arg}{
    リストで，その項目が対比置き換え関数に対して
    置き換え値(数値行列か関数の名前の文字列)として使われ，
    その名前が因子を含む
    \code{data} の列の名前になる．}
  \item{xlev}{
    もし \code{data} が \code{model.frame} が呼び出されたものならば，
    \code{\link{model.frame}} の引数として使われる．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\description{
  \code{model.matrix} はデザイン(またはモデル)行列を作る，
  例えば，
  matrix, e.g., by
  因子をダミー変数のセットに(対比に依存して)展開し，交互作用を
  同様に展開する．
}
\details{
  \code{model.matrix} は \code{data} 中のデータを使い
  \code{terms(object)} 中で与えられた記述からデザイン行列を作る．
  \code{data} は
  \code{model.frame(object)} への呼び出しで作られたのと同じ，
  より正確には \code{attr(terms(object), "variables")} の評価による，
  名前の変数を提供しなければならない．
  もし \code{data} がデータフレームならば，他の項があるかもしれず，
  列の順序は重要ではない．
  任意の文字列変数は因子に強制変換される．
  変換の後で，公式の右辺で使われた全ての変数は
  論理値，整数，実数，又は因子でなければならない．

  もし \code{contrasts.arg} が因子に対して提供されると，
  それはその変数に対する既定の因子のコーディングと，
  \code{\link{C}} 又は \code{\link{contrasts}} により
  設定された任意の \code{"contrasts"} 属性を上書きする．

  交互作用項中では，
  その水準が最も速く変化するのは公式中に最初に登場したものであり，
  従って \code{~ a + b + b:a} 中では交互作用は
  \code{a} が最も速く変化する．

  規約から，もし応答変数がやはり公式の右辺に現れればそれは
  (警告と共に)除かれるが，
  その項を含む交互作用は保存される．
}
\value{
  指定された公式とデータを持つ回帰風のモデルに対するデザイン行列．

  属性 \code{"assign"} があり，これは行列中の各列に対する
  項目を持つ整数ベクトルで，列を作った公式中の項を与える．
  値 \code{0} は切片に対応し(もしあれば)，
  正の値は \code{object} に対応する \code{terms} の \code{term.labels}
  属性で与えられた順序での項に対応する．

  もしモデル中の項に何らかの因子があれば，
  各因子に対する項目を持つ名前付きリストである属性 \code{"contrasts"}
  がある．
  これはそのなかで因子が対比によりコード化されている項中で
  使われる対比を，関数の名前を与える文字列としてか数値行列としてか，
  指定する(ある種の項ではダミーのコーディングが使われているかもしれない)．
}
\references{
  Chambers, J. M. (1992)
  \emph{Data for models.}
  Chapter 3 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{model.frame}}, \code{\link{model.extract}},
  \code{\link{terms}}

  \emph{疎}なモデル行列を作るにはパッケージ \CRANpkg{Matrix} 中の
  \code{\link[Matrix]{sparse.model.matrix}}，
  これは大きな次元ではより効率的かもしれない．
}
\examples{
ff <- log(Volume) ~ log(Height) + log(Girth)
utils::str(m <- model.frame(ff, trees))
mat <- model.matrix(ff, m)

dd <- data.frame(a = gl(3,4), b = gl(4,1,12)) # 釣り合い型二元
options("contrasts")
model.matrix(~ a + b, dd)
model.matrix(~ a + b, dd, contrasts = list(a = "contr.sum"))
model.matrix(~ a + b, dd, contrasts = list(a = "contr.sum", b = "contr.poly"))
m.orth <- model.matrix(~a+b, dd, contrasts = list(a = "contr.helmert"))
crossprod(m.orth) # m.orth はほとんど直交
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/model.matrix.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{model.matrix}
%\alias{model.matrix}
%\alias{model.matrix.default}
%\alias{model.matrix.lm}
%\title{Construct Design Matrices}
%\usage{
%model.matrix(object, \dots)
%
%\method{model.matrix}{default}(object, data = environment(object),
%             contrasts.arg = NULL, xlev = NULL, \dots)
%}
%\arguments{
%  \item{object}{an object of an appropriate class.  For the default
%    method, a model \link{formula} or a \code{\link{terms}} object.}
%  \item{data}{a data frame created with \code{\link{model.frame}}.  If
%    another sort of object, \code{model.frame} is called first.}
%  \item{contrasts.arg}{A list, whose entries are values (numeric
%    matrices or character strings naming functions) to be used
%    as replacement values for the \code{\link{contrasts}}
%    replacement function and whose names are the names of
%    columns of \code{data} containing \code{\link{factor}}s.}
%  \item{xlev}{to be used as argument of \code{\link{model.frame}} if
%    \code{data} is such that \code{model.frame} is called.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  \code{model.matrix} creates a design (or model) matrix, e.g., by
%  expanding factors to a set of dummary variables (depending on the
%  contrasts) and expanding interactions similarly.
%}
%\details{
%  \code{model.matrix} creates a design matrix from the description
%  given in \code{terms(object)}, using the data in \code{data} which
%  must supply variables with the same names as would be created by a
%  call to \code{model.frame(object)} or, more precisely, by evaluating
%  \code{attr(terms(object), "variables")}.  If \code{data} is a data
%  frame, there may be other columns and the order of columns is not
%  important.  Any character variables are coerced to factors.  After
%  coercion, all the variables used on the right-hand side of the
%  formula must be logical, integer, numeric or factor.
%
%  If \code{contrasts.arg} is specified for a factor it overrides the
%  default factor coding for that variable and any \code{"contrasts"}
%  attribute set by \code{\link{C}} or \code{\link{contrasts}}.
%
%  In an interaction term, the variable whose levels vary fastest is the
%  first one to appear in the formula (and not in the term), so in
%  \code{~ a + b + b:a} the interaction will have \code{a} varying
%  fastest.
%
%  By convention, if the response variable also appears on the
%  right-hand side of the formula it is dropped (with a warning),
%  although interactions involving the term are retained.
%}
%\value{
%  The design matrix for a regression-like model with the specified formula
%  and data.
%
%  There is an attribute \code{"assign"}, an integer vector with an entry
%  for each column in the matrix giving the term in the formula which
%  gave rise to the column.  Value \code{0} corresponds to the intercept
%  (if any), and positive values to terms in the order given by the
%  \code{term.labels} attribute of the \code{terms} structure
%  corresponding to \code{object}.
%
%  If there are any factors in terms in the model, there is an attribute
%  \code{"contrasts"}, a named list with an entry for each factor.  This
%  specifies the contrasts that would be used in terms in which the
%  factor is coded by contrasts (in some terms dummy coding may be used),
%  either as a character vector naming a function or as a numeric matrix.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Data for models.}
%  Chapter 3 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{model.frame}}, \code{\link{model.extract}},
%  \code{\link{terms}}
%
%  \code{\link[Matrix]{sparse.model.matrix}} from package
%  \CRANpkg{Matrix} for creating \emph{sparse} model matrices, which may
%  be more efficient in large dimensions.
%}
%\examples{
%ff <- log(Volume) ~ log(Height) + log(Girth)
%utils::str(m <- model.frame(ff, trees))
%mat <- model.matrix(ff, m)
%
%dd <- data.frame(a = gl(3,4), b = gl(4,1,12)) # balanced 2-way
%options("contrasts")
%model.matrix(~ a + b, dd)
%model.matrix(~ a + b, dd, contrasts = list(a = "contr.sum"))
%model.matrix(~ a + b, dd, contrasts = list(a = "contr.sum", b = "contr.poly"))
%m.orth <- model.matrix(~a+b, dd, contrasts = list(a = "contr.helmert"))
%crossprod(m.orth) # m.orth is  ALMOST  orthogonal
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
