% File src/library/stats/man/na.action.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{na.action}
\title{NA Action}
\description{
  オブジェクトを作る時の NA 値の扱いに関する情報を取り出す．
}
\usage{
na.action(object, \dots)
}
\alias{na.action}%@%\alias{オブジェクトから NA 値の扱いに関する情報を取り出す}
\alias{na.action.default}
\arguments{
  \item{object}{その NA 値の処理が与えられている任意のオブジェクト．}
  \item{\dots}{特別のメソッドが要求するかもしれない追加引数．}
}
\details{
  \code{na.action} は総称的な関数であり，
  その既定メソッドは \code{na.action.default} である．
  後者はもし存在すれば
  \code{"na.action"} 成分．さもなければ \code{"na.action"} 属性
  を取り出す．

  \code{\link{model.frame}} が呼び出された時，それは
  \code{"na.action"} 属性中の
  \code{NA} 値の処理に関する任意の情報を記録する．
  殆どのモデル当てはめ関数はこれを
  それらの結果の成分として返す．
}
\value{
  もし \code{NA} が特別に処理されていれば \code{object} に適用された
  処理からの情報，もしくは \code{NULL}．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S.}
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{options}("na.action")}, \code{\link{na.omit}},
  \code{\link{na.fail}}，又は \code{na.exclude}, \code{na.pass}．
}
\examples{
na.action(na.omit(c(1, NA)))
}
\keyword{NA}
\keyword{methods}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/na.action.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{na.action}
%\title{NA Action}
%\description{
%  Extract information on the NA action used to create an object.
%}
%\usage{
%na.action(object, \dots)
%}
%\alias{na.action}
%\alias{na.action.default}
%\arguments{
%  \item{object}{any object whose \code{\link{NA}} action is given.}
%  \item{\dots}{further arguments special methods could require.}
%}
%\details{
%  \code{na.action} is a generic function, and \code{na.action.default} its
%  default method.  The latter extracts the \code{"na.action"} component
%  of a list if present, otherwise the \code{"na.action"} attribute.
%
%  When \code{\link{model.frame}} is called, it records any information
%  on \code{NA} handling in a \code{"na.action"} attribute.  Most
%  model-fitting functions return this as a component of their result.
%}
%\value{
%  Information from the action which was applied to \code{object} if
%  \code{NA}s were handled specially, or \code{NULL}.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S.}
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{options}("na.action")}, \code{\link{na.omit}},
%  \code{\link{na.fail}}, also for \code{na.exclude}, \code{na.pass}.
%}
%\examples{
%na.action(na.omit(c(1, NA)))
%}
%\keyword{NA}
%\keyword{methods}
%
%\encoding{UTF-8}
%
