% File src/library/stats/man/pp.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{PP.test}
\alias{PP.test}%@%\alias{単位根に対する Phillips-Perron 検定}
\title{Phillips-Perron Test for Unit Roots}
\usage{
PP.test(x, lshort = TRUE)
}
\arguments{
  \item{x}{数値ベクトル又は一変量時系列．}
  \item{lshort}{
    打ち切りラグパラメータの短い又は長い
    バージョンを使うかどうかを指示する論理値．}
}
\description{
  \code{x} が定常対立仮説に対して単位根を持つという
  帰無仮説に対する Phillips-Perron 検定を実行する．
}
\details{
  定数項と線形トレンドを組み込んだ一般的な回帰式が使われ，
  一次の自己回帰係数が1であるという修正 t 統計量が計算される．
  \code{sigma^2} を推定するために Newey-West 推定量が使われる．
  もし \code{lshort} が \code{TRUE} ならば，打ち切りラグパラメータは
  \code{trunc(4*(n/100)^0.25)} に設定され，さもなければ
  \code{trunc(12*(n/100)^0.25)} が使われる．
  p 値は
  Banerjee \emph{et al} (1993), page 103 の 表 4.2 から
  補間される．

  欠損値は扱えない．
}
\value{
  クラス \code{"htest"} のりストで次の成分を持つ：
  \item{statistic}{検定統計量の値．}
  \item{parameter}{打ち切りラグパラメータ．}
  \item{p.value}{検定の p 値．}
  \item{method}{どのような検定が実行されたかを指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  A. Banerjee, J. J. Dolado, J. W. Galbraith, and D. F. Hendry (1993)
  \emph{Cointegration, Error Correction, and the Econometric Analysis
    of Non-Stationary Data}, Oxford University Press, Oxford.

  P. Perron (1988) Trends and random walks in macroeconomic time
  series. \emph{Journal of Economic Dynamics and Control} \bold{12},
  297--332.
}
\author{A. Trapletti}
\examples{
x <- rnorm(1000)
PP.test(x)
y <- cumsum(x) # 単位根を持つ
PP.test(y)
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/pp.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{PP.test}
%\alias{PP.test}
%\title{Phillips-Perron Test for Unit Roots}
%\usage{
%PP.test(x, lshort = TRUE)
%}
%\arguments{
%  \item{x}{a numeric vector or univariate time series.}
%  \item{lshort}{a logical indicating whether the short or long version
%    of the truncation lag parameter is used.}
%}
%\description{
%  Computes the Phillips-Perron test for the null hypothesis that
%  \code{x} has a unit root against a stationary alternative.
%}
%\details{
%  The general regression equation which incorporates a constant and a
%  linear trend is used and the corrected t-statistic for a first order
%  autoregressive coefficient equals one is computed.  To estimate
%  \code{sigma^2} the Newey-West estimator is used.  If \code{lshort}
%  is \code{TRUE}, then the truncation lag parameter is set to
%  \code{trunc(4*(n/100)^0.25)}, otherwise
%  \code{trunc(12*(n/100)^0.25)} is used.  The p-values are
%  interpolated from Table 4.2, page 103 of Banerjee \emph{et al}
%  (1993).
%
%  Missing values are not handled.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic.}
%  \item{parameter}{the truncation lag parameter.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{a character string indicating what type of test was
%    performed.}
%  \item{data.name}{a character string giving the name of the data.}
%}
%\references{
%  A. Banerjee, J. J. Dolado, J. W. Galbraith, and D. F. Hendry (1993)
%  \emph{Cointegration, Error Correction, and the Econometric Analysis
%    of Non-Stationary Data}, Oxford University Press, Oxford.
%
%  P. Perron (1988) Trends and random walks in macroeconomic time
%  series. \emph{Journal of Economic Dynamics and Control} \bold{12},
%  297--332.
%}
%\author{A. Trapletti}
%\examples{
%x <- rnorm(1000)
%PP.test(x)
%y <- cumsum(x) # has unit root
%PP.test(y)
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
