% File src/library/stats/man/predict.HoltWinters.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{predict.HoltWinters}
\alias{predict.HoltWinters}%@%\alias{Holt-Winters モデルに対する予測関数}
\title{Prediction Function for Fitted Holt-Winters Models}
\description{
  Holt-Winters 法で当てはめられたモデルに対する予測値と予測区間を計算する．
}
\usage{
\method{predict}{HoltWinters}(object, n.ahead = 1, prediction.interval = FALSE,
       level = 0.95, ...)
}
\arguments{
  \item{object}{
    クラス \code{HoltWinters} のオブジェクト．}
  \item{n.ahead}{予測する将来期間数．}
  \item{prediction.interval}{論理値．もし \code{TRUE} なら，
   対応する予測区間の上限と下限を計算する．}
  \item{level}{予測区間に対する信頼水準．}
  \item{\dots}{他のメソッドに・から渡される引数．}
}
\value{
  予測内の時系列．もし予測区間が要求されると，
  列 \code{fit}, \code{lwr} そして予測値に対する \code{upr} とそれぞれ上限と下限
  を持つ多変量時系列が返される．
}
\references{
  C. C. Holt (1957)
  Forecasting trends and seasonals by exponentially weighted
  moving averages,
  \emph{ONR Research Memorandum, Carnegie Institute of Technology} \bold{52}.

  P. R. Winters (1960)
  Forecasting sales by exponentially weighted moving averages,
  \emph{Management Science} \bold{6}, 324--342.
}
\author{
  David Meyer \email{David.Meyer@wu.ac.at}
}
\seealso{\code{\link{HoltWinters}}}

\examples{
require(graphics)

m <- HoltWinters(co2)
p <- predict(m, 50, prediction.interval = TRUE)
plot(m, p)
}
\keyword{ts}



\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/predict.HoltWinters.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict.HoltWinters}
%\alias{predict.HoltWinters}
%\title{Prediction Function for Fitted Holt-Winters Models}
%\description{
%  Computes predictions and prediction intervals for models fitted by
%  the Holt-Winters method.
%}
%\usage{
%\method{predict}{HoltWinters}(object, n.ahead = 1, prediction.interval = FALSE,
%       level = 0.95, ...)
%}
%\arguments{
%  \item{object}{An object of class \code{HoltWinters}.}
%  \item{n.ahead}{Number of future periods to predict.}
%  \item{prediction.interval}{logical. If \code{TRUE}, the lower and
%    upper bounds of the corresponding prediction intervals are computed.}
%  \item{level}{Confidence level for the prediction interval.}
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\value{
%  A time series of the predicted values. If prediction intervals are
%  requested, a multiple time series is returned with columns \code{fit},
%  \code{lwr} and \code{upr} for the predicted values and the lower and
%  upper bounds respectively.
%}
%\references{
%  C. C. Holt (1957)
%  Forecasting trends and seasonals by exponentially weighted
%  moving averages,
%  \emph{ONR Research Memorandum, Carnegie Institute of Technology} \bold{52}.
%
%  P. R. Winters (1960)
%  Forecasting sales by exponentially weighted moving averages,
%  \emph{Management Science} \bold{6}, 324--342.
%}
%\author{
%  David Meyer \email{David.Meyer@wu.ac.at}
%}
%\seealso{\code{\link{HoltWinters}}}
%
%\examples{
%require(graphics)
%
%m <- HoltWinters(co2)
%p <- predict(m, 50, prediction.interval = TRUE)
%plot(m, p)
%}
%\keyword{ts}
%
%
%
%\encoding{UTF-8}
%
