% File src/library/stats/man/predict.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{predict}
\title{Model Predictions}
\usage{
predict (object, \dots)
}
\alias{predict}%@%\alias{kモデル予測}
\arguments{
  \item{object}{予測したいモデルオブジェクト．}
  \item{\dots}{生成される予測に影響する追加引数．}
}
\description{
  \code{predict} は様々なモデル当てはめ関数の結果から予測をする総称的関数である．
  関数は最初の引数のクラスに依存して特定の\emph{メソッド}を呼び出す．
}
\details{
  線形モデルに対するそれらに類似した殆どの予測メソッドは
  予測に用いられる説明変数を最初に探す場所を指定する \code{newdata} を持つ．
  \code{newdata} 中の列を予測に用いられるそれらに適合させるのに
  かなりの努力がなされる．例えば，
  それらが比較可能なタイプを持ち，任意の因子が同じ順序の
  同じ水準集合(もしくはそうなるように変換可能)であるようにする．

  パッケージ \pkg{stats} 中の時系列予測メソッドは
  どれだけ先の時刻を予測するかを指示する引数 \code{n.ahead} を持つ．

  多くのメソッドは標準誤差を返すべきかどうかを指示する論理値引数
  \code{se.fit} を持つ．
}
 \value{
  \code{predict} で返される値の形式はそれの引数のクラスに依存する．
  そのメソッドで何が作られるかについての詳細は特定のメソッドの
  ドキュメントを見よ．
}
\seealso{
  \code{\link{predict.glm}},
  \code{\link{predict.lm}},
  \code{\link{predict.loess}},
  \code{\link{predict.nls}},
  \code{\link{predict.poly}},
  \code{\link{predict.princomp}},
  \code{\link{predict.smooth.spline}}.

  (一変量)多項式とスプライン当てはめからの予測は \link{SafePrediction}．

  時系列の予測には，
  \code{\link{predict.ar}},
  \code{\link{predict.Arima}},
  \code{\link{predict.arima0}},
  \code{\link{predict.HoltWinters}},
  \code{\link{predict.StructTS}}.
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.
}
\examples{
\testonly{old <- Sys.setlocale("LC_COLLATE", "C")}
require(utils)

## 全ての見つかった "predict" メソッド
## 注意：標準パッケージ中の殆どのメソッドは隠されている．
for(fn in methods("predict"))
   try({
       f <- eval(substitute(getAnywhere(fn)$objs[[1]], list(fn = fn)))
       cat(fn, ":\n\t", deparse(args(f)), "\n")
       }, silent = TRUE)
\testonly{old <- Sys.setlocale("LC_COLLATE", old)}
}
\keyword{methods}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/predict.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict}
%\title{Model Predictions}
%\usage{
%predict (object, \dots)
%}
%\alias{predict}
%\arguments{
%  \item{object}{a model object for which prediction is desired.}
%  \item{\dots}{additional arguments affecting the predictions produced.}
%}
%\description{
%  \code{predict} is a generic function for predictions from the results of
%  various model fitting functions.  The function invokes particular
%  \emph{methods} which depend on the \code{\link{class}} of
%  the first argument.
%}
%\details{
%  Most prediction methods which are similar to those for linear models
%  have an argument \code{newdata} specifying the first place to look for
%  explanatory variables to be used for prediction.  Some considerable
%  attempts are made to match up the columns in \code{newdata} to those
%  used for fitting, for example that they are of comparable types and
%  that any factors have the same level set in the same order (or can be
%  transformed to be so).
%
%  Time series prediction methods in package \pkg{stats} have an argument
%  \code{n.ahead} specifying how many time steps ahead to predict.
%
%  Many methods have a logical argument \code{se.fit} saying if standard
%  errors are to returned.
%}
% \value{
%  The form of the value returned by \code{predict} depends on the
%  class of its argument.  See the documentation of the
%  particular methods for details of what is produced by that method.
%}
%\seealso{
%  \code{\link{predict.glm}},
%  \code{\link{predict.lm}},
%  \code{\link{predict.loess}},
%  \code{\link{predict.nls}},
%  \code{\link{predict.poly}},
%  \code{\link{predict.princomp}},
%  \code{\link{predict.smooth.spline}}.
%
%  \link{SafePrediction} for prediction from (univariable) polynomial and
%  spline fits.
%
%  For time-series prediction,
%  \code{\link{predict.ar}},
%  \code{\link{predict.Arima}},
%  \code{\link{predict.arima0}},
%  \code{\link{predict.HoltWinters}},
%  \code{\link{predict.StructTS}}.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%\testonly{old <- Sys.setlocale("LC_COLLATE", "C")}
%require(utils)
%
%## All the "predict" methods found
%## NB most of the methods in the standard packages are hidden.
%for(fn in methods("predict"))
%   try({
%       f <- eval(substitute(getAnywhere(fn)$objs[[1]], list(fn = fn)))
%       cat(fn, ":\n\t", deparse(args(f)), "\n")
%       }, silent = TRUE)
%\testonly{old <- Sys.setlocale("LC_COLLATE", old)}
%}
%\keyword{methods}
%
%\encoding{UTF-8}
%
