% File src/library/stats/man/predict.lm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{predict.lm}
\title{Predict method for Linear Model Fits}
\alias{predict.lm}%@%\alias{線形モデル当てはめからの予測メソッド}
%\alias{predict.mlm}
\concept{regression}
\description{
  線形モデルに基づく予測値．
}
\usage{
\method{predict}{lm}(object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
        interval = c("none", "confidence", "prediction"),
        level = 0.95, type = c("response", "terms"),
        terms = NULL, na.action = na.pass,
        pred.var = res.var/weights, weights = 1, \dots)
}
\arguments{
  \item{object}{
    \code{"lm"} を継承するクラスのオブジェクト．}
  \item{newdata}{
    それで予測を行う変数をその中で探すオプションのデータフレーム．}
  \item{se.fit}{標準誤差が必要かどうかを指示するスイッチ．}
  \item{scale}{標準誤差の計算のためのスケールパラメータ．}
  \item{df}{スケールに対する自由度．}
  \item{interval}{区間計算のタイプ．短縮化出来る．}
  \item{level}{許容/信頼水準．}
  \item{type}{予測のタイプ(応答又はモデル項)．短縮化出来る．}
  \item{terms}{もし \code{type = "terms"} ならばどの
    項か(既定では全ての項)，文字列ベクトル．}
  \item{na.action}{
    \code{newdata} 中の欠損値をどうするかを決める関数．
    既定は \code{NA} を予測する．}
  \item{pred.var}{
    予測区間に対して仮定される将来の観測値に対する分散．
    \sQuote{詳細}節を見よ．}
  \item{weights}{予測に対する分散重み．
    これは数値ベクトルか片側モデル公式で良い．
    後者の場合それは
    \code{newdata} 中で評価される表現式と解釈される．}
  \item{\dots}{他のメソッドに・から渡される追加の引数．}
}
\details{
  \code{predict.lm} は
  回帰関数をフレーム
  \code{newdata} (既定では \code{model.frame(object)} 中で
  評価して得られる予測値を作る．
  もし論理値 \code{se.fit} が \code{TRUE} なら，
  予測の標準誤差が計算される．
  もし数値引数 \code{scale} が(オプションの \code{df} と共に)設定されると，
  それは標準誤差の計算中で残差標準偏差として使われる．
  さもなければこれはモデル当てはめから取り出される．
  設定 \code{intervals} は信頼もしくは予測(許容)区間を指定された
  \code{level} で計算することを指定する，
  これは時折狭い区間対広い区間と参照される，

  もし当てはめがランク落ちならば，デザイン行列の幾つかの列が
  取り除かれるかもしれない．
  そうした当てはめからの予測は
  もし \code{newdata} がオリジナルのデータと同じ部分空間に含まれる時だけ
  意味を持つ．
  これは正確にチェック出来ないので，警告が出される．

  もし \code{newdata} が省略されると，予測は当てはめに用いたデータに基づく．
  その場合欠損値を持つケースがどのように処理されるかは
  その当てはめの \code{na.action} 引数で決定される．
  もし \code{na.action = na.omit} なら，省略されたケースは
  予測値に現れず，他方でもし
  \code{na.action = na.exclude} ならばそれらは \code{NA} 値として
  (予測値，標準偏差，又は区間限界中に)現れる．
  \code{\link{napredict}} も見よ．

  予測区間は
  \code{newdata} 中の各ケースにおける単一の観測値用
  (又は既定では，当てはめに対して使われたデータ)であり
  誤差分散 \code{pred.var} を持つ．
  これは \eqn{\sigma^2} の推定値 \code{res.var} の倍数であって良い：
  既定では将来の観測値は当てはめに使われたのと同じ誤差分散を持つとされる．
  もし \code{weights} が提供されると，これの逆数がスケール因子として使われる．
  重み付き当てはめに対しては，もし予測がオリジナルのデータフレームに
  対するものであれば，\code{weights} の既定値はモデル当てはめに用いられた
  重みで，これは意図したものではないかもしれないので警告が出る．
  もし当てはめが重み付きで \code{newdata} が与えられると，
  既定では警告と共に定数の予測分散を仮定する．
}
\value{
  \code{predict.lm} は予測値のベクトル，又は
  \code{interval} が設定されていれば列名
  \code{fit}, \code{lwr} そして \code{upr} を持つ予測値と
  限界の行列を作る．
  \code{type = "terms"} に対してはこれは項毎に列を持つ行列で
  属性 \code{"constant"} を持つかもしれない．

  もし \code{se.fit} が \code{TRUE} なら，次の成分を持つリストが
  返される：
  \item{fit}{上と同じようなベクトル化行列．}
  \item{se.fit}{予測平均の標準誤差．}
  \item{residual.scale}{残差標準偏差．}
  \item{df}{残差に対する自由度．}
}
\note{
  変数は最初
  \code{newdata} で探され，それから通常の方法で探される
  (当てはめに使われた公式の環境を含む)．見つかった変数が
  もし提供され \code{newdata} 中のそれらと長さが異なれば
  警告が出る．

  予測分散と予測区間は常に
  \emph{将来}の観測値を参照することを注意する．
  可能性として当てはめに使われたのと同じ予測値に対応するかもしれない．
  \emph{残差}分散はより小さくなる．

  厳密に言えば，予測限界に対して使われる公式は
  当てはめに対する自由度が残差分散に対するそれらと同じことを
  仮定する．これは
  \code{res.var} が当てはめから得られていない時は成り立たないかもしれない．
}
\seealso{
  モデル当てはめ関数 \code{\link{lm}}, \code{\link{predict}}．

  (一変量)多項式とスプライン当てはめからの予測に対しては \link{SafePrediction}．
}
\examples{
require(graphics)

## 予測
x <- rnorm(15)
y <- x + rnorm(15)
predict(lm(y ~ x))
new <- data.frame(x = seq(-3, 3, 0.5))
predict(lm(y ~ x), new, se.fit = TRUE)
pred.w.plim <- predict(lm(y ~ x), new, interval = "prediction")
pred.w.clim <- predict(lm(y ~ x), new, interval = "confidence")
matplot(new$x, cbind(pred.w.clim, pred.w.plim[,-1]),
        lty = c(1,2,2,3,3), type = "l", ylab = "predicted y")

## 予測区間，特殊例
## 最初の三つは警告を与える
w <- 1 + x^2
fit <- lm(y ~ x)
wfit <- lm(y ~ x, weights = w)
predict(fit, interval = "prediction")
predict(wfit, interval = "prediction")
predict(wfit, new, interval = "prediction")
predict(wfit, new, interval = "prediction", weights = (new$x)^2)
predict(wfit, new, interval = "prediction", weights = ~x^2)

##-- aov(.) の例から ---- predict(.. terms)
npk.aov <- aov(yield ~ block + N*P*K, npk)
(termL <- attr(terms(npk.aov), "term.labels"))
(pt <- predict(npk.aov, type = "terms"))
pt. <- predict(npk.aov, type = "terms", terms = termL[1:4])
stopifnot(all.equal(pt[,1:4], pt.,
                    tolerance = 1e-12, check.attributes = FALSE))
}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/predict.lm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict.lm}
%\title{Predict method for Linear Model Fits}
%\alias{predict.lm}
%%\alias{predict.mlm}
%\concept{regression}
%\description{
%  Predicted values based on linear model object.
%}
%\usage{
%\method{predict}{lm}(object, newdata, se.fit = FALSE, scale = NULL, df = Inf,
%        interval = c("none", "confidence", "prediction"),
%        level = 0.95, type = c("response", "terms"),
%        terms = NULL, na.action = na.pass,
%        pred.var = res.var/weights, weights = 1, \dots)
%}
%\arguments{
%  \item{object}{Object of class inheriting from \code{"lm"}}
%  \item{newdata}{An optional data frame in which to look for variables with
%    which to predict.  If omitted, the fitted values are used.}
%  \item{se.fit}{A switch indicating if standard errors are required.}
%  \item{scale}{Scale parameter for std.err. calculation.}
%  \item{df}{Degrees of freedom for scale.}
%  \item{interval}{Type of interval calculation.  Can be abbreviated.}
%  \item{level}{Tolerance/confidence level.}
%  \item{type}{Type of prediction (response or model term).  Can be abbreviated.}
%  \item{terms}{If \code{type = "terms"}, which terms (default is all
%    terms), a \code{\link{character}} vector.}
%  \item{na.action}{function determining what should be done with missing
%    values in \code{newdata}.  The default is to predict \code{NA}.}
%  \item{pred.var}{the variance(s) for future observations to be assumed
%    for prediction intervals.  See \sQuote{Details}.}
%  \item{weights}{variance weights for prediction.  This can be a numeric
%    vector or a one-sided model formula.  In the latter case, it is
%    interpreted as an expression evaluated in \code{newdata}.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\details{
%  \code{predict.lm} produces predicted values, obtained by evaluating
%  the regression function in the frame \code{newdata} (which defaults to
%  \code{model.frame(object)}.  If the logical \code{se.fit} is
%  \code{TRUE}, standard errors of the predictions are calculated.  If
%  the numeric argument \code{scale} is set (with optional \code{df}), it
%  is used as the residual standard deviation in the computation of the
%  standard errors, otherwise this is extracted from the model fit.
%  Setting \code{intervals} specifies computation of confidence or
%  prediction (tolerance) intervals at the specified \code{level}, sometimes
%  referred to as narrow vs. wide intervals.
%
%  If the fit is rank-deficient, some of the columns of the design matrix
%  will have been dropped.  Prediction from such a fit only makes sense
%  if \code{newdata} is contained in the same subspace as the original
%  data.  That cannot be checked accurately, so a warning is issued.
%
%  If \code{newdata} is omitted the predictions are based on the data
%  used for the fit.  In that case how cases with missing values in the
%  original fit are handled is determined by the \code{na.action} argument of that
%  fit.  If \code{na.action = na.omit} omitted cases will not appear in
%  the predictions, whereas if \code{na.action = na.exclude} they will
%  appear (in predictions, standard errors or interval limits),
%  with value \code{NA}.  See also \code{\link{napredict}}.
%
%  The prediction intervals are for a single observation at each case in
%  \code{newdata} (or by default, the data used for the fit) with error
%  variance(s) \code{pred.var}.  This can be a multiple of \code{res.var},
%  the estimated value of \eqn{\sigma^2}: the default is to assume that
%  future observations have the same error variance as those
%  used for fitting.  If \code{weights} is supplied, the inverse of this
%  is used as a scale factor.  For a weighted fit, if the prediction
%  is for the original data frame, \code{weights} defaults to the weights
%  used for the  model fit, with a warning since it might not be the
%  intended result.  If the fit was weighted and \code{newdata} is given, the
%  default is to assume constant prediction variance, with a warning.
%}
%\value{
%  \code{predict.lm} produces a vector of predictions or a matrix of
%  predictions and bounds with column names \code{fit}, \code{lwr}, and
%  \code{upr} if \code{interval} is set.  For \code{type = "terms"} this
%  is a matrix with a column per term and may have an attribute
%  \code{"constant"}.
%
%  If \code{se.fit} is
%  \code{TRUE}, a list with the following components is returned:
%  \item{fit}{vector or matrix as above}
%  \item{se.fit}{standard error of predicted means}
%  \item{residual.scale}{residual standard deviations}
%  \item{df}{degrees of freedom for residual}
%}
%\note{
%  Variables are first looked for in \code{newdata} and then searched for
%  in the usual way (which will include the environment of the formula
%  used in the fit).  A warning will be given if the
%  variables found are not of the same length as those in \code{newdata}
%  if it was supplied.
%
%  Notice that prediction variances and prediction intervals always refer
%  to \emph{future} observations, possibly corresponding to the same
%  predictors as used for the fit.  The variance of the \emph{residuals}
%  will be smaller.
%
%  Strictly speaking, the formula used for prediction limits assumes that
%  the degrees of freedom for the fit are the same as those for the
%  residual variance.  This may not be the case if \code{res.var} is
%  not obtained from the fit.
%}
%\seealso{
%  The model fitting function \code{\link{lm}}, \code{\link{predict}}.
%
%  \link{SafePrediction} for prediction from (univariable) polynomial and
%  spline fits.
%}
%\examples{
%require(graphics)
%
%## Predictions
%x <- rnorm(15)
%y <- x + rnorm(15)
%predict(lm(y ~ x))
%new <- data.frame(x = seq(-3, 3, 0.5))
%predict(lm(y ~ x), new, se.fit = TRUE)
%pred.w.plim <- predict(lm(y ~ x), new, interval = "prediction")
%pred.w.clim <- predict(lm(y ~ x), new, interval = "confidence")
%matplot(new$x, cbind(pred.w.clim, pred.w.plim[,-1]),
%        lty = c(1,2,2,3,3), type = "l", ylab = "predicted y")
%
%## Prediction intervals, special cases
%##  The first three of these throw warnings
%w <- 1 + x^2
%fit <- lm(y ~ x)
%wfit <- lm(y ~ x, weights = w)
%predict(fit, interval = "prediction")
%predict(wfit, interval = "prediction")
%predict(wfit, new, interval = "prediction")
%predict(wfit, new, interval = "prediction", weights = (new$x)^2)
%predict(wfit, new, interval = "prediction", weights = ~x^2)
%
%##-- From  aov(.) example ---- predict(.. terms)
%npk.aov <- aov(yield ~ block + N*P*K, npk)
%(termL <- attr(terms(npk.aov), "term.labels"))
%(pt <- predict(npk.aov, type = "terms"))
%pt. <- predict(npk.aov, type = "terms", terms = termL[1:4])
%stopifnot(all.equal(pt[,1:4], pt.,
%                    tolerance = 1e-12, check.attributes = FALSE))
%}
%\keyword{regression}
%
%\encoding{UTF-8}
%
