% File src/library/stats/man/proj.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{proj}
\title{Projections of Models}
\usage{
proj(object, \dots)

\method{proj}{aov}(object, onedf = FALSE, unweighted.scale = FALSE, \dots)

\method{proj}{aovlist}(object, onedf = FALSE, unweighted.scale = FALSE, \dots)

\method{proj}{default}(object, onedf = TRUE, \dots)

\method{proj}{lm}(object, onedf = FALSE, unweighted.scale = FALSE, \dots)
}
\alias{proj}
\alias{proj.default}
\alias{proj.lm}
\alias{proj.aov}
\alias{proj.aovlist}
\arguments{
 \item{object}{
   クラス \code{"lm"} かそれを継承するクラスのオブジェクト，
   又は
   特に成分 \code{qr} と \code{effects} を含む類似の構造を持つオブジェクト．}
 \item{onedf}{論理フラグ．
   もし \code{TRUE} なら，モデル行列の全ての列に対する射影が返される．
   もし \code{FALSE} なら，単一項の射影はモデルの
   項により縮約される
   (分散分析表中の表現のように)．}
 \item{unweighted.scale}{
   もし \code{object} を作った当てはめが重みを使っていれば，
   weights,
   これは射影は重み付き観測値か重み無しの観測値に対応するかを決める．}
 \item{\dots}{任意の他の引数を飲み込み無視する．}
}
\description{
 \code{proj} はデータの線形モデル上への射影を与える行列か行列のリストを
 返す．これは最も頻繁に \code{\link{aov}} モデルで使われる．}
\details{
 射影はオブジェクトの各層に対して与えられるので，
 \code{Error} 項を持つ \code{aov} モデルに対しては
 結果は射影のリストである．
}
\value{
  射影行列又は
  (多層のオブジェクトに対しては)射影行列のリスト．

  各射影は各観測値に対する行と
  各項に対する列(\code{onedf = FALSE})か
  各係数に対する列(\code{onedf = TRUE})を持つ行列である．
  既定メソッドからの射影行列は QR 分解からの Q 行列の列空間上への
  射影を表現する直交列を持つ．
  当てはめ値は射影の和であり，
  各列に対する二乗和はその列の当てはめ(その左にあるものの後)
  からの二乗和の減少分である．

  \code{lm} と \code{aov} モデルに対するメソッドは
  射影行列に残差を与える列を加える
  (モデル区間の直交補空間上へのデータの射影)．

  厳密に言うと，\code{onedf = FALSE} の時は結果は射影ではなく，
  列はその項に対応するモデル行列の列への射影の和を表す．
  この場合行列は使われたコーディングに依存しない．
}
\references{
  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
  \emph{Analysis of variance; designed experiments.}
  Chapter 5 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\author{
  デザインは
  Chambers \emph{et al} (1992) で解説されている同名の S 関数に啓発されている．
}
\seealso{\code{\link{aov}}, \code{\link{lm}}, \code{\link{model.tables}}
}
\examples{
N <- c(0,1,0,1,1,1,0,0,0,1,1,0,1,1,0,0,1,0,1,0,1,1,0,0)
P <- c(1,1,0,0,0,1,0,1,1,1,0,0,0,1,0,1,1,0,0,1,0,1,1,0)
K <- c(1,0,0,1,0,1,1,0,0,1,0,1,0,1,1,0,0,0,1,1,1,0,1,0)
yield <- c(49.5,62.8,46.8,57.0,59.8,58.5,55.5,56.0,62.8,55.8,69.5,
55.0, 62.0,48.8,45.5,44.2,52.0,51.5,49.8,48.8,57.2,59.0,53.2,56.0)

npk <- data.frame(block = gl(6,4), N = factor(N), P = factor(P),
                  K = factor(K), yield = yield)
npk.aov <- aov(yield ~ block + N*P*K, npk)
proj(npk.aov)

## テストとして，特に意味はない
options(contrasts = c("contr.helmert", "contr.treatment"))
npk.aovE <- aov(yield ~  N*P*K + Error(block), npk)
proj(npk.aovE)
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/proj.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{proj}
%\title{Projections of Models}
%\usage{
%proj(object, \dots)
%
%\method{proj}{aov}(object, onedf = FALSE, unweighted.scale = FALSE, \dots)
%
%\method{proj}{aovlist}(object, onedf = FALSE, unweighted.scale = FALSE, \dots)
%
%\method{proj}{default}(object, onedf = TRUE, \dots)
%
%\method{proj}{lm}(object, onedf = FALSE, unweighted.scale = FALSE, \dots)
%}
%\alias{proj}
%\alias{proj.default}
%\alias{proj.lm}
%\alias{proj.aov}
%\alias{proj.aovlist}
%\arguments{
% \item{object}{An object of class \code{"lm"} or a class inheriting from
%   it, or an object with a similar structure including in particular
%   components \code{qr} and \code{effects}.}
% \item{onedf}{A logical flag. If \code{TRUE}, a projection is returned for all
%   the columns of the model matrix. If \code{FALSE}, the single-column
%   projections are collapsed by terms of the model (as represented in
%   the analysis of variance table).}
% \item{unweighted.scale}{If the fit producing \code{object} used
%   weights, this determines if the projections correspond to weighted or
%   unweighted observations.}
% \item{\dots}{Swallow and ignore any other arguments.}
%}
%\description{
% \code{proj} returns a matrix or list of matrices giving the projections
% of the data onto the terms of a linear model.  It is most frequently
% used for \code{\link{aov}} models.
%}
%\details{
% A projection is given for each stratum of the object, so for \code{aov}
% models with an \code{Error} term the result is a list of projections.
%}
%\value{
%  A projection matrix or (for multi-stratum objects) a list of
%  projection matrices.
%
%  Each projection is a matrix with a row for each observations and
%  either a column for each term (\code{onedf = FALSE}) or for each
%  coefficient (\code{onedf = TRUE}). Projection matrices from the
%  default method have orthogonal columns representing the projection of
%  the response onto the column space of the Q matrix from the QR
%  decomposition.  The fitted values are the sum of the projections, and
%  the sum of squares for each column is the reduction in sum of squares
%  from fitting that column (after those to the left of it).
%
%  The methods for \code{lm} and \code{aov} models add a column to the
%  projection matrix giving the residuals (the projection of the data
%  onto the orthogonal complement of the model space).
%
%  Strictly, when \code{onedf = FALSE} the result is not a projection,
%  but the columns represent sums of projections onto the columns of the
%  model matrix corresponding to that term. In this case the matrix does
%  not depend on the coding used.
%}
%\references{
%  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
%  \emph{Analysis of variance; designed experiments.}
%  Chapter 5 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\author{
%  The design was inspired by the S function of the same name described
%  in Chambers \emph{et al} (1992).
%}
%\seealso{\code{\link{aov}}, \code{\link{lm}}, \code{\link{model.tables}}
%}
%\examples{
%N <- c(0,1,0,1,1,1,0,0,0,1,1,0,1,1,0,0,1,0,1,0,1,1,0,0)
%P <- c(1,1,0,0,0,1,0,1,1,1,0,0,0,1,0,1,1,0,0,1,0,1,1,0)
%K <- c(1,0,0,1,0,1,1,0,0,1,0,1,0,1,1,0,0,0,1,1,1,0,1,0)
%yield <- c(49.5,62.8,46.8,57.0,59.8,58.5,55.5,56.0,62.8,55.8,69.5,
%55.0, 62.0,48.8,45.5,44.2,52.0,51.5,49.8,48.8,57.2,59.0,53.2,56.0)
%
%npk <- data.frame(block = gl(6,4), N = factor(N), P = factor(P),
%                  K = factor(K), yield = yield)
%npk.aov <- aov(yield ~ block + N*P*K, npk)
%proj(npk.aov)
%
%## as a test, not particularly sensible
%options(contrasts = c("contr.helmert", "contr.treatment"))
%npk.aovE <- aov(yield ~  N*P*K + Error(block), npk)
%proj(npk.aovE)
%}
%\keyword{models}
%
%\encoding{UTF-8}
%