% File src/library/stats/man/read.ftable.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Copyright 2002-2013 The R Foundation
% Distributed under GPL 2 or later

\name{read.ftable}
\title{Manipulate Flat Contingency Tables}
\alias{read.ftable}%@%\alias{フラットな分割表の読み書き}
\alias{write.ftable}
\alias{format.ftable}
\alias{print.ftable}
\description{\sQuote{フラット}な分割表の読み書きと強制変換．}
\usage{
read.ftable(file, sep = "", quote = "\"",
            row.var.names, col.vars, skip = 0)

write.ftable(x, file = "", quote = TRUE, append = FALSE,
             digits = getOption("digits"), \dots)

\method{format}{ftable}(x, quote = TRUE, digits = getOption("digits"),
                        method = c("non.compact", "row.compact",
                                  "col.compact", "compact"),
                        lsep = " | ", \dots)
\method{print}{ftable}(x, digits = getOption("digits"), \dots)
}
\arguments{
  \item{file}{
    データと読み込んだり書き出したりするファイルの名前である文字列かコネクション．
    \code{""} はコンソールからの入力とコンソールへの書き出しを指示する．}
  \item{sep}{欄分離文字列．ファイルの各行上の値は
    この文字列で分離される．}
  \item{quote}{
    \code{read.ftable} に対する引用符のセットを与える文字列；
    引用化を全て禁止するには
    \code{quote=""} を使う．
    \code{write.table} に対してはデータ中の文字列を二重引用符で
    囲むかどうかを指示する論理値．}
  \item{row.var.names}{
    行変数の名前の文字列ベクトルで，それらが自動的に決定できない時のため．}
  \item{col.vars}{
    列変数の名前とレベルを当てるリスト，それらが自動的に決定できない時のため．}
  \item{skip}{
    データの読み込みの前にスキップされるべきデータファイルの行数．}
  \item{x}{
    クラス \code{"ftable"} のオブジェクト．}
  \item{append}{論理値．もし \code{TRUE} で \code{file} が
    ファイル名であれば(そしてコネクションや \code{"|cmd"} でなければ)，
    \code{write.ftable} からの出力はファイルに追記される．
    もし \code{FALSE} ならば，
    \code{file} の中身は上書きされる．}
  \item{digits}{
    \code{x} (のセル要素)に使われる有効桁数を与える整数．}
  \item{method}{
    \code{"ftable"} オブジェクトをどのように整形
    (そしてもし
    \code{write.ftable()} や \code{print} メソッド中に於けるように
    使われた時プリントするか)するかを指示する文字列．
    短縮化出来る．利用できるメソッドは
    (例を見よ)：
    \describe{
      \item{"non.compact"}{
        \code{"ftable"} オブジェクトの既定の表現．}
      \item{"row.compact"}{
        列ラベルの下に空の項目がない行コンパクトなバージョン．}
      \item{"col.compact"}{
        行ラベルの右に空の項目がない列コンパクトなバージョン．}
      \item{"compact"}{
        行と列に関してコンパクトなバージョン．
        これは行と列のラベルが同じセルを共有することを意味するかもしれない．
        それらはそれから
	文字列 \code{lsep} で分離される．}
    }
  }
  \item{lsep}{\code{method = "compact"} の時だけ，
    行と列のラベルの分離文字列．}
  \item{\dots}{メソッドに・から渡される追加引数；
    \code{write()} と \code{print()} 用で，特に
    \code{method} のような引数で，\code{format()} に渡される．}
}
\details{
  \code{read.ftable} はフラット風の分割表をファイルから読み取る．
  もしファイルがフラットな表の表現の書き込みを含めば
  (より正確には，列変数の名前とレベルに関する全ての情報を持つヘッダに
  行変数名を持つ行が続く),
  それ以上の引数は不要である．
  同様に，最初の行の唯一の項目がその名前であるただ一つの列変数
  フラットな表は自動的に処理される．
  他の変種は
  \code{skip} を使い全てのヘッダ情報をスキップし，
  \code{row.var.names} と \code{col.vars} をそれぞれ使い
  行変数の名前と列変数の名前とレベルを提供することで扱われる．
  下の例を見よ．

  フラットな表はそれらの
  行(そして恐らく列も)のの\sQuote{ラグ}表現で特徴づけられることを注意しよう．
  もし行変数のレベルの完全なグリッドが与えられると，
  データの読み込みに代わりに
  \code{\link{read.table}} を使うべきであり，
  それから \code{\link{xtabs}} を使って分割表を作る．

  \code{write.ftable} はフラットな表をファイルに書き込み，
  それは分割表の
  \sQuote{見栄えの良い}アスキー表現を作るのに有用である．
  異なったバージョンが \code{method} 引数を使って得られ，
  それは例えば LaTeX の表を作るのに有用である．
}
\seealso{
  フラットな分割表に関するより多くの情報は \code{\link{ftable}}．
}
\references{
  Agresti, A. (1990)
  \emph{Categorical data analysis}.
  New York: Wiley.
}
\examples{
## Agresti (1990), page 157, Table 5.8.
## 標準的な ftable 書式ではないが問題ない．
file <- tempfile()
cat("             Intercourse\n",
    "Race  Gender     Yes  No\n",
    "White Male        43 134\n",
    "      Female      26 149\n",
    "Black Male        29  23\n",
    "      Female      22  36\n",
    file = file)
\donttest{file.show(file)}
ft1 <- read.ftable(file)
ft1
unlink(file)

## Agresti (1990), page 297, 表 8.16．
## ほとんど問題ないが，行変数の名前を間違える．
file <- tempfile()
cat("                      \"Tonsil Size\"\n",
    "            \"Not Enl.\" \"Enl.\" \"Greatly Enl.\"\n",
    "Noncarriers       497     560           269\n",
    "Carriers           19      29            24\n",
    file = file)
\donttest{file.show(file)}
ft <- read.ftable(file, skip = 2,
                  row.var.names = "Status",
                  col.vars = list("Tonsil Size" =
                      c("Not Enl.", "Enl.", "Greatly Enl.")))
ft
unlink(file)

ft22 <- ftable(Titanic, row.vars = 2:1, col.vars = 4:3)
write.ftable(ft22, quote = FALSE)
write.ftable(ft22, quote = FALSE, method="row.compact")
write.ftable(ft22, quote = FALSE, method="col.compact")
write.ftable(ft22, quote = FALSE, method="compact")
\dontshow{
 op <- options(warn = 2) # 警告は許されない
 stopifnot(dim(format(ft)) == 4:5,
	   dim(format(ftable(UCBAdmissions))) == c(6,9))
 meths <- c("non.compact", "row.compact", "col.compact", "compact")
 dimform <-
    function(ft) sapply(meths, function(M) dim(format(ft, method = M)))
 m.eq    <- function(M,m) all.equal(unname(M), m, tolerance = 0)
 ## 警告付き/無しの全てのformat(..)：
 stopifnot(m.eq(print(dimform(ft22)),
		rbind(11:10, rep(7:6, each = 2))),
	   m.eq(print(dimform(ftable(Titanic, row.vars = integer()))),
		rbind(rep(6:5,2), 33)))
 options(op)
}
}
\keyword{category}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/read.ftable.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Copyright 2002-2013 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{read.ftable}
%\title{Manipulate Flat Contingency Tables}
%\alias{read.ftable}
%\alias{write.ftable}
%\alias{format.ftable}
%\alias{print.ftable}
%\description{Read, write and coerce \sQuote{flat} contingency tables.}
%\usage{
%read.ftable(file, sep = "", quote = "\"",
%            row.var.names, col.vars, skip = 0)
%
%write.ftable(x, file = "", quote = TRUE, append = FALSE,
%             digits = getOption("digits"), \dots)
%
%\method{format}{ftable}(x, quote = TRUE, digits = getOption("digits"),
%                        method = c("non.compact", "row.compact",
%                                  "col.compact", "compact"),
%                        lsep = " | ", \dots)
%\method{print}{ftable}(x, digits = getOption("digits"), \dots)
%}
%\arguments{
%  \item{file}{either a character string naming a file or a connection
%    which the data are to be read from or written to.  \code{""}
%    indicates input from the console for reading and output to the
%    console for writing.}
%  \item{sep}{the field separator string.  Values on each line of the file
%    are separated by this string.}
%  \item{quote}{a character string giving the set of quoting characters
%    for \code{read.ftable}; to disable quoting altogether, use
%    \code{quote=""}.  For \code{write.table}, a logical indicating
%    whether strings in the data will be surrounded by double quotes.}
%  \item{row.var.names}{a character vector with the names of the row
%    variables, in case these cannot be determined automatically.}
%  \item{col.vars}{a list giving the names and levels of the column
%    variables, in case these cannot be determined automatically.}
%  \item{skip}{the number of lines of the data file to skip before
%    beginning to read data.}
%  \item{x}{an object of class \code{"ftable"}.}
%  \item{append}{logical.  If \code{TRUE} and \code{file} is the name of
%    a file (and not a connection or \code{"|cmd"}), the output from
%    \code{write.ftable} is appended to the file.  If \code{FALSE},
%    the contents of \code{file} will be overwritten.}
%  \item{digits}{an integer giving the number of significant digits to
%    use for (the cell entries of) \code{x}.}
%  \item{method}{string specifying how the \code{"ftable"} object is formatted
%    (and printed if used as in \code{write.ftable()} or the \code{print}
%    method).  Can be abbreviated.  Available methods are (see the examples):
%    \describe{
%      \item{"non.compact"}{the default representation of an
%        \code{"ftable"} object.}
%      \item{"row.compact"}{a row-compact version without empty cells
%        below the column labels.}
%      \item{"col.compact"}{a column-compact version without empty cells
%        to the right of the row labels.}
%      \item{"compact"}{a row- and column-compact version.  This may imply
%        a row and a column label sharing the same cell.  They are then
%        separated by the string \code{lsep}.}
%    }
%  }
%  \item{lsep}{only for \code{method = "compact"}, the separation string
%    for row and column labels.}
%  \item{\dots}{further arguments to be passed to or
%    from methods; for \code{write()} and \code{print()}, notably
%    arguments such as \code{method}, passed to \code{format()}.}
%}
%\details{
%  \code{read.ftable} reads in a flat-like contingency table from a
%  file.  If the file contains the written representation of a flat
%  table (more precisely, a header with all information on names and
%  levels of column variables, followed by a line with the names of the
%  row variables), no further arguments are needed.  Similarly, flat
%  tables with only one column variable the name of which is the only
%  entry in the first line are handled automatically.  Other variants can
%  be dealt with by skipping all header information using \code{skip},
%  and providing the names of the row variables and the names and levels
%  of the column variable using \code{row.var.names} and \code{col.vars},
%  respectively.  See the examples below.
%
%  Note that flat tables are characterized by their \sQuote{ragged}
%  display of row (and maybe also column) labels.  If the full grid of
%  levels of the row variables is given, one should instead use
%  \code{\link{read.table}} to read in the data, and create the
%  contingency table from this using \code{\link{xtabs}}.
%
%  \code{write.ftable} writes a flat table to a file, which is useful for
%  generating \sQuote{pretty} ASCII representations of contingency
%  tables.  Different versions are available via the \code{method}
%  argument, which may be useful, for example, for constructing LaTeX tables.
%}
%\seealso{
%  \code{\link{ftable}} for more information on flat contingency tables.
%}
%\references{
%  Agresti, A. (1990)
%  \emph{Categorical data analysis}.
%  New York: Wiley.
%}
%\examples{
%## Agresti (1990), page 157, Table 5.8.
%## Not in ftable standard format, but o.k.
%file <- tempfile()
%cat("             Intercourse\n",
%    "Race  Gender     Yes  No\n",
%    "White Male        43 134\n",
%    "      Female      26 149\n",
%    "Black Male        29  23\n",
%    "      Female      22  36\n",
%    file = file)
%\donttest{file.show(file)}
%ft1 <- read.ftable(file)
%ft1
%unlink(file)
%
%## Agresti (1990), page 297, Table 8.16.
%## Almost o.k., but misses the name of the row variable.
%file <- tempfile()
%cat("                      \"Tonsil Size\"\n",
%    "            \"Not Enl.\" \"Enl.\" \"Greatly Enl.\"\n",
%    "Noncarriers       497     560           269\n",
%    "Carriers           19      29            24\n",
%    file = file)
%\donttest{file.show(file)}
%ft <- read.ftable(file, skip = 2,
%                  row.var.names = "Status",
%                  col.vars = list("Tonsil Size" =
%                      c("Not Enl.", "Enl.", "Greatly Enl.")))
%ft
%unlink(file)
%
%ft22 <- ftable(Titanic, row.vars = 2:1, col.vars = 4:3)
%write.ftable(ft22, quote = FALSE)
%write.ftable(ft22, quote = FALSE, method="row.compact")
%write.ftable(ft22, quote = FALSE, method="col.compact")
%write.ftable(ft22, quote = FALSE, method="compact")
%\dontshow{
% op <- options(warn = 2) # no warnings allowed
% stopifnot(dim(format(ft)) == 4:5,
%	   dim(format(ftable(UCBAdmissions))) == c(6,9))
% meths <- c("non.compact", "row.compact", "col.compact", "compact")
% dimform <-
%    function(ft) sapply(meths, function(M) dim(format(ft, method = M)))
% m.eq    <- function(M,m) all.equal(unname(M), m, tolerance = 0)
% ## All format(..) w/o warnings:
% stopifnot(m.eq(print(dimform(ft22)),
%		rbind(11:10, rep(7:6, each = 2))),
%	   m.eq(print(dimform(ftable(Titanic, row.vars = integer()))),
%		rbind(rep(6:5,2), 33)))
% options(op)
%}
%}
%\keyword{category}
%
%\encoding{UTF-8}
%
