% File src/library/stats/man/tsp.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{tsp}
\title{Tsp Attribute of Time-Series-like Objects}
\alias{tsp}%@%\alias{時系列風オブジェクトの tsp 属性}
\alias{tsp<-}
\alias{hasTsp}
\usage{
tsp(x)
tsp(x) <- value
hasTsp(x)
}
\arguments{
  \item{x}{ベクトル，行列又は一変量か多変量の時系列．}
  \item{value}{長さ3 の数値ベクトルか \code{NULL}．}
}
\description{
  \code{tsp} は \code{tsp} 属性(又は \code{NULL})を返す．
  これは S のバージョン 2 との互換性のためにある．
  \code{tsp<-} は \code{tsp} 属性を設定する．
  \code{hasTsp} は \code{x} が \code{tsp} 属性を持つことを
  確実にし，必要ならそれを付け加える．
}
\details{
  \code{tsp} 属性は\emph{単位時間での}開始時間，終了時間，そして 
  周波数(単位時間あたりの観測数，例えば月別系列なら 12)を与える．

  付値は一貫性をチェックされる．

  \code{NULL} を付値すると \code{x} の
  \code{tsp} 属性と\emph{と}任意の \code{"ts"} (又は \code{"mts"}) クラス
  を取り除く．
}
\value{
  (\code{NULL} が付値されたのでなければ)
  \code{x} と \code{tsp} 属性だけが異なるオブジェクト．

  \code{hasTsp} は必要なら開始時間と周波数 1 そして終了時間
  \code{\link{NROW}(x)} を持つ属性を加える．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{ts}}, \code{\link{time}}, \code{\link{start}}.
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/tsp.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{tsp}
%\title{Tsp Attribute of Time-Series-like Objects}
%\alias{tsp}
%\alias{tsp<-}
%\alias{hasTsp}
%\usage{
%tsp(x)
%tsp(x) <- value
%hasTsp(x)
%}
%\arguments{
%  \item{x}{a vector or matrix or univariate or multivariate time-series.}
%  \item{value}{a numeric vector of length 3 or \code{NULL}.}
%}
%\description{
%  \code{tsp} returns the \code{tsp} attribute (or \code{NULL}).
%  It is included for compatibility with S version 2. \code{tsp<-}
%  sets the \code{tsp} attribute. \code{hasTsp} ensures \code{x} has a
%  \code{tsp} attribute, by adding one if needed.
%}
%\details{
%  The \code{tsp} attribute gives the start time \emph{in time units},
%  the end time and the frequency (the number of observations per unit of
%  time, e.g.\sspace{}12 for a monthly series).
%
%  Assignments are checked for consistency.
%
%  Assigning \code{NULL} which removes the \code{tsp} attribute
%  \emph{and} any \code{"ts"} (or \code{"mts"}) class of \code{x}.
%}
%\value{
%  An object which differs from \code{x} only in the \code{tsp} attribute
%  (unless \code{NULL} is assigned).
%
%  \code{hasTsp} adds, if needed, an attribute with a start time and
%  frequency of 1 and end time \code{\link{NROW}(x)}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{ts}}, \code{\link{time}}, \code{\link{start}}.
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
