% File src/library/tcltk/man/TclInterface.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{TclInterface}
\title{低水準の Tcl/Tk インタフェイス}
%\title{Low-level Tcl/Tk Interface}
%
%@%\alias{低水準の Tcl/Tk インタフェイス}
\alias{TclInterface}
\alias{.Tcl}
\alias{.Tcl.objv}
\alias{.Tcl.callback}
\alias{.Tcl.args}
\alias{.Tcl.args.objv}
\alias{tclvar}
\alias{tclVar}
\alias{as.character.tclVar}
\alias{tclArray}
\alias{[[.tclArray}
\alias{[[<-.tclArray}
\alias{$.tclArray}
\alias{$<-.tclArray}
\alias{names.tclArray}
\alias{length.tclArray}
\alias{names<-.tclArray}
\alias{length<-.tclArray}
\alias{tclvalue}
\alias{tclvalue<-}
\alias{tclvalue.default}
\alias{tclvalue<-.default}
\alias{tclvalue.tclVar}
\alias{tclvalue<-.tclVar}
\alias{tclvalue.tclObj}
\alias{as.character.tclObj}
\alias{as.integer.tclObj}
\alias{as.double.tclObj}
\alias{as.logical.tclObj}
\alias{as.raw.tclObj}
\alias{as.tclObj}
\alias{is.tclObj}
\alias{tclObj}
\alias{print.tclObj}
\alias{tclObj<-}
\alias{tclObj.tclVar}
\alias{tclObj<-.tclVar}
\alias{.Tk.ID}
\alias{.Tk.newwin}
\alias{.Tk.subwin}
\alias{is.tkwin}
\alias{tkdestroy}
\alias{.TkRoot}
\alias{addTclPath}
\alias{tclRequire}
\alias{tclVersion}
\description{
  これらの関数と変数は
  \R と Tcl インタプリタと Tk GUI ツールキットの間の基本的な連携機能を提供する．
  Tk ウィンドウは \R オブジェクトにより表現可能である．
  Tcl 変数は クラス \code{tclVar} のオブジェクトによりアクセス可能で，
  Tcl への C レベルのインタフェイスは
  クラス \code{tclObj} のオブジェクト経由でアクセスできる．
}
\usage{
.Tcl(...)
.Tcl.objv(objv)
.Tcl.args(...)
.Tcl.args.objv(...)
.Tcl.callback(...)
.Tk.ID(win)
.Tk.newwin(ID)
.Tk.subwin(parent)
.TkRoot

tkdestroy(win)
is.tkwin(x)

tclvalue(x)
tclvalue(x) <- value

tclVar(init = "")
\method{as.character}{tclVar}(x, ...)
\method{tclvalue}{tclVar}(x)
\method{tclvalue}{tclVar}(x) <- value

tclArray()
\method{[[}{tclArray}(x, ...)
\method{[[}{tclArray}(x, ...) <- value
\method{$}{tclArray}(x, i)
\method{$}{tclArray}(x, i) <- value

\method{names}{tclArray}(x)
\method{length}{tclArray}(x)

tclObj(x)
tclObj(x) <- value
\method{tclObj}{tclVar}(x)
\method{tclObj}{tclVar}(x) <- value

as.tclObj(x, drop = FALSE)
is.tclObj(x)

\method{as.character}{tclObj}(x, ...)
\method{as.integer}{tclObj}(x, ...)
\method{as.double}{tclObj}(x, ...)
\method{as.logical}{tclObj}(x, ...)
\method{as.raw}{tclObj}(x, ...)
\method{tclvalue}{tclObj}(x)

\method{tclvalue}{default}(x)
\method{tclvalue}{default}(x) <- value


addTclPath(path = ".")
tclRequire(package, warn = TRUE)
tclVersion()
}
\arguments{
  \item{objv}{
    Tcl オブジェクトの名前付きベクトル}
  \item{win}{ウィンドウ構造}
  \item{x}{オブジェクト}
  \item{i}{文字列または(引用符なしの)名前}
  \item{drop}{ 論理値．単一要素のベクトルが
    単一の Tcl オブジェクトにされるべきか，または長さ1のりストにすべきかを指示する}
  \item{value}{\code{tclvalue} 付値に対しては文字列．
    \code{tclObj} 付値に対しては
    クラス \code{tclObj} のオブジェクト}
  \item{ID}{ウィンドウの ID}
  \item{parent}{結果のウィンドウの親になるウィンドウ}
  \item{path}{Tcl パッケージを含むディレクトリへのパス}
  \item{package}{Tcl パッケージ名}
  \item{warn}{論理値．もし見つからなければ警告するか?}
  \item{...}{追加引数．下を見よ．}
  \item{init}{初期化値}
}
\details{
  これらの関数の多くは一般的な使用は意図されておらず，
  Tk ウィジェットと Tcl オブジェクトを作り操作する命令により
  内部的に使われる．最も低いレベルでは \code{.Tcl} は命令を文字列として
  Tcl インタプリタに送り結果をクラス
  \code{tclObj} のオブジェクトとして返す(下を見よ)．
  より新しい変種の \code{.Tcl.objv} は
  \code{tclObj} の名前付きリストの型式での引数を受け付ける．

  \code{.Tcl.args} は \code{tag = value} 対の R の引数リストを
  Tcl の \code{-option value} スタイルに変換するので，
  二つの言語間の単純な翻訳を可能にする．
  先立つオプションフラグの無い値を
  送るには，単にタグ付きでない引数を使う．
  先立つ値のないオプションが必要な稀なケースでは
  \code{tag = NULL} を使うことが出来る．
  殆どの値は単に文字列モードに変換され命令文字列に挿入されるが，
  ウィンドウオブジェクトはそれらの ID 文字列を使い渡され，
  コールバックは \code{.Tcl.callback} の結果を使い渡される．タグは単純に
  \code{-} を先頭につけてオプションフラグに変換される．

  \code{.Tcl.args.objv} は
  \code{.Tcl.args} と同じような役割を果たすが，
  \code{.Tcl.objv} に渡すのに適当な
  \code{tclObj} オブジェクトのりストを生成する．
  リストの名前は内部的に
  \code{.Tcl.objv} を使い Tcl オプションに変換される．

  コールバックは
  \code{.Tcl.callback} により処理される\emph{原子的なコールバック}または
  表現式が可能である．
  表現式は原子的なコールバックのリストとして扱われるが以下の
  例外がある：
  もし要素が名前ならそれは最初呼び出し側のフレームで評価され，
  そしてもしそれが明示的な関数定義の時も同様である；
  \code{break} 表現式は直接 Tcl の対応物に翻訳される．
  \code{.Tcl.callback} は \R 関数と未評価の呼び出しを
  Tcl の命令文字列に変換する．
  引数は関数クロージャか
  環境が続くモード \code{"call"} のオブジェクトでなければならない．
  最初のケースでの返り値は
  \code{R_call 0x408b94d4} の型式で16進数は関数のメモリアドレスである．
  二番目のケースではそれは
  \code{R_call_lang 0x8a95904 0x819bfd0} の形式になる．
  表現式に対しては似たような項目の系列が生成され，
  セミコロンで分離される．
  \code{.Tcl.args} は関数や呼び出しが指定されたアドレスに
  存在し続けているかどうかを
  コールバックを関連するウィンドウ環境に代入することで
  確認する特別な用心を行う(下を見よ)．

  Tk ウィンドウはクラス \code{tkwin} のオブジェクトとして表現され，
  これは \code{ID} 欄と
  大局的環境中で囲まれる \R の環境である \code{env} 欄を含む
  リストである．\code{ID} 欄の値は Tk ウィンドウの名前と同じである．
  \code{env} 環境は \code{parent} 変数と \code{num.subwin} 変数を含む．
  もしウィンドウが副ウィンドウとコールバックを受け取ると，
  それらは変数として環境に付け加えられる．\code{.TkRoot} は
  ID "." を持つトップウィンドウである；このウィンドウは
  それをウィンドウマネージャの制御で閉じるまずい効果を避けるため
  表示されない．\code{parent} 変数は
  \code{.TkRoot} に対しては定義されていない．

  \code{.Tk.ID} はウィンドウの \code{ID} を取り出し，
  \code{.Tk.newwin} は与えられた ID の新しいウィンドウ環境を作り，
  そして
  \code{.Tk.subwin} は与えられた親ウィンドウの副ウィンドウである
  新しいウィンドウを作る．

  \code{tkdestroy} はウィンドウを破壊し，そしてまた
  その親からウィンドウへの参照を除く．

  \code{is.tkwin} は与えられたオブジェクトがウィンドウ環境かどうかを
  テストするのに使うことが出来る．

  \code{tclVar} は新しい Tcl 変数を作りそれを
  \code{init} に初期化する．
  クラス \code{tclVar} の R オブジェクトがそれを表現するために
  作られる．オブジェクトに対して \code{as.character} を使うと
  Tcl 変数名を返す．R から Tcl 変数へのアクセスは
  \code{tclvalue} 関数を使ってなされ，
  これはまた付値の左辺側でも起きる．
  もし \code{tclvalue} が \code{tclVar} オブジェクトで無い引数に渡されると，
  それは Tcl 変数を明示的に命名する文字列であると仮定される．
  \code{tclVar} で作られた Tcl 変数はユニークに命名され
  表現するオブジェクトが最早使用されないと自動的に
  ガベージコレクションで未設定にされる．

  \code{tclArray} は新しい Tcl 配列を作りそれを空の配列に
  初期化する．クラス \code{tclArray} で
  クラス \code{tclVar} を継承する R オブジェクトがそれを
  表現するために使われる．Tcl 配列の要素には
  \code{[[} や \code{$} を使った添字操作でアクセスすることが出来，
  これは又置き換え形式も許す．
  Tcl 配列は原理的に結合的であり従って順序が付かないことを
  注意しよう；数値添字 \code{i} は
  \emph{名前} \code{as.character(i)} の要素を参照する．
  多重添字はコンマで分離された単一の名前に繋げられる．
  配列の長さと配列中の名前のセットはそれぞれ
  \code{length} と \code{names} を用いて問い合わせすることが出来る；
  これらは意味があるようには設定出来ず，
  従って付値形式はエラーメッセージをプリントするためだけに存在する．

  Tcl の\sQuote{dual-ported}オブジェクトに直接アクセスすることが可能で，
  それによりそれらの文字列表現を構文解析したり逆構文解析することを
  避けることが出来る．
  これはクラス
  \code{tclObj} のオブジェクトを使ってなされる．
  そうしたオブジェクトの文字列表現は
  \code{tclvalue} を使い取り出すことが出来(しかし設定できない)，
  そして モード \code{"character"},
  \code{"double"}, \code{"integer"}, \code{"logical"} そして
  \code{"raw"} のベクトルへの変換は \code{as.character} のような
  標準の強制変換を使い実行できる．
  逆にそうしたベクトルは \code{as.tclObj} を使い変換できる．
  長さ1のベクトルに対して何が起こるかについては曖昧さがあり，
  \code{drop} 引数で制御される；
  相違が Tcl に対して意味を持つケースがあるが，
  殆どの場合それはそれらを同等に扱う．
  \code{tclvalue} と \code{as.character} はその文字列表現が埋め込みの
  スペースを持つオブジェクトに関して相違がある．
  前者は時おり好まれ，特に
  \code{tclread}, \code{tkgetOpenFile} そして同様の関数の結果に適用される
  時が該当する．
  \code{as.raw} メソッドはバイト型ベクトルかバイト型ベクトルのりスト
  を返し，Tcl からバイナリデータを返すのに使うことが出来る．

  \code{tclVar} オブジェクトの背後にあるオブジェクトは
  \code{tclObj(x)} を使い取り出され，これは又付値型式を許し
  付値の右辺値は自動的に \code{as.tclObj} を使い強制変換される．
  \code{tclObj} オブジェクトに対するプリントメソッドがある；
  これは後にオブジェクトの文字列表現が続く
  \code{<Tcl>} をプリントする．
  \code{tclVar} オブジェクトに対する \code{as.character} は
  対応する Tcl の\emph{名前}を返しその値ではない．

  Tcl パッケージは \code{tclRequire} でロードできる；
  \code{addTclPath} でそれらが見つかるディレクトリを Tcl の
  検索パスに加えることが必要かもしれない．
  返り値はもしそれが成功すればクラス
  \code{"tclObj"} のオブジェクトで，失敗すれば
  \code{FALSE} である(警告が発せられる場合)．
  現在の検索パスを \R の文字列ベクトルとして見るためには次を使う
\preformatted{strsplit(tclvalue('auto_path'), " ")[[1]]}

  Tcl バージョン(パッチレベルを含む)は文字列
  (\code{"8.6.3"} のような)で返される．
}
\note{
  釣り合わない括弧を含む文字列は現在多くの状況で上手く処理されない．
}
\seealso{
  \code{\link{TkWidgets}},
  \code{\link{TkCommands}},
  \code{\link{TkWidgetcmds}}.

  Tcl/Tk のサポートがこの \R のビルトにコンパイルされているか
  どうかを見るには\cr
  \code{\link{capabilities}("tcltk")}．
}
\examples{
tclVersion()

\dontrun{
## これらは example() で実行できないがtcltk パッケージをロードした
## 対話的な R セッション中にペーストすれば実行できる
.Tcl("format \"\%s\\n\" \"Hello, World!\"")
f <- function()cat("HI!\n")
.Tcl.callback(f)
.Tcl.args(text = "Push!", command = f) # NB: 異なったアドレス

xyzzy <- tclVar(7913)
tclvalue(xyzzy)
tclvalue(xyzzy) <- "foo"
as.character(xyzzy)
tcl("set", as.character(xyzzy))

top <- tktoplevel() # Tk ウィジェット，Tk-widgets を見よ
ls(envir = top$env, all = TRUE)
ls(envir = .TkRoot$env, all = TRUE) # .Tcl.args はここで callback ref を置く
}
}
\keyword{ misc }


\encoding{UTF8}

%% File src/library/tcltk/man/TclInterface.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{TclInterface}
%\title{Low-level Tcl/Tk Interface}
%%
%\alias{TclInterface}
%\alias{.Tcl}
%\alias{.Tcl.objv}
%\alias{.Tcl.callback}
%\alias{.Tcl.args}
%\alias{.Tcl.args.objv}
%\alias{tclvar}
%\alias{tclVar}
%\alias{as.character.tclVar}
%\alias{tclArray}
%\alias{[[.tclArray}
%\alias{[[<-.tclArray}
%\alias{$.tclArray}
%\alias{$<-.tclArray}
%\alias{names.tclArray}
%\alias{length.tclArray}
%\alias{names<-.tclArray}
%\alias{length<-.tclArray}
%\alias{tclvalue}
%\alias{tclvalue<-}
%\alias{tclvalue.default}
%\alias{tclvalue<-.default}
%\alias{tclvalue.tclVar}
%\alias{tclvalue<-.tclVar}
%\alias{tclvalue.tclObj}
%\alias{as.character.tclObj}
%\alias{as.integer.tclObj}
%\alias{as.double.tclObj}
%\alias{as.logical.tclObj}
%\alias{as.raw.tclObj}
%\alias{as.tclObj}
%\alias{is.tclObj}
%\alias{tclObj}
%\alias{print.tclObj}
%\alias{tclObj<-}
%\alias{tclObj.tclVar}
%\alias{tclObj<-.tclVar}
%\alias{.Tk.ID}
%\alias{.Tk.newwin}
%\alias{.Tk.subwin}
%\alias{is.tkwin}
%\alias{tkdestroy}
%\alias{.TkRoot}
%\alias{addTclPath}
%\alias{tclRequire}
%\alias{tclVersion}
%\description{
%  These functions and variables provide the basic glue between \R and the
%  Tcl interpreter and Tk GUI toolkit. Tk
%  windows may be represented via \R objects. Tcl variables can be accessed
%  via objects of class \code{tclVar} and the C level interface to Tcl
%  objects is accessed via objects of class \code{tclObj}.
%}
%\usage{
%.Tcl(...)
%.Tcl.objv(objv)
%.Tcl.args(...)
%.Tcl.args.objv(...)
%.Tcl.callback(...)
%.Tk.ID(win)
%.Tk.newwin(ID)
%.Tk.subwin(parent)
%.TkRoot
%
%tkdestroy(win)
%is.tkwin(x)
%
%tclvalue(x)
%tclvalue(x) <- value
%
%tclVar(init = "")
%\method{as.character}{tclVar}(x, ...)
%\method{tclvalue}{tclVar}(x)
%\method{tclvalue}{tclVar}(x) <- value
%
%tclArray()
%\method{[[}{tclArray}(x, ...)
%\method{[[}{tclArray}(x, ...) <- value
%\method{$}{tclArray}(x, i)
%\method{$}{tclArray}(x, i) <- value
%
%\method{names}{tclArray}(x)
%\method{length}{tclArray}(x)
%
%tclObj(x)
%tclObj(x) <- value
%\method{tclObj}{tclVar}(x)
%\method{tclObj}{tclVar}(x) <- value
%
%as.tclObj(x, drop = FALSE)
%is.tclObj(x)
%
%\method{as.character}{tclObj}(x, ...)
%\method{as.integer}{tclObj}(x, ...)
%\method{as.double}{tclObj}(x, ...)
%\method{as.logical}{tclObj}(x, ...)
%\method{as.raw}{tclObj}(x, ...)
%\method{tclvalue}{tclObj}(x)
%
%\method{tclvalue}{default}(x)
%\method{tclvalue}{default}(x) <- value
%
%
%addTclPath(path = ".")
%tclRequire(package, warn = TRUE)
%tclVersion()
%}
%\arguments{
%  \item{objv}{a named vector of Tcl objects}
%  \item{win}{a window structure}
%  \item{x}{an object}
%  \item{i}{character or (unquoted) name}
%  \item{drop}{logical. Indicates whether a single-element vector should
%    be made into a simple Tcl object or a list of length one}
%  \item{value}{For \code{tclvalue} assignments, a character string. For
%    \code{tclObj} assignments, an object of class \code{tclObj}}
%  \item{ID}{a window ID}
%  \item{parent}{a window which becomes the parent of the resulting window}
%  \item{path}{path to a directory containing Tcl packages}
%  \item{package}{a Tcl package name}
%  \item{warn}{logical. Warn if not found?}
%  \item{...}{Additional arguments. See below.}
%  \item{init}{initialization value}
%}
%\details{
%  Many of these functions are not intended for general use but are used
%  internally by the commands that create and manipulate Tk widgets and
%  Tcl objects.  At the lowest level \code{.Tcl} sends a command as a text
%  string to the Tcl interpreter and returns the result as an object of
%  class \code{tclObj} (see below).  A newer variant \code{.Tcl.objv}
%  accepts arguments in the form of a named list of \code{tclObj}
%  objects.
%
%  \code{.Tcl.args} converts an R argument list of \code{tag = value} pairs
%  to the Tcl \code{-option value} style, thus
%  enabling a simple translation between the two languages. To send a
%  value with no preceding option flag to Tcl, just use an untagged
%  argument. In the rare case one needs an option with no subsequent
%  value \code{tag = NULL} can be used. Most values are just converted to
%  character mode and inserted in the command string, but window objects
%  are passed using their ID string, and callbacks are passed via the
%  result of \code{.Tcl.callback}. Tags are converted to option flags
%  simply by prepending a \code{-}
%
%  \code{.Tcl.args.objv} serves a similar purpose as \code{.Tcl.args} but
%  produces a list of \code{tclObj} objects suitable for passing to
%  \code{.Tcl.objv}. The names of the list are converted to Tcl option
%  style internally by \code{.Tcl.objv}.
%
%  Callbacks can be either \emph{atomic callbacks} handled by
%  \code{.Tcl.callback} or expressions. An expression is treated as a
%  list of atomic callbacks, with the following exceptions: if an
%  element is a name, it is first evaluated in the callers frame, and
%  likewise if it is an explicit function definition; the \code{break}
%  expression is translated directly to the Tcl counterpart.
%  \code{.Tcl.callback} converts \R functions and unevaluated calls to
%  Tcl command strings.  The argument must be either a function closure
%  or an object of mode \code{"call"} followed by an environment.  The
%  return value in the first case is of the form \code{R_call
%  0x408b94d4} in which the hexadecimal number is the memory address of
%  the function. In the second case it will be of the form
%  \code{R_call_lang 0x8a95904 0x819bfd0}. For expressions, a sequence
%  of similar items is generated, separated by
%  semicolons. \code{.Tcl.args} takes special precautions to ensure
%  that functions or calls will continue to exist at the specified
%  address by assigning the
%  callback into the relevant window environment (see below).
%
%  Tk windows are represented as objects of class \code{tkwin} which are
%  lists containing  a \code{ID} field and an \code{env} field which is
%  an \R environments, enclosed in the global environment.  The value of
%  the \code{ID} field is identical to the Tk window name. The \code{env}
%  environment contains a \code{parent} variable and a \code{num.subwin}
%  variable.  If the window obtains sub-windows and  callbacks, they are
%  added as variables to the environment.   \code{.TkRoot} is the top
%  window with ID "."; this window is not  displayed in order to avoid
%  ill effects of closing it via window  manager controls. The
%  \code{parent} variable is undefined for \code{.TkRoot}.
%
%  \code{.Tk.ID} extracts the \code{ID} of a window,
%  \code{.Tk.newwin} creates a new window environment with a given ID and
%  \code{.Tk.subwin} creates a new window which is a sub-window of a given
%  parent window.
%
%  \code{tkdestroy} destroys a window and also removes the reference to a
%  window from its parent.
%
%  \code{is.tkwin} can be used to test whether a given object is a window
%  environment.
%
%  \code{tclVar} creates a new Tcl variable and initializes it to
%  \code{init}.  An R object of class \code{tclVar} is created to
%  represent it.  Using \code{as.character} on the object returns the Tcl
%  variable name.  Accessing the Tcl variable from R is done using the
%  \code{tclvalue} function, which can also occur on the left-hand side of
%  assignments.  If \code{tclvalue} is passed an argument which is not a
%  \code{tclVar} object, then it will assume that it is a character string
%  explicitly naming global Tcl variable. Tcl variables created by
%  \code{tclVar} are uniquely named and automatically unset by the
%  garbage collector when the representing object is no longer in use.
%
%  \code{tclArray} creates a new Tcl array and initializes it to the empty
%  array.  An R object of class \code{tclArray} and inheriting from class
%  \code{tclVar} is created to represent it. You can access elements of
%  the Tcl array using indexing with \code{[[} or \code{$}, which also
%  allow replacement forms.  Notice that Tcl arrays are associative by
%  nature and hence unordered; indexing with a numeric index \code{i}
%  refers to the element with the \emph{name}
%  \code{as.character(i)}.  Multiple indices are pasted together separated
%  by commas to form a single name.  You can query the
%  length and the set of names in an array using methods for
%  \code{length} and \code{names}, respectively; these cannot
%  meaningfully be set so assignment forms exist only to print an error
%  message.
%
%  It is possible to access Tcl's \sQuote{dual-ported} objects directly,
%  thus avoiding parsing and deparsing of their string representation.
%  This works by using objects of class \code{tclObj}.  The string
%  representation of such objects can be extracted (but not set) using
%  \code{tclvalue} and conversion to vectors of mode \code{"character"},
%  \code{"double"}, \code{"integer"}, \code{"logical"}, and \code{"raw"}
%  is performed using the standard coercion functions \code{as.character},
%  etc.  Conversely, such
%  vectors can be converted using \code{as.tclObj}.  There is an
%  ambiguity as to what should happen for length one vectors, controlled
%  by the \code{drop} argument; there are cases where the distinction
%  matters to Tcl, although mostly it treats them equivalently.  Notice
%  that \code{tclvalue} and \code{as.character} differ on an object whose
%  string representation has embedded spaces, the former is sometimes to
%  be preferred, in particular when applied to the result of
%  \code{tclread}, \code{tkgetOpenFile}, and similar functions.  The
%  \code{as.raw} method returns a raw vector or a list of raw vectors and
%  can be used to return binary data from Tcl.
%
%  The object behind a \code{tclVar} object is extracted using
%  \code{tclObj(x)} which also allows an assignment form, in which the
%  right hand side of the assignment is automatically converted using
%  \code{as.tclObj}.  There is a print method for \code{tclObj} objects;
%  it prints \code{<Tcl>} followed by the string representation of the
%  object.  Notice that \code{as.character} on a \code{tclVar} object is
%  the \emph{name} of the corresponding Tcl variable and not the value.
%
%  Tcl packages can be loaded with \code{tclRequire}; it may be necessary
%  to add the directory where they are found to the Tcl search path with
%  \code{addTclPath}.  The return value is a class \code{"tclObj"} object
%  if it succeeds, or \code{FALSE} if it fails (when a warning is
%  issued).  To see the current search path as an \R character vector, use
%\preformatted{strsplit(tclvalue('auto_path'), " ")[[1]]}.
%
%  The Tcl version (including patchlevel) is returned as a character
%  string (such as \code{"8.6.3"}).
%}
%\note{
%  Strings containing unbalanced braces are currently not handled
%  well in many circumstances.
%}
%\seealso{
%  \code{\link{TkWidgets}},
%  \code{\link{TkCommands}},
%  \code{\link{TkWidgetcmds}}.
%
%  \code{\link{capabilities}("tcltk")} to see if Tcl/Tk support was
%  compiled into this build of \R.
%}
%\examples{
%tclVersion()
%
%\dontrun{
%## These cannot be run by example() but should be OK when pasted
%## into an interactive R session with the tcltk package loaded
%.Tcl("format \"\%s\\n\" \"Hello, World!\"")
%f <- function()cat("HI!\n")
%.Tcl.callback(f)
%.Tcl.args(text = "Push!", command = f) # NB: Different address
%
%xyzzy <- tclVar(7913)
%tclvalue(xyzzy)
%tclvalue(xyzzy) <- "foo"
%as.character(xyzzy)
%tcl("set", as.character(xyzzy))
%
%top <- tktoplevel() # a Tk widget, see Tk-widgets
%ls(envir = top$env, all = TRUE)
%ls(envir = .TkRoot$env, all = TRUE) # .Tcl.args put a callback ref in here
%}
%}
%\keyword{ misc }
%
%\encoding{UTF8}