% File src/library/tools/man/Rd2HTML.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2016 R Core Team
% Distributed under GPL 2 or later

\name{Rd2HTML}
%@%\alias{Rd ファイルの変換}
\alias{Rd2txt}
\alias{Rd2HTML}
\alias{Rd2ex}
\alias{Rd2latex}
\title{Rd ファイルの変換}
%\title{ Rd Converters }
\description{
  これらの関数は
  関数 \code{\link{parse_Rd}} の出力を受け取り
  それからヘルプページを作る．
  これらは主に内部的な使用を念頭に置いており，インタフェイスは
  変更される可能性がある．
}
\usage{
Rd2HTML(Rd, out = "", package = "", defines = .Platform$OS.type,
        Links = NULL, Links2 = NULL,
        stages = "render", outputEncoding = "UTF-8",
        dynamic = FALSE, no_links = FALSE, fragment = FALSE,
        stylesheet = "R.css", ...)

Rd2txt(Rd, out = "", package = "", defines = .Platform$OS.type,
       stages = "render", outputEncoding = "",
       fragment = FALSE, options, ...)

Rd2latex(Rd, out = "", defines = .Platform$OS.type,
         stages = "render", outputEncoding = "ASCII",
         fragment = FALSE, ..., writeEncoding = TRUE)

Rd2ex(Rd, out = "", defines = .Platform$OS.type,
      stages = "render", outputEncoding = "UTF-8",
      commentDontrun = TRUE, commentDonttest = FALSE, ...)
}
\arguments{
  \item{Rd}{入力として使うファイル名又は \code{Rd} オブジェクト．}
  \item{out}{出力を書き出すファイル名又はコネクションオブジェクト．}
  \item{package}{出力中にリストするパッケージ．}
  \item{defines}{\verb{#ifdef} テスト中で使われる文字列．}
  \item{stages}{
    どのステージ(\code{"build"}, \code{"install"} 又は \code{"render"}) で
    \verb{\Sexpr} マクロが実行されるべきか? 下の注意を見よ．}
  \item{outputEncoding}{下の\sQuote{エンコーディング}節を見よ．}
  \item{dynamic}{論理値：動的なヘルプシステムによる翻訳時間解決に対するリンクを設定する．}
  \item{no_links}{論理値：他のヘルプトピックへのハイパーリンクを抑制する．
    \command{R CMD \link{Rdconv}} で使われる．}
  \item{fragment}{論理値：Rd ファイルの断片を受け入れるか．下の注意を見よ．}
  \item{stylesheet}{文字列：
    HTML 出力ページのヘッダ中で用いられるスタイルシートに対する URL．}
  \item{Links, Links2}{
    \code{NULL} 又は \code{\link{findHTMLlinks}} が返すような
    リンクの(トピックによる)名前付き文字列ベクトル．}
  \item{options}{
    \code{\link{Rd2txt_options}} に渡されるオプションの名前付きオプションのリスト．}
  \item{...}{
    \code{Rd} がファイル名の時 \code{\link{parse_Rd}} に
    渡される追加パラメータ．}
  \item{writeEncoding}{
      非アスキーエンコーディングで
      \verb{\inputencoding} 行が書かれるべきか?}
  \item{commentDontrun}{\verb{\dontrun} 節はコメントアウトすべきか?}
  \item{commentDonttest}{\verb{\donttest} 節はコメントアウトすべきか?}
}
\details{
  これらの関数はヘルプドキュメントを変換する：
  \code{Rd2HTML} は HTML を，
  \code{Rd2txt} は平文テキストを，
  \code{Rd2latex} は LaTeX を生成する．
  \code{Rd2ex} は
  \code{\link{example}} と \R ユーティリティにより使われる書式で
  例を取り出す．

  各々の関数は Rd ファイルに対するファイル名を受け入れ，
  翻訳やチェックの前にそれを構文解析するために \code{\link{parse_Rd}} を使う．

  引数 \code{Link} と \code{Link2} の間の違いは
  リンクがそれらの中で順に探されることで，
  従って遅延評価はもし要求されるとリンクの第二水準の捜索だけを
  行うことに使うことが出来る．

  \code{Rd2latex} に対する既定は
  第二オプションの \verb{\enc} マークアップの使用を含むASCII出力である
  ことを注意する．
  これは LaTeX 中の UTF-8 の使用はバージョン
  \sQuote{2005/12/01} 又はそれ以降を必要とするために選ばれている．
  そのバージョンですら
  UTF-8 グリフのカバーは限られている(そして
  Latin-1 ほど完全ではない)．

  \code{Rd2txt} は
  \code{width} で決められる幅に適当な余白を持って
  テキストのパラグラフを整形する．
  既定はバージョン \R < 2.10.0 の翻訳に近い．

  Unix風システムでは
  もしオプション \code{"useFancyQuotes"} が真(既定)で
  現在のエンコーディングが UTF-8 ならば \code{Rd2txt} は向き付きの引用符を使う
  (\code{\link{sQuote}} を見よ)．
  
  Windows では
  もしオプション \code{"useFancyQuotes"} が真(既定)で
  現在のロケールが単バイトエンコーディング(C を除く)を使えば
  \code{Rd2txt} は向き付きの引用符を使う
  (\code{\link{sQuote}} を見よ)．
  (東アジアロケールでは引用符は普通倍幅
  であり英語のテキストと一緒では見かけが悪いので，向き付き引用符は
  試みられない．)

  \code{Rd2txt} による整形の様々な様相は
  \code{options} 引数で制御され，\code{\link{Rd2txt_options}} 関数
  と共に文章化されている．
  \code{options} を使ってなされた変更は一時的であり，
  \code{\link{Rd2txt_options}} を使ったものは持続性がある．

  \code{fragment = TRUE} の時は，\code{Rd} ファイルは
  \verb{\Sexpr} 要素や
  \verb{#ifdef} や \verb{#ifndef} を使った条件付き定義の処理
  無しで翻訳される．普通断片は節の内部のテキストを表すが，
  もし断片の最初の要素がセクションマクロならば，
  全ての断片が通常のソート無しに節の連続として翻訳される．
}
\section{エンコーディング}{
  Rd ファイルは普通多種多様なシステム上で翻訳されることを意図しているので，
  非ASCII文字のエンコーディングに注意する必要がある．
  一般にそうしたエンコーディングは正確なエンコーディングが期待できるように
  \samp{encoding}節を使って宣言されるべきである．

  出力に対しては \code{outputEncoding} 引数が使われる：
  \code{outputEncoding = ""} は現在のシステムの素朴なエンコーディングを選択する．

  もしテキストが \code{outputEncoding} に翻訳できなければ，バイト代入が
  使われる(\code{\link{iconv}} を見よ)： \code{Rd2latex}
  と \code{Rd2ex} は警告を与える．
}

\note{
  \verb{\Sexpr} マクロは
  Rd ファイルへの新しい追加である．これは三つの時の内の一つで実行される
  \R コードを含む：
  \emph{構築}時
  (パッケージソースがターボール中に構築される時)，
  \emph{インストール}時(パッケージがインストールされる時や
  バイナリパッケージに構築される時)，そして\emph{翻訳}時
  (マンページが可読な書式に変換される時)．

  例えばこのマンページは：
  \enumerate{
    \item 
    \Sexpr[stage=build]{format(Sys.time(), "\%Y-\%m-\%d at \%H:\%M:\%S")} に構築され，
    \item 
    \Sexpr[stage=install]{format(Sys.time(), "\%Y-\%m-\%d at \%H:\%M:\%S")} にインストールされ，そして
    \item 
    \Sexpr[stage=render]{format(Sys.time(), "\%Y-\%m-\%d at \%H:\%M:\%S")} に翻訳された.
  }
}

\value{
  これらの関数は主に翻訳ヘルプページを描き込む副作用のために実行される．
  それらの値は(不可視の)出力ファイル名である．
  \code{Rd2latex} に対しては出力名は
  属性 {"latexEncoding"} を与えられる，これは
  LaTeX の \samp{inputenc} パッケージと共に使われるのに適した書式の
  ファイルのエンコーディングを与える．
}
\author{
  Duncan Murdoch, Brian Ripley
}
\references{ \url{https://developer.r-project.org/parseRd.pdf} }
\seealso{
  \code{\link{parse_Rd}}, \code{\link{checkRd}},
  \code{\link{findHTMLlinks}}, \code{\link{Rd2txt_options}}.
}
\examples{\donttest{

\dontrun{
## このページのインストールと HTML とテキスト書式への翻訳をシミュレーションする：

Rd <- file.path("src/library/tools/man/Rd2HTML.Rd")

outfile <- tempfile(fileext = ".html")
browseURL(Rd2HTML(Rd, outfile, package = "tools",
          stages = c("install", "render")))

outfile <- tempfile(fileext = ".txt")
file.show(Rd2txt(Rd, outfile, package = "tools",
          stages = c("install", "render")))

checkRd(Rd) # Rd2HTML が使うのよりも厳格なテスト
}}}
\keyword{ documentation }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\\\\\\\\\\\\\\\\\\% File src/library/tools/man/Rd2HTML.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Rd2HTML}
%\alias{Rd2txt}
%\alias{Rd2HTML}
%\alias{Rd2ex}
%\alias{Rd2latex}
%\title{ Rd Converters }
%\description{
%  These functions take the output of the \code{\link{parse_Rd}} function
%  and produce a help page from it.  As they are mainly
%  intended for internal use, their interfaces are subject to change.
%}
%\usage{
%Rd2HTML(Rd, out = "", package = "", defines = .Platform$OS.type,
%        Links = NULL, Links2 = NULL,
%        stages = "render", outputEncoding = "UTF-8",
%        dynamic = FALSE, no_links = FALSE, fragment = FALSE,
%        stylesheet = "R.css", ...)
%
%Rd2txt(Rd, out = "", package = "", defines = .Platform$OS.type,
%       stages = "render", outputEncoding = "",
%       fragment = FALSE, options, ...)
%
%Rd2latex(Rd, out = "", defines = .Platform$OS.type,
%         stages = "render", outputEncoding = "ASCII",
%         fragment = FALSE, ..., writeEncoding = TRUE)
%
%Rd2ex(Rd, out = "", defines = .Platform$OS.type,
%      stages = "render", outputEncoding = "UTF-8",
%      commentDontrun = TRUE, commentDonttest = FALSE, ...)
%}
%\arguments{
%  \item{Rd}{ a filename or \code{Rd} object to use as input. }
%  \item{out}{ a filename or connection object to which to write the output. }
%  \item{package}{ the package to list in the output. }
%  \item{defines}{ string(s) to use in \verb{#ifdef} tests. }
%  \item{stages}{ at which stage (\code{"build"}, \code{"install"}, or
%    \code{"render"}) should \verb{\Sexpr} macros be executed? See the
%    notes below.}
%  \item{outputEncoding}{ see the \sQuote{Encodings} section below.}
%  \item{dynamic}{logical: set links for render-time resolution by
%      dynamic help system.}
%  \item{no_links}{logical: suppress hyperlinks to other help topics.
%      Used by \command{R CMD \link{Rdconv}}.}
%  \item{fragment}{logical:  should fragments of Rd files be accepted?  See the
%      notes below.}
%  \item{stylesheet}{character: a URL for a stylesheet to be used in the header
%      of the HTML output page.}
%  \item{Links, Links2}{\code{NULL} or a named (by topics) character vector of
%    links, as returned by \code{\link{findHTMLlinks}}.}
%  \item{options}{An optional named list of options to pass to
%    \code{\link{Rd2txt_options}}.}
%  \item{...}{ additional parameters to pass to \code{\link{parse_Rd}} when
%    \code{Rd} is a filename. }
%  \item{writeEncoding}{should \verb{\inputencoding} lines be written in
%      the file for non-ASCII encodings?}
%  \item{commentDontrun}{should \verb{\dontrun} sections be commented
%      out?}
%  \item{commentDonttest}{should \verb{\donttest} sections be commented out?}
%}
%\details{
%  These functions convert help documents: \code{Rd2HTML} produces HTML,
%  \code{Rd2txt} produces plain text, \code{Rd2latex} produces LaTeX.
%  \code{Rd2ex} extracts the examples in the format used by
%  \code{\link{example}} and \R utilities.
%
%  Each of the functions accepts a filename for an Rd file, and
%  will use \code{\link{parse_Rd}} to parse it before applying the
%  conversions or checks.
%
%  The difference between arguments \code{Link} and \code{Link2} is that
%  links are looked in them in turn, so lazy-evaluation can be used to
%  only do a second-level search for links if required.
%
%  Note that the default for \code{Rd2latex} is to output ASCII,
%  including using the second option of \verb{\enc} markup.  This was
%  chosen because use of UTF-8 in LaTeX requires version
%  \sQuote{2005/12/01} or later, and even with that version the coverage
%  of UTF-8 glyphs is not extensive (and not even as complete as
%  Latin-1).
%
%  \code{Rd2txt} will format text paragraphs to a width determined by
%  \code{width}, with appropriate margins.  The default is to be close to
%  the rendering in versions of \R < 2.10.0.
%
%  \code{Rd2txt} will use directional quotes (see \code{\link{sQuote}})
%  if option \code{"useFancyQuotes"} is true (the default) and
%#ifdef unix
%  the current encoding is UTF-8.
%#endif
%#ifdef windows
%  the current locale uses a single-byte encoding (except C).
%  (Directional quotes are not attempted in East Asian locales as they are
%  usually double-width, which looks wrong with English text.)
%#endif
%
%  Various aspects of formatting by \code{Rd2txt} are controlled by the
%  \code{options} argument, documented with the \code{\link{Rd2txt_options}}
%  function. Changes made using \code{options} are temporary, those
%  made with \code{\link{Rd2txt_options}} are persistent.
%
%  When \code{fragment = TRUE}, the \code{Rd} file will be rendered
%  with no processing of \verb{\Sexpr} elements or conditional defines
%  using \verb{#ifdef} or \verb{#ifndef}.  Normally a fragment represents
%  text within a section, but if the first element of the fragment
%  is a section macro, the whole fragment will be rendered as
%  a series of sections, without the usual sorting.
%}
%\section{Encodings}{
%  Rd files are normally intended to be rendered on a wide variety of
%  systems, so care must be taken in the encoding of non-ASCII
%  characters.  In general, any such encoding should be declared using
%  the \samp{encoding} section for there to be any hope of correct
%  rendering.
%
%  For output, the \code{outputEncoding} argument will be used:
%  \code{outputEncoding = ""} will choose the native encoding for the
%  current system.
%
%  If the text cannot be converted to the \code{outputEncoding}, byte
%  substitution will be used (see \code{\link{iconv}}): \code{Rd2latex}
%  and \code{Rd2ex} give a warning.
%}
%
%\note{
%  The \verb{\Sexpr} macro is a new addition to Rd files.  It includes
%  \R code that will be executed at one of three times: \emph{build} time
%  (when a package's source code is built into a tarball),
%  \emph{install} time (when the package is installed or
%  built into a binary package), and \emph{render} time (when the man
%  page is converted to a readable format).
%
%  For example, this man page was:
%  \enumerate{
%    \item built on
%    \Sexpr[stage=build]{format(Sys.time(), "\%Y-\%m-\%d at \%H:\%M:\%S")},
%    \item installed on
%    \Sexpr[stage=install]{format(Sys.time(), "\%Y-\%m-\%d at \%H:\%M:\%S")}, and
%    \item rendered on
%    \Sexpr[stage=render]{format(Sys.time(), "\%Y-\%m-\%d at \%H:\%M:\%S")}.
%  }
%}
%
%\value{
%  These functions are executed mainly for the side effect of
%  writing the converted help page.  Their value is the name of the output
%  file (invisibly).  For \code{Rd2latex}, the output name is given an
%  attribute \code{"latexEncoding"} giving the encoding of the file in a
%  form suitable for use with the LaTeX \samp{inputenc} package.
%}
%\author{
%  Duncan Murdoch, Brian Ripley
%}
%\references{ \url{https://developer.r-project.org/parseRd.pdf} }
%\seealso{
%  \code{\link{parse_Rd}}, \code{\link{checkRd}},
%  \code{\link{findHTMLlinks}}, \code{\link{Rd2txt_options}}.
%}
%\examples{\donttest{
%
%\dontrun{
%## Simulate install and rendering of this page in HTML and text format:
%
%Rd <- file.path("src/library/tools/man/Rd2HTML.Rd")
%
%outfile <- tempfile(fileext = ".html")
%browseURL(Rd2HTML(Rd, outfile, package = "tools",
%          stages = c("install", "render")))
%
%outfile <- tempfile(fileext = ".txt")
%file.show(Rd2txt(Rd, outfile, package = "tools",
%          stages = c("install", "render")))
%
%checkRd(Rd) # A stricter test than Rd2HTML uses
%}}}
%\keyword{ documentation }
%
%\encoding{UTF8}
%