% File src/library/tools/man/checkRd.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2014 R Core Team
% Distributed under GPL 2 or later

\name{checkRd}
%@%\alias{Rd オブジェクトのチェック}
\alias{checkRd}
\title{Rd オブジェクトをチェックする}
%\title{ Check an Rd Object }
\description{
  ヘルプファイル又は
  \code{\link{parse_Rd}} 関数の出力をチェックする．
}
\usage{
checkRd(Rd, defines = .Platform$OS.type, stages = "render",
        unknownOK = TRUE, listOK = TRUE, ..., def_enc = FALSE)
}
\arguments{
  \item{Rd}{入力として使うファイル名又は \code{Rd} オブジェクト．}
  \item{defines}{
    \verb{#ifdef} テスト中で使う文字列．}
  \item{stages}{
    どの段階(\code{"build"}, \code{"install"} 又は \code{"render"}) で
    \verb{\Sexpr} マクロを実行すべきか? 下の注意を見よ．}
  \item{unknownOK}{認識できないマクロは
    \code{FALSE} であるかのようにしてエラーとして，さもなければ警告として扱う．}
  \item{listOK}{ 不必要な空でない括弧(例えばテキストまわり，
    引数としてではない)は
    \code{FALSE} であるかのようにエラーとして，さもなければ警告として扱う．}
  \item{\dots}{\code{Rd} がファイル名の時
    \code{\link{parse_Rd}} に渡される追加引数．
    しばしば有用なものは \code{encoding}．}
  \item{def_enc}{論理値：パッケージはエンコーディングを宣言されており，
    従って非ASCIIテキストは抑制されるか?}
}
\details{
  \code{checkRd} は
  Rd ファイルに関する一貫性のチェックを行い，
  必要とされるセクションが存在するかなどを確認する．

  これは Rd ファイルに対するファイル名を受け入れ，
  チェックの実行前にそれを構文解析するために \code{\link{parse_Rd}} を使う．
  もしそうなら \code{parse_Rd} からの警告が
  内部関数 \code{prepare_Rd} からのものと一緒に
  集められる．
  内部関数は \verb{#ifdef} と \verb{\Sexpr} の処理を行い，
  翻訳出来ないセクションや重複(そしてあってはならない)セクション
  を取り去り，空のセクションを削除する．

  Rd オブジェクトは
  \code{prepare_Rd} を経由して渡されるが，既にそうされているかもしれない
  (そしてインストールされた Rd オブジェクトはそうである)．

  警告は\sQuote{レベル}を与えられる：\code{prepare_Rd}
  からのものはレベル 0 である．これらは以下を含む
  \tabular{l}{
    全てのテキストはあるセクション中になければならない\cr
    一つの \var{tag name} セクション名だけが許される：最初のものが使われる\cr
    セクション \var{name} は認識されず捨て去られる\cr
    空のセクション \var{name} の除去\cr
  }
  \code{checkRd} 自体は以下を示すことが出来る
  \tabular{rl}{
    7 \tab タグ \var{tag name} は認識できない\cr
    7 \tab \verb{\tabular} 書式は簡単でなければならない\cr
    7 \tab 認識できない \verb{\tabular} 書式：\ldots\cr
    7 \tab このテーブルには \var{n} 列だけが許される\cr
    7 \tab \var{tag name} を持たねばならない\cr
    7 \tab 一つの \var{tag name} だけが許される\cr
    7 \tab タグ \var{tag name} は空であってはならない\cr
    7 \tab \verb{\docType} は平文でなければならない\cr
    5 \tab タグ \verb{\method} は \verb{\usage} 中でのみ適正である\cr
    5 \tab タグ \verb{\dontrun} は \verb{\examples} 中でのみ適正である\cr
    5 \tab タグ \var{tag name} は \var{block name} ブロック中では不正である\cr
    5 \tab \verb{\section} のタイトルは空でない平文でなければならない\cr
    5 \tab \verb{\title} の内容は平文でなければならない\cr
    3 \tab 空のセクション \var{tag name}\cr
    -1 \tab エンコーディングが宣言されていない非ASCIIの内容\cr
    -1 \tab \verb{\enc} の二番目の部分に非ASCIIの内容\cr
    -3 \tab タグ \verb{\ldots} はコードブロック中は適正でない\cr
    -3 \tab 見かけ上エンコーディングが宣言されていない非ASCIIの内容\cr
    -3 \tab \verb{\enc} の二番目の部分に見かけ上非ASCIIの内容\cr
    -3 \tab 不必要な括弧が \ldots にある\cr
    -3 \tab \verb{\method} はコードブロックの外では不正である\cr
  }
  そして
  \verb{\method} が \verb{\S3method} や \verb{\S4method} に置き換えられたバリエーション．

  \code{prepare_Rd} と \code{checkRd} は共にからのセクションに対するテストを
  持つことを注意する：
  \code{checkRd} 中のものはより厳格である(本質的に何も出力されないもの)．
}
\value{これは \R のエラーを通じて失敗するかもしれないが，さもなければ
  クラス \code{"checkRd"} のオブジェクトとして返されるような
  警告が集められる．
  このクラスはユニークなメッセージをプリントするだけの
  \code{print} メソッドと，
  より深刻なメッセージだけを選択するのに使うことが出来る
  \code{minlevel} 引数を持つ．
  (これは \command{R CMD check} 中で \code{-1} と設定される．)

  可能な致命的なエラーは構文解析からのもの
  (たとえば，存在しないファイル，閉じられていない引用符，
  エンコーディングが指定されていない非ASCII入力)，又は
  \code{prepare_Rd} からのもの
  (多重の \verb{\Rdversion} 宣言，不正な \verb{\encoding} 又は
  \verb{\docType} 又は \verb{\name} セクション，そして欠損するか
  重複する \verb{\name} 又は \verb{\title} セクション)がある．
}
\author{
  Duncan Murdoch, Brian Ripley
}
\seealso{
  \code{\link{parse_Rd}}, \code{\link{Rd2HTML}}.
}

\keyword{ documentation }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/checkRd.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{checkRd}
%\alias{checkRd}
%\title{ Check an Rd Object }
%\description{
%  Check an help file or the output of the \code{\link{parse_Rd}} function.
%}
%\usage{
%checkRd(Rd, defines = .Platform$OS.type, stages = "render",
%        unknownOK = TRUE, listOK = TRUE, ..., def_enc = FALSE)
%}
%\arguments{
%  \item{Rd}{ a filename or \code{Rd} object to use as input. }
%  \item{defines}{ string(s) to use in \verb{#ifdef} tests. }
%  \item{stages}{ at which stage (\code{"build"}, \code{"install"}, or
%    \code{"render"}) should \verb{\Sexpr} macros be executed? See the
%    notes below.}
%  \item{unknownOK}{ unrecognized macros are treated as errors if
%    \code{FALSE}, otherwise warnings. }
%  \item{listOK}{ unnecessary non-empty braces (e.g., around text, not as
%    an argument) are treated as errors if \code{FALSE}, otherwise
%    warnings.}
%  \item{\dots}{ additional parameters to pass to \code{\link{parse_Rd}} when
%    \code{Rd} is a filename.  One that is often useful is \code{encoding}.}
%  \item{def_enc}{logical: has the package declared an encoding, so tests
%    for non-ASCII text are suppressed?}
%}
%\details{
%  \code{checkRd} performs consistency checks on an Rd file, confirming that
%  required sections are present, etc.
%
%  It accepts a filename for an Rd file, and will use
%  \code{\link{parse_Rd}} to parse it before applying the checks.  If so,
%  warnings from \code{parse_Rd} are collected, together with those from
%  the internal function \code{prepare_Rd}, which does the
%  \verb{#ifdef} and \verb{\Sexpr} processing, drops sections that
%  would not be rendered or are duplicated (and should not be) and
%  removes empty sections.
%
%  An Rd object is passed through \code{prepare_Rd}, but it may already
%  have been (and installed Rd objects have).
%
%  Warnings are given a \sQuote{level}: those from \code{prepare_Rd} have
%  level 0.  These include
%  \tabular{l}{
%    All text must be in a section\cr
%    Only one \var{tag name} section is allowed: the first will be used\cr
%    Section \var{name} is unrecognized and will be dropped\cr
%    Dropping empty section \var{name}\cr
%  }
%  \code{checkRd} itself can show
%  \tabular{rl}{
%    7 \tab Tag \var{tag name} not recognized\cr
%    7 \tab \verb{\tabular} format must be simple text\cr
%    7 \tab Unrecognized \verb{\tabular} format: \ldots\cr
%    7 \tab Only \var{n} columns allowed in this table\cr
%    7 \tab Must have a \var{tag name}\cr
%    7 \tab Only one \var{tag name} is allowed\cr
%    7 \tab Tag \var{tag name} must not be empty\cr
%    7 \tab \verb{\docType} must be plain text\cr
%    5 \tab Tag \verb{\method} is only valid in \verb{\usage}\cr
%    5 \tab Tag \verb{\dontrun} is only valid in \verb{\examples}\cr
%    5 \tab Tag \var{tag name} is invalid in a \var{block name} block\cr
%    5 \tab Title of \verb{\section} must be non-empty plain text\cr
%    5 \tab \verb{\title} content must be plain text\cr
%    3 \tab Empty section \var{tag name}\cr
%    -1 \tab Non-ASCII contents without declared encoding\cr
%    -1 \tab Non-ASCII contents in second part of \verb{\enc}\cr
%    -3 \tab Tag \verb{\ldots} is not valid in a code block\cr
%    -3 \tab Apparent non-ASCII contents without declared encoding\cr
%    -3 \tab Apparent non-ASCII contents in second part of \verb{\enc}\cr
%    -3 \tab Unnecessary braces at \ldots\cr
%    -3 \tab \verb{\method} not valid outside a code block\cr
%  }
%  and variations with \verb{\method} replaced by \verb{\S3method} or
%  \verb{\S4method}.
%
%  Note that both \code{prepare_Rd} and \code{checkRd} have tests for an
%  empty section: that in \code{checkRd} is stricter (essentially that
%  nothing is output).
%}
%\value{
%  This may fail through an \R error, but otherwise warnings are
%  collected as returned as an object of class \code{"checkRd"}, a
%  character vector of messages.  This class has a \code{print} method
%  which only prints unique messages, and has argument \code{minlevel}
%  that can be used to select only more serious messages.  (This is set
%  to \code{-1} in \command{R CMD check}.)
%
%  Possible fatal errors are those from running the parser (e.g., a
%  non-existent file, unclosed quoted string, non-ASCII input without a
%  specified encoding) or from \code{prepare_Rd} (multiple
%  \verb{\Rdversion} declarations, invalid \verb{\encoding} or
%  \verb{\docType} or \verb{\name} sections, and missing or duplicate
%  \verb{\name} or \verb{\title} sections).
%}
%\author{
%  Duncan Murdoch, Brian Ripley
%}
%\seealso{
%  \code{\link{parse_Rd}}, \code{\link{Rd2HTML}}.
%}
%
%\keyword{ documentation }
%
%\encoding{UTF8}
%