% File src/library/tools/man/delimMatch.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{delimMatch}
%@%\alias{区切り文字のパターンマッチ}
\alias{delimMatch}
\title{区切り文字のパターンマッチ}
%\title{Delimited Pattern Matching}
\description{
  文字列ベクトル中の区切り文字で囲まれた副文字列を適正な
  入れ子でマッチする．
}
\usage{
delimMatch(x, delim = c("{", "}"), syntax = "Rd")
}
\arguments{
  \item{x}{文字列ベクトル．}
  \item{delim}{長さ2の文字列ベクトルで
    開始と終了の区切り文字を与える．
    将来は任意の正規表現が許されるかもしれない．}
  \item{syntax}{現在は常に文字列 \code{"Rd"} で Rd シンタックスを
    指示する(つまり \samp{\%} は行末までのコメントで，
    \samp{\\} はエスケープ)．将来のバージョンは
    恐らく柔軟にコメント，エスケープ，そして引用符を指定
    することを許す\sQuote{シンタックス表}を使った他の
    シンタックスを理解するかもしれない．}
}
\value{
  \code{x} と同じ長さの整数ベクトルで最初のマッチの位置
  (文字数単位)，またはもしなければ \eqn{-1} を与え，
  マッチしたテキスト
  (もしくはマッチするものがなければ \eqn{-1})の長さを与える
  属性 \code{"match.length"} を持つ．
}
\seealso{
  \sQuote{単純}なパターンマッチングには \code{\link{regexpr}}．
}
\examples{
x <- c("\\\\value{foo}", "function(bar)")
delimMatch(x)
delimMatch(x, c("(", ")"))
}
\keyword{character}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/delimMatch.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{delimMatch}
%\alias{delimMatch}
%\title{Delimited Pattern Matching}
%\description{
%  Match delimited substrings in a character vector, with proper nesting.
%}
%\usage{
%delimMatch(x, delim = c("{", "}"), syntax = "Rd")
%}
%\arguments{
%  \item{x}{a character vector.}
%  \item{delim}{a character vector of length 2 giving the start and end
%    delimiters.  Future versions might allow for arbitrary regular
%    expressions.}
%  \item{syntax}{currently, always the string \code{"Rd"} indicating Rd
%    syntax (i.e., \samp{\%} starts a comment extending till the end of
%    the line, and \samp{\\} escapes).  Future versions might know about
%    other syntax, perhaps via \sQuote{syntax tables} allowing to
%    flexibly specify comment, escape, and quote characters.}
%}
%\value{
%  An integer vector of the same length as \code{x} giving the starting
%  position (in characters) of the first match, or \eqn{-1} if there is
%  none, with attribute \code{"match.length"} giving the length (in
%  characters) of the matched text (or \eqn{-1} for no match).
%}
%\seealso{
%  \code{\link{regexpr}} for \sQuote{simple} pattern matching.
%}
%\examples{
%x <- c("\\\\value{foo}", "function(bar)")
%delimMatch(x)
%delimMatch(x, c("(", ")"))
%}
%\keyword{character}
%
%\encoding{UTF8}
%