% File src/library/tools/man/getDepList.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{getDepList}
%@%\alias{従属性情報の検索}
\alias{getDepList}
\alias{pkgDepends}
%\title{Functions to Retrieve Dependency Information}
\title{従属性情報を検索する関数}
\description{
  これらの関数はパッケージの従属性情報や
  従属性行列に対する \code{DependsList} オブジェクトの
  情報を検索する．

  従属性行列をあたえた時，
  \code{getDepList()} はそのパッケージに対する
  \code{DependsList} オブジェクトを作る．
  このオブジェクトは行列に対する従属性，
  何がインストールされているか，
  どのような未解決の従属性がオンラインで見つかったか，
  そして任意の R 従属性を含む．

  \code{pkgDepends()} は便宜上パッケージ名を取り，
  従属性行列を構築し，それから対応する
  \code{getDepList()} を返す．
}
\usage{
getDepList(depMtrx, instPkgs, recursive = TRUE, local = TRUE,
           reduce = TRUE, lib.loc = NULL)

pkgDepends(pkg, recursive = TRUE, local = TRUE, reduce = TRUE,
           lib.loc = NULL)
}
\arguments{
  \item{depMtrx}{
    \code{\link{package.dependencies}()} が作るような従属性行列．}
  \item{pkg}{パッケージ名．}
  \item{instPkgs}{
    \code{\link{package.dependencies}} が作るような
    ローカルシステム上の全てのインストールされたパッケージ
    を指定する行列．}  
  \item{recursive}{間接的従属性を含めないかどうか．}
  \item{local}{ローカルのみ創作するかどうか．}
  \item{reduce}{従属性のセットを最少の値に簡略化するかどうか．}
  \item{lib.loc}{
    インストールされたパッケージを探す時どのライブラリを使うか．
    \code{NULL} は
    現在の \code{.libPaths()} 中の全てのライブラリディレクトリを指示する．
    \code{lib.loc} は \code{getDepList()} 中とそこで
    廃止予定とされたものでは使われないことを注意する．}
}
\details{
  便利関数 \code{pkgDepends(pkg)} は
  \code{\link{installed.packages}} を問い合わせ従属性行列を作り，
  この情報を使い \code{getDepList} を呼び出し，そして結果を返す．

  もし \code{recursive} が \code{TRUE} ならば，従属していると指示された
  任意のパッケージは次にその従属性を含む(等々)，これらは
  間接的従属性として知られている．
  もし \code{recursive} が \code{FALSE} ならば，パッケージが直接指示する従属性が
  使われる．

  もし \code{local} が \code{TRUE} ならば，システムは未解決の従属性を
  見つけるのにユーザがローカルにインストールしているものだけを探す．

  もし \code{reduce} が \code{TRUE} ならば，システムは
  最少の従属性のセットが指定されるように
  \code{DependsList} オブジェクト中の欄を縮小する
  (例えばもし \samp{foo, foo (>= 1.0.0), foo (>= 1.3.0)} ならば，
  \samp{foo (>= 1.3.0)} が返される)．
}
\value{
  S3 クラス \code{"DependsList"} のオブジェクトで，これは次の成分を含むリストである
  \item{Depends}{このパッケージに対する従属性のベクトル．}
  \item{Installed}{現在インストール済みのパッケージが満足する
    従属性のベクトル．}
  \item{Found}{
    \code{Installed} 中には無いがオンラインで見つかった従属性を表現するリスト．
    このリストはパッケージが見つかったレポジトリに対する URL である
    要素名を持ち
    要素自体はそれぞれのレポジトリで見つかったパッケージ名のベクトル
    である．もし
    \code{local = TRUE} ならば \code{Found} 要素は常に空である．}
  \item{NotFound}{...}
  \item{R}{任意の R のバージョンの従属性．}
}
\author{ Jeff Gentry }
\seealso{\code{\link{installFoundDepends}}}
\examples{
pkgDepends("tools", local = FALSE)
}
\keyword{utilities}


\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/getDepList.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getDepList}
%\alias{getDepList}
%\alias{pkgDepends}
%\title{Functions to Retrieve Dependency Information}
%\description{
%  These functions retrieve information about the dependencies of
%  a package or a dependency matrix, resulting in a \code{DependsList} object.
%
%  Given a dependency matrix, \code{getDepList()} creates a
%  \code{DependsList} object for that package.  That object includes the
%  dependencies for that matrix, which ones are installed, which
%  unresolved dependencies were found online, which unresolved
%  dependencies were not found online, and any R dependencies.
%
%  \code{pkgDepends()} for convenience takes a package name, builds a
%  dependency matrix and then returns a corresponding \code{getDepList()}.
%}
%\usage{
%getDepList(depMtrx, instPkgs, recursive = TRUE, local = TRUE,
%           reduce = TRUE, lib.loc = NULL)
%
%pkgDepends(pkg, recursive = TRUE, local = TRUE, reduce = TRUE,
%           lib.loc = NULL)
%}
%\arguments{
%  \item{depMtrx}{a dependency matrix as from \code{\link{package.dependencies}()}.}
%  \item{pkg}{the name of the package}
%  \item{instPkgs}{a matrix specifying all packages installed on the
%    local system, as from \code{installed.packages}}
%  \item{recursive}{whether or not to include indirect dependencies.}
%  \item{local}{whether or not to search only locally}
%  \item{reduce}{whether or not to collapse all sets of dependencies to a
%    minimal value}
%  \item{lib.loc}{what libraries to use when looking for installed
%    packages.  \code{NULL} indicates all library directories in the
%    current \code{.libPaths()}.
%    Note that \code{lib.loc} is not used in \code{getDepList()} and
%    deprecated there.}
%}
%\details{
%  The convenience function \code{pkgDepends(pkg)} queries
%  \code{\link{installed.packages}} and generates a dependency
%  matrix, calling \code{getDepList} with this information and returning
%  the result.
%
%  If \code{recursive} is \code{TRUE}, any package that is specified as a
%  dependency will in turn have its dependencies included (and so on),
%  these are known as indirect dependencies.  If \code{recursive} is
%  \code{FALSE}, only the dependencies directly stated by the package will
%  be used.
%
%  If \code{local} is \code{TRUE}, the system will only look at the user's local
%  install and not online to find unresolved dependencies.
%
%  If \code{reduce} is \code{TRUE}, the system will collapse the fields in the
%  \code{DependsList} object such that a minimal set of dependencies
%  are specified (for instance if there was
%  \samp{foo, foo (>= 1.0.0), foo (>= 1.3.0)}, it would only return
%  \samp{foo (>= 1.3.0)}).
%}
%\value{
%  An object of S3 class \code{"DependsList"}, which is a \code{\link{list}}
%  with components
%  \item{Depends}{A vector of the dependencies for this package.}
%  \item{Installed}{A vector of the dependencies which have been
%    satisfied by the currently installed packages.}
%  \item{Found}{A list representing the dependencies which are not in
%    \code{Installed} but were found online.  This list has element
%    names which are the URLs for the repositories in which packages
%    were found and the elements themselves are vectors of package
%    names which were found in the respective repositories.  If
%    \code{local = TRUE}, the \code{Found} element will always be empty.}
%  \item{NotFound}{...}
%  \item{R}{Any R version dependencies.}
%}
%\author{ Jeff Gentry }
%\seealso{\code{\link{installFoundDepends}}}
%\examples{
%pkgDepends("tools", local = FALSE)
%}
%\keyword{utilities}
%
%
%\encoding{UTF8}
%