% File src/library/tools/man/update_pkg_po.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2012-2013 R Core Team
% Distributed under GPL 2 or later

\name{update_pkg_po}
%@%\alias{パッケージの翻訳の準備}
\alias{update_pkg_po}
\title{パッケージに対する翻訳を準備する}
%\title{Prepare Translations for a Package}
\description{
  パッケージの \file{po} ディレクトリを準備し，
  そして翻訳をコンパイルしインストールする．
}
\usage{
update_pkg_po(pkgdir, pkg = NULL, version = NULL, copyright, bugs)
}
\arguments{
  \item{pkgdir}{パッケージのディレクトリへのパス．}
  \item{pkg}{パッケージ名：
    もし \code{NULL} ならばそれはパッケージの
    \file{DESCRIPTION} ファイルから読み取られる．}
  \item{version}{パッケージのバージョン：
    もし \code{NULL} ならばそれはパッケージの
    \file{DESCRIPTION} ファイルから読み取られる．}
  \item{copyright, bugs}{テンプレートファイル中の
    \samp{Copyright} と \samp{Report-Msgid-Bugs-To} の詳細に対する
    オプションの文字列．}
}
\details{
  これはパッケージ中のメッセージの準備や更新を行う何段階かのステップを実行する．
  \itemize{
    \item もしパッケージソースがまだ
      \file{po} ディレクトリを持たなければ，それが作られる．
    \item \code{\link{xgettext2pot}} がパッケージ中の翻訳可能なメッセージを含む
      ファイル \file{po/R-\var{pkgname}.pot} を作ったり更新したりするために
      呼び出される．
    \item
      ディレクトリ \code{po} 中の名前が
      \file{R-\var{lang}.po} の全てのファイルは
      \file{R-\var{pkgname}.pot} から更新され，
      \code{\link{checkPoFile}} が更新されたファイルに対して呼び出され，
      そしてもし問題が何m無ければコンパイルされ
      \file{inst/po} の下にインストールされる．
    \item UTF-8 ロケールでは．\sQuote{翻訳} \file{R-en@quot.po}
      は UTF-8 の向き付き引用符付きで作られ，\file{inst/po} の下に
      コンパイルしインストールされる．
   \item 残りのステップは
      ファイル \file{po/\var{pkgname}.pot} が既に存在する時だけ実行される．
      パッケージ中の \file{src/*.\{c,cc,cpp,m,mm\}} ファイルが
      C/C++ ファイル中の翻訳可能なメッセージを含む
      ファイル \file{po/\var{pkgname}.pot} を作るために
      調べられる．
      もし \code{src/windows} ディレクトリがあれば，その中の
      ファイルも調べられる．
    \item
      ディレクトリ \code{po} 中の名前が
      \file{\var{lang}.po} の全ての存在するファイルが
      \file{\var{pkgname}.pot} から更新され，
      \code{\link{checkPoFile}} が更新されたファイルに対して呼び出され，
      そしてもし何の問題も無ければファイルはコンパイルされ
      \file{inst/po} の下にインストールされる．
    \item UTF-8 ロケールでは．\sQuote{翻訳} \file{R-en@quot.po}
      は UTF-8 の向き付き引用符付きで作られ，\file{inst/po} の下に
      コンパイルしインストールされる．
  }

  C/C++ のメッセージはソースファイル中で明確にマークされる必要があるので
  自動的には翻訳の準備がされないことを注意する．
  それがなされると
  パッケージソース中の空のファル \file{po/\var{pkgname}.pot} が
  作られこの関数を再び実行する．

  \code{pkg = "base"} は特別である(そして
  \R の開発者だけが使用する)：
  C ファイルはパッケージのディレクトリ中には無く，
  メインのソース中にある．
}

\section{システム要件}{
  この関数は
  GNU の \command{gettext-tools} からの以下のツールを必要とする：
  \command{xgettext}, \command{msgmerge},
  \command{msgfmt}, \command{msginit} そして \command{msgconv}．
  これらはほとんどの
  Linux ディストリビューションの一部でありそして
  Unix 風システム(OS X を含む)ではソースから容易にコンパイルできる．
  Windows に対する予めコンパイルされたバージョンは
  \url{https://www.stats.ox.ac.uk/pub/Rtools/goodies/gettext-tools.zip}
  から入手できる．

  これは
  UTF-8 ロケール中を除けば \code{en@quot} 翻訳に対しては恐らく正しく
  動作しないので，これらは他のケースではスキップされる．
}

\seealso{
  \code{\link{xgettext2pot}}.
}
\keyword{ utilities }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/update_pkg_po.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2012-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{update_pkg_po}
%\alias{update_pkg_po}
%\title{
%  Prepare Translations for a Package
%}
%\description{
%  Prepare the \file{po} directory of a package and compile and install
%  the translations.
%}
%\usage{
%update_pkg_po(pkgdir, pkg = NULL, version = NULL, copyright, bugs)
%}
%\arguments{
%  \item{pkgdir}{The path to the package directory.}
%  \item{pkg}{The package name: if \code{NULL} it is read from the package's
%    \file{DESCRIPTION} file.}
%  \item{version}{The package version: if \code{NULL} it is read from the
%    package's \file{DESCRIPTION} file.}
%  \item{copyright, bugs}{optional character strings for the
%    \samp{Copyright} and \samp{Report-Msgid-Bugs-To} details in the
%    template files.}
%}
%\details{
%  This performs a series of steps to prepare or update messages in
%  the package.
%  \itemize{
%    \item If the package sources do not already have a \file{po}
%    directory, one is created.
%    \item \code{\link{xgettext2pot}} is called to create/update a file
%    \file{po/R-\var{pkgname}.pot} containing the translatable messages
%    in the package.
%    \item All existing files in directory \code{po} with names
%    \file{R-\var{lang}.po} are updated from \file{R-\var{pkgname}.pot},
%    \code{\link{checkPoFile}} is called on the updated file, and if
%    there are no problems the file is  compiled and installed under
%    \file{inst/po}.
%    \item In a UTF-8 locale, a \sQuote{translation} \file{R-en@quot.po}
%    is created with UTF-8 directional quotes, compiled and installed
%    under \file{inst/po}.
%   \item The remaining steps are done only if file
%    \file{po/\var{pkgname}.pot} already exists.  The
%    \file{src/*.\{c,cc,cpp,m,mm\}} files in the package are examined to
%    create a file \file{po/\var{pkgname}.pot} containing the translatable
%    messages in the C/C++ files.  If there is a \code{src/windows}
%    directory, files within it are also examined.
%    \item All existing files in directory \code{po} with names
%    \file{\var{lang}.po} are updated from \file{\var{pkgname}.pot},
%    \code{\link{checkPoFile}} is called on the updated file, and if
%    there are no problems the file is  compiled and
%    installed under \file{inst/po}.
%    \item In a UTF-8 locale, a \sQuote{translation} \file{en@quot.po} is
%    created with UTF-8 directional quotes, compiled and installed under
%    \file{inst/po}.
%  }
%
%  Note that C/C++ messages are not automatically prepared for
%  translation as they need to be explicitly marked for translation in
%  the source files.  Once that has been done, create an empty file
%  \file{po/\var{pkgname}.pot} in the package sources and run this
%  function again.
%
%  \code{pkg = "base"} is special (and for use by \R developers only):
%  the C files are not in the package directory but in the main sources.
%}
%
%\section{System requirements}{
%  This function requires the following tools from the GNU
%  \command{gettext-tools}: \command{xgettext}, \command{msgmerge},
%  \command{msgfmt}, \command{msginit} and \command{msgconv}.  These are
%  part of most Linux distributions and easily compiled from the sources
%  on Unix-alikes (including OS X).  Pre-compiled versions for
%  Windows are available in
%  \url{https://www.stats.ox.ac.uk/pub/Rtools/goodies/gettext-tools.zip}.
%
%  It will probably not work correctly for \code{en@quot} translations
%  except in a UTF-8 locale, so these are skipped elsewhere.
%}
%
%\seealso{
%  \code{\link{xgettext2pot}}.
%}
%\keyword{ utilities }
%
%\encoding{UTF8}
%