% File src/library/tools/man/vignetteEngine.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2013-2014 R Core Team
% Distributed under GPL 2 or later

\name{vignetteEngine}
%@%\alias{ビニエットのエンジン}
\alias{vignetteEngine}
\title{ビニエットを処理するエンジンを設定する，得る}
%\title{Set or Get a Vignette Processing Engine}
\description{
ビニエットは普通
\code{\link{Sweave}} で処理されるが，パッケージの作者は
異なったエンジンを使うことを選択するかもしれない
(例えば
\CRANpkg{knitr}, \CRANpkg{noweb} または \CRANpkg{R.rsp} パッケージが提供するもの)．
この関数はこれらのパッケージによりそれらのエンジンを登録するために使われ，
そして内部的に
\R{} によりそれらを検索するために使われる．
}
\usage{
vignetteEngine(name, weave, tangle, pattern = NULL,
	       package = NULL, aspell = list())
}
\arguments{
  \item{name}{エンジンの名前．}
  \item{weave}{ビニエットのソースファイルを
    LaTeX 出力に変換する関数．}
  \item{tangle}{ビニエットのソースファイルを
    \R コードに変換する関数．}
  \item{pattern}{このエンジンで処理されるファイル名に対する
    正規表現パターン，もしくは既定のパターンに対しては
    \code{NULL}．}
  \item{package}{パッケージを登録するパッケージ．
    既定ではこれは
    \code{vignetteEngine} を呼び出すパッケージ．}
  \item{aspell}{
    ビニエットのソースファイル中のテキストを \code{\link{aspell}} で
    スペルチェックする時に使われる引数
    \code{filter} と/または \code{control} をそれぞれ与える
    名前の要素のリスト，}
}
\details{
もし \code{weave} が無ければ，\code{vignetteEngine} は
\code{name} と \code{package} にマッチする現在登録されているエンジンを返す．

もし \code{weave} が \code{NULL} なら指定されたエンジンは削除される．

他の設定は新しいエンジンを定義する．
\code{weave} と \code{tangle} 関数は
\code{function(file, ...)}
と両立する引数リストで定義されなければならない．
現在 \code{...} 引数は論理値引数
\code{quiet} と文字列引数
\code{encoding} を含むことが出来る：これらは
\code{\link{Sweave}} と \code{\link{Stangle}} に対するドキュメント中で
解説されている．

\code{weave} と \code{tangle} 関数は作成された出力ファイルの
ファイル名を返さなければならない．
現在 \code{weave} 関数は名前が
\file{<name><pattern>} のファイルに適用すると
\file{<name>[.](tex|pdf|html)} という名前のファイルを返す．
ファイル \file{.tex} は \command{pdflatex} で処理され
ユーザに表示するための \file{.pdf} 出力を作成する：
他は作成された様に表示される．
\code{tangle} 関数はビニエットからの \R{} コードを含む名前が
\file{<name>[.][rRsS]} を作る．\code{tangle} 関数は引数
\code{split = TRUE} をサポートするかもしれず，そしてそれは名前が
\file{<name>.*[.][rRsS]} のファイルを作るべきである．

\code{pattern} 引数はビニエット入力ファイルとして処理されるべき
ファイルの拡張子にマッチする正規表現を与える．
もし \code{NULL} に設定されると，既定のパターン \code{"[.][RrSs](nw|tex)$"}
が使われる．
}
\value{
  もしエンジンが削除されていれば \code{NULL}．さもなければ次の成分を含む
  リスト
  \item{name}{エンジンの名前}
  \item{package}{そのパッケージの名前}
  \item{pattern}{ビニエット入力ファイルのパターン}
  \item{weave}{weave 関数}
  \item{tangle}{tangle 関数}
}
\author{
Duncan Murdoch と Henrik Bengtsson.
}
\seealso{
\code{\link{Sweave}} そしてマニュアル \sQuote{Writing R Extensions}．
}
\examples{
str(vignetteEngine("Sweave"))
}
\keyword{utilities}
\keyword{documentation}


\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/vignetteEngine.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2013-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{vignetteEngine}
%\alias{vignetteEngine}
%\title{Set or Get a Vignette Processing Engine}
%\description{
%Vignettes are normally processed by \code{\link{Sweave}}, but package
%writers may choose to use a different engine (e.g., one provided by the
%\CRANpkg{knitr}, \CRANpkg{noweb} or \CRANpkg{R.rsp} packages).  This function
%is used by those packages to register their engines, and internally by
%\R{} to retrieve them.
%}
%\usage{
%vignetteEngine(name, weave, tangle, pattern = NULL,
%	       package = NULL, aspell = list())
%}
%\arguments{
%  \item{name}{the name of the engine.}
%  \item{weave}{a function to convert vignette source files to LaTeX output.}
%  \item{tangle}{a function to convert vignette source files to \R code.}
%  \item{pattern}{a regular expression pattern for the filenames handled
%    by this engine, or \code{NULL} for the default pattern.}
%  \item{package}{the package registering the engine.  By default, this
%    is the package calling \code{vignetteEngine}.}
%  \item{aspell}{a list with element names \code{filter} and/or
%    \code{control} giving the respective arguments to be used when spell
%    checking the text in the vignette source file with
%    \code{\link{aspell}}.}
%}
%\details{
%If \code{weave} is missing, \code{vignetteEngine} will return the currently
%registered engine matching \code{name} and \code{package}.
%
%If \code{weave} is \code{NULL}, the specified engine will be deleted.
%
%Other settings define a new engine. The \code{weave} and \code{tangle}
%functions must be defined with argument lists compatible with
%\code{function(file, ...)}. Currently the \code{...} arguments may
%include logical argument \code{quiet} and character argument
%\code{encoding}; others may be added in future. These are described in
%the documentation for \code{\link{Sweave}} and \code{\link{Stangle}}.
%
%The \code{weave} and \code{tangle} functions should return the
%filename of the output file that has been produced. Currently the
%\code{weave} function, when operating on a file named \file{<name>
%<pattern>} must produce a file named \file{<name>[.](tex|pdf|html)}.
%The \file{.tex} files will be processed by \command{pdflatex} to
%produce \file{.pdf} output for display to the user; the others will be
%displayed as produced.  The \code{tangle} function must produce a file
%named \file{<name>[.][rRsS]} containing the executable \R{} code from
%the vignette.  The \code{tangle} function may support a \code{split =
%TRUE} argument, and then it should produce files named
%\file{<name>.*[.][rRsS]}.
%
%The \code{pattern} argument gives a regular expression to match the
%extensions of files which are to be processed as vignette input files.
%If set to \code{NULL}, the default pattern \code{"[.][RrSs](nw|tex)$"}
%is used.
%}
%\value{
%  If the engine is being deleted, \code{NULL}.  Otherwise a list
%  containing components
%  \item{name}{The name of the engine}
%  \item{package}{The name of its package}
%  \item{pattern}{The pattern for vignette input files}
%  \item{weave}{The weave function}
%  \item{tangle}{The tangle function}
%}
%\author{
%Duncan Murdoch and Henrik Bengtsson.
%}
%\seealso{
%\code{\link{Sweave}} and the \sQuote{Writing R Extensions} manual.
%}
%\examples{
%str(vignetteEngine("Sweave"))
%}
%\keyword{utilities}
%\keyword{documentation}
%
%
%\encoding{UTF8}
%