% File src/library/tools/man/xgettext.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{xgettext}
\title{パッケージ中の R ファイルから翻訳可能なメッセージを取り出す}
%\title{Extract Translatable Messages from R Files in a Package}
%@%\alias{メッセージの取り出し}
\alias{xgettext}
\alias{xngettext}
\alias{xgettext2pot}
\description{
  パッケージの(システム固有の副ディレクトリを含む)
  \file{R} ディレクトリ中の各ファイルに対して，
  \code{\link{stop}}, \code{\link{warning}}, \code{\link{message}},
  \code{\link{gettext}} そして \code{\link{gettextf}}，または
  \code{\link{ngettext}} に渡されるユニークな引数を取り出す．
}
\usage{
xgettext(dir, verbose = FALSE, asCall = TRUE)

xngettext(dir, verbose = FALSE)

xgettext2pot(dir, potFile, name = "R", version, bugs)
}
\arguments{
  \item{dir}{ソースパッケージのディレクトリ．}
  \item{verbose}{論理値：各ファイルは処理中にリストすべきか?}
  \item{asCall}{論理値：もし \code{TRUE} なら各引数は全体として返される，
    さもなければ各引数中の文字列が取り出される．}
  \item{potFile}{作られる \code{po} テンプレートファイルの名前．
    既定は \file{R-\var{pkgname}.pot} で，ここで
    \var{pkgname} は \file{dir} の基本名．}
  \item{name, version, bugs}{
    テンプレートファイル中に記録されるもの：
    \code{version} は既定で現在稼働中の \R のバージョン番号で，
    \code{bugs} は \code{"bugs.r-project.org"}．}
}
\details{
  先頭と末尾に続く空白(スペース，タブ，そしてラインフィード)は
  \code{gettext}, \code{gettextf}, \code{stop},
  \code{warning} そして \code{message} に対する呼び出しでは，翻訳に対する文字列を
  渡す内部コードによるものなので, 取り除かれる．

  これらの関数が \code{domain = NA} と共に呼び出されるかを調べ，
  そしてもしそうなら
  \code{asCall = TRUE} なら呼び出しを省略する：
  呼び出しはもし \code{asCall = FALSE} なら可視である 
  \code{gettext} への呼び出しを含むかもしれないことを注意する．
  

  \code{xgettext2pot} は \code{xgettext} をそしてそれから
  \code{xngettext} を呼び出し，
  PO テンプレートファイルを
  \pkg{GNU Gettext} ツールと共に使うために書き出す．
  これは単純な翻訳に対する文字列がユニーク(\pkg{GNU Gettext} が要求するように)
  であることを保証するが，
  \code{ngettext} 呼び出しに対してはそれを行わない
  (そして規則は
  Gettext のマニュアルには述べられていないが，
  \command{msgfmt} はセットの間に重複があると文句を言う)．

  \pkg{base} パッケージに適用されると，これは更に
  \file{\var{\link{R_HOME}}/share/R} 中の \file{.R} ファイルも調べる．
}
\value{
  \code{xgettext} に対しては
  クラス \code{"xgettext"} のりスト
  (\code{print} メソッドを持つ)で，ソースファイル毎に翻訳可能な
  文字列を可能性として含む．

  \code{xngettext} に対してはクラス
  \code{"xngettext"} のオブジェクトのリストで，
  それ自体長さ2の文字列のりストである．
}
\seealso{
  \code{xgettext2pot()} を呼び出す \code{\link{update_pkg_po}()}．
}
\examples{\dontrun{## R のソースディレクトリビルド中で：
xgettext(file.path(R.home(), "src", "library", "splines"))
}}
\keyword{ utilities }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/xgettext.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xgettext}
%\title{Extract Translatable Messages from R Files in a Package}
%\alias{xgettext}
%\alias{xngettext}
%\alias{xgettext2pot}
%\description{
%  For each file in the \file{R} directory (including system-specific
%  subdirectories) of a package, extract the unique arguments passed
%  to \code{\link{stop}}, \code{\link{warning}}, \code{\link{message}},
%  \code{\link{gettext}} and \code{\link{gettextf}}, or to
%  \code{\link{ngettext}}.
%}
%\usage{
%xgettext(dir, verbose = FALSE, asCall = TRUE)
%
%xngettext(dir, verbose = FALSE)
%
%xgettext2pot(dir, potFile, name = "R", version, bugs)
%}
%\arguments{
%  \item{dir}{the directory of a source package.}
%  \item{verbose}{logical: should each file be listed as it is processed?}
%  \item{asCall}{logical: if \code{TRUE} each argument is returned whole,
%    otherwise the strings within each argument are extracted.}
%
%  \item{potFile}{name of \code{po} template file to be produced.
%    Defaults to \file{R-\var{pkgname}.pot} where
%    \var{pkgname} is the basename of \file{dir}.}
%  \item{name, version, bugs}{as recorded in the template file:
%    \code{version} defaults the version number of the currently running
%    \R, and \code{bugs} to \code{"bugs.r-project.org"}.}
%}
%\details{
%  Leading and trailing white space (space, tab and linefeed) is removed
%  for calls to \code{gettext}, \code{gettextf}, \code{stop},
%  \code{warning}, and \code{message}, as it is by the internal code that
%  passes strings for translation.
%
%  We look to see if these functions were called with \code{domain = NA}
%  and if so omit the call if \code{asCall = TRUE}: note that the
%  call might contain a call to \code{gettext} which would be visible if
%  \code{asCall = FALSE}.
%
%  \code{xgettext2pot} calls \code{xgettext} and then \code{xngettext},
%  and writes a PO template file for use with the \pkg{GNU Gettext}
%  tools.  This ensures that the strings for simple translation are
%  unique in the file (as \pkg{GNU Gettext} requires), but does not do so
%  for \code{ngettext} calls (and the rules are not stated in the Gettext
%  manual, but \command{msgfmt} complains if there is duplication between
%  the sets.).
%
%  If applied to the \pkg{base} package, this also looks in the \file{.R}
%  files in \file{\var{\link{R_HOME}}/share/R}.
%}
%\value{
%  For \code{xgettext}, a list of objects of class \code{"xgettext"}
%  (which has a \code{print} method), one per source file that
%  potentially contains translatable strings.
%
%  For \code{xngettext}, a list of objects of class \code{"xngettext"},
%  which are themselves lists of length-2 character strings.
%}
%\seealso{
%  \code{\link{update_pkg_po}()} which calls \code{xgettext2pot()}.
%}
%\examples{\dontrun{## in a source-directory build of R:
%xgettext(file.path(R.home(), "src", "library", "splines"))
%}}
%\keyword{ utilities }
%
%\encoding{UTF8}
%